window.Gleam.initSearch([{"doc":"aws_api","title":"aws_api","content":"# aws_api\n\nA `gleam_http` request builder for AWS service APIs, generated using [aws_codegen](https://github.com/ryanmiville/aws_codegen) and built on top of [aws4_request](https://github.com/lpil/aws4_request).\n\n[![Package Version](https://img.shields.io/hexpm/v/aws_api)](https://hex.pm/packages/aws_api)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/aws_api/)\n\n```sh\ngleam add aws_api\n```\n\n```gleam\nimport aws_api/dynamodb\nimport gleam/bit_array\nimport gleam/httpc\n\npub fn main() {\n  // create a client for the AWS service, such as DynamoDB\n  let dynamo_client =\n    dynamodb.new(\n      access_key_id: &quot;AKIDEXAMPLE&quot;,\n      secret_access_key: &quot;wJalrXUtnFEMI/K7MDENG+bPxRfiCYEXAMPLEKEY&quot;,\n      region: &quot;us-east-1&quot;,\n    )\n\n  // Create the request body if necessary\n  let body =\n    &quot;{\n    \\&quot;TableName\\&quot;: \\&quot;people\\&quot;,\n    \\&quot;Key\\&quot;: { \\&quot;name\\&quot;: { \\&quot;S\\&quot;: \\&quot;Ryan\\&quot; } }\n    }&quot;\n    |&gt; bit_array.from_string\n\n    // each API endpoint is a function in the service&#39;s module\n    let req = dynamodb.get_item(dynamo_client, body)\n\n    // use a gleam_http client adapter to send the request\n    let resp = httpc.send_bits(req)\n}\n```\n\n```gleam\nOk(Response(\n  200,\n  [\n    #(&quot;connection&quot;, &quot;keep-alive&quot;),\n    #(\n      &quot;date&quot;,\n      &quot;Mon, 26 Aug 2024 01:14:37 GMT&quot;,\n    ),\n    #(&quot;server&quot;, &quot;Server&quot;),\n    #(&quot;content-length&quot;, &quot;48&quot;),\n    #(\n      &quot;content-type&quot;,\n      &quot;application/x-amz-json-1.0&quot;,\n    ),\n    #(\n      &quot;x-amzn-requestid&quot;,\n      &quot;9UDMAF5C9T46D39RJSCHUB7IMFVV4KQNSO5AEMVJF66Q9ASUAAJG&quot;,\n    ),\n    #(&quot;x-amz-crc32&quot;, &quot;3152510195&quot;),\n  ],\n  &quot;{\\&quot;Item\\&quot;:{\\&quot;name\\&quot;:{\\&quot;S\\&quot;:\\&quot;Ryan\\&quot;}}}&quot;,\n))\n```\n\n## Project Goals\n\n`aws_api` is NOT an AWS SDK for Gleam. It intends to be a base for idiomatic SDKs.\n\n## Missing features\n\n- [ ] other AWS partitions (gov, cn, etc.)\n- [ ] fips and dualstack endpoints\n- [ ] docs\n- [ ] tests\n","url":"index.html"},{"doc":"aws_api/accessanalyzer","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/accessanalyzer.Client\naws_api/accessanalyzer Client","url":"aws_api/accessanalyzer.html#Client"},{"doc":"aws_api/accessanalyzer","title":"apply_archive_rule","content":"pub fn apply_archive_rule(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/accessanalyzer.apply_archive_rule\naws_api/accessanalyzer apply_archive_rule","url":"aws_api/accessanalyzer.html#apply_archive_rule"},{"doc":"aws_api/accessanalyzer","title":"cancel_policy_generation","content":"pub fn cancel_policy_generation(\n  client: Client,\n  job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/accessanalyzer.cancel_policy_generation\naws_api/accessanalyzer cancel_policy_generation","url":"aws_api/accessanalyzer.html#cancel_policy_generation"},{"doc":"aws_api/accessanalyzer","title":"check_access_not_granted","content":"pub fn check_access_not_granted(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/accessanalyzer.check_access_not_granted\naws_api/accessanalyzer check_access_not_granted","url":"aws_api/accessanalyzer.html#check_access_not_granted"},{"doc":"aws_api/accessanalyzer","title":"check_no_new_access","content":"pub fn check_no_new_access(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/accessanalyzer.check_no_new_access\naws_api/accessanalyzer check_no_new_access","url":"aws_api/accessanalyzer.html#check_no_new_access"},{"doc":"aws_api/accessanalyzer","title":"check_no_public_access","content":"pub fn check_no_public_access(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/accessanalyzer.check_no_public_access\naws_api/accessanalyzer check_no_public_access","url":"aws_api/accessanalyzer.html#check_no_public_access"},{"doc":"aws_api/accessanalyzer","title":"create_access_preview","content":"pub fn create_access_preview(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/accessanalyzer.create_access_preview\naws_api/accessanalyzer create_access_preview","url":"aws_api/accessanalyzer.html#create_access_preview"},{"doc":"aws_api/accessanalyzer","title":"generate_finding_recommendation","content":"pub fn generate_finding_recommendation(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/accessanalyzer.generate_finding_recommendation\naws_api/accessanalyzer generate_finding_recommendation","url":"aws_api/accessanalyzer.html#generate_finding_recommendation"},{"doc":"aws_api/accessanalyzer","title":"get_access_preview","content":"pub fn get_access_preview(\n  client: Client,\n  access_preview_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/accessanalyzer.get_access_preview\naws_api/accessanalyzer get_access_preview","url":"aws_api/accessanalyzer.html#get_access_preview"},{"doc":"aws_api/accessanalyzer","title":"get_analyzed_resource","content":"pub fn get_analyzed_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/accessanalyzer.get_analyzed_resource\naws_api/accessanalyzer get_analyzed_resource","url":"aws_api/accessanalyzer.html#get_analyzed_resource"},{"doc":"aws_api/accessanalyzer","title":"get_finding","content":"pub fn get_finding(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/accessanalyzer.get_finding\naws_api/accessanalyzer get_finding","url":"aws_api/accessanalyzer.html#get_finding"},{"doc":"aws_api/accessanalyzer","title":"get_finding_recommendation","content":"pub fn get_finding_recommendation(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/accessanalyzer.get_finding_recommendation\naws_api/accessanalyzer get_finding_recommendation","url":"aws_api/accessanalyzer.html#get_finding_recommendation"},{"doc":"aws_api/accessanalyzer","title":"get_finding_v2","content":"pub fn get_finding_v2(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/accessanalyzer.get_finding_v2\naws_api/accessanalyzer get_finding_v2","url":"aws_api/accessanalyzer.html#get_finding_v2"},{"doc":"aws_api/accessanalyzer","title":"get_generated_policy","content":"pub fn get_generated_policy(\n  client: Client,\n  job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/accessanalyzer.get_generated_policy\naws_api/accessanalyzer get_generated_policy","url":"aws_api/accessanalyzer.html#get_generated_policy"},{"doc":"aws_api/accessanalyzer","title":"list_access_preview_findings","content":"pub fn list_access_preview_findings(\n  client: Client,\n  access_preview_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/accessanalyzer.list_access_preview_findings\naws_api/accessanalyzer list_access_preview_findings","url":"aws_api/accessanalyzer.html#list_access_preview_findings"},{"doc":"aws_api/accessanalyzer","title":"list_access_previews","content":"pub fn list_access_previews(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/accessanalyzer.list_access_previews\naws_api/accessanalyzer list_access_previews","url":"aws_api/accessanalyzer.html#list_access_previews"},{"doc":"aws_api/accessanalyzer","title":"list_analyzed_resources","content":"pub fn list_analyzed_resources(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/accessanalyzer.list_analyzed_resources\naws_api/accessanalyzer list_analyzed_resources","url":"aws_api/accessanalyzer.html#list_analyzed_resources"},{"doc":"aws_api/accessanalyzer","title":"list_findings","content":"pub fn list_findings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/accessanalyzer.list_findings\naws_api/accessanalyzer list_findings","url":"aws_api/accessanalyzer.html#list_findings"},{"doc":"aws_api/accessanalyzer","title":"list_findings_v2","content":"pub fn list_findings_v2(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/accessanalyzer.list_findings_v2\naws_api/accessanalyzer list_findings_v2","url":"aws_api/accessanalyzer.html#list_findings_v2"},{"doc":"aws_api/accessanalyzer","title":"list_policy_generations","content":"pub fn list_policy_generations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/accessanalyzer.list_policy_generations\naws_api/accessanalyzer list_policy_generations","url":"aws_api/accessanalyzer.html#list_policy_generations"},{"doc":"aws_api/accessanalyzer","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/accessanalyzer.list_tags_for_resource\naws_api/accessanalyzer list_tags_for_resource","url":"aws_api/accessanalyzer.html#list_tags_for_resource"},{"doc":"aws_api/accessanalyzer","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/accessanalyzer.new\naws_api/accessanalyzer new","url":"aws_api/accessanalyzer.html#new"},{"doc":"aws_api/accessanalyzer","title":"start_policy_generation","content":"pub fn start_policy_generation(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/accessanalyzer.start_policy_generation\naws_api/accessanalyzer start_policy_generation","url":"aws_api/accessanalyzer.html#start_policy_generation"},{"doc":"aws_api/accessanalyzer","title":"start_resource_scan","content":"pub fn start_resource_scan(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/accessanalyzer.start_resource_scan\naws_api/accessanalyzer start_resource_scan","url":"aws_api/accessanalyzer.html#start_resource_scan"},{"doc":"aws_api/accessanalyzer","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/accessanalyzer.tag_resource\naws_api/accessanalyzer tag_resource","url":"aws_api/accessanalyzer.html#tag_resource"},{"doc":"aws_api/accessanalyzer","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/accessanalyzer.untag_resource\naws_api/accessanalyzer untag_resource","url":"aws_api/accessanalyzer.html#untag_resource"},{"doc":"aws_api/accessanalyzer","title":"update_findings","content":"pub fn update_findings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/accessanalyzer.update_findings\naws_api/accessanalyzer update_findings","url":"aws_api/accessanalyzer.html#update_findings"},{"doc":"aws_api/accessanalyzer","title":"validate_policy","content":"pub fn validate_policy(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/accessanalyzer.validate_policy\naws_api/accessanalyzer validate_policy","url":"aws_api/accessanalyzer.html#validate_policy"},{"doc":"aws_api/accessanalyzer","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/accessanalyzer.with_custom_endpoint\naws_api/accessanalyzer with_custom_endpoint","url":"aws_api/accessanalyzer.html#with_custom_endpoint"},{"doc":"aws_api/accessanalyzer","title":"aws_api/accessanalyzer","content":"","url":"aws_api/accessanalyzer.html"},{"doc":"aws_api/acm","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/acm.Client\naws_api/acm Client","url":"aws_api/acm.html#Client"},{"doc":"aws_api/acm","title":"add_tags_to_certificate","content":"pub fn add_tags_to_certificate(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/acm.add_tags_to_certificate\naws_api/acm add_tags_to_certificate","url":"aws_api/acm.html#add_tags_to_certificate"},{"doc":"aws_api/acm","title":"delete_certificate","content":"pub fn delete_certificate(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/acm.delete_certificate\naws_api/acm delete_certificate","url":"aws_api/acm.html#delete_certificate"},{"doc":"aws_api/acm","title":"describe_certificate","content":"pub fn describe_certificate(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/acm.describe_certificate\naws_api/acm describe_certificate","url":"aws_api/acm.html#describe_certificate"},{"doc":"aws_api/acm","title":"export_certificate","content":"pub fn export_certificate(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/acm.export_certificate\naws_api/acm export_certificate","url":"aws_api/acm.html#export_certificate"},{"doc":"aws_api/acm","title":"get_account_configuration","content":"pub fn get_account_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/acm.get_account_configuration\naws_api/acm get_account_configuration","url":"aws_api/acm.html#get_account_configuration"},{"doc":"aws_api/acm","title":"get_certificate","content":"pub fn get_certificate(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/acm.get_certificate\naws_api/acm get_certificate","url":"aws_api/acm.html#get_certificate"},{"doc":"aws_api/acm","title":"import_certificate","content":"pub fn import_certificate(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/acm.import_certificate\naws_api/acm import_certificate","url":"aws_api/acm.html#import_certificate"},{"doc":"aws_api/acm","title":"list_certificates","content":"pub fn list_certificates(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/acm.list_certificates\naws_api/acm list_certificates","url":"aws_api/acm.html#list_certificates"},{"doc":"aws_api/acm","title":"list_tags_for_certificate","content":"pub fn list_tags_for_certificate(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/acm.list_tags_for_certificate\naws_api/acm list_tags_for_certificate","url":"aws_api/acm.html#list_tags_for_certificate"},{"doc":"aws_api/acm","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/acm.new\naws_api/acm new","url":"aws_api/acm.html#new"},{"doc":"aws_api/acm","title":"put_account_configuration","content":"pub fn put_account_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/acm.put_account_configuration\naws_api/acm put_account_configuration","url":"aws_api/acm.html#put_account_configuration"},{"doc":"aws_api/acm","title":"remove_tags_from_certificate","content":"pub fn remove_tags_from_certificate(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/acm.remove_tags_from_certificate\naws_api/acm remove_tags_from_certificate","url":"aws_api/acm.html#remove_tags_from_certificate"},{"doc":"aws_api/acm","title":"renew_certificate","content":"pub fn renew_certificate(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/acm.renew_certificate\naws_api/acm renew_certificate","url":"aws_api/acm.html#renew_certificate"},{"doc":"aws_api/acm","title":"request_certificate","content":"pub fn request_certificate(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/acm.request_certificate\naws_api/acm request_certificate","url":"aws_api/acm.html#request_certificate"},{"doc":"aws_api/acm","title":"resend_validation_email","content":"pub fn resend_validation_email(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/acm.resend_validation_email\naws_api/acm resend_validation_email","url":"aws_api/acm.html#resend_validation_email"},{"doc":"aws_api/acm","title":"update_certificate_options","content":"pub fn update_certificate_options(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/acm.update_certificate_options\naws_api/acm update_certificate_options","url":"aws_api/acm.html#update_certificate_options"},{"doc":"aws_api/acm","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/acm.with_custom_endpoint\naws_api/acm with_custom_endpoint","url":"aws_api/acm.html#with_custom_endpoint"},{"doc":"aws_api/acm","title":"aws_api/acm","content":"","url":"aws_api/acm.html"},{"doc":"aws_api/acm_pca","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/acm_pca.Client\naws_api/acm_pca Client","url":"aws_api/acm_pca.html#Client"},{"doc":"aws_api/acm_pca","title":"create_certificate_authority","content":"pub fn create_certificate_authority(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/acm_pca.create_certificate_authority\naws_api/acm_pca create_certificate_authority","url":"aws_api/acm_pca.html#create_certificate_authority"},{"doc":"aws_api/acm_pca","title":"create_certificate_authority_audit_report","content":"pub fn create_certificate_authority_audit_report(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/acm_pca.create_certificate_authority_audit_report\naws_api/acm_pca create_certificate_authority_audit_report","url":"aws_api/acm_pca.html#create_certificate_authority_audit_report"},{"doc":"aws_api/acm_pca","title":"create_permission","content":"pub fn create_permission(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/acm_pca.create_permission\naws_api/acm_pca create_permission","url":"aws_api/acm_pca.html#create_permission"},{"doc":"aws_api/acm_pca","title":"delete_certificate_authority","content":"pub fn delete_certificate_authority(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/acm_pca.delete_certificate_authority\naws_api/acm_pca delete_certificate_authority","url":"aws_api/acm_pca.html#delete_certificate_authority"},{"doc":"aws_api/acm_pca","title":"delete_permission","content":"pub fn delete_permission(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/acm_pca.delete_permission\naws_api/acm_pca delete_permission","url":"aws_api/acm_pca.html#delete_permission"},{"doc":"aws_api/acm_pca","title":"delete_policy","content":"pub fn delete_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/acm_pca.delete_policy\naws_api/acm_pca delete_policy","url":"aws_api/acm_pca.html#delete_policy"},{"doc":"aws_api/acm_pca","title":"describe_certificate_authority","content":"pub fn describe_certificate_authority(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/acm_pca.describe_certificate_authority\naws_api/acm_pca describe_certificate_authority","url":"aws_api/acm_pca.html#describe_certificate_authority"},{"doc":"aws_api/acm_pca","title":"describe_certificate_authority_audit_report","content":"pub fn describe_certificate_authority_audit_report(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/acm_pca.describe_certificate_authority_audit_report\naws_api/acm_pca describe_certificate_authority_audit_report","url":"aws_api/acm_pca.html#describe_certificate_authority_audit_report"},{"doc":"aws_api/acm_pca","title":"get_certificate","content":"pub fn get_certificate(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/acm_pca.get_certificate\naws_api/acm_pca get_certificate","url":"aws_api/acm_pca.html#get_certificate"},{"doc":"aws_api/acm_pca","title":"get_certificate_authority_certificate","content":"pub fn get_certificate_authority_certificate(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/acm_pca.get_certificate_authority_certificate\naws_api/acm_pca get_certificate_authority_certificate","url":"aws_api/acm_pca.html#get_certificate_authority_certificate"},{"doc":"aws_api/acm_pca","title":"get_certificate_authority_csr","content":"pub fn get_certificate_authority_csr(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/acm_pca.get_certificate_authority_csr\naws_api/acm_pca get_certificate_authority_csr","url":"aws_api/acm_pca.html#get_certificate_authority_csr"},{"doc":"aws_api/acm_pca","title":"get_policy","content":"pub fn get_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/acm_pca.get_policy\naws_api/acm_pca get_policy","url":"aws_api/acm_pca.html#get_policy"},{"doc":"aws_api/acm_pca","title":"import_certificate_authority_certificate","content":"pub fn import_certificate_authority_certificate(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/acm_pca.import_certificate_authority_certificate\naws_api/acm_pca import_certificate_authority_certificate","url":"aws_api/acm_pca.html#import_certificate_authority_certificate"},{"doc":"aws_api/acm_pca","title":"issue_certificate","content":"pub fn issue_certificate(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/acm_pca.issue_certificate\naws_api/acm_pca issue_certificate","url":"aws_api/acm_pca.html#issue_certificate"},{"doc":"aws_api/acm_pca","title":"list_certificate_authorities","content":"pub fn list_certificate_authorities(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/acm_pca.list_certificate_authorities\naws_api/acm_pca list_certificate_authorities","url":"aws_api/acm_pca.html#list_certificate_authorities"},{"doc":"aws_api/acm_pca","title":"list_permissions","content":"pub fn list_permissions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/acm_pca.list_permissions\naws_api/acm_pca list_permissions","url":"aws_api/acm_pca.html#list_permissions"},{"doc":"aws_api/acm_pca","title":"list_tags","content":"pub fn list_tags(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/acm_pca.list_tags\naws_api/acm_pca list_tags","url":"aws_api/acm_pca.html#list_tags"},{"doc":"aws_api/acm_pca","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/acm_pca.new\naws_api/acm_pca new","url":"aws_api/acm_pca.html#new"},{"doc":"aws_api/acm_pca","title":"put_policy","content":"pub fn put_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/acm_pca.put_policy\naws_api/acm_pca put_policy","url":"aws_api/acm_pca.html#put_policy"},{"doc":"aws_api/acm_pca","title":"restore_certificate_authority","content":"pub fn restore_certificate_authority(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/acm_pca.restore_certificate_authority\naws_api/acm_pca restore_certificate_authority","url":"aws_api/acm_pca.html#restore_certificate_authority"},{"doc":"aws_api/acm_pca","title":"revoke_certificate","content":"pub fn revoke_certificate(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/acm_pca.revoke_certificate\naws_api/acm_pca revoke_certificate","url":"aws_api/acm_pca.html#revoke_certificate"},{"doc":"aws_api/acm_pca","title":"tag_certificate_authority","content":"pub fn tag_certificate_authority(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/acm_pca.tag_certificate_authority\naws_api/acm_pca tag_certificate_authority","url":"aws_api/acm_pca.html#tag_certificate_authority"},{"doc":"aws_api/acm_pca","title":"untag_certificate_authority","content":"pub fn untag_certificate_authority(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/acm_pca.untag_certificate_authority\naws_api/acm_pca untag_certificate_authority","url":"aws_api/acm_pca.html#untag_certificate_authority"},{"doc":"aws_api/acm_pca","title":"update_certificate_authority","content":"pub fn update_certificate_authority(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/acm_pca.update_certificate_authority\naws_api/acm_pca update_certificate_authority","url":"aws_api/acm_pca.html#update_certificate_authority"},{"doc":"aws_api/acm_pca","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/acm_pca.with_custom_endpoint\naws_api/acm_pca with_custom_endpoint","url":"aws_api/acm_pca.html#with_custom_endpoint"},{"doc":"aws_api/acm_pca","title":"aws_api/acm_pca","content":"","url":"aws_api/acm_pca.html"},{"doc":"aws_api/amp","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/amp.Client\naws_api/amp Client","url":"aws_api/amp.html#Client"},{"doc":"aws_api/amp","title":"get_default_scraper_configuration","content":"pub fn get_default_scraper_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amp.get_default_scraper_configuration\naws_api/amp get_default_scraper_configuration","url":"aws_api/amp.html#get_default_scraper_configuration"},{"doc":"aws_api/amp","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amp.list_tags_for_resource\naws_api/amp list_tags_for_resource","url":"aws_api/amp.html#list_tags_for_resource"},{"doc":"aws_api/amp","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/amp.new\naws_api/amp new","url":"aws_api/amp.html#new"},{"doc":"aws_api/amp","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amp.tag_resource\naws_api/amp tag_resource","url":"aws_api/amp.html#tag_resource"},{"doc":"aws_api/amp","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amp.untag_resource\naws_api/amp untag_resource","url":"aws_api/amp.html#untag_resource"},{"doc":"aws_api/amp","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/amp.with_custom_endpoint\naws_api/amp with_custom_endpoint","url":"aws_api/amp.html#with_custom_endpoint"},{"doc":"aws_api/amp","title":"aws_api/amp","content":"","url":"aws_api/amp.html"},{"doc":"aws_api/amplify","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/amplify.Client\naws_api/amplify Client","url":"aws_api/amplify.html#Client"},{"doc":"aws_api/amplify","title":"create_app","content":"pub fn create_app(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplify.create_app\naws_api/amplify create_app","url":"aws_api/amplify.html#create_app"},{"doc":"aws_api/amplify","title":"create_backend_environment","content":"pub fn create_backend_environment(\n  client: Client,\n  app_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplify.create_backend_environment\naws_api/amplify create_backend_environment","url":"aws_api/amplify.html#create_backend_environment"},{"doc":"aws_api/amplify","title":"create_branch","content":"pub fn create_branch(\n  client: Client,\n  app_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplify.create_branch\naws_api/amplify create_branch","url":"aws_api/amplify.html#create_branch"},{"doc":"aws_api/amplify","title":"create_deployment","content":"pub fn create_deployment(\n  client: Client,\n  app_id: String,\n  branch_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplify.create_deployment\naws_api/amplify create_deployment","url":"aws_api/amplify.html#create_deployment"},{"doc":"aws_api/amplify","title":"create_domain_association","content":"pub fn create_domain_association(\n  client: Client,\n  app_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplify.create_domain_association\naws_api/amplify create_domain_association","url":"aws_api/amplify.html#create_domain_association"},{"doc":"aws_api/amplify","title":"create_webhook","content":"pub fn create_webhook(\n  client: Client,\n  app_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplify.create_webhook\naws_api/amplify create_webhook","url":"aws_api/amplify.html#create_webhook"},{"doc":"aws_api/amplify","title":"delete_app","content":"pub fn delete_app(\n  client: Client,\n  app_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplify.delete_app\naws_api/amplify delete_app","url":"aws_api/amplify.html#delete_app"},{"doc":"aws_api/amplify","title":"delete_backend_environment","content":"pub fn delete_backend_environment(\n  client: Client,\n  app_id: String,\n  environment_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplify.delete_backend_environment\naws_api/amplify delete_backend_environment","url":"aws_api/amplify.html#delete_backend_environment"},{"doc":"aws_api/amplify","title":"delete_branch","content":"pub fn delete_branch(\n  client: Client,\n  app_id: String,\n  branch_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplify.delete_branch\naws_api/amplify delete_branch","url":"aws_api/amplify.html#delete_branch"},{"doc":"aws_api/amplify","title":"delete_domain_association","content":"pub fn delete_domain_association(\n  client: Client,\n  app_id: String,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplify.delete_domain_association\naws_api/amplify delete_domain_association","url":"aws_api/amplify.html#delete_domain_association"},{"doc":"aws_api/amplify","title":"delete_job","content":"pub fn delete_job(\n  client: Client,\n  app_id: String,\n  branch_name: String,\n  job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplify.delete_job\naws_api/amplify delete_job","url":"aws_api/amplify.html#delete_job"},{"doc":"aws_api/amplify","title":"delete_webhook","content":"pub fn delete_webhook(\n  client: Client,\n  webhook_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplify.delete_webhook\naws_api/amplify delete_webhook","url":"aws_api/amplify.html#delete_webhook"},{"doc":"aws_api/amplify","title":"generate_access_logs","content":"pub fn generate_access_logs(\n  client: Client,\n  app_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplify.generate_access_logs\naws_api/amplify generate_access_logs","url":"aws_api/amplify.html#generate_access_logs"},{"doc":"aws_api/amplify","title":"get_app","content":"pub fn get_app(\n  client: Client,\n  app_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplify.get_app\naws_api/amplify get_app","url":"aws_api/amplify.html#get_app"},{"doc":"aws_api/amplify","title":"get_artifact_url","content":"pub fn get_artifact_url(\n  client: Client,\n  artifact_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplify.get_artifact_url\naws_api/amplify get_artifact_url","url":"aws_api/amplify.html#get_artifact_url"},{"doc":"aws_api/amplify","title":"get_backend_environment","content":"pub fn get_backend_environment(\n  client: Client,\n  app_id: String,\n  environment_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplify.get_backend_environment\naws_api/amplify get_backend_environment","url":"aws_api/amplify.html#get_backend_environment"},{"doc":"aws_api/amplify","title":"get_branch","content":"pub fn get_branch(\n  client: Client,\n  app_id: String,\n  branch_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplify.get_branch\naws_api/amplify get_branch","url":"aws_api/amplify.html#get_branch"},{"doc":"aws_api/amplify","title":"get_domain_association","content":"pub fn get_domain_association(\n  client: Client,\n  app_id: String,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplify.get_domain_association\naws_api/amplify get_domain_association","url":"aws_api/amplify.html#get_domain_association"},{"doc":"aws_api/amplify","title":"get_job","content":"pub fn get_job(\n  client: Client,\n  app_id: String,\n  branch_name: String,\n  job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplify.get_job\naws_api/amplify get_job","url":"aws_api/amplify.html#get_job"},{"doc":"aws_api/amplify","title":"get_webhook","content":"pub fn get_webhook(\n  client: Client,\n  webhook_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplify.get_webhook\naws_api/amplify get_webhook","url":"aws_api/amplify.html#get_webhook"},{"doc":"aws_api/amplify","title":"list_apps","content":"pub fn list_apps(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplify.list_apps\naws_api/amplify list_apps","url":"aws_api/amplify.html#list_apps"},{"doc":"aws_api/amplify","title":"list_artifacts","content":"pub fn list_artifacts(\n  client: Client,\n  app_id: String,\n  branch_name: String,\n  job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplify.list_artifacts\naws_api/amplify list_artifacts","url":"aws_api/amplify.html#list_artifacts"},{"doc":"aws_api/amplify","title":"list_backend_environments","content":"pub fn list_backend_environments(\n  client: Client,\n  app_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplify.list_backend_environments\naws_api/amplify list_backend_environments","url":"aws_api/amplify.html#list_backend_environments"},{"doc":"aws_api/amplify","title":"list_branches","content":"pub fn list_branches(\n  client: Client,\n  app_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplify.list_branches\naws_api/amplify list_branches","url":"aws_api/amplify.html#list_branches"},{"doc":"aws_api/amplify","title":"list_domain_associations","content":"pub fn list_domain_associations(\n  client: Client,\n  app_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplify.list_domain_associations\naws_api/amplify list_domain_associations","url":"aws_api/amplify.html#list_domain_associations"},{"doc":"aws_api/amplify","title":"list_jobs","content":"pub fn list_jobs(\n  client: Client,\n  app_id: String,\n  branch_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplify.list_jobs\naws_api/amplify list_jobs","url":"aws_api/amplify.html#list_jobs"},{"doc":"aws_api/amplify","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplify.list_tags_for_resource\naws_api/amplify list_tags_for_resource","url":"aws_api/amplify.html#list_tags_for_resource"},{"doc":"aws_api/amplify","title":"list_webhooks","content":"pub fn list_webhooks(\n  client: Client,\n  app_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplify.list_webhooks\naws_api/amplify list_webhooks","url":"aws_api/amplify.html#list_webhooks"},{"doc":"aws_api/amplify","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/amplify.new\naws_api/amplify new","url":"aws_api/amplify.html#new"},{"doc":"aws_api/amplify","title":"start_deployment","content":"pub fn start_deployment(\n  client: Client,\n  app_id: String,\n  branch_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplify.start_deployment\naws_api/amplify start_deployment","url":"aws_api/amplify.html#start_deployment"},{"doc":"aws_api/amplify","title":"start_job","content":"pub fn start_job(\n  client: Client,\n  app_id: String,\n  branch_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplify.start_job\naws_api/amplify start_job","url":"aws_api/amplify.html#start_job"},{"doc":"aws_api/amplify","title":"stop_job","content":"pub fn stop_job(\n  client: Client,\n  app_id: String,\n  branch_name: String,\n  job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplify.stop_job\naws_api/amplify stop_job","url":"aws_api/amplify.html#stop_job"},{"doc":"aws_api/amplify","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplify.tag_resource\naws_api/amplify tag_resource","url":"aws_api/amplify.html#tag_resource"},{"doc":"aws_api/amplify","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplify.untag_resource\naws_api/amplify untag_resource","url":"aws_api/amplify.html#untag_resource"},{"doc":"aws_api/amplify","title":"update_app","content":"pub fn update_app(\n  client: Client,\n  app_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplify.update_app\naws_api/amplify update_app","url":"aws_api/amplify.html#update_app"},{"doc":"aws_api/amplify","title":"update_branch","content":"pub fn update_branch(\n  client: Client,\n  app_id: String,\n  branch_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplify.update_branch\naws_api/amplify update_branch","url":"aws_api/amplify.html#update_branch"},{"doc":"aws_api/amplify","title":"update_domain_association","content":"pub fn update_domain_association(\n  client: Client,\n  app_id: String,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplify.update_domain_association\naws_api/amplify update_domain_association","url":"aws_api/amplify.html#update_domain_association"},{"doc":"aws_api/amplify","title":"update_webhook","content":"pub fn update_webhook(\n  client: Client,\n  webhook_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplify.update_webhook\naws_api/amplify update_webhook","url":"aws_api/amplify.html#update_webhook"},{"doc":"aws_api/amplify","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/amplify.with_custom_endpoint\naws_api/amplify with_custom_endpoint","url":"aws_api/amplify.html#with_custom_endpoint"},{"doc":"aws_api/amplify","title":"aws_api/amplify","content":"","url":"aws_api/amplify.html"},{"doc":"aws_api/amplifybackend","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/amplifybackend.Client\naws_api/amplifybackend Client","url":"aws_api/amplifybackend.html#Client"},{"doc":"aws_api/amplifybackend","title":"clone_backend","content":"pub fn clone_backend(\n  client: Client,\n  app_id: String,\n  backend_environment_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplifybackend.clone_backend\naws_api/amplifybackend clone_backend","url":"aws_api/amplifybackend.html#clone_backend"},{"doc":"aws_api/amplifybackend","title":"create_backend","content":"pub fn create_backend(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplifybackend.create_backend\naws_api/amplifybackend create_backend","url":"aws_api/amplifybackend.html#create_backend"},{"doc":"aws_api/amplifybackend","title":"create_backend_api","content":"pub fn create_backend_api(\n  client: Client,\n  app_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplifybackend.create_backend_api\naws_api/amplifybackend create_backend_api","url":"aws_api/amplifybackend.html#create_backend_api"},{"doc":"aws_api/amplifybackend","title":"create_backend_auth","content":"pub fn create_backend_auth(\n  client: Client,\n  app_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplifybackend.create_backend_auth\naws_api/amplifybackend create_backend_auth","url":"aws_api/amplifybackend.html#create_backend_auth"},{"doc":"aws_api/amplifybackend","title":"create_backend_config","content":"pub fn create_backend_config(\n  client: Client,\n  app_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplifybackend.create_backend_config\naws_api/amplifybackend create_backend_config","url":"aws_api/amplifybackend.html#create_backend_config"},{"doc":"aws_api/amplifybackend","title":"create_backend_storage","content":"pub fn create_backend_storage(\n  client: Client,\n  app_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplifybackend.create_backend_storage\naws_api/amplifybackend create_backend_storage","url":"aws_api/amplifybackend.html#create_backend_storage"},{"doc":"aws_api/amplifybackend","title":"create_token","content":"pub fn create_token(\n  client: Client,\n  app_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplifybackend.create_token\naws_api/amplifybackend create_token","url":"aws_api/amplifybackend.html#create_token"},{"doc":"aws_api/amplifybackend","title":"delete_backend","content":"pub fn delete_backend(\n  client: Client,\n  app_id: String,\n  backend_environment_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplifybackend.delete_backend\naws_api/amplifybackend delete_backend","url":"aws_api/amplifybackend.html#delete_backend"},{"doc":"aws_api/amplifybackend","title":"delete_backend_api","content":"pub fn delete_backend_api(\n  client: Client,\n  app_id: String,\n  backend_environment_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplifybackend.delete_backend_api\naws_api/amplifybackend delete_backend_api","url":"aws_api/amplifybackend.html#delete_backend_api"},{"doc":"aws_api/amplifybackend","title":"delete_backend_auth","content":"pub fn delete_backend_auth(\n  client: Client,\n  app_id: String,\n  backend_environment_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplifybackend.delete_backend_auth\naws_api/amplifybackend delete_backend_auth","url":"aws_api/amplifybackend.html#delete_backend_auth"},{"doc":"aws_api/amplifybackend","title":"delete_backend_storage","content":"pub fn delete_backend_storage(\n  client: Client,\n  app_id: String,\n  backend_environment_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplifybackend.delete_backend_storage\naws_api/amplifybackend delete_backend_storage","url":"aws_api/amplifybackend.html#delete_backend_storage"},{"doc":"aws_api/amplifybackend","title":"delete_token","content":"pub fn delete_token(\n  client: Client,\n  app_id: String,\n  session_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplifybackend.delete_token\naws_api/amplifybackend delete_token","url":"aws_api/amplifybackend.html#delete_token"},{"doc":"aws_api/amplifybackend","title":"generate_backend_api_models","content":"pub fn generate_backend_api_models(\n  client: Client,\n  app_id: String,\n  backend_environment_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplifybackend.generate_backend_api_models\naws_api/amplifybackend generate_backend_api_models","url":"aws_api/amplifybackend.html#generate_backend_api_models"},{"doc":"aws_api/amplifybackend","title":"get_backend","content":"pub fn get_backend(\n  client: Client,\n  app_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplifybackend.get_backend\naws_api/amplifybackend get_backend","url":"aws_api/amplifybackend.html#get_backend"},{"doc":"aws_api/amplifybackend","title":"get_backend_api","content":"pub fn get_backend_api(\n  client: Client,\n  app_id: String,\n  backend_environment_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplifybackend.get_backend_api\naws_api/amplifybackend get_backend_api","url":"aws_api/amplifybackend.html#get_backend_api"},{"doc":"aws_api/amplifybackend","title":"get_backend_api_models","content":"pub fn get_backend_api_models(\n  client: Client,\n  app_id: String,\n  backend_environment_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplifybackend.get_backend_api_models\naws_api/amplifybackend get_backend_api_models","url":"aws_api/amplifybackend.html#get_backend_api_models"},{"doc":"aws_api/amplifybackend","title":"get_backend_auth","content":"pub fn get_backend_auth(\n  client: Client,\n  app_id: String,\n  backend_environment_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplifybackend.get_backend_auth\naws_api/amplifybackend get_backend_auth","url":"aws_api/amplifybackend.html#get_backend_auth"},{"doc":"aws_api/amplifybackend","title":"get_backend_job","content":"pub fn get_backend_job(\n  client: Client,\n  app_id: String,\n  backend_environment_name: String,\n  job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplifybackend.get_backend_job\naws_api/amplifybackend get_backend_job","url":"aws_api/amplifybackend.html#get_backend_job"},{"doc":"aws_api/amplifybackend","title":"get_backend_storage","content":"pub fn get_backend_storage(\n  client: Client,\n  app_id: String,\n  backend_environment_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplifybackend.get_backend_storage\naws_api/amplifybackend get_backend_storage","url":"aws_api/amplifybackend.html#get_backend_storage"},{"doc":"aws_api/amplifybackend","title":"get_token","content":"pub fn get_token(\n  client: Client,\n  app_id: String,\n  session_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplifybackend.get_token\naws_api/amplifybackend get_token","url":"aws_api/amplifybackend.html#get_token"},{"doc":"aws_api/amplifybackend","title":"import_backend_auth","content":"pub fn import_backend_auth(\n  client: Client,\n  app_id: String,\n  backend_environment_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplifybackend.import_backend_auth\naws_api/amplifybackend import_backend_auth","url":"aws_api/amplifybackend.html#import_backend_auth"},{"doc":"aws_api/amplifybackend","title":"import_backend_storage","content":"pub fn import_backend_storage(\n  client: Client,\n  app_id: String,\n  backend_environment_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplifybackend.import_backend_storage\naws_api/amplifybackend import_backend_storage","url":"aws_api/amplifybackend.html#import_backend_storage"},{"doc":"aws_api/amplifybackend","title":"list_backend_jobs","content":"pub fn list_backend_jobs(\n  client: Client,\n  app_id: String,\n  backend_environment_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplifybackend.list_backend_jobs\naws_api/amplifybackend list_backend_jobs","url":"aws_api/amplifybackend.html#list_backend_jobs"},{"doc":"aws_api/amplifybackend","title":"list_s3_buckets","content":"pub fn list_s3_buckets(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplifybackend.list_s3_buckets\naws_api/amplifybackend list_s3_buckets","url":"aws_api/amplifybackend.html#list_s3_buckets"},{"doc":"aws_api/amplifybackend","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/amplifybackend.new\naws_api/amplifybackend new","url":"aws_api/amplifybackend.html#new"},{"doc":"aws_api/amplifybackend","title":"remove_all_backends","content":"pub fn remove_all_backends(\n  client: Client,\n  app_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplifybackend.remove_all_backends\naws_api/amplifybackend remove_all_backends","url":"aws_api/amplifybackend.html#remove_all_backends"},{"doc":"aws_api/amplifybackend","title":"remove_backend_config","content":"pub fn remove_backend_config(\n  client: Client,\n  app_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplifybackend.remove_backend_config\naws_api/amplifybackend remove_backend_config","url":"aws_api/amplifybackend.html#remove_backend_config"},{"doc":"aws_api/amplifybackend","title":"update_backend_api","content":"pub fn update_backend_api(\n  client: Client,\n  app_id: String,\n  backend_environment_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplifybackend.update_backend_api\naws_api/amplifybackend update_backend_api","url":"aws_api/amplifybackend.html#update_backend_api"},{"doc":"aws_api/amplifybackend","title":"update_backend_auth","content":"pub fn update_backend_auth(\n  client: Client,\n  app_id: String,\n  backend_environment_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplifybackend.update_backend_auth\naws_api/amplifybackend update_backend_auth","url":"aws_api/amplifybackend.html#update_backend_auth"},{"doc":"aws_api/amplifybackend","title":"update_backend_config","content":"pub fn update_backend_config(\n  client: Client,\n  app_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplifybackend.update_backend_config\naws_api/amplifybackend update_backend_config","url":"aws_api/amplifybackend.html#update_backend_config"},{"doc":"aws_api/amplifybackend","title":"update_backend_job","content":"pub fn update_backend_job(\n  client: Client,\n  app_id: String,\n  backend_environment_name: String,\n  job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplifybackend.update_backend_job\naws_api/amplifybackend update_backend_job","url":"aws_api/amplifybackend.html#update_backend_job"},{"doc":"aws_api/amplifybackend","title":"update_backend_storage","content":"pub fn update_backend_storage(\n  client: Client,\n  app_id: String,\n  backend_environment_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplifybackend.update_backend_storage\naws_api/amplifybackend update_backend_storage","url":"aws_api/amplifybackend.html#update_backend_storage"},{"doc":"aws_api/amplifybackend","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/amplifybackend.with_custom_endpoint\naws_api/amplifybackend with_custom_endpoint","url":"aws_api/amplifybackend.html#with_custom_endpoint"},{"doc":"aws_api/amplifybackend","title":"aws_api/amplifybackend","content":"","url":"aws_api/amplifybackend.html"},{"doc":"aws_api/amplifyuibuilder","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/amplifyuibuilder.Client\naws_api/amplifyuibuilder Client","url":"aws_api/amplifyuibuilder.html#Client"},{"doc":"aws_api/amplifyuibuilder","title":"exchange_code_for_token","content":"pub fn exchange_code_for_token(\n  client: Client,\n  provider: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplifyuibuilder.exchange_code_for_token\naws_api/amplifyuibuilder exchange_code_for_token","url":"aws_api/amplifyuibuilder.html#exchange_code_for_token"},{"doc":"aws_api/amplifyuibuilder","title":"get_metadata","content":"pub fn get_metadata(\n  client: Client,\n  app_id: String,\n  environment_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplifyuibuilder.get_metadata\naws_api/amplifyuibuilder get_metadata","url":"aws_api/amplifyuibuilder.html#get_metadata"},{"doc":"aws_api/amplifyuibuilder","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplifyuibuilder.list_tags_for_resource\naws_api/amplifyuibuilder list_tags_for_resource","url":"aws_api/amplifyuibuilder.html#list_tags_for_resource"},{"doc":"aws_api/amplifyuibuilder","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/amplifyuibuilder.new\naws_api/amplifyuibuilder new","url":"aws_api/amplifyuibuilder.html#new"},{"doc":"aws_api/amplifyuibuilder","title":"put_metadata_flag","content":"pub fn put_metadata_flag(\n  client: Client,\n  app_id: String,\n  environment_name: String,\n  feature_name: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplifyuibuilder.put_metadata_flag\naws_api/amplifyuibuilder put_metadata_flag","url":"aws_api/amplifyuibuilder.html#put_metadata_flag"},{"doc":"aws_api/amplifyuibuilder","title":"refresh_token","content":"pub fn refresh_token(\n  client: Client,\n  provider: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplifyuibuilder.refresh_token\naws_api/amplifyuibuilder refresh_token","url":"aws_api/amplifyuibuilder.html#refresh_token"},{"doc":"aws_api/amplifyuibuilder","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplifyuibuilder.tag_resource\naws_api/amplifyuibuilder tag_resource","url":"aws_api/amplifyuibuilder.html#tag_resource"},{"doc":"aws_api/amplifyuibuilder","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/amplifyuibuilder.untag_resource\naws_api/amplifyuibuilder untag_resource","url":"aws_api/amplifyuibuilder.html#untag_resource"},{"doc":"aws_api/amplifyuibuilder","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/amplifyuibuilder.with_custom_endpoint\naws_api/amplifyuibuilder with_custom_endpoint","url":"aws_api/amplifyuibuilder.html#with_custom_endpoint"},{"doc":"aws_api/amplifyuibuilder","title":"aws_api/amplifyuibuilder","content":"","url":"aws_api/amplifyuibuilder.html"},{"doc":"aws_api/api_gateway","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/api_gateway.Client\naws_api/api_gateway Client","url":"aws_api/api_gateway.html#Client"},{"doc":"aws_api/api_gateway","title":"create_api_key","content":"pub fn create_api_key(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.create_api_key\naws_api/api_gateway create_api_key","url":"aws_api/api_gateway.html#create_api_key"},{"doc":"aws_api/api_gateway","title":"create_authorizer","content":"pub fn create_authorizer(\n  client: Client,\n  rest_api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.create_authorizer\naws_api/api_gateway create_authorizer","url":"aws_api/api_gateway.html#create_authorizer"},{"doc":"aws_api/api_gateway","title":"create_base_path_mapping","content":"pub fn create_base_path_mapping(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.create_base_path_mapping\naws_api/api_gateway create_base_path_mapping","url":"aws_api/api_gateway.html#create_base_path_mapping"},{"doc":"aws_api/api_gateway","title":"create_deployment","content":"pub fn create_deployment(\n  client: Client,\n  rest_api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.create_deployment\naws_api/api_gateway create_deployment","url":"aws_api/api_gateway.html#create_deployment"},{"doc":"aws_api/api_gateway","title":"create_documentation_part","content":"pub fn create_documentation_part(\n  client: Client,\n  rest_api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.create_documentation_part\naws_api/api_gateway create_documentation_part","url":"aws_api/api_gateway.html#create_documentation_part"},{"doc":"aws_api/api_gateway","title":"create_documentation_version","content":"pub fn create_documentation_version(\n  client: Client,\n  rest_api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.create_documentation_version\naws_api/api_gateway create_documentation_version","url":"aws_api/api_gateway.html#create_documentation_version"},{"doc":"aws_api/api_gateway","title":"create_domain_name","content":"pub fn create_domain_name(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.create_domain_name\naws_api/api_gateway create_domain_name","url":"aws_api/api_gateway.html#create_domain_name"},{"doc":"aws_api/api_gateway","title":"create_model","content":"pub fn create_model(\n  client: Client,\n  rest_api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.create_model\naws_api/api_gateway create_model","url":"aws_api/api_gateway.html#create_model"},{"doc":"aws_api/api_gateway","title":"create_request_validator","content":"pub fn create_request_validator(\n  client: Client,\n  rest_api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.create_request_validator\naws_api/api_gateway create_request_validator","url":"aws_api/api_gateway.html#create_request_validator"},{"doc":"aws_api/api_gateway","title":"create_resource","content":"pub fn create_resource(\n  client: Client,\n  rest_api_id: String,\n  parent_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.create_resource\naws_api/api_gateway create_resource","url":"aws_api/api_gateway.html#create_resource"},{"doc":"aws_api/api_gateway","title":"create_rest_api","content":"pub fn create_rest_api(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.create_rest_api\naws_api/api_gateway create_rest_api","url":"aws_api/api_gateway.html#create_rest_api"},{"doc":"aws_api/api_gateway","title":"create_stage","content":"pub fn create_stage(\n  client: Client,\n  rest_api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.create_stage\naws_api/api_gateway create_stage","url":"aws_api/api_gateway.html#create_stage"},{"doc":"aws_api/api_gateway","title":"create_usage_plan","content":"pub fn create_usage_plan(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.create_usage_plan\naws_api/api_gateway create_usage_plan","url":"aws_api/api_gateway.html#create_usage_plan"},{"doc":"aws_api/api_gateway","title":"create_usage_plan_key","content":"pub fn create_usage_plan_key(\n  client: Client,\n  usage_plan_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.create_usage_plan_key\naws_api/api_gateway create_usage_plan_key","url":"aws_api/api_gateway.html#create_usage_plan_key"},{"doc":"aws_api/api_gateway","title":"create_vpc_link","content":"pub fn create_vpc_link(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.create_vpc_link\naws_api/api_gateway create_vpc_link","url":"aws_api/api_gateway.html#create_vpc_link"},{"doc":"aws_api/api_gateway","title":"delete_api_key","content":"pub fn delete_api_key(\n  client: Client,\n  api_key: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.delete_api_key\naws_api/api_gateway delete_api_key","url":"aws_api/api_gateway.html#delete_api_key"},{"doc":"aws_api/api_gateway","title":"delete_authorizer","content":"pub fn delete_authorizer(\n  client: Client,\n  rest_api_id: String,\n  authorizer_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.delete_authorizer\naws_api/api_gateway delete_authorizer","url":"aws_api/api_gateway.html#delete_authorizer"},{"doc":"aws_api/api_gateway","title":"delete_base_path_mapping","content":"pub fn delete_base_path_mapping(\n  client: Client,\n  domain_name: String,\n  base_path: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.delete_base_path_mapping\naws_api/api_gateway delete_base_path_mapping","url":"aws_api/api_gateway.html#delete_base_path_mapping"},{"doc":"aws_api/api_gateway","title":"delete_client_certificate","content":"pub fn delete_client_certificate(\n  client: Client,\n  client_certificate_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.delete_client_certificate\naws_api/api_gateway delete_client_certificate","url":"aws_api/api_gateway.html#delete_client_certificate"},{"doc":"aws_api/api_gateway","title":"delete_deployment","content":"pub fn delete_deployment(\n  client: Client,\n  rest_api_id: String,\n  deployment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.delete_deployment\naws_api/api_gateway delete_deployment","url":"aws_api/api_gateway.html#delete_deployment"},{"doc":"aws_api/api_gateway","title":"delete_documentation_part","content":"pub fn delete_documentation_part(\n  client: Client,\n  rest_api_id: String,\n  documentation_part_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.delete_documentation_part\naws_api/api_gateway delete_documentation_part","url":"aws_api/api_gateway.html#delete_documentation_part"},{"doc":"aws_api/api_gateway","title":"delete_documentation_version","content":"pub fn delete_documentation_version(\n  client: Client,\n  rest_api_id: String,\n  documentation_version: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.delete_documentation_version\naws_api/api_gateway delete_documentation_version","url":"aws_api/api_gateway.html#delete_documentation_version"},{"doc":"aws_api/api_gateway","title":"delete_domain_name","content":"pub fn delete_domain_name(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.delete_domain_name\naws_api/api_gateway delete_domain_name","url":"aws_api/api_gateway.html#delete_domain_name"},{"doc":"aws_api/api_gateway","title":"delete_gateway_response","content":"pub fn delete_gateway_response(\n  client: Client,\n  rest_api_id: String,\n  response_type: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.delete_gateway_response\naws_api/api_gateway delete_gateway_response","url":"aws_api/api_gateway.html#delete_gateway_response"},{"doc":"aws_api/api_gateway","title":"delete_integration","content":"pub fn delete_integration(\n  client: Client,\n  rest_api_id: String,\n  resource_id: String,\n  http_method: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.delete_integration\naws_api/api_gateway delete_integration","url":"aws_api/api_gateway.html#delete_integration"},{"doc":"aws_api/api_gateway","title":"delete_integration_response","content":"pub fn delete_integration_response(\n  client: Client,\n  rest_api_id: String,\n  resource_id: String,\n  http_method: String,\n  status_code: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.delete_integration_response\naws_api/api_gateway delete_integration_response","url":"aws_api/api_gateway.html#delete_integration_response"},{"doc":"aws_api/api_gateway","title":"delete_method","content":"pub fn delete_method(\n  client: Client,\n  rest_api_id: String,\n  resource_id: String,\n  http_method: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.delete_method\naws_api/api_gateway delete_method","url":"aws_api/api_gateway.html#delete_method"},{"doc":"aws_api/api_gateway","title":"delete_method_response","content":"pub fn delete_method_response(\n  client: Client,\n  rest_api_id: String,\n  resource_id: String,\n  http_method: String,\n  status_code: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.delete_method_response\naws_api/api_gateway delete_method_response","url":"aws_api/api_gateway.html#delete_method_response"},{"doc":"aws_api/api_gateway","title":"delete_model","content":"pub fn delete_model(\n  client: Client,\n  rest_api_id: String,\n  model_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.delete_model\naws_api/api_gateway delete_model","url":"aws_api/api_gateway.html#delete_model"},{"doc":"aws_api/api_gateway","title":"delete_request_validator","content":"pub fn delete_request_validator(\n  client: Client,\n  rest_api_id: String,\n  request_validator_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.delete_request_validator\naws_api/api_gateway delete_request_validator","url":"aws_api/api_gateway.html#delete_request_validator"},{"doc":"aws_api/api_gateway","title":"delete_resource","content":"pub fn delete_resource(\n  client: Client,\n  rest_api_id: String,\n  resource_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.delete_resource\naws_api/api_gateway delete_resource","url":"aws_api/api_gateway.html#delete_resource"},{"doc":"aws_api/api_gateway","title":"delete_rest_api","content":"pub fn delete_rest_api(\n  client: Client,\n  rest_api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.delete_rest_api\naws_api/api_gateway delete_rest_api","url":"aws_api/api_gateway.html#delete_rest_api"},{"doc":"aws_api/api_gateway","title":"delete_stage","content":"pub fn delete_stage(\n  client: Client,\n  rest_api_id: String,\n  stage_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.delete_stage\naws_api/api_gateway delete_stage","url":"aws_api/api_gateway.html#delete_stage"},{"doc":"aws_api/api_gateway","title":"delete_usage_plan","content":"pub fn delete_usage_plan(\n  client: Client,\n  usage_plan_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.delete_usage_plan\naws_api/api_gateway delete_usage_plan","url":"aws_api/api_gateway.html#delete_usage_plan"},{"doc":"aws_api/api_gateway","title":"delete_usage_plan_key","content":"pub fn delete_usage_plan_key(\n  client: Client,\n  usage_plan_id: String,\n  key_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.delete_usage_plan_key\naws_api/api_gateway delete_usage_plan_key","url":"aws_api/api_gateway.html#delete_usage_plan_key"},{"doc":"aws_api/api_gateway","title":"delete_vpc_link","content":"pub fn delete_vpc_link(\n  client: Client,\n  vpc_link_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.delete_vpc_link\naws_api/api_gateway delete_vpc_link","url":"aws_api/api_gateway.html#delete_vpc_link"},{"doc":"aws_api/api_gateway","title":"flush_stage_authorizers_cache","content":"pub fn flush_stage_authorizers_cache(\n  client: Client,\n  rest_api_id: String,\n  stage_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.flush_stage_authorizers_cache\naws_api/api_gateway flush_stage_authorizers_cache","url":"aws_api/api_gateway.html#flush_stage_authorizers_cache"},{"doc":"aws_api/api_gateway","title":"flush_stage_cache","content":"pub fn flush_stage_cache(\n  client: Client,\n  rest_api_id: String,\n  stage_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.flush_stage_cache\naws_api/api_gateway flush_stage_cache","url":"aws_api/api_gateway.html#flush_stage_cache"},{"doc":"aws_api/api_gateway","title":"generate_client_certificate","content":"pub fn generate_client_certificate(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.generate_client_certificate\naws_api/api_gateway generate_client_certificate","url":"aws_api/api_gateway.html#generate_client_certificate"},{"doc":"aws_api/api_gateway","title":"get_account","content":"pub fn get_account(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.get_account\naws_api/api_gateway get_account","url":"aws_api/api_gateway.html#get_account"},{"doc":"aws_api/api_gateway","title":"get_api_key","content":"pub fn get_api_key(\n  client: Client,\n  api_key: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.get_api_key\naws_api/api_gateway get_api_key","url":"aws_api/api_gateway.html#get_api_key"},{"doc":"aws_api/api_gateway","title":"get_api_keys","content":"pub fn get_api_keys(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.get_api_keys\naws_api/api_gateway get_api_keys","url":"aws_api/api_gateway.html#get_api_keys"},{"doc":"aws_api/api_gateway","title":"get_authorizer","content":"pub fn get_authorizer(\n  client: Client,\n  rest_api_id: String,\n  authorizer_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.get_authorizer\naws_api/api_gateway get_authorizer","url":"aws_api/api_gateway.html#get_authorizer"},{"doc":"aws_api/api_gateway","title":"get_authorizers","content":"pub fn get_authorizers(\n  client: Client,\n  rest_api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.get_authorizers\naws_api/api_gateway get_authorizers","url":"aws_api/api_gateway.html#get_authorizers"},{"doc":"aws_api/api_gateway","title":"get_base_path_mapping","content":"pub fn get_base_path_mapping(\n  client: Client,\n  domain_name: String,\n  base_path: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.get_base_path_mapping\naws_api/api_gateway get_base_path_mapping","url":"aws_api/api_gateway.html#get_base_path_mapping"},{"doc":"aws_api/api_gateway","title":"get_base_path_mappings","content":"pub fn get_base_path_mappings(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.get_base_path_mappings\naws_api/api_gateway get_base_path_mappings","url":"aws_api/api_gateway.html#get_base_path_mappings"},{"doc":"aws_api/api_gateway","title":"get_client_certificate","content":"pub fn get_client_certificate(\n  client: Client,\n  client_certificate_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.get_client_certificate\naws_api/api_gateway get_client_certificate","url":"aws_api/api_gateway.html#get_client_certificate"},{"doc":"aws_api/api_gateway","title":"get_client_certificates","content":"pub fn get_client_certificates(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.get_client_certificates\naws_api/api_gateway get_client_certificates","url":"aws_api/api_gateway.html#get_client_certificates"},{"doc":"aws_api/api_gateway","title":"get_deployment","content":"pub fn get_deployment(\n  client: Client,\n  rest_api_id: String,\n  deployment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.get_deployment\naws_api/api_gateway get_deployment","url":"aws_api/api_gateway.html#get_deployment"},{"doc":"aws_api/api_gateway","title":"get_deployments","content":"pub fn get_deployments(\n  client: Client,\n  rest_api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.get_deployments\naws_api/api_gateway get_deployments","url":"aws_api/api_gateway.html#get_deployments"},{"doc":"aws_api/api_gateway","title":"get_documentation_part","content":"pub fn get_documentation_part(\n  client: Client,\n  rest_api_id: String,\n  documentation_part_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.get_documentation_part\naws_api/api_gateway get_documentation_part","url":"aws_api/api_gateway.html#get_documentation_part"},{"doc":"aws_api/api_gateway","title":"get_documentation_parts","content":"pub fn get_documentation_parts(\n  client: Client,\n  rest_api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.get_documentation_parts\naws_api/api_gateway get_documentation_parts","url":"aws_api/api_gateway.html#get_documentation_parts"},{"doc":"aws_api/api_gateway","title":"get_documentation_version","content":"pub fn get_documentation_version(\n  client: Client,\n  rest_api_id: String,\n  documentation_version: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.get_documentation_version\naws_api/api_gateway get_documentation_version","url":"aws_api/api_gateway.html#get_documentation_version"},{"doc":"aws_api/api_gateway","title":"get_documentation_versions","content":"pub fn get_documentation_versions(\n  client: Client,\n  rest_api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.get_documentation_versions\naws_api/api_gateway get_documentation_versions","url":"aws_api/api_gateway.html#get_documentation_versions"},{"doc":"aws_api/api_gateway","title":"get_domain_name","content":"pub fn get_domain_name(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.get_domain_name\naws_api/api_gateway get_domain_name","url":"aws_api/api_gateway.html#get_domain_name"},{"doc":"aws_api/api_gateway","title":"get_domain_names","content":"pub fn get_domain_names(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.get_domain_names\naws_api/api_gateway get_domain_names","url":"aws_api/api_gateway.html#get_domain_names"},{"doc":"aws_api/api_gateway","title":"get_export","content":"pub fn get_export(\n  client: Client,\n  rest_api_id: String,\n  stage_name: String,\n  export_type: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.get_export\naws_api/api_gateway get_export","url":"aws_api/api_gateway.html#get_export"},{"doc":"aws_api/api_gateway","title":"get_gateway_response","content":"pub fn get_gateway_response(\n  client: Client,\n  rest_api_id: String,\n  response_type: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.get_gateway_response\naws_api/api_gateway get_gateway_response","url":"aws_api/api_gateway.html#get_gateway_response"},{"doc":"aws_api/api_gateway","title":"get_gateway_responses","content":"pub fn get_gateway_responses(\n  client: Client,\n  rest_api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.get_gateway_responses\naws_api/api_gateway get_gateway_responses","url":"aws_api/api_gateway.html#get_gateway_responses"},{"doc":"aws_api/api_gateway","title":"get_integration","content":"pub fn get_integration(\n  client: Client,\n  rest_api_id: String,\n  resource_id: String,\n  http_method: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.get_integration\naws_api/api_gateway get_integration","url":"aws_api/api_gateway.html#get_integration"},{"doc":"aws_api/api_gateway","title":"get_integration_response","content":"pub fn get_integration_response(\n  client: Client,\n  rest_api_id: String,\n  resource_id: String,\n  http_method: String,\n  status_code: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.get_integration_response\naws_api/api_gateway get_integration_response","url":"aws_api/api_gateway.html#get_integration_response"},{"doc":"aws_api/api_gateway","title":"get_method","content":"pub fn get_method(\n  client: Client,\n  rest_api_id: String,\n  resource_id: String,\n  http_method: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.get_method\naws_api/api_gateway get_method","url":"aws_api/api_gateway.html#get_method"},{"doc":"aws_api/api_gateway","title":"get_method_response","content":"pub fn get_method_response(\n  client: Client,\n  rest_api_id: String,\n  resource_id: String,\n  http_method: String,\n  status_code: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.get_method_response\naws_api/api_gateway get_method_response","url":"aws_api/api_gateway.html#get_method_response"},{"doc":"aws_api/api_gateway","title":"get_model","content":"pub fn get_model(\n  client: Client,\n  rest_api_id: String,\n  model_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.get_model\naws_api/api_gateway get_model","url":"aws_api/api_gateway.html#get_model"},{"doc":"aws_api/api_gateway","title":"get_model_template","content":"pub fn get_model_template(\n  client: Client,\n  rest_api_id: String,\n  model_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.get_model_template\naws_api/api_gateway get_model_template","url":"aws_api/api_gateway.html#get_model_template"},{"doc":"aws_api/api_gateway","title":"get_models","content":"pub fn get_models(\n  client: Client,\n  rest_api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.get_models\naws_api/api_gateway get_models","url":"aws_api/api_gateway.html#get_models"},{"doc":"aws_api/api_gateway","title":"get_request_validator","content":"pub fn get_request_validator(\n  client: Client,\n  rest_api_id: String,\n  request_validator_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.get_request_validator\naws_api/api_gateway get_request_validator","url":"aws_api/api_gateway.html#get_request_validator"},{"doc":"aws_api/api_gateway","title":"get_request_validators","content":"pub fn get_request_validators(\n  client: Client,\n  rest_api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.get_request_validators\naws_api/api_gateway get_request_validators","url":"aws_api/api_gateway.html#get_request_validators"},{"doc":"aws_api/api_gateway","title":"get_resource","content":"pub fn get_resource(\n  client: Client,\n  rest_api_id: String,\n  resource_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.get_resource\naws_api/api_gateway get_resource","url":"aws_api/api_gateway.html#get_resource"},{"doc":"aws_api/api_gateway","title":"get_resources","content":"pub fn get_resources(\n  client: Client,\n  rest_api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.get_resources\naws_api/api_gateway get_resources","url":"aws_api/api_gateway.html#get_resources"},{"doc":"aws_api/api_gateway","title":"get_rest_api","content":"pub fn get_rest_api(\n  client: Client,\n  rest_api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.get_rest_api\naws_api/api_gateway get_rest_api","url":"aws_api/api_gateway.html#get_rest_api"},{"doc":"aws_api/api_gateway","title":"get_rest_apis","content":"pub fn get_rest_apis(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.get_rest_apis\naws_api/api_gateway get_rest_apis","url":"aws_api/api_gateway.html#get_rest_apis"},{"doc":"aws_api/api_gateway","title":"get_sdk","content":"pub fn get_sdk(\n  client: Client,\n  rest_api_id: String,\n  stage_name: String,\n  sdk_type: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.get_sdk\naws_api/api_gateway get_sdk","url":"aws_api/api_gateway.html#get_sdk"},{"doc":"aws_api/api_gateway","title":"get_sdk_type","content":"pub fn get_sdk_type(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.get_sdk_type\naws_api/api_gateway get_sdk_type","url":"aws_api/api_gateway.html#get_sdk_type"},{"doc":"aws_api/api_gateway","title":"get_sdk_types","content":"pub fn get_sdk_types(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.get_sdk_types\naws_api/api_gateway get_sdk_types","url":"aws_api/api_gateway.html#get_sdk_types"},{"doc":"aws_api/api_gateway","title":"get_stage","content":"pub fn get_stage(\n  client: Client,\n  rest_api_id: String,\n  stage_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.get_stage\naws_api/api_gateway get_stage","url":"aws_api/api_gateway.html#get_stage"},{"doc":"aws_api/api_gateway","title":"get_stages","content":"pub fn get_stages(\n  client: Client,\n  rest_api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.get_stages\naws_api/api_gateway get_stages","url":"aws_api/api_gateway.html#get_stages"},{"doc":"aws_api/api_gateway","title":"get_tags","content":"pub fn get_tags(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.get_tags\naws_api/api_gateway get_tags","url":"aws_api/api_gateway.html#get_tags"},{"doc":"aws_api/api_gateway","title":"get_usage","content":"pub fn get_usage(\n  client: Client,\n  usage_plan_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.get_usage\naws_api/api_gateway get_usage","url":"aws_api/api_gateway.html#get_usage"},{"doc":"aws_api/api_gateway","title":"get_usage_plan","content":"pub fn get_usage_plan(\n  client: Client,\n  usage_plan_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.get_usage_plan\naws_api/api_gateway get_usage_plan","url":"aws_api/api_gateway.html#get_usage_plan"},{"doc":"aws_api/api_gateway","title":"get_usage_plan_key","content":"pub fn get_usage_plan_key(\n  client: Client,\n  usage_plan_id: String,\n  key_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.get_usage_plan_key\naws_api/api_gateway get_usage_plan_key","url":"aws_api/api_gateway.html#get_usage_plan_key"},{"doc":"aws_api/api_gateway","title":"get_usage_plan_keys","content":"pub fn get_usage_plan_keys(\n  client: Client,\n  usage_plan_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.get_usage_plan_keys\naws_api/api_gateway get_usage_plan_keys","url":"aws_api/api_gateway.html#get_usage_plan_keys"},{"doc":"aws_api/api_gateway","title":"get_usage_plans","content":"pub fn get_usage_plans(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.get_usage_plans\naws_api/api_gateway get_usage_plans","url":"aws_api/api_gateway.html#get_usage_plans"},{"doc":"aws_api/api_gateway","title":"get_vpc_link","content":"pub fn get_vpc_link(\n  client: Client,\n  vpc_link_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.get_vpc_link\naws_api/api_gateway get_vpc_link","url":"aws_api/api_gateway.html#get_vpc_link"},{"doc":"aws_api/api_gateway","title":"get_vpc_links","content":"pub fn get_vpc_links(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.get_vpc_links\naws_api/api_gateway get_vpc_links","url":"aws_api/api_gateway.html#get_vpc_links"},{"doc":"aws_api/api_gateway","title":"import_api_keys","content":"pub fn import_api_keys(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.import_api_keys\naws_api/api_gateway import_api_keys","url":"aws_api/api_gateway.html#import_api_keys"},{"doc":"aws_api/api_gateway","title":"import_documentation_parts","content":"pub fn import_documentation_parts(\n  client: Client,\n  rest_api_id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.import_documentation_parts\naws_api/api_gateway import_documentation_parts","url":"aws_api/api_gateway.html#import_documentation_parts"},{"doc":"aws_api/api_gateway","title":"import_rest_api","content":"pub fn import_rest_api(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.import_rest_api\naws_api/api_gateway import_rest_api","url":"aws_api/api_gateway.html#import_rest_api"},{"doc":"aws_api/api_gateway","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/api_gateway.new\naws_api/api_gateway new","url":"aws_api/api_gateway.html#new"},{"doc":"aws_api/api_gateway","title":"put_gateway_response","content":"pub fn put_gateway_response(\n  client: Client,\n  rest_api_id: String,\n  response_type: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.put_gateway_response\naws_api/api_gateway put_gateway_response","url":"aws_api/api_gateway.html#put_gateway_response"},{"doc":"aws_api/api_gateway","title":"put_integration","content":"pub fn put_integration(\n  client: Client,\n  rest_api_id: String,\n  resource_id: String,\n  http_method: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.put_integration\naws_api/api_gateway put_integration","url":"aws_api/api_gateway.html#put_integration"},{"doc":"aws_api/api_gateway","title":"put_integration_response","content":"pub fn put_integration_response(\n  client: Client,\n  rest_api_id: String,\n  resource_id: String,\n  http_method: String,\n  status_code: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.put_integration_response\naws_api/api_gateway put_integration_response","url":"aws_api/api_gateway.html#put_integration_response"},{"doc":"aws_api/api_gateway","title":"put_method","content":"pub fn put_method(\n  client: Client,\n  rest_api_id: String,\n  resource_id: String,\n  http_method: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.put_method\naws_api/api_gateway put_method","url":"aws_api/api_gateway.html#put_method"},{"doc":"aws_api/api_gateway","title":"put_method_response","content":"pub fn put_method_response(\n  client: Client,\n  rest_api_id: String,\n  resource_id: String,\n  http_method: String,\n  status_code: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.put_method_response\naws_api/api_gateway put_method_response","url":"aws_api/api_gateway.html#put_method_response"},{"doc":"aws_api/api_gateway","title":"put_rest_api","content":"pub fn put_rest_api(\n  client: Client,\n  rest_api_id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.put_rest_api\naws_api/api_gateway put_rest_api","url":"aws_api/api_gateway.html#put_rest_api"},{"doc":"aws_api/api_gateway","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.tag_resource\naws_api/api_gateway tag_resource","url":"aws_api/api_gateway.html#tag_resource"},{"doc":"aws_api/api_gateway","title":"test_invoke_authorizer","content":"pub fn test_invoke_authorizer(\n  client: Client,\n  rest_api_id: String,\n  authorizer_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.test_invoke_authorizer\naws_api/api_gateway test_invoke_authorizer","url":"aws_api/api_gateway.html#test_invoke_authorizer"},{"doc":"aws_api/api_gateway","title":"test_invoke_method","content":"pub fn test_invoke_method(\n  client: Client,\n  rest_api_id: String,\n  resource_id: String,\n  http_method: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.test_invoke_method\naws_api/api_gateway test_invoke_method","url":"aws_api/api_gateway.html#test_invoke_method"},{"doc":"aws_api/api_gateway","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.untag_resource\naws_api/api_gateway untag_resource","url":"aws_api/api_gateway.html#untag_resource"},{"doc":"aws_api/api_gateway","title":"update_account","content":"pub fn update_account(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.update_account\naws_api/api_gateway update_account","url":"aws_api/api_gateway.html#update_account"},{"doc":"aws_api/api_gateway","title":"update_api_key","content":"pub fn update_api_key(\n  client: Client,\n  api_key: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.update_api_key\naws_api/api_gateway update_api_key","url":"aws_api/api_gateway.html#update_api_key"},{"doc":"aws_api/api_gateway","title":"update_authorizer","content":"pub fn update_authorizer(\n  client: Client,\n  rest_api_id: String,\n  authorizer_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.update_authorizer\naws_api/api_gateway update_authorizer","url":"aws_api/api_gateway.html#update_authorizer"},{"doc":"aws_api/api_gateway","title":"update_base_path_mapping","content":"pub fn update_base_path_mapping(\n  client: Client,\n  domain_name: String,\n  base_path: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.update_base_path_mapping\naws_api/api_gateway update_base_path_mapping","url":"aws_api/api_gateway.html#update_base_path_mapping"},{"doc":"aws_api/api_gateway","title":"update_client_certificate","content":"pub fn update_client_certificate(\n  client: Client,\n  client_certificate_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.update_client_certificate\naws_api/api_gateway update_client_certificate","url":"aws_api/api_gateway.html#update_client_certificate"},{"doc":"aws_api/api_gateway","title":"update_deployment","content":"pub fn update_deployment(\n  client: Client,\n  rest_api_id: String,\n  deployment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.update_deployment\naws_api/api_gateway update_deployment","url":"aws_api/api_gateway.html#update_deployment"},{"doc":"aws_api/api_gateway","title":"update_documentation_part","content":"pub fn update_documentation_part(\n  client: Client,\n  rest_api_id: String,\n  documentation_part_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.update_documentation_part\naws_api/api_gateway update_documentation_part","url":"aws_api/api_gateway.html#update_documentation_part"},{"doc":"aws_api/api_gateway","title":"update_documentation_version","content":"pub fn update_documentation_version(\n  client: Client,\n  rest_api_id: String,\n  documentation_version: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.update_documentation_version\naws_api/api_gateway update_documentation_version","url":"aws_api/api_gateway.html#update_documentation_version"},{"doc":"aws_api/api_gateway","title":"update_domain_name","content":"pub fn update_domain_name(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.update_domain_name\naws_api/api_gateway update_domain_name","url":"aws_api/api_gateway.html#update_domain_name"},{"doc":"aws_api/api_gateway","title":"update_gateway_response","content":"pub fn update_gateway_response(\n  client: Client,\n  rest_api_id: String,\n  response_type: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.update_gateway_response\naws_api/api_gateway update_gateway_response","url":"aws_api/api_gateway.html#update_gateway_response"},{"doc":"aws_api/api_gateway","title":"update_integration","content":"pub fn update_integration(\n  client: Client,\n  rest_api_id: String,\n  resource_id: String,\n  http_method: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.update_integration\naws_api/api_gateway update_integration","url":"aws_api/api_gateway.html#update_integration"},{"doc":"aws_api/api_gateway","title":"update_integration_response","content":"pub fn update_integration_response(\n  client: Client,\n  rest_api_id: String,\n  resource_id: String,\n  http_method: String,\n  status_code: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.update_integration_response\naws_api/api_gateway update_integration_response","url":"aws_api/api_gateway.html#update_integration_response"},{"doc":"aws_api/api_gateway","title":"update_method","content":"pub fn update_method(\n  client: Client,\n  rest_api_id: String,\n  resource_id: String,\n  http_method: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.update_method\naws_api/api_gateway update_method","url":"aws_api/api_gateway.html#update_method"},{"doc":"aws_api/api_gateway","title":"update_method_response","content":"pub fn update_method_response(\n  client: Client,\n  rest_api_id: String,\n  resource_id: String,\n  http_method: String,\n  status_code: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.update_method_response\naws_api/api_gateway update_method_response","url":"aws_api/api_gateway.html#update_method_response"},{"doc":"aws_api/api_gateway","title":"update_model","content":"pub fn update_model(\n  client: Client,\n  rest_api_id: String,\n  model_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.update_model\naws_api/api_gateway update_model","url":"aws_api/api_gateway.html#update_model"},{"doc":"aws_api/api_gateway","title":"update_request_validator","content":"pub fn update_request_validator(\n  client: Client,\n  rest_api_id: String,\n  request_validator_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.update_request_validator\naws_api/api_gateway update_request_validator","url":"aws_api/api_gateway.html#update_request_validator"},{"doc":"aws_api/api_gateway","title":"update_resource","content":"pub fn update_resource(\n  client: Client,\n  rest_api_id: String,\n  resource_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.update_resource\naws_api/api_gateway update_resource","url":"aws_api/api_gateway.html#update_resource"},{"doc":"aws_api/api_gateway","title":"update_rest_api","content":"pub fn update_rest_api(\n  client: Client,\n  rest_api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.update_rest_api\naws_api/api_gateway update_rest_api","url":"aws_api/api_gateway.html#update_rest_api"},{"doc":"aws_api/api_gateway","title":"update_stage","content":"pub fn update_stage(\n  client: Client,\n  rest_api_id: String,\n  stage_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.update_stage\naws_api/api_gateway update_stage","url":"aws_api/api_gateway.html#update_stage"},{"doc":"aws_api/api_gateway","title":"update_usage","content":"pub fn update_usage(\n  client: Client,\n  usage_plan_id: String,\n  key_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.update_usage\naws_api/api_gateway update_usage","url":"aws_api/api_gateway.html#update_usage"},{"doc":"aws_api/api_gateway","title":"update_usage_plan","content":"pub fn update_usage_plan(\n  client: Client,\n  usage_plan_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.update_usage_plan\naws_api/api_gateway update_usage_plan","url":"aws_api/api_gateway.html#update_usage_plan"},{"doc":"aws_api/api_gateway","title":"update_vpc_link","content":"pub fn update_vpc_link(\n  client: Client,\n  vpc_link_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/api_gateway.update_vpc_link\naws_api/api_gateway update_vpc_link","url":"aws_api/api_gateway.html#update_vpc_link"},{"doc":"aws_api/api_gateway","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/api_gateway.with_custom_endpoint\naws_api/api_gateway with_custom_endpoint","url":"aws_api/api_gateway.html#with_custom_endpoint"},{"doc":"aws_api/api_gateway","title":"aws_api/api_gateway","content":"","url":"aws_api/api_gateway.html"},{"doc":"aws_api/apigatewayv2","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/apigatewayv2.Client\naws_api/apigatewayv2 Client","url":"aws_api/apigatewayv2.html#Client"},{"doc":"aws_api/apigatewayv2","title":"create_api","content":"pub fn create_api(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.create_api\naws_api/apigatewayv2 create_api","url":"aws_api/apigatewayv2.html#create_api"},{"doc":"aws_api/apigatewayv2","title":"create_api_mapping","content":"pub fn create_api_mapping(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.create_api_mapping\naws_api/apigatewayv2 create_api_mapping","url":"aws_api/apigatewayv2.html#create_api_mapping"},{"doc":"aws_api/apigatewayv2","title":"create_authorizer","content":"pub fn create_authorizer(\n  client: Client,\n  api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.create_authorizer\naws_api/apigatewayv2 create_authorizer","url":"aws_api/apigatewayv2.html#create_authorizer"},{"doc":"aws_api/apigatewayv2","title":"create_deployment","content":"pub fn create_deployment(\n  client: Client,\n  api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.create_deployment\naws_api/apigatewayv2 create_deployment","url":"aws_api/apigatewayv2.html#create_deployment"},{"doc":"aws_api/apigatewayv2","title":"create_domain_name","content":"pub fn create_domain_name(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.create_domain_name\naws_api/apigatewayv2 create_domain_name","url":"aws_api/apigatewayv2.html#create_domain_name"},{"doc":"aws_api/apigatewayv2","title":"create_integration","content":"pub fn create_integration(\n  client: Client,\n  api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.create_integration\naws_api/apigatewayv2 create_integration","url":"aws_api/apigatewayv2.html#create_integration"},{"doc":"aws_api/apigatewayv2","title":"create_integration_response","content":"pub fn create_integration_response(\n  client: Client,\n  api_id: String,\n  integration_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.create_integration_response\naws_api/apigatewayv2 create_integration_response","url":"aws_api/apigatewayv2.html#create_integration_response"},{"doc":"aws_api/apigatewayv2","title":"create_model","content":"pub fn create_model(\n  client: Client,\n  api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.create_model\naws_api/apigatewayv2 create_model","url":"aws_api/apigatewayv2.html#create_model"},{"doc":"aws_api/apigatewayv2","title":"create_route","content":"pub fn create_route(\n  client: Client,\n  api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.create_route\naws_api/apigatewayv2 create_route","url":"aws_api/apigatewayv2.html#create_route"},{"doc":"aws_api/apigatewayv2","title":"create_route_response","content":"pub fn create_route_response(\n  client: Client,\n  api_id: String,\n  route_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.create_route_response\naws_api/apigatewayv2 create_route_response","url":"aws_api/apigatewayv2.html#create_route_response"},{"doc":"aws_api/apigatewayv2","title":"create_stage","content":"pub fn create_stage(\n  client: Client,\n  api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.create_stage\naws_api/apigatewayv2 create_stage","url":"aws_api/apigatewayv2.html#create_stage"},{"doc":"aws_api/apigatewayv2","title":"create_vpc_link","content":"pub fn create_vpc_link(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.create_vpc_link\naws_api/apigatewayv2 create_vpc_link","url":"aws_api/apigatewayv2.html#create_vpc_link"},{"doc":"aws_api/apigatewayv2","title":"delete_access_log_settings","content":"pub fn delete_access_log_settings(\n  client: Client,\n  api_id: String,\n  stage_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.delete_access_log_settings\naws_api/apigatewayv2 delete_access_log_settings","url":"aws_api/apigatewayv2.html#delete_access_log_settings"},{"doc":"aws_api/apigatewayv2","title":"delete_api","content":"pub fn delete_api(\n  client: Client,\n  api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.delete_api\naws_api/apigatewayv2 delete_api","url":"aws_api/apigatewayv2.html#delete_api"},{"doc":"aws_api/apigatewayv2","title":"delete_api_mapping","content":"pub fn delete_api_mapping(\n  client: Client,\n  domain_name: String,\n  api_mapping_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.delete_api_mapping\naws_api/apigatewayv2 delete_api_mapping","url":"aws_api/apigatewayv2.html#delete_api_mapping"},{"doc":"aws_api/apigatewayv2","title":"delete_authorizer","content":"pub fn delete_authorizer(\n  client: Client,\n  api_id: String,\n  authorizer_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.delete_authorizer\naws_api/apigatewayv2 delete_authorizer","url":"aws_api/apigatewayv2.html#delete_authorizer"},{"doc":"aws_api/apigatewayv2","title":"delete_cors_configuration","content":"pub fn delete_cors_configuration(\n  client: Client,\n  api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.delete_cors_configuration\naws_api/apigatewayv2 delete_cors_configuration","url":"aws_api/apigatewayv2.html#delete_cors_configuration"},{"doc":"aws_api/apigatewayv2","title":"delete_deployment","content":"pub fn delete_deployment(\n  client: Client,\n  api_id: String,\n  deployment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.delete_deployment\naws_api/apigatewayv2 delete_deployment","url":"aws_api/apigatewayv2.html#delete_deployment"},{"doc":"aws_api/apigatewayv2","title":"delete_domain_name","content":"pub fn delete_domain_name(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.delete_domain_name\naws_api/apigatewayv2 delete_domain_name","url":"aws_api/apigatewayv2.html#delete_domain_name"},{"doc":"aws_api/apigatewayv2","title":"delete_integration","content":"pub fn delete_integration(\n  client: Client,\n  api_id: String,\n  integration_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.delete_integration\naws_api/apigatewayv2 delete_integration","url":"aws_api/apigatewayv2.html#delete_integration"},{"doc":"aws_api/apigatewayv2","title":"delete_integration_response","content":"pub fn delete_integration_response(\n  client: Client,\n  api_id: String,\n  integration_id: String,\n  integration_response_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.delete_integration_response\naws_api/apigatewayv2 delete_integration_response","url":"aws_api/apigatewayv2.html#delete_integration_response"},{"doc":"aws_api/apigatewayv2","title":"delete_model","content":"pub fn delete_model(\n  client: Client,\n  api_id: String,\n  model_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.delete_model\naws_api/apigatewayv2 delete_model","url":"aws_api/apigatewayv2.html#delete_model"},{"doc":"aws_api/apigatewayv2","title":"delete_route","content":"pub fn delete_route(\n  client: Client,\n  api_id: String,\n  route_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.delete_route\naws_api/apigatewayv2 delete_route","url":"aws_api/apigatewayv2.html#delete_route"},{"doc":"aws_api/apigatewayv2","title":"delete_route_request_parameter","content":"pub fn delete_route_request_parameter(\n  client: Client,\n  api_id: String,\n  route_id: String,\n  request_parameter_key: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.delete_route_request_parameter\naws_api/apigatewayv2 delete_route_request_parameter","url":"aws_api/apigatewayv2.html#delete_route_request_parameter"},{"doc":"aws_api/apigatewayv2","title":"delete_route_response","content":"pub fn delete_route_response(\n  client: Client,\n  api_id: String,\n  route_id: String,\n  route_response_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.delete_route_response\naws_api/apigatewayv2 delete_route_response","url":"aws_api/apigatewayv2.html#delete_route_response"},{"doc":"aws_api/apigatewayv2","title":"delete_route_settings","content":"pub fn delete_route_settings(\n  client: Client,\n  api_id: String,\n  stage_name: String,\n  route_key: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.delete_route_settings\naws_api/apigatewayv2 delete_route_settings","url":"aws_api/apigatewayv2.html#delete_route_settings"},{"doc":"aws_api/apigatewayv2","title":"delete_stage","content":"pub fn delete_stage(\n  client: Client,\n  api_id: String,\n  stage_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.delete_stage\naws_api/apigatewayv2 delete_stage","url":"aws_api/apigatewayv2.html#delete_stage"},{"doc":"aws_api/apigatewayv2","title":"delete_vpc_link","content":"pub fn delete_vpc_link(\n  client: Client,\n  vpc_link_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.delete_vpc_link\naws_api/apigatewayv2 delete_vpc_link","url":"aws_api/apigatewayv2.html#delete_vpc_link"},{"doc":"aws_api/apigatewayv2","title":"export_api","content":"pub fn export_api(\n  client: Client,\n  api_id: String,\n  specification: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.export_api\naws_api/apigatewayv2 export_api","url":"aws_api/apigatewayv2.html#export_api"},{"doc":"aws_api/apigatewayv2","title":"get_api","content":"pub fn get_api(\n  client: Client,\n  api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.get_api\naws_api/apigatewayv2 get_api","url":"aws_api/apigatewayv2.html#get_api"},{"doc":"aws_api/apigatewayv2","title":"get_api_mapping","content":"pub fn get_api_mapping(\n  client: Client,\n  domain_name: String,\n  api_mapping_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.get_api_mapping\naws_api/apigatewayv2 get_api_mapping","url":"aws_api/apigatewayv2.html#get_api_mapping"},{"doc":"aws_api/apigatewayv2","title":"get_api_mappings","content":"pub fn get_api_mappings(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.get_api_mappings\naws_api/apigatewayv2 get_api_mappings","url":"aws_api/apigatewayv2.html#get_api_mappings"},{"doc":"aws_api/apigatewayv2","title":"get_apis","content":"pub fn get_apis(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.get_apis\naws_api/apigatewayv2 get_apis","url":"aws_api/apigatewayv2.html#get_apis"},{"doc":"aws_api/apigatewayv2","title":"get_authorizer","content":"pub fn get_authorizer(\n  client: Client,\n  api_id: String,\n  authorizer_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.get_authorizer\naws_api/apigatewayv2 get_authorizer","url":"aws_api/apigatewayv2.html#get_authorizer"},{"doc":"aws_api/apigatewayv2","title":"get_authorizers","content":"pub fn get_authorizers(\n  client: Client,\n  api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.get_authorizers\naws_api/apigatewayv2 get_authorizers","url":"aws_api/apigatewayv2.html#get_authorizers"},{"doc":"aws_api/apigatewayv2","title":"get_deployment","content":"pub fn get_deployment(\n  client: Client,\n  api_id: String,\n  deployment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.get_deployment\naws_api/apigatewayv2 get_deployment","url":"aws_api/apigatewayv2.html#get_deployment"},{"doc":"aws_api/apigatewayv2","title":"get_deployments","content":"pub fn get_deployments(\n  client: Client,\n  api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.get_deployments\naws_api/apigatewayv2 get_deployments","url":"aws_api/apigatewayv2.html#get_deployments"},{"doc":"aws_api/apigatewayv2","title":"get_domain_name","content":"pub fn get_domain_name(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.get_domain_name\naws_api/apigatewayv2 get_domain_name","url":"aws_api/apigatewayv2.html#get_domain_name"},{"doc":"aws_api/apigatewayv2","title":"get_domain_names","content":"pub fn get_domain_names(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.get_domain_names\naws_api/apigatewayv2 get_domain_names","url":"aws_api/apigatewayv2.html#get_domain_names"},{"doc":"aws_api/apigatewayv2","title":"get_integration","content":"pub fn get_integration(\n  client: Client,\n  api_id: String,\n  integration_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.get_integration\naws_api/apigatewayv2 get_integration","url":"aws_api/apigatewayv2.html#get_integration"},{"doc":"aws_api/apigatewayv2","title":"get_integration_response","content":"pub fn get_integration_response(\n  client: Client,\n  api_id: String,\n  integration_id: String,\n  integration_response_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.get_integration_response\naws_api/apigatewayv2 get_integration_response","url":"aws_api/apigatewayv2.html#get_integration_response"},{"doc":"aws_api/apigatewayv2","title":"get_integration_responses","content":"pub fn get_integration_responses(\n  client: Client,\n  api_id: String,\n  integration_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.get_integration_responses\naws_api/apigatewayv2 get_integration_responses","url":"aws_api/apigatewayv2.html#get_integration_responses"},{"doc":"aws_api/apigatewayv2","title":"get_integrations","content":"pub fn get_integrations(\n  client: Client,\n  api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.get_integrations\naws_api/apigatewayv2 get_integrations","url":"aws_api/apigatewayv2.html#get_integrations"},{"doc":"aws_api/apigatewayv2","title":"get_model","content":"pub fn get_model(\n  client: Client,\n  api_id: String,\n  model_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.get_model\naws_api/apigatewayv2 get_model","url":"aws_api/apigatewayv2.html#get_model"},{"doc":"aws_api/apigatewayv2","title":"get_model_template","content":"pub fn get_model_template(\n  client: Client,\n  api_id: String,\n  model_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.get_model_template\naws_api/apigatewayv2 get_model_template","url":"aws_api/apigatewayv2.html#get_model_template"},{"doc":"aws_api/apigatewayv2","title":"get_models","content":"pub fn get_models(\n  client: Client,\n  api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.get_models\naws_api/apigatewayv2 get_models","url":"aws_api/apigatewayv2.html#get_models"},{"doc":"aws_api/apigatewayv2","title":"get_route","content":"pub fn get_route(\n  client: Client,\n  api_id: String,\n  route_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.get_route\naws_api/apigatewayv2 get_route","url":"aws_api/apigatewayv2.html#get_route"},{"doc":"aws_api/apigatewayv2","title":"get_route_response","content":"pub fn get_route_response(\n  client: Client,\n  api_id: String,\n  route_id: String,\n  route_response_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.get_route_response\naws_api/apigatewayv2 get_route_response","url":"aws_api/apigatewayv2.html#get_route_response"},{"doc":"aws_api/apigatewayv2","title":"get_route_responses","content":"pub fn get_route_responses(\n  client: Client,\n  api_id: String,\n  route_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.get_route_responses\naws_api/apigatewayv2 get_route_responses","url":"aws_api/apigatewayv2.html#get_route_responses"},{"doc":"aws_api/apigatewayv2","title":"get_routes","content":"pub fn get_routes(\n  client: Client,\n  api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.get_routes\naws_api/apigatewayv2 get_routes","url":"aws_api/apigatewayv2.html#get_routes"},{"doc":"aws_api/apigatewayv2","title":"get_stage","content":"pub fn get_stage(\n  client: Client,\n  api_id: String,\n  stage_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.get_stage\naws_api/apigatewayv2 get_stage","url":"aws_api/apigatewayv2.html#get_stage"},{"doc":"aws_api/apigatewayv2","title":"get_stages","content":"pub fn get_stages(\n  client: Client,\n  api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.get_stages\naws_api/apigatewayv2 get_stages","url":"aws_api/apigatewayv2.html#get_stages"},{"doc":"aws_api/apigatewayv2","title":"get_tags","content":"pub fn get_tags(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.get_tags\naws_api/apigatewayv2 get_tags","url":"aws_api/apigatewayv2.html#get_tags"},{"doc":"aws_api/apigatewayv2","title":"get_vpc_link","content":"pub fn get_vpc_link(\n  client: Client,\n  vpc_link_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.get_vpc_link\naws_api/apigatewayv2 get_vpc_link","url":"aws_api/apigatewayv2.html#get_vpc_link"},{"doc":"aws_api/apigatewayv2","title":"get_vpc_links","content":"pub fn get_vpc_links(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.get_vpc_links\naws_api/apigatewayv2 get_vpc_links","url":"aws_api/apigatewayv2.html#get_vpc_links"},{"doc":"aws_api/apigatewayv2","title":"import_api","content":"pub fn import_api(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.import_api\naws_api/apigatewayv2 import_api","url":"aws_api/apigatewayv2.html#import_api"},{"doc":"aws_api/apigatewayv2","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/apigatewayv2.new\naws_api/apigatewayv2 new","url":"aws_api/apigatewayv2.html#new"},{"doc":"aws_api/apigatewayv2","title":"reimport_api","content":"pub fn reimport_api(\n  client: Client,\n  api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.reimport_api\naws_api/apigatewayv2 reimport_api","url":"aws_api/apigatewayv2.html#reimport_api"},{"doc":"aws_api/apigatewayv2","title":"reset_authorizers_cache","content":"pub fn reset_authorizers_cache(\n  client: Client,\n  api_id: String,\n  stage_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.reset_authorizers_cache\naws_api/apigatewayv2 reset_authorizers_cache","url":"aws_api/apigatewayv2.html#reset_authorizers_cache"},{"doc":"aws_api/apigatewayv2","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.tag_resource\naws_api/apigatewayv2 tag_resource","url":"aws_api/apigatewayv2.html#tag_resource"},{"doc":"aws_api/apigatewayv2","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.untag_resource\naws_api/apigatewayv2 untag_resource","url":"aws_api/apigatewayv2.html#untag_resource"},{"doc":"aws_api/apigatewayv2","title":"update_api","content":"pub fn update_api(\n  client: Client,\n  api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.update_api\naws_api/apigatewayv2 update_api","url":"aws_api/apigatewayv2.html#update_api"},{"doc":"aws_api/apigatewayv2","title":"update_api_mapping","content":"pub fn update_api_mapping(\n  client: Client,\n  domain_name: String,\n  api_mapping_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.update_api_mapping\naws_api/apigatewayv2 update_api_mapping","url":"aws_api/apigatewayv2.html#update_api_mapping"},{"doc":"aws_api/apigatewayv2","title":"update_authorizer","content":"pub fn update_authorizer(\n  client: Client,\n  api_id: String,\n  authorizer_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.update_authorizer\naws_api/apigatewayv2 update_authorizer","url":"aws_api/apigatewayv2.html#update_authorizer"},{"doc":"aws_api/apigatewayv2","title":"update_deployment","content":"pub fn update_deployment(\n  client: Client,\n  api_id: String,\n  deployment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.update_deployment\naws_api/apigatewayv2 update_deployment","url":"aws_api/apigatewayv2.html#update_deployment"},{"doc":"aws_api/apigatewayv2","title":"update_domain_name","content":"pub fn update_domain_name(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.update_domain_name\naws_api/apigatewayv2 update_domain_name","url":"aws_api/apigatewayv2.html#update_domain_name"},{"doc":"aws_api/apigatewayv2","title":"update_integration","content":"pub fn update_integration(\n  client: Client,\n  api_id: String,\n  integration_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.update_integration\naws_api/apigatewayv2 update_integration","url":"aws_api/apigatewayv2.html#update_integration"},{"doc":"aws_api/apigatewayv2","title":"update_integration_response","content":"pub fn update_integration_response(\n  client: Client,\n  api_id: String,\n  integration_id: String,\n  integration_response_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.update_integration_response\naws_api/apigatewayv2 update_integration_response","url":"aws_api/apigatewayv2.html#update_integration_response"},{"doc":"aws_api/apigatewayv2","title":"update_model","content":"pub fn update_model(\n  client: Client,\n  api_id: String,\n  model_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.update_model\naws_api/apigatewayv2 update_model","url":"aws_api/apigatewayv2.html#update_model"},{"doc":"aws_api/apigatewayv2","title":"update_route","content":"pub fn update_route(\n  client: Client,\n  api_id: String,\n  route_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.update_route\naws_api/apigatewayv2 update_route","url":"aws_api/apigatewayv2.html#update_route"},{"doc":"aws_api/apigatewayv2","title":"update_route_response","content":"pub fn update_route_response(\n  client: Client,\n  api_id: String,\n  route_id: String,\n  route_response_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.update_route_response\naws_api/apigatewayv2 update_route_response","url":"aws_api/apigatewayv2.html#update_route_response"},{"doc":"aws_api/apigatewayv2","title":"update_stage","content":"pub fn update_stage(\n  client: Client,\n  api_id: String,\n  stage_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.update_stage\naws_api/apigatewayv2 update_stage","url":"aws_api/apigatewayv2.html#update_stage"},{"doc":"aws_api/apigatewayv2","title":"update_vpc_link","content":"pub fn update_vpc_link(\n  client: Client,\n  vpc_link_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apigatewayv2.update_vpc_link\naws_api/apigatewayv2 update_vpc_link","url":"aws_api/apigatewayv2.html#update_vpc_link"},{"doc":"aws_api/apigatewayv2","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/apigatewayv2.with_custom_endpoint\naws_api/apigatewayv2 with_custom_endpoint","url":"aws_api/apigatewayv2.html#with_custom_endpoint"},{"doc":"aws_api/apigatewayv2","title":"aws_api/apigatewayv2","content":"","url":"aws_api/apigatewayv2.html"},{"doc":"aws_api/app_mesh","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/app_mesh.Client\naws_api/app_mesh Client","url":"aws_api/app_mesh.html#Client"},{"doc":"aws_api/app_mesh","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/app_mesh.list_tags_for_resource\naws_api/app_mesh list_tags_for_resource","url":"aws_api/app_mesh.html#list_tags_for_resource"},{"doc":"aws_api/app_mesh","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/app_mesh.new\naws_api/app_mesh new","url":"aws_api/app_mesh.html#new"},{"doc":"aws_api/app_mesh","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/app_mesh.tag_resource\naws_api/app_mesh tag_resource","url":"aws_api/app_mesh.html#tag_resource"},{"doc":"aws_api/app_mesh","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/app_mesh.untag_resource\naws_api/app_mesh untag_resource","url":"aws_api/app_mesh.html#untag_resource"},{"doc":"aws_api/app_mesh","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/app_mesh.with_custom_endpoint\naws_api/app_mesh with_custom_endpoint","url":"aws_api/app_mesh.html#with_custom_endpoint"},{"doc":"aws_api/app_mesh","title":"aws_api/app_mesh","content":"","url":"aws_api/app_mesh.html"},{"doc":"aws_api/appconfig","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/appconfig.Client\naws_api/appconfig Client","url":"aws_api/appconfig.html#Client"},{"doc":"aws_api/appconfig","title":"create_application","content":"pub fn create_application(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appconfig.create_application\naws_api/appconfig create_application","url":"aws_api/appconfig.html#create_application"},{"doc":"aws_api/appconfig","title":"create_configuration_profile","content":"pub fn create_configuration_profile(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appconfig.create_configuration_profile\naws_api/appconfig create_configuration_profile","url":"aws_api/appconfig.html#create_configuration_profile"},{"doc":"aws_api/appconfig","title":"create_deployment_strategy","content":"pub fn create_deployment_strategy(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appconfig.create_deployment_strategy\naws_api/appconfig create_deployment_strategy","url":"aws_api/appconfig.html#create_deployment_strategy"},{"doc":"aws_api/appconfig","title":"create_environment","content":"pub fn create_environment(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appconfig.create_environment\naws_api/appconfig create_environment","url":"aws_api/appconfig.html#create_environment"},{"doc":"aws_api/appconfig","title":"create_extension","content":"pub fn create_extension(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appconfig.create_extension\naws_api/appconfig create_extension","url":"aws_api/appconfig.html#create_extension"},{"doc":"aws_api/appconfig","title":"create_extension_association","content":"pub fn create_extension_association(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appconfig.create_extension_association\naws_api/appconfig create_extension_association","url":"aws_api/appconfig.html#create_extension_association"},{"doc":"aws_api/appconfig","title":"create_hosted_configuration_version","content":"pub fn create_hosted_configuration_version(\n  client: Client,\n  application_id: String,\n  configuration_profile_id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appconfig.create_hosted_configuration_version\naws_api/appconfig create_hosted_configuration_version","url":"aws_api/appconfig.html#create_hosted_configuration_version"},{"doc":"aws_api/appconfig","title":"delete_application","content":"pub fn delete_application(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appconfig.delete_application\naws_api/appconfig delete_application","url":"aws_api/appconfig.html#delete_application"},{"doc":"aws_api/appconfig","title":"delete_configuration_profile","content":"pub fn delete_configuration_profile(\n  client: Client,\n  application_id: String,\n  configuration_profile_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appconfig.delete_configuration_profile\naws_api/appconfig delete_configuration_profile","url":"aws_api/appconfig.html#delete_configuration_profile"},{"doc":"aws_api/appconfig","title":"delete_deployment_strategy","content":"pub fn delete_deployment_strategy(\n  client: Client,\n  deployment_strategy_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appconfig.delete_deployment_strategy\naws_api/appconfig delete_deployment_strategy","url":"aws_api/appconfig.html#delete_deployment_strategy"},{"doc":"aws_api/appconfig","title":"delete_environment","content":"pub fn delete_environment(\n  client: Client,\n  application_id: String,\n  environment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appconfig.delete_environment\naws_api/appconfig delete_environment","url":"aws_api/appconfig.html#delete_environment"},{"doc":"aws_api/appconfig","title":"delete_extension","content":"pub fn delete_extension(\n  client: Client,\n  extension_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appconfig.delete_extension\naws_api/appconfig delete_extension","url":"aws_api/appconfig.html#delete_extension"},{"doc":"aws_api/appconfig","title":"delete_extension_association","content":"pub fn delete_extension_association(\n  client: Client,\n  extension_association_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appconfig.delete_extension_association\naws_api/appconfig delete_extension_association","url":"aws_api/appconfig.html#delete_extension_association"},{"doc":"aws_api/appconfig","title":"delete_hosted_configuration_version","content":"pub fn delete_hosted_configuration_version(\n  client: Client,\n  application_id: String,\n  configuration_profile_id: String,\n  version_number: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appconfig.delete_hosted_configuration_version\naws_api/appconfig delete_hosted_configuration_version","url":"aws_api/appconfig.html#delete_hosted_configuration_version"},{"doc":"aws_api/appconfig","title":"get_application","content":"pub fn get_application(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appconfig.get_application\naws_api/appconfig get_application","url":"aws_api/appconfig.html#get_application"},{"doc":"aws_api/appconfig","title":"get_configuration","content":"pub fn get_configuration(\n  client: Client,\n  application: String,\n  environment: String,\n  configuration: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appconfig.get_configuration\naws_api/appconfig get_configuration","url":"aws_api/appconfig.html#get_configuration"},{"doc":"aws_api/appconfig","title":"get_configuration_profile","content":"pub fn get_configuration_profile(\n  client: Client,\n  application_id: String,\n  configuration_profile_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appconfig.get_configuration_profile\naws_api/appconfig get_configuration_profile","url":"aws_api/appconfig.html#get_configuration_profile"},{"doc":"aws_api/appconfig","title":"get_deployment","content":"pub fn get_deployment(\n  client: Client,\n  application_id: String,\n  environment_id: String,\n  deployment_number: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appconfig.get_deployment\naws_api/appconfig get_deployment","url":"aws_api/appconfig.html#get_deployment"},{"doc":"aws_api/appconfig","title":"get_deployment_strategy","content":"pub fn get_deployment_strategy(\n  client: Client,\n  deployment_strategy_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appconfig.get_deployment_strategy\naws_api/appconfig get_deployment_strategy","url":"aws_api/appconfig.html#get_deployment_strategy"},{"doc":"aws_api/appconfig","title":"get_environment","content":"pub fn get_environment(\n  client: Client,\n  application_id: String,\n  environment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appconfig.get_environment\naws_api/appconfig get_environment","url":"aws_api/appconfig.html#get_environment"},{"doc":"aws_api/appconfig","title":"get_extension","content":"pub fn get_extension(\n  client: Client,\n  extension_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appconfig.get_extension\naws_api/appconfig get_extension","url":"aws_api/appconfig.html#get_extension"},{"doc":"aws_api/appconfig","title":"get_extension_association","content":"pub fn get_extension_association(\n  client: Client,\n  extension_association_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appconfig.get_extension_association\naws_api/appconfig get_extension_association","url":"aws_api/appconfig.html#get_extension_association"},{"doc":"aws_api/appconfig","title":"get_hosted_configuration_version","content":"pub fn get_hosted_configuration_version(\n  client: Client,\n  application_id: String,\n  configuration_profile_id: String,\n  version_number: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appconfig.get_hosted_configuration_version\naws_api/appconfig get_hosted_configuration_version","url":"aws_api/appconfig.html#get_hosted_configuration_version"},{"doc":"aws_api/appconfig","title":"list_applications","content":"pub fn list_applications(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appconfig.list_applications\naws_api/appconfig list_applications","url":"aws_api/appconfig.html#list_applications"},{"doc":"aws_api/appconfig","title":"list_configuration_profiles","content":"pub fn list_configuration_profiles(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appconfig.list_configuration_profiles\naws_api/appconfig list_configuration_profiles","url":"aws_api/appconfig.html#list_configuration_profiles"},{"doc":"aws_api/appconfig","title":"list_deployment_strategies","content":"pub fn list_deployment_strategies(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appconfig.list_deployment_strategies\naws_api/appconfig list_deployment_strategies","url":"aws_api/appconfig.html#list_deployment_strategies"},{"doc":"aws_api/appconfig","title":"list_deployments","content":"pub fn list_deployments(\n  client: Client,\n  application_id: String,\n  environment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appconfig.list_deployments\naws_api/appconfig list_deployments","url":"aws_api/appconfig.html#list_deployments"},{"doc":"aws_api/appconfig","title":"list_environments","content":"pub fn list_environments(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appconfig.list_environments\naws_api/appconfig list_environments","url":"aws_api/appconfig.html#list_environments"},{"doc":"aws_api/appconfig","title":"list_extension_associations","content":"pub fn list_extension_associations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appconfig.list_extension_associations\naws_api/appconfig list_extension_associations","url":"aws_api/appconfig.html#list_extension_associations"},{"doc":"aws_api/appconfig","title":"list_extensions","content":"pub fn list_extensions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appconfig.list_extensions\naws_api/appconfig list_extensions","url":"aws_api/appconfig.html#list_extensions"},{"doc":"aws_api/appconfig","title":"list_hosted_configuration_versions","content":"pub fn list_hosted_configuration_versions(\n  client: Client,\n  application_id: String,\n  configuration_profile_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appconfig.list_hosted_configuration_versions\naws_api/appconfig list_hosted_configuration_versions","url":"aws_api/appconfig.html#list_hosted_configuration_versions"},{"doc":"aws_api/appconfig","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appconfig.list_tags_for_resource\naws_api/appconfig list_tags_for_resource","url":"aws_api/appconfig.html#list_tags_for_resource"},{"doc":"aws_api/appconfig","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/appconfig.new\naws_api/appconfig new","url":"aws_api/appconfig.html#new"},{"doc":"aws_api/appconfig","title":"start_deployment","content":"pub fn start_deployment(\n  client: Client,\n  application_id: String,\n  environment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appconfig.start_deployment\naws_api/appconfig start_deployment","url":"aws_api/appconfig.html#start_deployment"},{"doc":"aws_api/appconfig","title":"stop_deployment","content":"pub fn stop_deployment(\n  client: Client,\n  application_id: String,\n  environment_id: String,\n  deployment_number: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appconfig.stop_deployment\naws_api/appconfig stop_deployment","url":"aws_api/appconfig.html#stop_deployment"},{"doc":"aws_api/appconfig","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appconfig.tag_resource\naws_api/appconfig tag_resource","url":"aws_api/appconfig.html#tag_resource"},{"doc":"aws_api/appconfig","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appconfig.untag_resource\naws_api/appconfig untag_resource","url":"aws_api/appconfig.html#untag_resource"},{"doc":"aws_api/appconfig","title":"update_application","content":"pub fn update_application(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appconfig.update_application\naws_api/appconfig update_application","url":"aws_api/appconfig.html#update_application"},{"doc":"aws_api/appconfig","title":"update_configuration_profile","content":"pub fn update_configuration_profile(\n  client: Client,\n  application_id: String,\n  configuration_profile_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appconfig.update_configuration_profile\naws_api/appconfig update_configuration_profile","url":"aws_api/appconfig.html#update_configuration_profile"},{"doc":"aws_api/appconfig","title":"update_deployment_strategy","content":"pub fn update_deployment_strategy(\n  client: Client,\n  deployment_strategy_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appconfig.update_deployment_strategy\naws_api/appconfig update_deployment_strategy","url":"aws_api/appconfig.html#update_deployment_strategy"},{"doc":"aws_api/appconfig","title":"update_environment","content":"pub fn update_environment(\n  client: Client,\n  application_id: String,\n  environment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appconfig.update_environment\naws_api/appconfig update_environment","url":"aws_api/appconfig.html#update_environment"},{"doc":"aws_api/appconfig","title":"update_extension","content":"pub fn update_extension(\n  client: Client,\n  extension_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appconfig.update_extension\naws_api/appconfig update_extension","url":"aws_api/appconfig.html#update_extension"},{"doc":"aws_api/appconfig","title":"update_extension_association","content":"pub fn update_extension_association(\n  client: Client,\n  extension_association_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appconfig.update_extension_association\naws_api/appconfig update_extension_association","url":"aws_api/appconfig.html#update_extension_association"},{"doc":"aws_api/appconfig","title":"validate_configuration","content":"pub fn validate_configuration(\n  client: Client,\n  application_id: String,\n  configuration_profile_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appconfig.validate_configuration\naws_api/appconfig validate_configuration","url":"aws_api/appconfig.html#validate_configuration"},{"doc":"aws_api/appconfig","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/appconfig.with_custom_endpoint\naws_api/appconfig with_custom_endpoint","url":"aws_api/appconfig.html#with_custom_endpoint"},{"doc":"aws_api/appconfig","title":"aws_api/appconfig","content":"","url":"aws_api/appconfig.html"},{"doc":"aws_api/appconfigdata","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/appconfigdata.Client\naws_api/appconfigdata Client","url":"aws_api/appconfigdata.html#Client"},{"doc":"aws_api/appconfigdata","title":"get_latest_configuration","content":"pub fn get_latest_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appconfigdata.get_latest_configuration\naws_api/appconfigdata get_latest_configuration","url":"aws_api/appconfigdata.html#get_latest_configuration"},{"doc":"aws_api/appconfigdata","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/appconfigdata.new\naws_api/appconfigdata new","url":"aws_api/appconfigdata.html#new"},{"doc":"aws_api/appconfigdata","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/appconfigdata.with_custom_endpoint\naws_api/appconfigdata with_custom_endpoint","url":"aws_api/appconfigdata.html#with_custom_endpoint"},{"doc":"aws_api/appconfigdata","title":"aws_api/appconfigdata","content":"","url":"aws_api/appconfigdata.html"},{"doc":"aws_api/appflow","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/appflow.Client\naws_api/appflow Client","url":"aws_api/appflow.html#Client"},{"doc":"aws_api/appflow","title":"cancel_flow_executions","content":"pub fn cancel_flow_executions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appflow.cancel_flow_executions\naws_api/appflow cancel_flow_executions","url":"aws_api/appflow.html#cancel_flow_executions"},{"doc":"aws_api/appflow","title":"create_connector_profile","content":"pub fn create_connector_profile(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appflow.create_connector_profile\naws_api/appflow create_connector_profile","url":"aws_api/appflow.html#create_connector_profile"},{"doc":"aws_api/appflow","title":"create_flow","content":"pub fn create_flow(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appflow.create_flow\naws_api/appflow create_flow","url":"aws_api/appflow.html#create_flow"},{"doc":"aws_api/appflow","title":"delete_connector_profile","content":"pub fn delete_connector_profile(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appflow.delete_connector_profile\naws_api/appflow delete_connector_profile","url":"aws_api/appflow.html#delete_connector_profile"},{"doc":"aws_api/appflow","title":"delete_flow","content":"pub fn delete_flow(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appflow.delete_flow\naws_api/appflow delete_flow","url":"aws_api/appflow.html#delete_flow"},{"doc":"aws_api/appflow","title":"describe_connector","content":"pub fn describe_connector(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appflow.describe_connector\naws_api/appflow describe_connector","url":"aws_api/appflow.html#describe_connector"},{"doc":"aws_api/appflow","title":"describe_connector_entity","content":"pub fn describe_connector_entity(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appflow.describe_connector_entity\naws_api/appflow describe_connector_entity","url":"aws_api/appflow.html#describe_connector_entity"},{"doc":"aws_api/appflow","title":"describe_connector_profiles","content":"pub fn describe_connector_profiles(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appflow.describe_connector_profiles\naws_api/appflow describe_connector_profiles","url":"aws_api/appflow.html#describe_connector_profiles"},{"doc":"aws_api/appflow","title":"describe_connectors","content":"pub fn describe_connectors(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appflow.describe_connectors\naws_api/appflow describe_connectors","url":"aws_api/appflow.html#describe_connectors"},{"doc":"aws_api/appflow","title":"describe_flow","content":"pub fn describe_flow(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appflow.describe_flow\naws_api/appflow describe_flow","url":"aws_api/appflow.html#describe_flow"},{"doc":"aws_api/appflow","title":"describe_flow_execution_records","content":"pub fn describe_flow_execution_records(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appflow.describe_flow_execution_records\naws_api/appflow describe_flow_execution_records","url":"aws_api/appflow.html#describe_flow_execution_records"},{"doc":"aws_api/appflow","title":"list_connector_entities","content":"pub fn list_connector_entities(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appflow.list_connector_entities\naws_api/appflow list_connector_entities","url":"aws_api/appflow.html#list_connector_entities"},{"doc":"aws_api/appflow","title":"list_connectors","content":"pub fn list_connectors(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appflow.list_connectors\naws_api/appflow list_connectors","url":"aws_api/appflow.html#list_connectors"},{"doc":"aws_api/appflow","title":"list_flows","content":"pub fn list_flows(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appflow.list_flows\naws_api/appflow list_flows","url":"aws_api/appflow.html#list_flows"},{"doc":"aws_api/appflow","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appflow.list_tags_for_resource\naws_api/appflow list_tags_for_resource","url":"aws_api/appflow.html#list_tags_for_resource"},{"doc":"aws_api/appflow","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/appflow.new\naws_api/appflow new","url":"aws_api/appflow.html#new"},{"doc":"aws_api/appflow","title":"register_connector","content":"pub fn register_connector(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appflow.register_connector\naws_api/appflow register_connector","url":"aws_api/appflow.html#register_connector"},{"doc":"aws_api/appflow","title":"reset_connector_metadata_cache","content":"pub fn reset_connector_metadata_cache(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appflow.reset_connector_metadata_cache\naws_api/appflow reset_connector_metadata_cache","url":"aws_api/appflow.html#reset_connector_metadata_cache"},{"doc":"aws_api/appflow","title":"start_flow","content":"pub fn start_flow(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appflow.start_flow\naws_api/appflow start_flow","url":"aws_api/appflow.html#start_flow"},{"doc":"aws_api/appflow","title":"stop_flow","content":"pub fn stop_flow(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appflow.stop_flow\naws_api/appflow stop_flow","url":"aws_api/appflow.html#stop_flow"},{"doc":"aws_api/appflow","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appflow.tag_resource\naws_api/appflow tag_resource","url":"aws_api/appflow.html#tag_resource"},{"doc":"aws_api/appflow","title":"unregister_connector","content":"pub fn unregister_connector(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appflow.unregister_connector\naws_api/appflow unregister_connector","url":"aws_api/appflow.html#unregister_connector"},{"doc":"aws_api/appflow","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appflow.untag_resource\naws_api/appflow untag_resource","url":"aws_api/appflow.html#untag_resource"},{"doc":"aws_api/appflow","title":"update_connector_profile","content":"pub fn update_connector_profile(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appflow.update_connector_profile\naws_api/appflow update_connector_profile","url":"aws_api/appflow.html#update_connector_profile"},{"doc":"aws_api/appflow","title":"update_connector_registration","content":"pub fn update_connector_registration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appflow.update_connector_registration\naws_api/appflow update_connector_registration","url":"aws_api/appflow.html#update_connector_registration"},{"doc":"aws_api/appflow","title":"update_flow","content":"pub fn update_flow(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appflow.update_flow\naws_api/appflow update_flow","url":"aws_api/appflow.html#update_flow"},{"doc":"aws_api/appflow","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/appflow.with_custom_endpoint\naws_api/appflow with_custom_endpoint","url":"aws_api/appflow.html#with_custom_endpoint"},{"doc":"aws_api/appflow","title":"aws_api/appflow","content":"","url":"aws_api/appflow.html"},{"doc":"aws_api/appintegrations","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/appintegrations.Client\naws_api/appintegrations Client","url":"aws_api/appintegrations.html#Client"},{"doc":"aws_api/appintegrations","title":"create_application","content":"pub fn create_application(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appintegrations.create_application\naws_api/appintegrations create_application","url":"aws_api/appintegrations.html#create_application"},{"doc":"aws_api/appintegrations","title":"create_data_integration","content":"pub fn create_data_integration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appintegrations.create_data_integration\naws_api/appintegrations create_data_integration","url":"aws_api/appintegrations.html#create_data_integration"},{"doc":"aws_api/appintegrations","title":"create_data_integration_association","content":"pub fn create_data_integration_association(\n  client: Client,\n  data_integration_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appintegrations.create_data_integration_association\naws_api/appintegrations create_data_integration_association","url":"aws_api/appintegrations.html#create_data_integration_association"},{"doc":"aws_api/appintegrations","title":"create_event_integration","content":"pub fn create_event_integration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appintegrations.create_event_integration\naws_api/appintegrations create_event_integration","url":"aws_api/appintegrations.html#create_event_integration"},{"doc":"aws_api/appintegrations","title":"delete_application","content":"pub fn delete_application(\n  client: Client,\n  arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appintegrations.delete_application\naws_api/appintegrations delete_application","url":"aws_api/appintegrations.html#delete_application"},{"doc":"aws_api/appintegrations","title":"delete_data_integration","content":"pub fn delete_data_integration(\n  client: Client,\n  data_integration_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appintegrations.delete_data_integration\naws_api/appintegrations delete_data_integration","url":"aws_api/appintegrations.html#delete_data_integration"},{"doc":"aws_api/appintegrations","title":"delete_event_integration","content":"pub fn delete_event_integration(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appintegrations.delete_event_integration\naws_api/appintegrations delete_event_integration","url":"aws_api/appintegrations.html#delete_event_integration"},{"doc":"aws_api/appintegrations","title":"get_application","content":"pub fn get_application(\n  client: Client,\n  arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appintegrations.get_application\naws_api/appintegrations get_application","url":"aws_api/appintegrations.html#get_application"},{"doc":"aws_api/appintegrations","title":"get_data_integration","content":"pub fn get_data_integration(\n  client: Client,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appintegrations.get_data_integration\naws_api/appintegrations get_data_integration","url":"aws_api/appintegrations.html#get_data_integration"},{"doc":"aws_api/appintegrations","title":"get_event_integration","content":"pub fn get_event_integration(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appintegrations.get_event_integration\naws_api/appintegrations get_event_integration","url":"aws_api/appintegrations.html#get_event_integration"},{"doc":"aws_api/appintegrations","title":"list_application_associations","content":"pub fn list_application_associations(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appintegrations.list_application_associations\naws_api/appintegrations list_application_associations","url":"aws_api/appintegrations.html#list_application_associations"},{"doc":"aws_api/appintegrations","title":"list_applications","content":"pub fn list_applications(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appintegrations.list_applications\naws_api/appintegrations list_applications","url":"aws_api/appintegrations.html#list_applications"},{"doc":"aws_api/appintegrations","title":"list_data_integration_associations","content":"pub fn list_data_integration_associations(\n  client: Client,\n  data_integration_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appintegrations.list_data_integration_associations\naws_api/appintegrations list_data_integration_associations","url":"aws_api/appintegrations.html#list_data_integration_associations"},{"doc":"aws_api/appintegrations","title":"list_data_integrations","content":"pub fn list_data_integrations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appintegrations.list_data_integrations\naws_api/appintegrations list_data_integrations","url":"aws_api/appintegrations.html#list_data_integrations"},{"doc":"aws_api/appintegrations","title":"list_event_integration_associations","content":"pub fn list_event_integration_associations(\n  client: Client,\n  event_integration_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appintegrations.list_event_integration_associations\naws_api/appintegrations list_event_integration_associations","url":"aws_api/appintegrations.html#list_event_integration_associations"},{"doc":"aws_api/appintegrations","title":"list_event_integrations","content":"pub fn list_event_integrations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appintegrations.list_event_integrations\naws_api/appintegrations list_event_integrations","url":"aws_api/appintegrations.html#list_event_integrations"},{"doc":"aws_api/appintegrations","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appintegrations.list_tags_for_resource\naws_api/appintegrations list_tags_for_resource","url":"aws_api/appintegrations.html#list_tags_for_resource"},{"doc":"aws_api/appintegrations","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/appintegrations.new\naws_api/appintegrations new","url":"aws_api/appintegrations.html#new"},{"doc":"aws_api/appintegrations","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appintegrations.tag_resource\naws_api/appintegrations tag_resource","url":"aws_api/appintegrations.html#tag_resource"},{"doc":"aws_api/appintegrations","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appintegrations.untag_resource\naws_api/appintegrations untag_resource","url":"aws_api/appintegrations.html#untag_resource"},{"doc":"aws_api/appintegrations","title":"update_application","content":"pub fn update_application(\n  client: Client,\n  arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appintegrations.update_application\naws_api/appintegrations update_application","url":"aws_api/appintegrations.html#update_application"},{"doc":"aws_api/appintegrations","title":"update_data_integration","content":"pub fn update_data_integration(\n  client: Client,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appintegrations.update_data_integration\naws_api/appintegrations update_data_integration","url":"aws_api/appintegrations.html#update_data_integration"},{"doc":"aws_api/appintegrations","title":"update_data_integration_association","content":"pub fn update_data_integration_association(\n  client: Client,\n  data_integration_identifier: String,\n  data_integration_association_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appintegrations.update_data_integration_association\naws_api/appintegrations update_data_integration_association","url":"aws_api/appintegrations.html#update_data_integration_association"},{"doc":"aws_api/appintegrations","title":"update_event_integration","content":"pub fn update_event_integration(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appintegrations.update_event_integration\naws_api/appintegrations update_event_integration","url":"aws_api/appintegrations.html#update_event_integration"},{"doc":"aws_api/appintegrations","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/appintegrations.with_custom_endpoint\naws_api/appintegrations with_custom_endpoint","url":"aws_api/appintegrations.html#with_custom_endpoint"},{"doc":"aws_api/appintegrations","title":"aws_api/appintegrations","content":"","url":"aws_api/appintegrations.html"},{"doc":"aws_api/application_auto_scaling","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/application_auto_scaling.Client\naws_api/application_auto_scaling Client","url":"aws_api/application_auto_scaling.html#Client"},{"doc":"aws_api/application_auto_scaling","title":"delete_scaling_policy","content":"pub fn delete_scaling_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_auto_scaling.delete_scaling_policy\naws_api/application_auto_scaling delete_scaling_policy","url":"aws_api/application_auto_scaling.html#delete_scaling_policy"},{"doc":"aws_api/application_auto_scaling","title":"delete_scheduled_action","content":"pub fn delete_scheduled_action(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_auto_scaling.delete_scheduled_action\naws_api/application_auto_scaling delete_scheduled_action","url":"aws_api/application_auto_scaling.html#delete_scheduled_action"},{"doc":"aws_api/application_auto_scaling","title":"deregister_scalable_target","content":"pub fn deregister_scalable_target(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_auto_scaling.deregister_scalable_target\naws_api/application_auto_scaling deregister_scalable_target","url":"aws_api/application_auto_scaling.html#deregister_scalable_target"},{"doc":"aws_api/application_auto_scaling","title":"describe_scalable_targets","content":"pub fn describe_scalable_targets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_auto_scaling.describe_scalable_targets\naws_api/application_auto_scaling describe_scalable_targets","url":"aws_api/application_auto_scaling.html#describe_scalable_targets"},{"doc":"aws_api/application_auto_scaling","title":"describe_scaling_activities","content":"pub fn describe_scaling_activities(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_auto_scaling.describe_scaling_activities\naws_api/application_auto_scaling describe_scaling_activities","url":"aws_api/application_auto_scaling.html#describe_scaling_activities"},{"doc":"aws_api/application_auto_scaling","title":"describe_scaling_policies","content":"pub fn describe_scaling_policies(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_auto_scaling.describe_scaling_policies\naws_api/application_auto_scaling describe_scaling_policies","url":"aws_api/application_auto_scaling.html#describe_scaling_policies"},{"doc":"aws_api/application_auto_scaling","title":"describe_scheduled_actions","content":"pub fn describe_scheduled_actions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_auto_scaling.describe_scheduled_actions\naws_api/application_auto_scaling describe_scheduled_actions","url":"aws_api/application_auto_scaling.html#describe_scheduled_actions"},{"doc":"aws_api/application_auto_scaling","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_auto_scaling.list_tags_for_resource\naws_api/application_auto_scaling list_tags_for_resource","url":"aws_api/application_auto_scaling.html#list_tags_for_resource"},{"doc":"aws_api/application_auto_scaling","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/application_auto_scaling.new\naws_api/application_auto_scaling new","url":"aws_api/application_auto_scaling.html#new"},{"doc":"aws_api/application_auto_scaling","title":"put_scaling_policy","content":"pub fn put_scaling_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_auto_scaling.put_scaling_policy\naws_api/application_auto_scaling put_scaling_policy","url":"aws_api/application_auto_scaling.html#put_scaling_policy"},{"doc":"aws_api/application_auto_scaling","title":"put_scheduled_action","content":"pub fn put_scheduled_action(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_auto_scaling.put_scheduled_action\naws_api/application_auto_scaling put_scheduled_action","url":"aws_api/application_auto_scaling.html#put_scheduled_action"},{"doc":"aws_api/application_auto_scaling","title":"register_scalable_target","content":"pub fn register_scalable_target(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_auto_scaling.register_scalable_target\naws_api/application_auto_scaling register_scalable_target","url":"aws_api/application_auto_scaling.html#register_scalable_target"},{"doc":"aws_api/application_auto_scaling","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_auto_scaling.tag_resource\naws_api/application_auto_scaling tag_resource","url":"aws_api/application_auto_scaling.html#tag_resource"},{"doc":"aws_api/application_auto_scaling","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_auto_scaling.untag_resource\naws_api/application_auto_scaling untag_resource","url":"aws_api/application_auto_scaling.html#untag_resource"},{"doc":"aws_api/application_auto_scaling","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/application_auto_scaling.with_custom_endpoint\naws_api/application_auto_scaling with_custom_endpoint","url":"aws_api/application_auto_scaling.html#with_custom_endpoint"},{"doc":"aws_api/application_auto_scaling","title":"aws_api/application_auto_scaling","content":"","url":"aws_api/application_auto_scaling.html"},{"doc":"aws_api/application_discovery_service","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/application_discovery_service.Client\naws_api/application_discovery_service Client","url":"aws_api/application_discovery_service.html#Client"},{"doc":"aws_api/application_discovery_service","title":"associate_configuration_items_to_application","content":"pub fn associate_configuration_items_to_application(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_discovery_service.associate_configuration_items_to_application\naws_api/application_discovery_service associate_configuration_items_to_application","url":"aws_api/application_discovery_service.html#associate_configuration_items_to_application"},{"doc":"aws_api/application_discovery_service","title":"batch_delete_agents","content":"pub fn batch_delete_agents(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_discovery_service.batch_delete_agents\naws_api/application_discovery_service batch_delete_agents","url":"aws_api/application_discovery_service.html#batch_delete_agents"},{"doc":"aws_api/application_discovery_service","title":"batch_delete_import_data","content":"pub fn batch_delete_import_data(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_discovery_service.batch_delete_import_data\naws_api/application_discovery_service batch_delete_import_data","url":"aws_api/application_discovery_service.html#batch_delete_import_data"},{"doc":"aws_api/application_discovery_service","title":"create_application","content":"pub fn create_application(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_discovery_service.create_application\naws_api/application_discovery_service create_application","url":"aws_api/application_discovery_service.html#create_application"},{"doc":"aws_api/application_discovery_service","title":"create_tags","content":"pub fn create_tags(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_discovery_service.create_tags\naws_api/application_discovery_service create_tags","url":"aws_api/application_discovery_service.html#create_tags"},{"doc":"aws_api/application_discovery_service","title":"delete_applications","content":"pub fn delete_applications(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_discovery_service.delete_applications\naws_api/application_discovery_service delete_applications","url":"aws_api/application_discovery_service.html#delete_applications"},{"doc":"aws_api/application_discovery_service","title":"delete_tags","content":"pub fn delete_tags(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_discovery_service.delete_tags\naws_api/application_discovery_service delete_tags","url":"aws_api/application_discovery_service.html#delete_tags"},{"doc":"aws_api/application_discovery_service","title":"describe_agents","content":"pub fn describe_agents(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_discovery_service.describe_agents\naws_api/application_discovery_service describe_agents","url":"aws_api/application_discovery_service.html#describe_agents"},{"doc":"aws_api/application_discovery_service","title":"describe_batch_delete_configuration_task","content":"pub fn describe_batch_delete_configuration_task(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_discovery_service.describe_batch_delete_configuration_task\naws_api/application_discovery_service describe_batch_delete_configuration_task","url":"aws_api/application_discovery_service.html#describe_batch_delete_configuration_task"},{"doc":"aws_api/application_discovery_service","title":"describe_configurations","content":"pub fn describe_configurations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_discovery_service.describe_configurations\naws_api/application_discovery_service describe_configurations","url":"aws_api/application_discovery_service.html#describe_configurations"},{"doc":"aws_api/application_discovery_service","title":"describe_continuous_exports","content":"pub fn describe_continuous_exports(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_discovery_service.describe_continuous_exports\naws_api/application_discovery_service describe_continuous_exports","url":"aws_api/application_discovery_service.html#describe_continuous_exports"},{"doc":"aws_api/application_discovery_service","title":"describe_export_configurations","content":"pub fn describe_export_configurations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_discovery_service.describe_export_configurations\naws_api/application_discovery_service describe_export_configurations","url":"aws_api/application_discovery_service.html#describe_export_configurations"},{"doc":"aws_api/application_discovery_service","title":"describe_export_tasks","content":"pub fn describe_export_tasks(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_discovery_service.describe_export_tasks\naws_api/application_discovery_service describe_export_tasks","url":"aws_api/application_discovery_service.html#describe_export_tasks"},{"doc":"aws_api/application_discovery_service","title":"describe_import_tasks","content":"pub fn describe_import_tasks(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_discovery_service.describe_import_tasks\naws_api/application_discovery_service describe_import_tasks","url":"aws_api/application_discovery_service.html#describe_import_tasks"},{"doc":"aws_api/application_discovery_service","title":"describe_tags","content":"pub fn describe_tags(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_discovery_service.describe_tags\naws_api/application_discovery_service describe_tags","url":"aws_api/application_discovery_service.html#describe_tags"},{"doc":"aws_api/application_discovery_service","title":"disassociate_configuration_items_from_application","content":"pub fn disassociate_configuration_items_from_application(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_discovery_service.disassociate_configuration_items_from_application\naws_api/application_discovery_service disassociate_configuration_items_from_application","url":"aws_api/application_discovery_service.html#disassociate_configuration_items_from_application"},{"doc":"aws_api/application_discovery_service","title":"export_configurations","content":"pub fn export_configurations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_discovery_service.export_configurations\naws_api/application_discovery_service export_configurations","url":"aws_api/application_discovery_service.html#export_configurations"},{"doc":"aws_api/application_discovery_service","title":"get_discovery_summary","content":"pub fn get_discovery_summary(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_discovery_service.get_discovery_summary\naws_api/application_discovery_service get_discovery_summary","url":"aws_api/application_discovery_service.html#get_discovery_summary"},{"doc":"aws_api/application_discovery_service","title":"list_configurations","content":"pub fn list_configurations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_discovery_service.list_configurations\naws_api/application_discovery_service list_configurations","url":"aws_api/application_discovery_service.html#list_configurations"},{"doc":"aws_api/application_discovery_service","title":"list_server_neighbors","content":"pub fn list_server_neighbors(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_discovery_service.list_server_neighbors\naws_api/application_discovery_service list_server_neighbors","url":"aws_api/application_discovery_service.html#list_server_neighbors"},{"doc":"aws_api/application_discovery_service","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/application_discovery_service.new\naws_api/application_discovery_service new","url":"aws_api/application_discovery_service.html#new"},{"doc":"aws_api/application_discovery_service","title":"start_batch_delete_configuration_task","content":"pub fn start_batch_delete_configuration_task(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_discovery_service.start_batch_delete_configuration_task\naws_api/application_discovery_service start_batch_delete_configuration_task","url":"aws_api/application_discovery_service.html#start_batch_delete_configuration_task"},{"doc":"aws_api/application_discovery_service","title":"start_continuous_export","content":"pub fn start_continuous_export(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_discovery_service.start_continuous_export\naws_api/application_discovery_service start_continuous_export","url":"aws_api/application_discovery_service.html#start_continuous_export"},{"doc":"aws_api/application_discovery_service","title":"start_data_collection_by_agent_ids","content":"pub fn start_data_collection_by_agent_ids(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_discovery_service.start_data_collection_by_agent_ids\naws_api/application_discovery_service start_data_collection_by_agent_ids","url":"aws_api/application_discovery_service.html#start_data_collection_by_agent_ids"},{"doc":"aws_api/application_discovery_service","title":"start_export_task","content":"pub fn start_export_task(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_discovery_service.start_export_task\naws_api/application_discovery_service start_export_task","url":"aws_api/application_discovery_service.html#start_export_task"},{"doc":"aws_api/application_discovery_service","title":"start_import_task","content":"pub fn start_import_task(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_discovery_service.start_import_task\naws_api/application_discovery_service start_import_task","url":"aws_api/application_discovery_service.html#start_import_task"},{"doc":"aws_api/application_discovery_service","title":"stop_continuous_export","content":"pub fn stop_continuous_export(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_discovery_service.stop_continuous_export\naws_api/application_discovery_service stop_continuous_export","url":"aws_api/application_discovery_service.html#stop_continuous_export"},{"doc":"aws_api/application_discovery_service","title":"stop_data_collection_by_agent_ids","content":"pub fn stop_data_collection_by_agent_ids(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_discovery_service.stop_data_collection_by_agent_ids\naws_api/application_discovery_service stop_data_collection_by_agent_ids","url":"aws_api/application_discovery_service.html#stop_data_collection_by_agent_ids"},{"doc":"aws_api/application_discovery_service","title":"update_application","content":"pub fn update_application(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_discovery_service.update_application\naws_api/application_discovery_service update_application","url":"aws_api/application_discovery_service.html#update_application"},{"doc":"aws_api/application_discovery_service","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/application_discovery_service.with_custom_endpoint\naws_api/application_discovery_service with_custom_endpoint","url":"aws_api/application_discovery_service.html#with_custom_endpoint"},{"doc":"aws_api/application_discovery_service","title":"aws_api/application_discovery_service","content":"","url":"aws_api/application_discovery_service.html"},{"doc":"aws_api/application_insights","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/application_insights.Client\naws_api/application_insights Client","url":"aws_api/application_insights.html#Client"},{"doc":"aws_api/application_insights","title":"add_workload","content":"pub fn add_workload(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_insights.add_workload\naws_api/application_insights add_workload","url":"aws_api/application_insights.html#add_workload"},{"doc":"aws_api/application_insights","title":"create_application","content":"pub fn create_application(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_insights.create_application\naws_api/application_insights create_application","url":"aws_api/application_insights.html#create_application"},{"doc":"aws_api/application_insights","title":"create_component","content":"pub fn create_component(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_insights.create_component\naws_api/application_insights create_component","url":"aws_api/application_insights.html#create_component"},{"doc":"aws_api/application_insights","title":"create_log_pattern","content":"pub fn create_log_pattern(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_insights.create_log_pattern\naws_api/application_insights create_log_pattern","url":"aws_api/application_insights.html#create_log_pattern"},{"doc":"aws_api/application_insights","title":"delete_application","content":"pub fn delete_application(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_insights.delete_application\naws_api/application_insights delete_application","url":"aws_api/application_insights.html#delete_application"},{"doc":"aws_api/application_insights","title":"delete_component","content":"pub fn delete_component(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_insights.delete_component\naws_api/application_insights delete_component","url":"aws_api/application_insights.html#delete_component"},{"doc":"aws_api/application_insights","title":"delete_log_pattern","content":"pub fn delete_log_pattern(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_insights.delete_log_pattern\naws_api/application_insights delete_log_pattern","url":"aws_api/application_insights.html#delete_log_pattern"},{"doc":"aws_api/application_insights","title":"describe_application","content":"pub fn describe_application(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_insights.describe_application\naws_api/application_insights describe_application","url":"aws_api/application_insights.html#describe_application"},{"doc":"aws_api/application_insights","title":"describe_component","content":"pub fn describe_component(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_insights.describe_component\naws_api/application_insights describe_component","url":"aws_api/application_insights.html#describe_component"},{"doc":"aws_api/application_insights","title":"describe_component_configuration","content":"pub fn describe_component_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_insights.describe_component_configuration\naws_api/application_insights describe_component_configuration","url":"aws_api/application_insights.html#describe_component_configuration"},{"doc":"aws_api/application_insights","title":"describe_component_configuration_recommendation","content":"pub fn describe_component_configuration_recommendation(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_insights.describe_component_configuration_recommendation\naws_api/application_insights describe_component_configuration_recommendation","url":"aws_api/application_insights.html#describe_component_configuration_recommendation"},{"doc":"aws_api/application_insights","title":"describe_log_pattern","content":"pub fn describe_log_pattern(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_insights.describe_log_pattern\naws_api/application_insights describe_log_pattern","url":"aws_api/application_insights.html#describe_log_pattern"},{"doc":"aws_api/application_insights","title":"describe_observation","content":"pub fn describe_observation(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_insights.describe_observation\naws_api/application_insights describe_observation","url":"aws_api/application_insights.html#describe_observation"},{"doc":"aws_api/application_insights","title":"describe_problem","content":"pub fn describe_problem(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_insights.describe_problem\naws_api/application_insights describe_problem","url":"aws_api/application_insights.html#describe_problem"},{"doc":"aws_api/application_insights","title":"describe_problem_observations","content":"pub fn describe_problem_observations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_insights.describe_problem_observations\naws_api/application_insights describe_problem_observations","url":"aws_api/application_insights.html#describe_problem_observations"},{"doc":"aws_api/application_insights","title":"describe_workload","content":"pub fn describe_workload(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_insights.describe_workload\naws_api/application_insights describe_workload","url":"aws_api/application_insights.html#describe_workload"},{"doc":"aws_api/application_insights","title":"list_applications","content":"pub fn list_applications(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_insights.list_applications\naws_api/application_insights list_applications","url":"aws_api/application_insights.html#list_applications"},{"doc":"aws_api/application_insights","title":"list_components","content":"pub fn list_components(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_insights.list_components\naws_api/application_insights list_components","url":"aws_api/application_insights.html#list_components"},{"doc":"aws_api/application_insights","title":"list_configuration_history","content":"pub fn list_configuration_history(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_insights.list_configuration_history\naws_api/application_insights list_configuration_history","url":"aws_api/application_insights.html#list_configuration_history"},{"doc":"aws_api/application_insights","title":"list_log_pattern_sets","content":"pub fn list_log_pattern_sets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_insights.list_log_pattern_sets\naws_api/application_insights list_log_pattern_sets","url":"aws_api/application_insights.html#list_log_pattern_sets"},{"doc":"aws_api/application_insights","title":"list_log_patterns","content":"pub fn list_log_patterns(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_insights.list_log_patterns\naws_api/application_insights list_log_patterns","url":"aws_api/application_insights.html#list_log_patterns"},{"doc":"aws_api/application_insights","title":"list_problems","content":"pub fn list_problems(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_insights.list_problems\naws_api/application_insights list_problems","url":"aws_api/application_insights.html#list_problems"},{"doc":"aws_api/application_insights","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_insights.list_tags_for_resource\naws_api/application_insights list_tags_for_resource","url":"aws_api/application_insights.html#list_tags_for_resource"},{"doc":"aws_api/application_insights","title":"list_workloads","content":"pub fn list_workloads(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_insights.list_workloads\naws_api/application_insights list_workloads","url":"aws_api/application_insights.html#list_workloads"},{"doc":"aws_api/application_insights","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/application_insights.new\naws_api/application_insights new","url":"aws_api/application_insights.html#new"},{"doc":"aws_api/application_insights","title":"remove_workload","content":"pub fn remove_workload(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_insights.remove_workload\naws_api/application_insights remove_workload","url":"aws_api/application_insights.html#remove_workload"},{"doc":"aws_api/application_insights","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_insights.tag_resource\naws_api/application_insights tag_resource","url":"aws_api/application_insights.html#tag_resource"},{"doc":"aws_api/application_insights","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_insights.untag_resource\naws_api/application_insights untag_resource","url":"aws_api/application_insights.html#untag_resource"},{"doc":"aws_api/application_insights","title":"update_application","content":"pub fn update_application(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_insights.update_application\naws_api/application_insights update_application","url":"aws_api/application_insights.html#update_application"},{"doc":"aws_api/application_insights","title":"update_component","content":"pub fn update_component(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_insights.update_component\naws_api/application_insights update_component","url":"aws_api/application_insights.html#update_component"},{"doc":"aws_api/application_insights","title":"update_component_configuration","content":"pub fn update_component_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_insights.update_component_configuration\naws_api/application_insights update_component_configuration","url":"aws_api/application_insights.html#update_component_configuration"},{"doc":"aws_api/application_insights","title":"update_log_pattern","content":"pub fn update_log_pattern(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_insights.update_log_pattern\naws_api/application_insights update_log_pattern","url":"aws_api/application_insights.html#update_log_pattern"},{"doc":"aws_api/application_insights","title":"update_problem","content":"pub fn update_problem(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_insights.update_problem\naws_api/application_insights update_problem","url":"aws_api/application_insights.html#update_problem"},{"doc":"aws_api/application_insights","title":"update_workload","content":"pub fn update_workload(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/application_insights.update_workload\naws_api/application_insights update_workload","url":"aws_api/application_insights.html#update_workload"},{"doc":"aws_api/application_insights","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/application_insights.with_custom_endpoint\naws_api/application_insights with_custom_endpoint","url":"aws_api/application_insights.html#with_custom_endpoint"},{"doc":"aws_api/application_insights","title":"aws_api/application_insights","content":"","url":"aws_api/application_insights.html"},{"doc":"aws_api/apprunner","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/apprunner.Client\naws_api/apprunner Client","url":"aws_api/apprunner.html#Client"},{"doc":"aws_api/apprunner","title":"associate_custom_domain","content":"pub fn associate_custom_domain(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apprunner.associate_custom_domain\naws_api/apprunner associate_custom_domain","url":"aws_api/apprunner.html#associate_custom_domain"},{"doc":"aws_api/apprunner","title":"create_auto_scaling_configuration","content":"pub fn create_auto_scaling_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apprunner.create_auto_scaling_configuration\naws_api/apprunner create_auto_scaling_configuration","url":"aws_api/apprunner.html#create_auto_scaling_configuration"},{"doc":"aws_api/apprunner","title":"create_connection","content":"pub fn create_connection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apprunner.create_connection\naws_api/apprunner create_connection","url":"aws_api/apprunner.html#create_connection"},{"doc":"aws_api/apprunner","title":"create_observability_configuration","content":"pub fn create_observability_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apprunner.create_observability_configuration\naws_api/apprunner create_observability_configuration","url":"aws_api/apprunner.html#create_observability_configuration"},{"doc":"aws_api/apprunner","title":"create_service","content":"pub fn create_service(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apprunner.create_service\naws_api/apprunner create_service","url":"aws_api/apprunner.html#create_service"},{"doc":"aws_api/apprunner","title":"create_vpc_connector","content":"pub fn create_vpc_connector(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apprunner.create_vpc_connector\naws_api/apprunner create_vpc_connector","url":"aws_api/apprunner.html#create_vpc_connector"},{"doc":"aws_api/apprunner","title":"create_vpc_ingress_connection","content":"pub fn create_vpc_ingress_connection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apprunner.create_vpc_ingress_connection\naws_api/apprunner create_vpc_ingress_connection","url":"aws_api/apprunner.html#create_vpc_ingress_connection"},{"doc":"aws_api/apprunner","title":"delete_auto_scaling_configuration","content":"pub fn delete_auto_scaling_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apprunner.delete_auto_scaling_configuration\naws_api/apprunner delete_auto_scaling_configuration","url":"aws_api/apprunner.html#delete_auto_scaling_configuration"},{"doc":"aws_api/apprunner","title":"delete_connection","content":"pub fn delete_connection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apprunner.delete_connection\naws_api/apprunner delete_connection","url":"aws_api/apprunner.html#delete_connection"},{"doc":"aws_api/apprunner","title":"delete_observability_configuration","content":"pub fn delete_observability_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apprunner.delete_observability_configuration\naws_api/apprunner delete_observability_configuration","url":"aws_api/apprunner.html#delete_observability_configuration"},{"doc":"aws_api/apprunner","title":"delete_service","content":"pub fn delete_service(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apprunner.delete_service\naws_api/apprunner delete_service","url":"aws_api/apprunner.html#delete_service"},{"doc":"aws_api/apprunner","title":"delete_vpc_connector","content":"pub fn delete_vpc_connector(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apprunner.delete_vpc_connector\naws_api/apprunner delete_vpc_connector","url":"aws_api/apprunner.html#delete_vpc_connector"},{"doc":"aws_api/apprunner","title":"delete_vpc_ingress_connection","content":"pub fn delete_vpc_ingress_connection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apprunner.delete_vpc_ingress_connection\naws_api/apprunner delete_vpc_ingress_connection","url":"aws_api/apprunner.html#delete_vpc_ingress_connection"},{"doc":"aws_api/apprunner","title":"describe_auto_scaling_configuration","content":"pub fn describe_auto_scaling_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apprunner.describe_auto_scaling_configuration\naws_api/apprunner describe_auto_scaling_configuration","url":"aws_api/apprunner.html#describe_auto_scaling_configuration"},{"doc":"aws_api/apprunner","title":"describe_custom_domains","content":"pub fn describe_custom_domains(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apprunner.describe_custom_domains\naws_api/apprunner describe_custom_domains","url":"aws_api/apprunner.html#describe_custom_domains"},{"doc":"aws_api/apprunner","title":"describe_observability_configuration","content":"pub fn describe_observability_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apprunner.describe_observability_configuration\naws_api/apprunner describe_observability_configuration","url":"aws_api/apprunner.html#describe_observability_configuration"},{"doc":"aws_api/apprunner","title":"describe_service","content":"pub fn describe_service(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apprunner.describe_service\naws_api/apprunner describe_service","url":"aws_api/apprunner.html#describe_service"},{"doc":"aws_api/apprunner","title":"describe_vpc_connector","content":"pub fn describe_vpc_connector(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apprunner.describe_vpc_connector\naws_api/apprunner describe_vpc_connector","url":"aws_api/apprunner.html#describe_vpc_connector"},{"doc":"aws_api/apprunner","title":"describe_vpc_ingress_connection","content":"pub fn describe_vpc_ingress_connection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apprunner.describe_vpc_ingress_connection\naws_api/apprunner describe_vpc_ingress_connection","url":"aws_api/apprunner.html#describe_vpc_ingress_connection"},{"doc":"aws_api/apprunner","title":"disassociate_custom_domain","content":"pub fn disassociate_custom_domain(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apprunner.disassociate_custom_domain\naws_api/apprunner disassociate_custom_domain","url":"aws_api/apprunner.html#disassociate_custom_domain"},{"doc":"aws_api/apprunner","title":"list_auto_scaling_configurations","content":"pub fn list_auto_scaling_configurations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apprunner.list_auto_scaling_configurations\naws_api/apprunner list_auto_scaling_configurations","url":"aws_api/apprunner.html#list_auto_scaling_configurations"},{"doc":"aws_api/apprunner","title":"list_connections","content":"pub fn list_connections(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apprunner.list_connections\naws_api/apprunner list_connections","url":"aws_api/apprunner.html#list_connections"},{"doc":"aws_api/apprunner","title":"list_observability_configurations","content":"pub fn list_observability_configurations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apprunner.list_observability_configurations\naws_api/apprunner list_observability_configurations","url":"aws_api/apprunner.html#list_observability_configurations"},{"doc":"aws_api/apprunner","title":"list_operations","content":"pub fn list_operations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apprunner.list_operations\naws_api/apprunner list_operations","url":"aws_api/apprunner.html#list_operations"},{"doc":"aws_api/apprunner","title":"list_services","content":"pub fn list_services(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apprunner.list_services\naws_api/apprunner list_services","url":"aws_api/apprunner.html#list_services"},{"doc":"aws_api/apprunner","title":"list_services_for_auto_scaling_configuration","content":"pub fn list_services_for_auto_scaling_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apprunner.list_services_for_auto_scaling_configuration\naws_api/apprunner list_services_for_auto_scaling_configuration","url":"aws_api/apprunner.html#list_services_for_auto_scaling_configuration"},{"doc":"aws_api/apprunner","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apprunner.list_tags_for_resource\naws_api/apprunner list_tags_for_resource","url":"aws_api/apprunner.html#list_tags_for_resource"},{"doc":"aws_api/apprunner","title":"list_vpc_connectors","content":"pub fn list_vpc_connectors(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apprunner.list_vpc_connectors\naws_api/apprunner list_vpc_connectors","url":"aws_api/apprunner.html#list_vpc_connectors"},{"doc":"aws_api/apprunner","title":"list_vpc_ingress_connections","content":"pub fn list_vpc_ingress_connections(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apprunner.list_vpc_ingress_connections\naws_api/apprunner list_vpc_ingress_connections","url":"aws_api/apprunner.html#list_vpc_ingress_connections"},{"doc":"aws_api/apprunner","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/apprunner.new\naws_api/apprunner new","url":"aws_api/apprunner.html#new"},{"doc":"aws_api/apprunner","title":"pause_service","content":"pub fn pause_service(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apprunner.pause_service\naws_api/apprunner pause_service","url":"aws_api/apprunner.html#pause_service"},{"doc":"aws_api/apprunner","title":"resume_service","content":"pub fn resume_service(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apprunner.resume_service\naws_api/apprunner resume_service","url":"aws_api/apprunner.html#resume_service"},{"doc":"aws_api/apprunner","title":"start_deployment","content":"pub fn start_deployment(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apprunner.start_deployment\naws_api/apprunner start_deployment","url":"aws_api/apprunner.html#start_deployment"},{"doc":"aws_api/apprunner","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apprunner.tag_resource\naws_api/apprunner tag_resource","url":"aws_api/apprunner.html#tag_resource"},{"doc":"aws_api/apprunner","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apprunner.untag_resource\naws_api/apprunner untag_resource","url":"aws_api/apprunner.html#untag_resource"},{"doc":"aws_api/apprunner","title":"update_default_auto_scaling_configuration","content":"pub fn update_default_auto_scaling_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apprunner.update_default_auto_scaling_configuration\naws_api/apprunner update_default_auto_scaling_configuration","url":"aws_api/apprunner.html#update_default_auto_scaling_configuration"},{"doc":"aws_api/apprunner","title":"update_service","content":"pub fn update_service(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apprunner.update_service\naws_api/apprunner update_service","url":"aws_api/apprunner.html#update_service"},{"doc":"aws_api/apprunner","title":"update_vpc_ingress_connection","content":"pub fn update_vpc_ingress_connection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/apprunner.update_vpc_ingress_connection\naws_api/apprunner update_vpc_ingress_connection","url":"aws_api/apprunner.html#update_vpc_ingress_connection"},{"doc":"aws_api/apprunner","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/apprunner.with_custom_endpoint\naws_api/apprunner with_custom_endpoint","url":"aws_api/apprunner.html#with_custom_endpoint"},{"doc":"aws_api/apprunner","title":"aws_api/apprunner","content":"","url":"aws_api/apprunner.html"},{"doc":"aws_api/appstream","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/appstream.Client\naws_api/appstream Client","url":"aws_api/appstream.html#Client"},{"doc":"aws_api/appstream","title":"associate_app_block_builder_app_block","content":"pub fn associate_app_block_builder_app_block(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.associate_app_block_builder_app_block\naws_api/appstream associate_app_block_builder_app_block","url":"aws_api/appstream.html#associate_app_block_builder_app_block"},{"doc":"aws_api/appstream","title":"associate_application_fleet","content":"pub fn associate_application_fleet(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.associate_application_fleet\naws_api/appstream associate_application_fleet","url":"aws_api/appstream.html#associate_application_fleet"},{"doc":"aws_api/appstream","title":"associate_application_to_entitlement","content":"pub fn associate_application_to_entitlement(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.associate_application_to_entitlement\naws_api/appstream associate_application_to_entitlement","url":"aws_api/appstream.html#associate_application_to_entitlement"},{"doc":"aws_api/appstream","title":"associate_fleet","content":"pub fn associate_fleet(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.associate_fleet\naws_api/appstream associate_fleet","url":"aws_api/appstream.html#associate_fleet"},{"doc":"aws_api/appstream","title":"batch_associate_user_stack","content":"pub fn batch_associate_user_stack(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.batch_associate_user_stack\naws_api/appstream batch_associate_user_stack","url":"aws_api/appstream.html#batch_associate_user_stack"},{"doc":"aws_api/appstream","title":"batch_disassociate_user_stack","content":"pub fn batch_disassociate_user_stack(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.batch_disassociate_user_stack\naws_api/appstream batch_disassociate_user_stack","url":"aws_api/appstream.html#batch_disassociate_user_stack"},{"doc":"aws_api/appstream","title":"copy_image","content":"pub fn copy_image(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.copy_image\naws_api/appstream copy_image","url":"aws_api/appstream.html#copy_image"},{"doc":"aws_api/appstream","title":"create_app_block","content":"pub fn create_app_block(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.create_app_block\naws_api/appstream create_app_block","url":"aws_api/appstream.html#create_app_block"},{"doc":"aws_api/appstream","title":"create_app_block_builder","content":"pub fn create_app_block_builder(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.create_app_block_builder\naws_api/appstream create_app_block_builder","url":"aws_api/appstream.html#create_app_block_builder"},{"doc":"aws_api/appstream","title":"create_app_block_builder_streaming_url","content":"pub fn create_app_block_builder_streaming_url(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.create_app_block_builder_streaming_url\naws_api/appstream create_app_block_builder_streaming_url","url":"aws_api/appstream.html#create_app_block_builder_streaming_url"},{"doc":"aws_api/appstream","title":"create_application","content":"pub fn create_application(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.create_application\naws_api/appstream create_application","url":"aws_api/appstream.html#create_application"},{"doc":"aws_api/appstream","title":"create_directory_config","content":"pub fn create_directory_config(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.create_directory_config\naws_api/appstream create_directory_config","url":"aws_api/appstream.html#create_directory_config"},{"doc":"aws_api/appstream","title":"create_entitlement","content":"pub fn create_entitlement(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.create_entitlement\naws_api/appstream create_entitlement","url":"aws_api/appstream.html#create_entitlement"},{"doc":"aws_api/appstream","title":"create_fleet","content":"pub fn create_fleet(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.create_fleet\naws_api/appstream create_fleet","url":"aws_api/appstream.html#create_fleet"},{"doc":"aws_api/appstream","title":"create_image_builder","content":"pub fn create_image_builder(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.create_image_builder\naws_api/appstream create_image_builder","url":"aws_api/appstream.html#create_image_builder"},{"doc":"aws_api/appstream","title":"create_image_builder_streaming_url","content":"pub fn create_image_builder_streaming_url(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.create_image_builder_streaming_url\naws_api/appstream create_image_builder_streaming_url","url":"aws_api/appstream.html#create_image_builder_streaming_url"},{"doc":"aws_api/appstream","title":"create_stack","content":"pub fn create_stack(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.create_stack\naws_api/appstream create_stack","url":"aws_api/appstream.html#create_stack"},{"doc":"aws_api/appstream","title":"create_streaming_url","content":"pub fn create_streaming_url(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.create_streaming_url\naws_api/appstream create_streaming_url","url":"aws_api/appstream.html#create_streaming_url"},{"doc":"aws_api/appstream","title":"create_updated_image","content":"pub fn create_updated_image(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.create_updated_image\naws_api/appstream create_updated_image","url":"aws_api/appstream.html#create_updated_image"},{"doc":"aws_api/appstream","title":"create_usage_report_subscription","content":"pub fn create_usage_report_subscription(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.create_usage_report_subscription\naws_api/appstream create_usage_report_subscription","url":"aws_api/appstream.html#create_usage_report_subscription"},{"doc":"aws_api/appstream","title":"create_user","content":"pub fn create_user(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.create_user\naws_api/appstream create_user","url":"aws_api/appstream.html#create_user"},{"doc":"aws_api/appstream","title":"delete_app_block","content":"pub fn delete_app_block(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.delete_app_block\naws_api/appstream delete_app_block","url":"aws_api/appstream.html#delete_app_block"},{"doc":"aws_api/appstream","title":"delete_app_block_builder","content":"pub fn delete_app_block_builder(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.delete_app_block_builder\naws_api/appstream delete_app_block_builder","url":"aws_api/appstream.html#delete_app_block_builder"},{"doc":"aws_api/appstream","title":"delete_application","content":"pub fn delete_application(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.delete_application\naws_api/appstream delete_application","url":"aws_api/appstream.html#delete_application"},{"doc":"aws_api/appstream","title":"delete_directory_config","content":"pub fn delete_directory_config(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.delete_directory_config\naws_api/appstream delete_directory_config","url":"aws_api/appstream.html#delete_directory_config"},{"doc":"aws_api/appstream","title":"delete_entitlement","content":"pub fn delete_entitlement(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.delete_entitlement\naws_api/appstream delete_entitlement","url":"aws_api/appstream.html#delete_entitlement"},{"doc":"aws_api/appstream","title":"delete_fleet","content":"pub fn delete_fleet(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.delete_fleet\naws_api/appstream delete_fleet","url":"aws_api/appstream.html#delete_fleet"},{"doc":"aws_api/appstream","title":"delete_image","content":"pub fn delete_image(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.delete_image\naws_api/appstream delete_image","url":"aws_api/appstream.html#delete_image"},{"doc":"aws_api/appstream","title":"delete_image_builder","content":"pub fn delete_image_builder(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.delete_image_builder\naws_api/appstream delete_image_builder","url":"aws_api/appstream.html#delete_image_builder"},{"doc":"aws_api/appstream","title":"delete_image_permissions","content":"pub fn delete_image_permissions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.delete_image_permissions\naws_api/appstream delete_image_permissions","url":"aws_api/appstream.html#delete_image_permissions"},{"doc":"aws_api/appstream","title":"delete_stack","content":"pub fn delete_stack(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.delete_stack\naws_api/appstream delete_stack","url":"aws_api/appstream.html#delete_stack"},{"doc":"aws_api/appstream","title":"delete_usage_report_subscription","content":"pub fn delete_usage_report_subscription(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.delete_usage_report_subscription\naws_api/appstream delete_usage_report_subscription","url":"aws_api/appstream.html#delete_usage_report_subscription"},{"doc":"aws_api/appstream","title":"delete_user","content":"pub fn delete_user(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.delete_user\naws_api/appstream delete_user","url":"aws_api/appstream.html#delete_user"},{"doc":"aws_api/appstream","title":"describe_app_block_builder_app_block_associations","content":"pub fn describe_app_block_builder_app_block_associations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.describe_app_block_builder_app_block_associations\naws_api/appstream describe_app_block_builder_app_block_associations","url":"aws_api/appstream.html#describe_app_block_builder_app_block_associations"},{"doc":"aws_api/appstream","title":"describe_app_block_builders","content":"pub fn describe_app_block_builders(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.describe_app_block_builders\naws_api/appstream describe_app_block_builders","url":"aws_api/appstream.html#describe_app_block_builders"},{"doc":"aws_api/appstream","title":"describe_app_blocks","content":"pub fn describe_app_blocks(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.describe_app_blocks\naws_api/appstream describe_app_blocks","url":"aws_api/appstream.html#describe_app_blocks"},{"doc":"aws_api/appstream","title":"describe_application_fleet_associations","content":"pub fn describe_application_fleet_associations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.describe_application_fleet_associations\naws_api/appstream describe_application_fleet_associations","url":"aws_api/appstream.html#describe_application_fleet_associations"},{"doc":"aws_api/appstream","title":"describe_applications","content":"pub fn describe_applications(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.describe_applications\naws_api/appstream describe_applications","url":"aws_api/appstream.html#describe_applications"},{"doc":"aws_api/appstream","title":"describe_directory_configs","content":"pub fn describe_directory_configs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.describe_directory_configs\naws_api/appstream describe_directory_configs","url":"aws_api/appstream.html#describe_directory_configs"},{"doc":"aws_api/appstream","title":"describe_entitlements","content":"pub fn describe_entitlements(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.describe_entitlements\naws_api/appstream describe_entitlements","url":"aws_api/appstream.html#describe_entitlements"},{"doc":"aws_api/appstream","title":"describe_fleets","content":"pub fn describe_fleets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.describe_fleets\naws_api/appstream describe_fleets","url":"aws_api/appstream.html#describe_fleets"},{"doc":"aws_api/appstream","title":"describe_image_builders","content":"pub fn describe_image_builders(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.describe_image_builders\naws_api/appstream describe_image_builders","url":"aws_api/appstream.html#describe_image_builders"},{"doc":"aws_api/appstream","title":"describe_image_permissions","content":"pub fn describe_image_permissions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.describe_image_permissions\naws_api/appstream describe_image_permissions","url":"aws_api/appstream.html#describe_image_permissions"},{"doc":"aws_api/appstream","title":"describe_images","content":"pub fn describe_images(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.describe_images\naws_api/appstream describe_images","url":"aws_api/appstream.html#describe_images"},{"doc":"aws_api/appstream","title":"describe_sessions","content":"pub fn describe_sessions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.describe_sessions\naws_api/appstream describe_sessions","url":"aws_api/appstream.html#describe_sessions"},{"doc":"aws_api/appstream","title":"describe_stacks","content":"pub fn describe_stacks(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.describe_stacks\naws_api/appstream describe_stacks","url":"aws_api/appstream.html#describe_stacks"},{"doc":"aws_api/appstream","title":"describe_usage_report_subscriptions","content":"pub fn describe_usage_report_subscriptions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.describe_usage_report_subscriptions\naws_api/appstream describe_usage_report_subscriptions","url":"aws_api/appstream.html#describe_usage_report_subscriptions"},{"doc":"aws_api/appstream","title":"describe_user_stack_associations","content":"pub fn describe_user_stack_associations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.describe_user_stack_associations\naws_api/appstream describe_user_stack_associations","url":"aws_api/appstream.html#describe_user_stack_associations"},{"doc":"aws_api/appstream","title":"describe_users","content":"pub fn describe_users(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.describe_users\naws_api/appstream describe_users","url":"aws_api/appstream.html#describe_users"},{"doc":"aws_api/appstream","title":"disable_user","content":"pub fn disable_user(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.disable_user\naws_api/appstream disable_user","url":"aws_api/appstream.html#disable_user"},{"doc":"aws_api/appstream","title":"disassociate_app_block_builder_app_block","content":"pub fn disassociate_app_block_builder_app_block(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.disassociate_app_block_builder_app_block\naws_api/appstream disassociate_app_block_builder_app_block","url":"aws_api/appstream.html#disassociate_app_block_builder_app_block"},{"doc":"aws_api/appstream","title":"disassociate_application_fleet","content":"pub fn disassociate_application_fleet(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.disassociate_application_fleet\naws_api/appstream disassociate_application_fleet","url":"aws_api/appstream.html#disassociate_application_fleet"},{"doc":"aws_api/appstream","title":"disassociate_application_from_entitlement","content":"pub fn disassociate_application_from_entitlement(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.disassociate_application_from_entitlement\naws_api/appstream disassociate_application_from_entitlement","url":"aws_api/appstream.html#disassociate_application_from_entitlement"},{"doc":"aws_api/appstream","title":"disassociate_fleet","content":"pub fn disassociate_fleet(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.disassociate_fleet\naws_api/appstream disassociate_fleet","url":"aws_api/appstream.html#disassociate_fleet"},{"doc":"aws_api/appstream","title":"enable_user","content":"pub fn enable_user(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.enable_user\naws_api/appstream enable_user","url":"aws_api/appstream.html#enable_user"},{"doc":"aws_api/appstream","title":"expire_session","content":"pub fn expire_session(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.expire_session\naws_api/appstream expire_session","url":"aws_api/appstream.html#expire_session"},{"doc":"aws_api/appstream","title":"list_associated_fleets","content":"pub fn list_associated_fleets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.list_associated_fleets\naws_api/appstream list_associated_fleets","url":"aws_api/appstream.html#list_associated_fleets"},{"doc":"aws_api/appstream","title":"list_associated_stacks","content":"pub fn list_associated_stacks(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.list_associated_stacks\naws_api/appstream list_associated_stacks","url":"aws_api/appstream.html#list_associated_stacks"},{"doc":"aws_api/appstream","title":"list_entitled_applications","content":"pub fn list_entitled_applications(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.list_entitled_applications\naws_api/appstream list_entitled_applications","url":"aws_api/appstream.html#list_entitled_applications"},{"doc":"aws_api/appstream","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.list_tags_for_resource\naws_api/appstream list_tags_for_resource","url":"aws_api/appstream.html#list_tags_for_resource"},{"doc":"aws_api/appstream","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/appstream.new\naws_api/appstream new","url":"aws_api/appstream.html#new"},{"doc":"aws_api/appstream","title":"start_app_block_builder","content":"pub fn start_app_block_builder(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.start_app_block_builder\naws_api/appstream start_app_block_builder","url":"aws_api/appstream.html#start_app_block_builder"},{"doc":"aws_api/appstream","title":"start_fleet","content":"pub fn start_fleet(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.start_fleet\naws_api/appstream start_fleet","url":"aws_api/appstream.html#start_fleet"},{"doc":"aws_api/appstream","title":"start_image_builder","content":"pub fn start_image_builder(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.start_image_builder\naws_api/appstream start_image_builder","url":"aws_api/appstream.html#start_image_builder"},{"doc":"aws_api/appstream","title":"stop_app_block_builder","content":"pub fn stop_app_block_builder(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.stop_app_block_builder\naws_api/appstream stop_app_block_builder","url":"aws_api/appstream.html#stop_app_block_builder"},{"doc":"aws_api/appstream","title":"stop_fleet","content":"pub fn stop_fleet(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.stop_fleet\naws_api/appstream stop_fleet","url":"aws_api/appstream.html#stop_fleet"},{"doc":"aws_api/appstream","title":"stop_image_builder","content":"pub fn stop_image_builder(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.stop_image_builder\naws_api/appstream stop_image_builder","url":"aws_api/appstream.html#stop_image_builder"},{"doc":"aws_api/appstream","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.tag_resource\naws_api/appstream tag_resource","url":"aws_api/appstream.html#tag_resource"},{"doc":"aws_api/appstream","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.untag_resource\naws_api/appstream untag_resource","url":"aws_api/appstream.html#untag_resource"},{"doc":"aws_api/appstream","title":"update_app_block_builder","content":"pub fn update_app_block_builder(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.update_app_block_builder\naws_api/appstream update_app_block_builder","url":"aws_api/appstream.html#update_app_block_builder"},{"doc":"aws_api/appstream","title":"update_application","content":"pub fn update_application(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.update_application\naws_api/appstream update_application","url":"aws_api/appstream.html#update_application"},{"doc":"aws_api/appstream","title":"update_directory_config","content":"pub fn update_directory_config(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.update_directory_config\naws_api/appstream update_directory_config","url":"aws_api/appstream.html#update_directory_config"},{"doc":"aws_api/appstream","title":"update_entitlement","content":"pub fn update_entitlement(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.update_entitlement\naws_api/appstream update_entitlement","url":"aws_api/appstream.html#update_entitlement"},{"doc":"aws_api/appstream","title":"update_fleet","content":"pub fn update_fleet(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.update_fleet\naws_api/appstream update_fleet","url":"aws_api/appstream.html#update_fleet"},{"doc":"aws_api/appstream","title":"update_image_permissions","content":"pub fn update_image_permissions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.update_image_permissions\naws_api/appstream update_image_permissions","url":"aws_api/appstream.html#update_image_permissions"},{"doc":"aws_api/appstream","title":"update_stack","content":"pub fn update_stack(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appstream.update_stack\naws_api/appstream update_stack","url":"aws_api/appstream.html#update_stack"},{"doc":"aws_api/appstream","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/appstream.with_custom_endpoint\naws_api/appstream with_custom_endpoint","url":"aws_api/appstream.html#with_custom_endpoint"},{"doc":"aws_api/appstream","title":"aws_api/appstream","content":"","url":"aws_api/appstream.html"},{"doc":"aws_api/appsync","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/appsync.Client\naws_api/appsync Client","url":"aws_api/appsync.html#Client"},{"doc":"aws_api/appsync","title":"associate_api","content":"pub fn associate_api(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.associate_api\naws_api/appsync associate_api","url":"aws_api/appsync.html#associate_api"},{"doc":"aws_api/appsync","title":"associate_merged_graphql_api","content":"pub fn associate_merged_graphql_api(\n  client: Client,\n  source_api_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.associate_merged_graphql_api\naws_api/appsync associate_merged_graphql_api","url":"aws_api/appsync.html#associate_merged_graphql_api"},{"doc":"aws_api/appsync","title":"associate_source_graphql_api","content":"pub fn associate_source_graphql_api(\n  client: Client,\n  merged_api_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.associate_source_graphql_api\naws_api/appsync associate_source_graphql_api","url":"aws_api/appsync.html#associate_source_graphql_api"},{"doc":"aws_api/appsync","title":"create_api_cache","content":"pub fn create_api_cache(\n  client: Client,\n  api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.create_api_cache\naws_api/appsync create_api_cache","url":"aws_api/appsync.html#create_api_cache"},{"doc":"aws_api/appsync","title":"create_api_key","content":"pub fn create_api_key(\n  client: Client,\n  api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.create_api_key\naws_api/appsync create_api_key","url":"aws_api/appsync.html#create_api_key"},{"doc":"aws_api/appsync","title":"create_data_source","content":"pub fn create_data_source(\n  client: Client,\n  api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.create_data_source\naws_api/appsync create_data_source","url":"aws_api/appsync.html#create_data_source"},{"doc":"aws_api/appsync","title":"create_domain_name","content":"pub fn create_domain_name(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.create_domain_name\naws_api/appsync create_domain_name","url":"aws_api/appsync.html#create_domain_name"},{"doc":"aws_api/appsync","title":"create_function","content":"pub fn create_function(\n  client: Client,\n  api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.create_function\naws_api/appsync create_function","url":"aws_api/appsync.html#create_function"},{"doc":"aws_api/appsync","title":"create_graphql_api","content":"pub fn create_graphql_api(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.create_graphql_api\naws_api/appsync create_graphql_api","url":"aws_api/appsync.html#create_graphql_api"},{"doc":"aws_api/appsync","title":"create_resolver","content":"pub fn create_resolver(\n  client: Client,\n  api_id: String,\n  type_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.create_resolver\naws_api/appsync create_resolver","url":"aws_api/appsync.html#create_resolver"},{"doc":"aws_api/appsync","title":"create_type","content":"pub fn create_type(\n  client: Client,\n  api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.create_type\naws_api/appsync create_type","url":"aws_api/appsync.html#create_type"},{"doc":"aws_api/appsync","title":"delete_api_cache","content":"pub fn delete_api_cache(\n  client: Client,\n  api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.delete_api_cache\naws_api/appsync delete_api_cache","url":"aws_api/appsync.html#delete_api_cache"},{"doc":"aws_api/appsync","title":"delete_api_key","content":"pub fn delete_api_key(\n  client: Client,\n  api_id: String,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.delete_api_key\naws_api/appsync delete_api_key","url":"aws_api/appsync.html#delete_api_key"},{"doc":"aws_api/appsync","title":"delete_data_source","content":"pub fn delete_data_source(\n  client: Client,\n  api_id: String,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.delete_data_source\naws_api/appsync delete_data_source","url":"aws_api/appsync.html#delete_data_source"},{"doc":"aws_api/appsync","title":"delete_domain_name","content":"pub fn delete_domain_name(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.delete_domain_name\naws_api/appsync delete_domain_name","url":"aws_api/appsync.html#delete_domain_name"},{"doc":"aws_api/appsync","title":"delete_function","content":"pub fn delete_function(\n  client: Client,\n  api_id: String,\n  function_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.delete_function\naws_api/appsync delete_function","url":"aws_api/appsync.html#delete_function"},{"doc":"aws_api/appsync","title":"delete_graphql_api","content":"pub fn delete_graphql_api(\n  client: Client,\n  api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.delete_graphql_api\naws_api/appsync delete_graphql_api","url":"aws_api/appsync.html#delete_graphql_api"},{"doc":"aws_api/appsync","title":"delete_resolver","content":"pub fn delete_resolver(\n  client: Client,\n  api_id: String,\n  type_name: String,\n  field_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.delete_resolver\naws_api/appsync delete_resolver","url":"aws_api/appsync.html#delete_resolver"},{"doc":"aws_api/appsync","title":"delete_type","content":"pub fn delete_type(\n  client: Client,\n  api_id: String,\n  type_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.delete_type\naws_api/appsync delete_type","url":"aws_api/appsync.html#delete_type"},{"doc":"aws_api/appsync","title":"disassociate_api","content":"pub fn disassociate_api(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.disassociate_api\naws_api/appsync disassociate_api","url":"aws_api/appsync.html#disassociate_api"},{"doc":"aws_api/appsync","title":"disassociate_merged_graphql_api","content":"pub fn disassociate_merged_graphql_api(\n  client: Client,\n  source_api_identifier: String,\n  association_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.disassociate_merged_graphql_api\naws_api/appsync disassociate_merged_graphql_api","url":"aws_api/appsync.html#disassociate_merged_graphql_api"},{"doc":"aws_api/appsync","title":"disassociate_source_graphql_api","content":"pub fn disassociate_source_graphql_api(\n  client: Client,\n  merged_api_identifier: String,\n  association_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.disassociate_source_graphql_api\naws_api/appsync disassociate_source_graphql_api","url":"aws_api/appsync.html#disassociate_source_graphql_api"},{"doc":"aws_api/appsync","title":"evaluate_code","content":"pub fn evaluate_code(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.evaluate_code\naws_api/appsync evaluate_code","url":"aws_api/appsync.html#evaluate_code"},{"doc":"aws_api/appsync","title":"evaluate_mapping_template","content":"pub fn evaluate_mapping_template(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.evaluate_mapping_template\naws_api/appsync evaluate_mapping_template","url":"aws_api/appsync.html#evaluate_mapping_template"},{"doc":"aws_api/appsync","title":"flush_api_cache","content":"pub fn flush_api_cache(\n  client: Client,\n  api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.flush_api_cache\naws_api/appsync flush_api_cache","url":"aws_api/appsync.html#flush_api_cache"},{"doc":"aws_api/appsync","title":"get_api_association","content":"pub fn get_api_association(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.get_api_association\naws_api/appsync get_api_association","url":"aws_api/appsync.html#get_api_association"},{"doc":"aws_api/appsync","title":"get_api_cache","content":"pub fn get_api_cache(\n  client: Client,\n  api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.get_api_cache\naws_api/appsync get_api_cache","url":"aws_api/appsync.html#get_api_cache"},{"doc":"aws_api/appsync","title":"get_data_source","content":"pub fn get_data_source(\n  client: Client,\n  api_id: String,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.get_data_source\naws_api/appsync get_data_source","url":"aws_api/appsync.html#get_data_source"},{"doc":"aws_api/appsync","title":"get_data_source_introspection","content":"pub fn get_data_source_introspection(\n  client: Client,\n  introspection_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.get_data_source_introspection\naws_api/appsync get_data_source_introspection","url":"aws_api/appsync.html#get_data_source_introspection"},{"doc":"aws_api/appsync","title":"get_domain_name","content":"pub fn get_domain_name(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.get_domain_name\naws_api/appsync get_domain_name","url":"aws_api/appsync.html#get_domain_name"},{"doc":"aws_api/appsync","title":"get_function","content":"pub fn get_function(\n  client: Client,\n  api_id: String,\n  function_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.get_function\naws_api/appsync get_function","url":"aws_api/appsync.html#get_function"},{"doc":"aws_api/appsync","title":"get_graphql_api","content":"pub fn get_graphql_api(\n  client: Client,\n  api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.get_graphql_api\naws_api/appsync get_graphql_api","url":"aws_api/appsync.html#get_graphql_api"},{"doc":"aws_api/appsync","title":"get_graphql_api_environment_variables","content":"pub fn get_graphql_api_environment_variables(\n  client: Client,\n  api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.get_graphql_api_environment_variables\naws_api/appsync get_graphql_api_environment_variables","url":"aws_api/appsync.html#get_graphql_api_environment_variables"},{"doc":"aws_api/appsync","title":"get_introspection_schema","content":"pub fn get_introspection_schema(\n  client: Client,\n  api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.get_introspection_schema\naws_api/appsync get_introspection_schema","url":"aws_api/appsync.html#get_introspection_schema"},{"doc":"aws_api/appsync","title":"get_resolver","content":"pub fn get_resolver(\n  client: Client,\n  api_id: String,\n  type_name: String,\n  field_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.get_resolver\naws_api/appsync get_resolver","url":"aws_api/appsync.html#get_resolver"},{"doc":"aws_api/appsync","title":"get_schema_creation_status","content":"pub fn get_schema_creation_status(\n  client: Client,\n  api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.get_schema_creation_status\naws_api/appsync get_schema_creation_status","url":"aws_api/appsync.html#get_schema_creation_status"},{"doc":"aws_api/appsync","title":"get_source_api_association","content":"pub fn get_source_api_association(\n  client: Client,\n  merged_api_identifier: String,\n  association_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.get_source_api_association\naws_api/appsync get_source_api_association","url":"aws_api/appsync.html#get_source_api_association"},{"doc":"aws_api/appsync","title":"get_type","content":"pub fn get_type(\n  client: Client,\n  api_id: String,\n  type_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.get_type\naws_api/appsync get_type","url":"aws_api/appsync.html#get_type"},{"doc":"aws_api/appsync","title":"list_api_keys","content":"pub fn list_api_keys(\n  client: Client,\n  api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.list_api_keys\naws_api/appsync list_api_keys","url":"aws_api/appsync.html#list_api_keys"},{"doc":"aws_api/appsync","title":"list_data_sources","content":"pub fn list_data_sources(\n  client: Client,\n  api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.list_data_sources\naws_api/appsync list_data_sources","url":"aws_api/appsync.html#list_data_sources"},{"doc":"aws_api/appsync","title":"list_domain_names","content":"pub fn list_domain_names(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.list_domain_names\naws_api/appsync list_domain_names","url":"aws_api/appsync.html#list_domain_names"},{"doc":"aws_api/appsync","title":"list_functions","content":"pub fn list_functions(\n  client: Client,\n  api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.list_functions\naws_api/appsync list_functions","url":"aws_api/appsync.html#list_functions"},{"doc":"aws_api/appsync","title":"list_graphql_apis","content":"pub fn list_graphql_apis(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.list_graphql_apis\naws_api/appsync list_graphql_apis","url":"aws_api/appsync.html#list_graphql_apis"},{"doc":"aws_api/appsync","title":"list_resolvers","content":"pub fn list_resolvers(\n  client: Client,\n  api_id: String,\n  type_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.list_resolvers\naws_api/appsync list_resolvers","url":"aws_api/appsync.html#list_resolvers"},{"doc":"aws_api/appsync","title":"list_resolvers_by_function","content":"pub fn list_resolvers_by_function(\n  client: Client,\n  api_id: String,\n  function_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.list_resolvers_by_function\naws_api/appsync list_resolvers_by_function","url":"aws_api/appsync.html#list_resolvers_by_function"},{"doc":"aws_api/appsync","title":"list_source_api_associations","content":"pub fn list_source_api_associations(\n  client: Client,\n  api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.list_source_api_associations\naws_api/appsync list_source_api_associations","url":"aws_api/appsync.html#list_source_api_associations"},{"doc":"aws_api/appsync","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.list_tags_for_resource\naws_api/appsync list_tags_for_resource","url":"aws_api/appsync.html#list_tags_for_resource"},{"doc":"aws_api/appsync","title":"list_types","content":"pub fn list_types(\n  client: Client,\n  api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.list_types\naws_api/appsync list_types","url":"aws_api/appsync.html#list_types"},{"doc":"aws_api/appsync","title":"list_types_by_association","content":"pub fn list_types_by_association(\n  client: Client,\n  merged_api_identifier: String,\n  association_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.list_types_by_association\naws_api/appsync list_types_by_association","url":"aws_api/appsync.html#list_types_by_association"},{"doc":"aws_api/appsync","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/appsync.new\naws_api/appsync new","url":"aws_api/appsync.html#new"},{"doc":"aws_api/appsync","title":"put_graphql_api_environment_variables","content":"pub fn put_graphql_api_environment_variables(\n  client: Client,\n  api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.put_graphql_api_environment_variables\naws_api/appsync put_graphql_api_environment_variables","url":"aws_api/appsync.html#put_graphql_api_environment_variables"},{"doc":"aws_api/appsync","title":"start_data_source_introspection","content":"pub fn start_data_source_introspection(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.start_data_source_introspection\naws_api/appsync start_data_source_introspection","url":"aws_api/appsync.html#start_data_source_introspection"},{"doc":"aws_api/appsync","title":"start_schema_creation","content":"pub fn start_schema_creation(\n  client: Client,\n  api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.start_schema_creation\naws_api/appsync start_schema_creation","url":"aws_api/appsync.html#start_schema_creation"},{"doc":"aws_api/appsync","title":"start_schema_merge","content":"pub fn start_schema_merge(\n  client: Client,\n  merged_api_identifier: String,\n  association_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.start_schema_merge\naws_api/appsync start_schema_merge","url":"aws_api/appsync.html#start_schema_merge"},{"doc":"aws_api/appsync","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.tag_resource\naws_api/appsync tag_resource","url":"aws_api/appsync.html#tag_resource"},{"doc":"aws_api/appsync","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.untag_resource\naws_api/appsync untag_resource","url":"aws_api/appsync.html#untag_resource"},{"doc":"aws_api/appsync","title":"update_api_cache","content":"pub fn update_api_cache(\n  client: Client,\n  api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.update_api_cache\naws_api/appsync update_api_cache","url":"aws_api/appsync.html#update_api_cache"},{"doc":"aws_api/appsync","title":"update_api_key","content":"pub fn update_api_key(\n  client: Client,\n  api_id: String,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.update_api_key\naws_api/appsync update_api_key","url":"aws_api/appsync.html#update_api_key"},{"doc":"aws_api/appsync","title":"update_data_source","content":"pub fn update_data_source(\n  client: Client,\n  api_id: String,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.update_data_source\naws_api/appsync update_data_source","url":"aws_api/appsync.html#update_data_source"},{"doc":"aws_api/appsync","title":"update_domain_name","content":"pub fn update_domain_name(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.update_domain_name\naws_api/appsync update_domain_name","url":"aws_api/appsync.html#update_domain_name"},{"doc":"aws_api/appsync","title":"update_function","content":"pub fn update_function(\n  client: Client,\n  api_id: String,\n  function_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.update_function\naws_api/appsync update_function","url":"aws_api/appsync.html#update_function"},{"doc":"aws_api/appsync","title":"update_graphql_api","content":"pub fn update_graphql_api(\n  client: Client,\n  api_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.update_graphql_api\naws_api/appsync update_graphql_api","url":"aws_api/appsync.html#update_graphql_api"},{"doc":"aws_api/appsync","title":"update_resolver","content":"pub fn update_resolver(\n  client: Client,\n  api_id: String,\n  type_name: String,\n  field_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.update_resolver\naws_api/appsync update_resolver","url":"aws_api/appsync.html#update_resolver"},{"doc":"aws_api/appsync","title":"update_source_api_association","content":"pub fn update_source_api_association(\n  client: Client,\n  merged_api_identifier: String,\n  association_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.update_source_api_association\naws_api/appsync update_source_api_association","url":"aws_api/appsync.html#update_source_api_association"},{"doc":"aws_api/appsync","title":"update_type","content":"pub fn update_type(\n  client: Client,\n  api_id: String,\n  type_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/appsync.update_type\naws_api/appsync update_type","url":"aws_api/appsync.html#update_type"},{"doc":"aws_api/appsync","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/appsync.with_custom_endpoint\naws_api/appsync with_custom_endpoint","url":"aws_api/appsync.html#with_custom_endpoint"},{"doc":"aws_api/appsync","title":"aws_api/appsync","content":"","url":"aws_api/appsync.html"},{"doc":"aws_api/athena","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/athena.Client\naws_api/athena Client","url":"aws_api/athena.html#Client"},{"doc":"aws_api/athena","title":"batch_get_named_query","content":"pub fn batch_get_named_query(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.batch_get_named_query\naws_api/athena batch_get_named_query","url":"aws_api/athena.html#batch_get_named_query"},{"doc":"aws_api/athena","title":"batch_get_prepared_statement","content":"pub fn batch_get_prepared_statement(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.batch_get_prepared_statement\naws_api/athena batch_get_prepared_statement","url":"aws_api/athena.html#batch_get_prepared_statement"},{"doc":"aws_api/athena","title":"batch_get_query_execution","content":"pub fn batch_get_query_execution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.batch_get_query_execution\naws_api/athena batch_get_query_execution","url":"aws_api/athena.html#batch_get_query_execution"},{"doc":"aws_api/athena","title":"cancel_capacity_reservation","content":"pub fn cancel_capacity_reservation(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.cancel_capacity_reservation\naws_api/athena cancel_capacity_reservation","url":"aws_api/athena.html#cancel_capacity_reservation"},{"doc":"aws_api/athena","title":"create_capacity_reservation","content":"pub fn create_capacity_reservation(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.create_capacity_reservation\naws_api/athena create_capacity_reservation","url":"aws_api/athena.html#create_capacity_reservation"},{"doc":"aws_api/athena","title":"create_data_catalog","content":"pub fn create_data_catalog(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.create_data_catalog\naws_api/athena create_data_catalog","url":"aws_api/athena.html#create_data_catalog"},{"doc":"aws_api/athena","title":"create_named_query","content":"pub fn create_named_query(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.create_named_query\naws_api/athena create_named_query","url":"aws_api/athena.html#create_named_query"},{"doc":"aws_api/athena","title":"create_notebook","content":"pub fn create_notebook(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.create_notebook\naws_api/athena create_notebook","url":"aws_api/athena.html#create_notebook"},{"doc":"aws_api/athena","title":"create_prepared_statement","content":"pub fn create_prepared_statement(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.create_prepared_statement\naws_api/athena create_prepared_statement","url":"aws_api/athena.html#create_prepared_statement"},{"doc":"aws_api/athena","title":"create_presigned_notebook_url","content":"pub fn create_presigned_notebook_url(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.create_presigned_notebook_url\naws_api/athena create_presigned_notebook_url","url":"aws_api/athena.html#create_presigned_notebook_url"},{"doc":"aws_api/athena","title":"create_work_group","content":"pub fn create_work_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.create_work_group\naws_api/athena create_work_group","url":"aws_api/athena.html#create_work_group"},{"doc":"aws_api/athena","title":"delete_capacity_reservation","content":"pub fn delete_capacity_reservation(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.delete_capacity_reservation\naws_api/athena delete_capacity_reservation","url":"aws_api/athena.html#delete_capacity_reservation"},{"doc":"aws_api/athena","title":"delete_data_catalog","content":"pub fn delete_data_catalog(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.delete_data_catalog\naws_api/athena delete_data_catalog","url":"aws_api/athena.html#delete_data_catalog"},{"doc":"aws_api/athena","title":"delete_named_query","content":"pub fn delete_named_query(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.delete_named_query\naws_api/athena delete_named_query","url":"aws_api/athena.html#delete_named_query"},{"doc":"aws_api/athena","title":"delete_notebook","content":"pub fn delete_notebook(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.delete_notebook\naws_api/athena delete_notebook","url":"aws_api/athena.html#delete_notebook"},{"doc":"aws_api/athena","title":"delete_prepared_statement","content":"pub fn delete_prepared_statement(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.delete_prepared_statement\naws_api/athena delete_prepared_statement","url":"aws_api/athena.html#delete_prepared_statement"},{"doc":"aws_api/athena","title":"delete_work_group","content":"pub fn delete_work_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.delete_work_group\naws_api/athena delete_work_group","url":"aws_api/athena.html#delete_work_group"},{"doc":"aws_api/athena","title":"export_notebook","content":"pub fn export_notebook(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.export_notebook\naws_api/athena export_notebook","url":"aws_api/athena.html#export_notebook"},{"doc":"aws_api/athena","title":"get_calculation_execution","content":"pub fn get_calculation_execution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.get_calculation_execution\naws_api/athena get_calculation_execution","url":"aws_api/athena.html#get_calculation_execution"},{"doc":"aws_api/athena","title":"get_calculation_execution_code","content":"pub fn get_calculation_execution_code(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.get_calculation_execution_code\naws_api/athena get_calculation_execution_code","url":"aws_api/athena.html#get_calculation_execution_code"},{"doc":"aws_api/athena","title":"get_calculation_execution_status","content":"pub fn get_calculation_execution_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.get_calculation_execution_status\naws_api/athena get_calculation_execution_status","url":"aws_api/athena.html#get_calculation_execution_status"},{"doc":"aws_api/athena","title":"get_capacity_assignment_configuration","content":"pub fn get_capacity_assignment_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.get_capacity_assignment_configuration\naws_api/athena get_capacity_assignment_configuration","url":"aws_api/athena.html#get_capacity_assignment_configuration"},{"doc":"aws_api/athena","title":"get_capacity_reservation","content":"pub fn get_capacity_reservation(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.get_capacity_reservation\naws_api/athena get_capacity_reservation","url":"aws_api/athena.html#get_capacity_reservation"},{"doc":"aws_api/athena","title":"get_data_catalog","content":"pub fn get_data_catalog(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.get_data_catalog\naws_api/athena get_data_catalog","url":"aws_api/athena.html#get_data_catalog"},{"doc":"aws_api/athena","title":"get_database","content":"pub fn get_database(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.get_database\naws_api/athena get_database","url":"aws_api/athena.html#get_database"},{"doc":"aws_api/athena","title":"get_named_query","content":"pub fn get_named_query(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.get_named_query\naws_api/athena get_named_query","url":"aws_api/athena.html#get_named_query"},{"doc":"aws_api/athena","title":"get_notebook_metadata","content":"pub fn get_notebook_metadata(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.get_notebook_metadata\naws_api/athena get_notebook_metadata","url":"aws_api/athena.html#get_notebook_metadata"},{"doc":"aws_api/athena","title":"get_prepared_statement","content":"pub fn get_prepared_statement(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.get_prepared_statement\naws_api/athena get_prepared_statement","url":"aws_api/athena.html#get_prepared_statement"},{"doc":"aws_api/athena","title":"get_query_execution","content":"pub fn get_query_execution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.get_query_execution\naws_api/athena get_query_execution","url":"aws_api/athena.html#get_query_execution"},{"doc":"aws_api/athena","title":"get_query_results","content":"pub fn get_query_results(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.get_query_results\naws_api/athena get_query_results","url":"aws_api/athena.html#get_query_results"},{"doc":"aws_api/athena","title":"get_query_runtime_statistics","content":"pub fn get_query_runtime_statistics(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.get_query_runtime_statistics\naws_api/athena get_query_runtime_statistics","url":"aws_api/athena.html#get_query_runtime_statistics"},{"doc":"aws_api/athena","title":"get_session","content":"pub fn get_session(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.get_session\naws_api/athena get_session","url":"aws_api/athena.html#get_session"},{"doc":"aws_api/athena","title":"get_session_status","content":"pub fn get_session_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.get_session_status\naws_api/athena get_session_status","url":"aws_api/athena.html#get_session_status"},{"doc":"aws_api/athena","title":"get_table_metadata","content":"pub fn get_table_metadata(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.get_table_metadata\naws_api/athena get_table_metadata","url":"aws_api/athena.html#get_table_metadata"},{"doc":"aws_api/athena","title":"get_work_group","content":"pub fn get_work_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.get_work_group\naws_api/athena get_work_group","url":"aws_api/athena.html#get_work_group"},{"doc":"aws_api/athena","title":"import_notebook","content":"pub fn import_notebook(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.import_notebook\naws_api/athena import_notebook","url":"aws_api/athena.html#import_notebook"},{"doc":"aws_api/athena","title":"list_application_dpu_sizes","content":"pub fn list_application_dpu_sizes(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.list_application_dpu_sizes\naws_api/athena list_application_dpu_sizes","url":"aws_api/athena.html#list_application_dpu_sizes"},{"doc":"aws_api/athena","title":"list_calculation_executions","content":"pub fn list_calculation_executions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.list_calculation_executions\naws_api/athena list_calculation_executions","url":"aws_api/athena.html#list_calculation_executions"},{"doc":"aws_api/athena","title":"list_capacity_reservations","content":"pub fn list_capacity_reservations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.list_capacity_reservations\naws_api/athena list_capacity_reservations","url":"aws_api/athena.html#list_capacity_reservations"},{"doc":"aws_api/athena","title":"list_data_catalogs","content":"pub fn list_data_catalogs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.list_data_catalogs\naws_api/athena list_data_catalogs","url":"aws_api/athena.html#list_data_catalogs"},{"doc":"aws_api/athena","title":"list_databases","content":"pub fn list_databases(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.list_databases\naws_api/athena list_databases","url":"aws_api/athena.html#list_databases"},{"doc":"aws_api/athena","title":"list_engine_versions","content":"pub fn list_engine_versions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.list_engine_versions\naws_api/athena list_engine_versions","url":"aws_api/athena.html#list_engine_versions"},{"doc":"aws_api/athena","title":"list_executors","content":"pub fn list_executors(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.list_executors\naws_api/athena list_executors","url":"aws_api/athena.html#list_executors"},{"doc":"aws_api/athena","title":"list_named_queries","content":"pub fn list_named_queries(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.list_named_queries\naws_api/athena list_named_queries","url":"aws_api/athena.html#list_named_queries"},{"doc":"aws_api/athena","title":"list_notebook_metadata","content":"pub fn list_notebook_metadata(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.list_notebook_metadata\naws_api/athena list_notebook_metadata","url":"aws_api/athena.html#list_notebook_metadata"},{"doc":"aws_api/athena","title":"list_notebook_sessions","content":"pub fn list_notebook_sessions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.list_notebook_sessions\naws_api/athena list_notebook_sessions","url":"aws_api/athena.html#list_notebook_sessions"},{"doc":"aws_api/athena","title":"list_prepared_statements","content":"pub fn list_prepared_statements(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.list_prepared_statements\naws_api/athena list_prepared_statements","url":"aws_api/athena.html#list_prepared_statements"},{"doc":"aws_api/athena","title":"list_query_executions","content":"pub fn list_query_executions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.list_query_executions\naws_api/athena list_query_executions","url":"aws_api/athena.html#list_query_executions"},{"doc":"aws_api/athena","title":"list_sessions","content":"pub fn list_sessions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.list_sessions\naws_api/athena list_sessions","url":"aws_api/athena.html#list_sessions"},{"doc":"aws_api/athena","title":"list_table_metadata","content":"pub fn list_table_metadata(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.list_table_metadata\naws_api/athena list_table_metadata","url":"aws_api/athena.html#list_table_metadata"},{"doc":"aws_api/athena","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.list_tags_for_resource\naws_api/athena list_tags_for_resource","url":"aws_api/athena.html#list_tags_for_resource"},{"doc":"aws_api/athena","title":"list_work_groups","content":"pub fn list_work_groups(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.list_work_groups\naws_api/athena list_work_groups","url":"aws_api/athena.html#list_work_groups"},{"doc":"aws_api/athena","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/athena.new\naws_api/athena new","url":"aws_api/athena.html#new"},{"doc":"aws_api/athena","title":"put_capacity_assignment_configuration","content":"pub fn put_capacity_assignment_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.put_capacity_assignment_configuration\naws_api/athena put_capacity_assignment_configuration","url":"aws_api/athena.html#put_capacity_assignment_configuration"},{"doc":"aws_api/athena","title":"start_calculation_execution","content":"pub fn start_calculation_execution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.start_calculation_execution\naws_api/athena start_calculation_execution","url":"aws_api/athena.html#start_calculation_execution"},{"doc":"aws_api/athena","title":"start_query_execution","content":"pub fn start_query_execution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.start_query_execution\naws_api/athena start_query_execution","url":"aws_api/athena.html#start_query_execution"},{"doc":"aws_api/athena","title":"start_session","content":"pub fn start_session(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.start_session\naws_api/athena start_session","url":"aws_api/athena.html#start_session"},{"doc":"aws_api/athena","title":"stop_calculation_execution","content":"pub fn stop_calculation_execution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.stop_calculation_execution\naws_api/athena stop_calculation_execution","url":"aws_api/athena.html#stop_calculation_execution"},{"doc":"aws_api/athena","title":"stop_query_execution","content":"pub fn stop_query_execution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.stop_query_execution\naws_api/athena stop_query_execution","url":"aws_api/athena.html#stop_query_execution"},{"doc":"aws_api/athena","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.tag_resource\naws_api/athena tag_resource","url":"aws_api/athena.html#tag_resource"},{"doc":"aws_api/athena","title":"terminate_session","content":"pub fn terminate_session(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.terminate_session\naws_api/athena terminate_session","url":"aws_api/athena.html#terminate_session"},{"doc":"aws_api/athena","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.untag_resource\naws_api/athena untag_resource","url":"aws_api/athena.html#untag_resource"},{"doc":"aws_api/athena","title":"update_capacity_reservation","content":"pub fn update_capacity_reservation(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.update_capacity_reservation\naws_api/athena update_capacity_reservation","url":"aws_api/athena.html#update_capacity_reservation"},{"doc":"aws_api/athena","title":"update_data_catalog","content":"pub fn update_data_catalog(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.update_data_catalog\naws_api/athena update_data_catalog","url":"aws_api/athena.html#update_data_catalog"},{"doc":"aws_api/athena","title":"update_named_query","content":"pub fn update_named_query(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.update_named_query\naws_api/athena update_named_query","url":"aws_api/athena.html#update_named_query"},{"doc":"aws_api/athena","title":"update_notebook","content":"pub fn update_notebook(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.update_notebook\naws_api/athena update_notebook","url":"aws_api/athena.html#update_notebook"},{"doc":"aws_api/athena","title":"update_notebook_metadata","content":"pub fn update_notebook_metadata(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.update_notebook_metadata\naws_api/athena update_notebook_metadata","url":"aws_api/athena.html#update_notebook_metadata"},{"doc":"aws_api/athena","title":"update_prepared_statement","content":"pub fn update_prepared_statement(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.update_prepared_statement\naws_api/athena update_prepared_statement","url":"aws_api/athena.html#update_prepared_statement"},{"doc":"aws_api/athena","title":"update_work_group","content":"pub fn update_work_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/athena.update_work_group\naws_api/athena update_work_group","url":"aws_api/athena.html#update_work_group"},{"doc":"aws_api/athena","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/athena.with_custom_endpoint\naws_api/athena with_custom_endpoint","url":"aws_api/athena.html#with_custom_endpoint"},{"doc":"aws_api/athena","title":"aws_api/athena","content":"","url":"aws_api/athena.html"},{"doc":"aws_api/auditmanager","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/auditmanager.Client\naws_api/auditmanager Client","url":"aws_api/auditmanager.html#Client"},{"doc":"aws_api/auditmanager","title":"associate_assessment_report_evidence_folder","content":"pub fn associate_assessment_report_evidence_folder(\n  client: Client,\n  assessment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.associate_assessment_report_evidence_folder\naws_api/auditmanager associate_assessment_report_evidence_folder","url":"aws_api/auditmanager.html#associate_assessment_report_evidence_folder"},{"doc":"aws_api/auditmanager","title":"batch_associate_assessment_report_evidence","content":"pub fn batch_associate_assessment_report_evidence(\n  client: Client,\n  assessment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.batch_associate_assessment_report_evidence\naws_api/auditmanager batch_associate_assessment_report_evidence","url":"aws_api/auditmanager.html#batch_associate_assessment_report_evidence"},{"doc":"aws_api/auditmanager","title":"batch_create_delegation_by_assessment","content":"pub fn batch_create_delegation_by_assessment(\n  client: Client,\n  assessment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.batch_create_delegation_by_assessment\naws_api/auditmanager batch_create_delegation_by_assessment","url":"aws_api/auditmanager.html#batch_create_delegation_by_assessment"},{"doc":"aws_api/auditmanager","title":"batch_delete_delegation_by_assessment","content":"pub fn batch_delete_delegation_by_assessment(\n  client: Client,\n  assessment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.batch_delete_delegation_by_assessment\naws_api/auditmanager batch_delete_delegation_by_assessment","url":"aws_api/auditmanager.html#batch_delete_delegation_by_assessment"},{"doc":"aws_api/auditmanager","title":"batch_disassociate_assessment_report_evidence","content":"pub fn batch_disassociate_assessment_report_evidence(\n  client: Client,\n  assessment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.batch_disassociate_assessment_report_evidence\naws_api/auditmanager batch_disassociate_assessment_report_evidence","url":"aws_api/auditmanager.html#batch_disassociate_assessment_report_evidence"},{"doc":"aws_api/auditmanager","title":"batch_import_evidence_to_assessment_control","content":"pub fn batch_import_evidence_to_assessment_control(\n  client: Client,\n  assessment_id: String,\n  control_set_id: String,\n  control_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.batch_import_evidence_to_assessment_control\naws_api/auditmanager batch_import_evidence_to_assessment_control","url":"aws_api/auditmanager.html#batch_import_evidence_to_assessment_control"},{"doc":"aws_api/auditmanager","title":"create_assessment","content":"pub fn create_assessment(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.create_assessment\naws_api/auditmanager create_assessment","url":"aws_api/auditmanager.html#create_assessment"},{"doc":"aws_api/auditmanager","title":"create_assessment_framework","content":"pub fn create_assessment_framework(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.create_assessment_framework\naws_api/auditmanager create_assessment_framework","url":"aws_api/auditmanager.html#create_assessment_framework"},{"doc":"aws_api/auditmanager","title":"create_assessment_report","content":"pub fn create_assessment_report(\n  client: Client,\n  assessment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.create_assessment_report\naws_api/auditmanager create_assessment_report","url":"aws_api/auditmanager.html#create_assessment_report"},{"doc":"aws_api/auditmanager","title":"create_control","content":"pub fn create_control(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.create_control\naws_api/auditmanager create_control","url":"aws_api/auditmanager.html#create_control"},{"doc":"aws_api/auditmanager","title":"delete_assessment","content":"pub fn delete_assessment(\n  client: Client,\n  assessment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.delete_assessment\naws_api/auditmanager delete_assessment","url":"aws_api/auditmanager.html#delete_assessment"},{"doc":"aws_api/auditmanager","title":"delete_assessment_framework","content":"pub fn delete_assessment_framework(\n  client: Client,\n  framework_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.delete_assessment_framework\naws_api/auditmanager delete_assessment_framework","url":"aws_api/auditmanager.html#delete_assessment_framework"},{"doc":"aws_api/auditmanager","title":"delete_assessment_framework_share","content":"pub fn delete_assessment_framework_share(\n  client: Client,\n  request_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.delete_assessment_framework_share\naws_api/auditmanager delete_assessment_framework_share","url":"aws_api/auditmanager.html#delete_assessment_framework_share"},{"doc":"aws_api/auditmanager","title":"delete_assessment_report","content":"pub fn delete_assessment_report(\n  client: Client,\n  assessment_id: String,\n  assessment_report_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.delete_assessment_report\naws_api/auditmanager delete_assessment_report","url":"aws_api/auditmanager.html#delete_assessment_report"},{"doc":"aws_api/auditmanager","title":"delete_control","content":"pub fn delete_control(\n  client: Client,\n  control_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.delete_control\naws_api/auditmanager delete_control","url":"aws_api/auditmanager.html#delete_control"},{"doc":"aws_api/auditmanager","title":"deregister_account","content":"pub fn deregister_account(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.deregister_account\naws_api/auditmanager deregister_account","url":"aws_api/auditmanager.html#deregister_account"},{"doc":"aws_api/auditmanager","title":"deregister_organization_admin_account","content":"pub fn deregister_organization_admin_account(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.deregister_organization_admin_account\naws_api/auditmanager deregister_organization_admin_account","url":"aws_api/auditmanager.html#deregister_organization_admin_account"},{"doc":"aws_api/auditmanager","title":"disassociate_assessment_report_evidence_folder","content":"pub fn disassociate_assessment_report_evidence_folder(\n  client: Client,\n  assessment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.disassociate_assessment_report_evidence_folder\naws_api/auditmanager disassociate_assessment_report_evidence_folder","url":"aws_api/auditmanager.html#disassociate_assessment_report_evidence_folder"},{"doc":"aws_api/auditmanager","title":"get_account_status","content":"pub fn get_account_status(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.get_account_status\naws_api/auditmanager get_account_status","url":"aws_api/auditmanager.html#get_account_status"},{"doc":"aws_api/auditmanager","title":"get_assessment","content":"pub fn get_assessment(\n  client: Client,\n  assessment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.get_assessment\naws_api/auditmanager get_assessment","url":"aws_api/auditmanager.html#get_assessment"},{"doc":"aws_api/auditmanager","title":"get_assessment_framework","content":"pub fn get_assessment_framework(\n  client: Client,\n  framework_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.get_assessment_framework\naws_api/auditmanager get_assessment_framework","url":"aws_api/auditmanager.html#get_assessment_framework"},{"doc":"aws_api/auditmanager","title":"get_assessment_report_url","content":"pub fn get_assessment_report_url(\n  client: Client,\n  assessment_id: String,\n  assessment_report_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.get_assessment_report_url\naws_api/auditmanager get_assessment_report_url","url":"aws_api/auditmanager.html#get_assessment_report_url"},{"doc":"aws_api/auditmanager","title":"get_change_logs","content":"pub fn get_change_logs(\n  client: Client,\n  assessment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.get_change_logs\naws_api/auditmanager get_change_logs","url":"aws_api/auditmanager.html#get_change_logs"},{"doc":"aws_api/auditmanager","title":"get_control","content":"pub fn get_control(\n  client: Client,\n  control_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.get_control\naws_api/auditmanager get_control","url":"aws_api/auditmanager.html#get_control"},{"doc":"aws_api/auditmanager","title":"get_delegations","content":"pub fn get_delegations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.get_delegations\naws_api/auditmanager get_delegations","url":"aws_api/auditmanager.html#get_delegations"},{"doc":"aws_api/auditmanager","title":"get_evidence","content":"pub fn get_evidence(\n  client: Client,\n  assessment_id: String,\n  control_set_id: String,\n  evidence_folder_id: String,\n  evidence_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.get_evidence\naws_api/auditmanager get_evidence","url":"aws_api/auditmanager.html#get_evidence"},{"doc":"aws_api/auditmanager","title":"get_evidence_by_evidence_folder","content":"pub fn get_evidence_by_evidence_folder(\n  client: Client,\n  assessment_id: String,\n  control_set_id: String,\n  evidence_folder_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.get_evidence_by_evidence_folder\naws_api/auditmanager get_evidence_by_evidence_folder","url":"aws_api/auditmanager.html#get_evidence_by_evidence_folder"},{"doc":"aws_api/auditmanager","title":"get_evidence_file_upload_url","content":"pub fn get_evidence_file_upload_url(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.get_evidence_file_upload_url\naws_api/auditmanager get_evidence_file_upload_url","url":"aws_api/auditmanager.html#get_evidence_file_upload_url"},{"doc":"aws_api/auditmanager","title":"get_evidence_folder","content":"pub fn get_evidence_folder(\n  client: Client,\n  assessment_id: String,\n  control_set_id: String,\n  evidence_folder_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.get_evidence_folder\naws_api/auditmanager get_evidence_folder","url":"aws_api/auditmanager.html#get_evidence_folder"},{"doc":"aws_api/auditmanager","title":"get_evidence_folders_by_assessment","content":"pub fn get_evidence_folders_by_assessment(\n  client: Client,\n  assessment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.get_evidence_folders_by_assessment\naws_api/auditmanager get_evidence_folders_by_assessment","url":"aws_api/auditmanager.html#get_evidence_folders_by_assessment"},{"doc":"aws_api/auditmanager","title":"get_evidence_folders_by_assessment_control","content":"pub fn get_evidence_folders_by_assessment_control(\n  client: Client,\n  assessment_id: String,\n  control_set_id: String,\n  control_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.get_evidence_folders_by_assessment_control\naws_api/auditmanager get_evidence_folders_by_assessment_control","url":"aws_api/auditmanager.html#get_evidence_folders_by_assessment_control"},{"doc":"aws_api/auditmanager","title":"get_insights","content":"pub fn get_insights(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.get_insights\naws_api/auditmanager get_insights","url":"aws_api/auditmanager.html#get_insights"},{"doc":"aws_api/auditmanager","title":"get_insights_by_assessment","content":"pub fn get_insights_by_assessment(\n  client: Client,\n  assessment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.get_insights_by_assessment\naws_api/auditmanager get_insights_by_assessment","url":"aws_api/auditmanager.html#get_insights_by_assessment"},{"doc":"aws_api/auditmanager","title":"get_organization_admin_account","content":"pub fn get_organization_admin_account(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.get_organization_admin_account\naws_api/auditmanager get_organization_admin_account","url":"aws_api/auditmanager.html#get_organization_admin_account"},{"doc":"aws_api/auditmanager","title":"get_services_in_scope","content":"pub fn get_services_in_scope(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.get_services_in_scope\naws_api/auditmanager get_services_in_scope","url":"aws_api/auditmanager.html#get_services_in_scope"},{"doc":"aws_api/auditmanager","title":"get_settings","content":"pub fn get_settings(\n  client: Client,\n  attribute: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.get_settings\naws_api/auditmanager get_settings","url":"aws_api/auditmanager.html#get_settings"},{"doc":"aws_api/auditmanager","title":"list_assessment_control_insights_by_control_domain","content":"pub fn list_assessment_control_insights_by_control_domain(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.list_assessment_control_insights_by_control_domain\naws_api/auditmanager list_assessment_control_insights_by_control_domain","url":"aws_api/auditmanager.html#list_assessment_control_insights_by_control_domain"},{"doc":"aws_api/auditmanager","title":"list_assessment_framework_share_requests","content":"pub fn list_assessment_framework_share_requests(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.list_assessment_framework_share_requests\naws_api/auditmanager list_assessment_framework_share_requests","url":"aws_api/auditmanager.html#list_assessment_framework_share_requests"},{"doc":"aws_api/auditmanager","title":"list_assessment_frameworks","content":"pub fn list_assessment_frameworks(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.list_assessment_frameworks\naws_api/auditmanager list_assessment_frameworks","url":"aws_api/auditmanager.html#list_assessment_frameworks"},{"doc":"aws_api/auditmanager","title":"list_assessment_reports","content":"pub fn list_assessment_reports(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.list_assessment_reports\naws_api/auditmanager list_assessment_reports","url":"aws_api/auditmanager.html#list_assessment_reports"},{"doc":"aws_api/auditmanager","title":"list_assessments","content":"pub fn list_assessments(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.list_assessments\naws_api/auditmanager list_assessments","url":"aws_api/auditmanager.html#list_assessments"},{"doc":"aws_api/auditmanager","title":"list_control_domain_insights","content":"pub fn list_control_domain_insights(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.list_control_domain_insights\naws_api/auditmanager list_control_domain_insights","url":"aws_api/auditmanager.html#list_control_domain_insights"},{"doc":"aws_api/auditmanager","title":"list_control_domain_insights_by_assessment","content":"pub fn list_control_domain_insights_by_assessment(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.list_control_domain_insights_by_assessment\naws_api/auditmanager list_control_domain_insights_by_assessment","url":"aws_api/auditmanager.html#list_control_domain_insights_by_assessment"},{"doc":"aws_api/auditmanager","title":"list_control_insights_by_control_domain","content":"pub fn list_control_insights_by_control_domain(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.list_control_insights_by_control_domain\naws_api/auditmanager list_control_insights_by_control_domain","url":"aws_api/auditmanager.html#list_control_insights_by_control_domain"},{"doc":"aws_api/auditmanager","title":"list_controls","content":"pub fn list_controls(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.list_controls\naws_api/auditmanager list_controls","url":"aws_api/auditmanager.html#list_controls"},{"doc":"aws_api/auditmanager","title":"list_keywords_for_data_source","content":"pub fn list_keywords_for_data_source(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.list_keywords_for_data_source\naws_api/auditmanager list_keywords_for_data_source","url":"aws_api/auditmanager.html#list_keywords_for_data_source"},{"doc":"aws_api/auditmanager","title":"list_notifications","content":"pub fn list_notifications(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.list_notifications\naws_api/auditmanager list_notifications","url":"aws_api/auditmanager.html#list_notifications"},{"doc":"aws_api/auditmanager","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.list_tags_for_resource\naws_api/auditmanager list_tags_for_resource","url":"aws_api/auditmanager.html#list_tags_for_resource"},{"doc":"aws_api/auditmanager","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/auditmanager.new\naws_api/auditmanager new","url":"aws_api/auditmanager.html#new"},{"doc":"aws_api/auditmanager","title":"register_account","content":"pub fn register_account(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.register_account\naws_api/auditmanager register_account","url":"aws_api/auditmanager.html#register_account"},{"doc":"aws_api/auditmanager","title":"register_organization_admin_account","content":"pub fn register_organization_admin_account(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.register_organization_admin_account\naws_api/auditmanager register_organization_admin_account","url":"aws_api/auditmanager.html#register_organization_admin_account"},{"doc":"aws_api/auditmanager","title":"start_assessment_framework_share","content":"pub fn start_assessment_framework_share(\n  client: Client,\n  framework_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.start_assessment_framework_share\naws_api/auditmanager start_assessment_framework_share","url":"aws_api/auditmanager.html#start_assessment_framework_share"},{"doc":"aws_api/auditmanager","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.tag_resource\naws_api/auditmanager tag_resource","url":"aws_api/auditmanager.html#tag_resource"},{"doc":"aws_api/auditmanager","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.untag_resource\naws_api/auditmanager untag_resource","url":"aws_api/auditmanager.html#untag_resource"},{"doc":"aws_api/auditmanager","title":"update_assessment","content":"pub fn update_assessment(\n  client: Client,\n  assessment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.update_assessment\naws_api/auditmanager update_assessment","url":"aws_api/auditmanager.html#update_assessment"},{"doc":"aws_api/auditmanager","title":"update_assessment_control","content":"pub fn update_assessment_control(\n  client: Client,\n  assessment_id: String,\n  control_set_id: String,\n  control_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.update_assessment_control\naws_api/auditmanager update_assessment_control","url":"aws_api/auditmanager.html#update_assessment_control"},{"doc":"aws_api/auditmanager","title":"update_assessment_control_set_status","content":"pub fn update_assessment_control_set_status(\n  client: Client,\n  assessment_id: String,\n  control_set_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.update_assessment_control_set_status\naws_api/auditmanager update_assessment_control_set_status","url":"aws_api/auditmanager.html#update_assessment_control_set_status"},{"doc":"aws_api/auditmanager","title":"update_assessment_framework","content":"pub fn update_assessment_framework(\n  client: Client,\n  framework_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.update_assessment_framework\naws_api/auditmanager update_assessment_framework","url":"aws_api/auditmanager.html#update_assessment_framework"},{"doc":"aws_api/auditmanager","title":"update_assessment_framework_share","content":"pub fn update_assessment_framework_share(\n  client: Client,\n  request_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.update_assessment_framework_share\naws_api/auditmanager update_assessment_framework_share","url":"aws_api/auditmanager.html#update_assessment_framework_share"},{"doc":"aws_api/auditmanager","title":"update_assessment_status","content":"pub fn update_assessment_status(\n  client: Client,\n  assessment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.update_assessment_status\naws_api/auditmanager update_assessment_status","url":"aws_api/auditmanager.html#update_assessment_status"},{"doc":"aws_api/auditmanager","title":"update_control","content":"pub fn update_control(\n  client: Client,\n  control_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.update_control\naws_api/auditmanager update_control","url":"aws_api/auditmanager.html#update_control"},{"doc":"aws_api/auditmanager","title":"update_settings","content":"pub fn update_settings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.update_settings\naws_api/auditmanager update_settings","url":"aws_api/auditmanager.html#update_settings"},{"doc":"aws_api/auditmanager","title":"validate_assessment_report_integrity","content":"pub fn validate_assessment_report_integrity(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auditmanager.validate_assessment_report_integrity\naws_api/auditmanager validate_assessment_report_integrity","url":"aws_api/auditmanager.html#validate_assessment_report_integrity"},{"doc":"aws_api/auditmanager","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/auditmanager.with_custom_endpoint\naws_api/auditmanager with_custom_endpoint","url":"aws_api/auditmanager.html#with_custom_endpoint"},{"doc":"aws_api/auditmanager","title":"aws_api/auditmanager","content":"","url":"aws_api/auditmanager.html"},{"doc":"aws_api/auto_scaling","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/auto_scaling.Client\naws_api/auto_scaling Client","url":"aws_api/auto_scaling.html#Client"},{"doc":"aws_api/auto_scaling","title":"attach_instances","content":"pub fn attach_instances(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.attach_instances\naws_api/auto_scaling attach_instances","url":"aws_api/auto_scaling.html#attach_instances"},{"doc":"aws_api/auto_scaling","title":"attach_load_balancer_target_groups","content":"pub fn attach_load_balancer_target_groups(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.attach_load_balancer_target_groups\naws_api/auto_scaling attach_load_balancer_target_groups","url":"aws_api/auto_scaling.html#attach_load_balancer_target_groups"},{"doc":"aws_api/auto_scaling","title":"attach_load_balancers","content":"pub fn attach_load_balancers(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.attach_load_balancers\naws_api/auto_scaling attach_load_balancers","url":"aws_api/auto_scaling.html#attach_load_balancers"},{"doc":"aws_api/auto_scaling","title":"attach_traffic_sources","content":"pub fn attach_traffic_sources(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.attach_traffic_sources\naws_api/auto_scaling attach_traffic_sources","url":"aws_api/auto_scaling.html#attach_traffic_sources"},{"doc":"aws_api/auto_scaling","title":"batch_delete_scheduled_action","content":"pub fn batch_delete_scheduled_action(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.batch_delete_scheduled_action\naws_api/auto_scaling batch_delete_scheduled_action","url":"aws_api/auto_scaling.html#batch_delete_scheduled_action"},{"doc":"aws_api/auto_scaling","title":"batch_put_scheduled_update_group_action","content":"pub fn batch_put_scheduled_update_group_action(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.batch_put_scheduled_update_group_action\naws_api/auto_scaling batch_put_scheduled_update_group_action","url":"aws_api/auto_scaling.html#batch_put_scheduled_update_group_action"},{"doc":"aws_api/auto_scaling","title":"cancel_instance_refresh","content":"pub fn cancel_instance_refresh(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.cancel_instance_refresh\naws_api/auto_scaling cancel_instance_refresh","url":"aws_api/auto_scaling.html#cancel_instance_refresh"},{"doc":"aws_api/auto_scaling","title":"complete_lifecycle_action","content":"pub fn complete_lifecycle_action(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.complete_lifecycle_action\naws_api/auto_scaling complete_lifecycle_action","url":"aws_api/auto_scaling.html#complete_lifecycle_action"},{"doc":"aws_api/auto_scaling","title":"create_auto_scaling_group","content":"pub fn create_auto_scaling_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.create_auto_scaling_group\naws_api/auto_scaling create_auto_scaling_group","url":"aws_api/auto_scaling.html#create_auto_scaling_group"},{"doc":"aws_api/auto_scaling","title":"create_launch_configuration","content":"pub fn create_launch_configuration(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.create_launch_configuration\naws_api/auto_scaling create_launch_configuration","url":"aws_api/auto_scaling.html#create_launch_configuration"},{"doc":"aws_api/auto_scaling","title":"create_or_update_tags","content":"pub fn create_or_update_tags(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.create_or_update_tags\naws_api/auto_scaling create_or_update_tags","url":"aws_api/auto_scaling.html#create_or_update_tags"},{"doc":"aws_api/auto_scaling","title":"delete_auto_scaling_group","content":"pub fn delete_auto_scaling_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.delete_auto_scaling_group\naws_api/auto_scaling delete_auto_scaling_group","url":"aws_api/auto_scaling.html#delete_auto_scaling_group"},{"doc":"aws_api/auto_scaling","title":"delete_launch_configuration","content":"pub fn delete_launch_configuration(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.delete_launch_configuration\naws_api/auto_scaling delete_launch_configuration","url":"aws_api/auto_scaling.html#delete_launch_configuration"},{"doc":"aws_api/auto_scaling","title":"delete_lifecycle_hook","content":"pub fn delete_lifecycle_hook(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.delete_lifecycle_hook\naws_api/auto_scaling delete_lifecycle_hook","url":"aws_api/auto_scaling.html#delete_lifecycle_hook"},{"doc":"aws_api/auto_scaling","title":"delete_notification_configuration","content":"pub fn delete_notification_configuration(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.delete_notification_configuration\naws_api/auto_scaling delete_notification_configuration","url":"aws_api/auto_scaling.html#delete_notification_configuration"},{"doc":"aws_api/auto_scaling","title":"delete_policy","content":"pub fn delete_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.delete_policy\naws_api/auto_scaling delete_policy","url":"aws_api/auto_scaling.html#delete_policy"},{"doc":"aws_api/auto_scaling","title":"delete_scheduled_action","content":"pub fn delete_scheduled_action(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.delete_scheduled_action\naws_api/auto_scaling delete_scheduled_action","url":"aws_api/auto_scaling.html#delete_scheduled_action"},{"doc":"aws_api/auto_scaling","title":"delete_tags","content":"pub fn delete_tags(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.delete_tags\naws_api/auto_scaling delete_tags","url":"aws_api/auto_scaling.html#delete_tags"},{"doc":"aws_api/auto_scaling","title":"delete_warm_pool","content":"pub fn delete_warm_pool(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.delete_warm_pool\naws_api/auto_scaling delete_warm_pool","url":"aws_api/auto_scaling.html#delete_warm_pool"},{"doc":"aws_api/auto_scaling","title":"describe_account_limits","content":"pub fn describe_account_limits(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.describe_account_limits\naws_api/auto_scaling describe_account_limits","url":"aws_api/auto_scaling.html#describe_account_limits"},{"doc":"aws_api/auto_scaling","title":"describe_adjustment_types","content":"pub fn describe_adjustment_types(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.describe_adjustment_types\naws_api/auto_scaling describe_adjustment_types","url":"aws_api/auto_scaling.html#describe_adjustment_types"},{"doc":"aws_api/auto_scaling","title":"describe_auto_scaling_groups","content":"pub fn describe_auto_scaling_groups(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.describe_auto_scaling_groups\naws_api/auto_scaling describe_auto_scaling_groups","url":"aws_api/auto_scaling.html#describe_auto_scaling_groups"},{"doc":"aws_api/auto_scaling","title":"describe_auto_scaling_instances","content":"pub fn describe_auto_scaling_instances(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.describe_auto_scaling_instances\naws_api/auto_scaling describe_auto_scaling_instances","url":"aws_api/auto_scaling.html#describe_auto_scaling_instances"},{"doc":"aws_api/auto_scaling","title":"describe_auto_scaling_notification_types","content":"pub fn describe_auto_scaling_notification_types(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.describe_auto_scaling_notification_types\naws_api/auto_scaling describe_auto_scaling_notification_types","url":"aws_api/auto_scaling.html#describe_auto_scaling_notification_types"},{"doc":"aws_api/auto_scaling","title":"describe_instance_refreshes","content":"pub fn describe_instance_refreshes(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.describe_instance_refreshes\naws_api/auto_scaling describe_instance_refreshes","url":"aws_api/auto_scaling.html#describe_instance_refreshes"},{"doc":"aws_api/auto_scaling","title":"describe_launch_configurations","content":"pub fn describe_launch_configurations(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.describe_launch_configurations\naws_api/auto_scaling describe_launch_configurations","url":"aws_api/auto_scaling.html#describe_launch_configurations"},{"doc":"aws_api/auto_scaling","title":"describe_lifecycle_hook_types","content":"pub fn describe_lifecycle_hook_types(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.describe_lifecycle_hook_types\naws_api/auto_scaling describe_lifecycle_hook_types","url":"aws_api/auto_scaling.html#describe_lifecycle_hook_types"},{"doc":"aws_api/auto_scaling","title":"describe_lifecycle_hooks","content":"pub fn describe_lifecycle_hooks(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.describe_lifecycle_hooks\naws_api/auto_scaling describe_lifecycle_hooks","url":"aws_api/auto_scaling.html#describe_lifecycle_hooks"},{"doc":"aws_api/auto_scaling","title":"describe_load_balancer_target_groups","content":"pub fn describe_load_balancer_target_groups(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.describe_load_balancer_target_groups\naws_api/auto_scaling describe_load_balancer_target_groups","url":"aws_api/auto_scaling.html#describe_load_balancer_target_groups"},{"doc":"aws_api/auto_scaling","title":"describe_load_balancers","content":"pub fn describe_load_balancers(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.describe_load_balancers\naws_api/auto_scaling describe_load_balancers","url":"aws_api/auto_scaling.html#describe_load_balancers"},{"doc":"aws_api/auto_scaling","title":"describe_metric_collection_types","content":"pub fn describe_metric_collection_types(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.describe_metric_collection_types\naws_api/auto_scaling describe_metric_collection_types","url":"aws_api/auto_scaling.html#describe_metric_collection_types"},{"doc":"aws_api/auto_scaling","title":"describe_notification_configurations","content":"pub fn describe_notification_configurations(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.describe_notification_configurations\naws_api/auto_scaling describe_notification_configurations","url":"aws_api/auto_scaling.html#describe_notification_configurations"},{"doc":"aws_api/auto_scaling","title":"describe_policies","content":"pub fn describe_policies(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.describe_policies\naws_api/auto_scaling describe_policies","url":"aws_api/auto_scaling.html#describe_policies"},{"doc":"aws_api/auto_scaling","title":"describe_scaling_activities","content":"pub fn describe_scaling_activities(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.describe_scaling_activities\naws_api/auto_scaling describe_scaling_activities","url":"aws_api/auto_scaling.html#describe_scaling_activities"},{"doc":"aws_api/auto_scaling","title":"describe_scaling_process_types","content":"pub fn describe_scaling_process_types(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.describe_scaling_process_types\naws_api/auto_scaling describe_scaling_process_types","url":"aws_api/auto_scaling.html#describe_scaling_process_types"},{"doc":"aws_api/auto_scaling","title":"describe_scheduled_actions","content":"pub fn describe_scheduled_actions(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.describe_scheduled_actions\naws_api/auto_scaling describe_scheduled_actions","url":"aws_api/auto_scaling.html#describe_scheduled_actions"},{"doc":"aws_api/auto_scaling","title":"describe_tags","content":"pub fn describe_tags(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.describe_tags\naws_api/auto_scaling describe_tags","url":"aws_api/auto_scaling.html#describe_tags"},{"doc":"aws_api/auto_scaling","title":"describe_termination_policy_types","content":"pub fn describe_termination_policy_types(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.describe_termination_policy_types\naws_api/auto_scaling describe_termination_policy_types","url":"aws_api/auto_scaling.html#describe_termination_policy_types"},{"doc":"aws_api/auto_scaling","title":"describe_traffic_sources","content":"pub fn describe_traffic_sources(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.describe_traffic_sources\naws_api/auto_scaling describe_traffic_sources","url":"aws_api/auto_scaling.html#describe_traffic_sources"},{"doc":"aws_api/auto_scaling","title":"describe_warm_pool","content":"pub fn describe_warm_pool(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.describe_warm_pool\naws_api/auto_scaling describe_warm_pool","url":"aws_api/auto_scaling.html#describe_warm_pool"},{"doc":"aws_api/auto_scaling","title":"detach_instances","content":"pub fn detach_instances(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.detach_instances\naws_api/auto_scaling detach_instances","url":"aws_api/auto_scaling.html#detach_instances"},{"doc":"aws_api/auto_scaling","title":"detach_load_balancer_target_groups","content":"pub fn detach_load_balancer_target_groups(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.detach_load_balancer_target_groups\naws_api/auto_scaling detach_load_balancer_target_groups","url":"aws_api/auto_scaling.html#detach_load_balancer_target_groups"},{"doc":"aws_api/auto_scaling","title":"detach_load_balancers","content":"pub fn detach_load_balancers(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.detach_load_balancers\naws_api/auto_scaling detach_load_balancers","url":"aws_api/auto_scaling.html#detach_load_balancers"},{"doc":"aws_api/auto_scaling","title":"detach_traffic_sources","content":"pub fn detach_traffic_sources(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.detach_traffic_sources\naws_api/auto_scaling detach_traffic_sources","url":"aws_api/auto_scaling.html#detach_traffic_sources"},{"doc":"aws_api/auto_scaling","title":"disable_metrics_collection","content":"pub fn disable_metrics_collection(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.disable_metrics_collection\naws_api/auto_scaling disable_metrics_collection","url":"aws_api/auto_scaling.html#disable_metrics_collection"},{"doc":"aws_api/auto_scaling","title":"enable_metrics_collection","content":"pub fn enable_metrics_collection(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.enable_metrics_collection\naws_api/auto_scaling enable_metrics_collection","url":"aws_api/auto_scaling.html#enable_metrics_collection"},{"doc":"aws_api/auto_scaling","title":"enter_standby","content":"pub fn enter_standby(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.enter_standby\naws_api/auto_scaling enter_standby","url":"aws_api/auto_scaling.html#enter_standby"},{"doc":"aws_api/auto_scaling","title":"execute_policy","content":"pub fn execute_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.execute_policy\naws_api/auto_scaling execute_policy","url":"aws_api/auto_scaling.html#execute_policy"},{"doc":"aws_api/auto_scaling","title":"exit_standby","content":"pub fn exit_standby(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.exit_standby\naws_api/auto_scaling exit_standby","url":"aws_api/auto_scaling.html#exit_standby"},{"doc":"aws_api/auto_scaling","title":"get_predictive_scaling_forecast","content":"pub fn get_predictive_scaling_forecast(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.get_predictive_scaling_forecast\naws_api/auto_scaling get_predictive_scaling_forecast","url":"aws_api/auto_scaling.html#get_predictive_scaling_forecast"},{"doc":"aws_api/auto_scaling","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/auto_scaling.new\naws_api/auto_scaling new","url":"aws_api/auto_scaling.html#new"},{"doc":"aws_api/auto_scaling","title":"put_lifecycle_hook","content":"pub fn put_lifecycle_hook(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.put_lifecycle_hook\naws_api/auto_scaling put_lifecycle_hook","url":"aws_api/auto_scaling.html#put_lifecycle_hook"},{"doc":"aws_api/auto_scaling","title":"put_notification_configuration","content":"pub fn put_notification_configuration(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.put_notification_configuration\naws_api/auto_scaling put_notification_configuration","url":"aws_api/auto_scaling.html#put_notification_configuration"},{"doc":"aws_api/auto_scaling","title":"put_scaling_policy","content":"pub fn put_scaling_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.put_scaling_policy\naws_api/auto_scaling put_scaling_policy","url":"aws_api/auto_scaling.html#put_scaling_policy"},{"doc":"aws_api/auto_scaling","title":"put_scheduled_update_group_action","content":"pub fn put_scheduled_update_group_action(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.put_scheduled_update_group_action\naws_api/auto_scaling put_scheduled_update_group_action","url":"aws_api/auto_scaling.html#put_scheduled_update_group_action"},{"doc":"aws_api/auto_scaling","title":"put_warm_pool","content":"pub fn put_warm_pool(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.put_warm_pool\naws_api/auto_scaling put_warm_pool","url":"aws_api/auto_scaling.html#put_warm_pool"},{"doc":"aws_api/auto_scaling","title":"record_lifecycle_action_heartbeat","content":"pub fn record_lifecycle_action_heartbeat(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.record_lifecycle_action_heartbeat\naws_api/auto_scaling record_lifecycle_action_heartbeat","url":"aws_api/auto_scaling.html#record_lifecycle_action_heartbeat"},{"doc":"aws_api/auto_scaling","title":"resume_processes","content":"pub fn resume_processes(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.resume_processes\naws_api/auto_scaling resume_processes","url":"aws_api/auto_scaling.html#resume_processes"},{"doc":"aws_api/auto_scaling","title":"rollback_instance_refresh","content":"pub fn rollback_instance_refresh(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.rollback_instance_refresh\naws_api/auto_scaling rollback_instance_refresh","url":"aws_api/auto_scaling.html#rollback_instance_refresh"},{"doc":"aws_api/auto_scaling","title":"set_desired_capacity","content":"pub fn set_desired_capacity(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.set_desired_capacity\naws_api/auto_scaling set_desired_capacity","url":"aws_api/auto_scaling.html#set_desired_capacity"},{"doc":"aws_api/auto_scaling","title":"set_instance_health","content":"pub fn set_instance_health(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.set_instance_health\naws_api/auto_scaling set_instance_health","url":"aws_api/auto_scaling.html#set_instance_health"},{"doc":"aws_api/auto_scaling","title":"set_instance_protection","content":"pub fn set_instance_protection(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.set_instance_protection\naws_api/auto_scaling set_instance_protection","url":"aws_api/auto_scaling.html#set_instance_protection"},{"doc":"aws_api/auto_scaling","title":"start_instance_refresh","content":"pub fn start_instance_refresh(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.start_instance_refresh\naws_api/auto_scaling start_instance_refresh","url":"aws_api/auto_scaling.html#start_instance_refresh"},{"doc":"aws_api/auto_scaling","title":"suspend_processes","content":"pub fn suspend_processes(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.suspend_processes\naws_api/auto_scaling suspend_processes","url":"aws_api/auto_scaling.html#suspend_processes"},{"doc":"aws_api/auto_scaling","title":"terminate_instance_in_auto_scaling_group","content":"pub fn terminate_instance_in_auto_scaling_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.terminate_instance_in_auto_scaling_group\naws_api/auto_scaling terminate_instance_in_auto_scaling_group","url":"aws_api/auto_scaling.html#terminate_instance_in_auto_scaling_group"},{"doc":"aws_api/auto_scaling","title":"update_auto_scaling_group","content":"pub fn update_auto_scaling_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling.update_auto_scaling_group\naws_api/auto_scaling update_auto_scaling_group","url":"aws_api/auto_scaling.html#update_auto_scaling_group"},{"doc":"aws_api/auto_scaling","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/auto_scaling.with_custom_endpoint\naws_api/auto_scaling with_custom_endpoint","url":"aws_api/auto_scaling.html#with_custom_endpoint"},{"doc":"aws_api/auto_scaling","title":"aws_api/auto_scaling","content":"","url":"aws_api/auto_scaling.html"},{"doc":"aws_api/auto_scaling_plans","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/auto_scaling_plans.Client\naws_api/auto_scaling_plans Client","url":"aws_api/auto_scaling_plans.html#Client"},{"doc":"aws_api/auto_scaling_plans","title":"create_scaling_plan","content":"pub fn create_scaling_plan(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling_plans.create_scaling_plan\naws_api/auto_scaling_plans create_scaling_plan","url":"aws_api/auto_scaling_plans.html#create_scaling_plan"},{"doc":"aws_api/auto_scaling_plans","title":"delete_scaling_plan","content":"pub fn delete_scaling_plan(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling_plans.delete_scaling_plan\naws_api/auto_scaling_plans delete_scaling_plan","url":"aws_api/auto_scaling_plans.html#delete_scaling_plan"},{"doc":"aws_api/auto_scaling_plans","title":"describe_scaling_plan_resources","content":"pub fn describe_scaling_plan_resources(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling_plans.describe_scaling_plan_resources\naws_api/auto_scaling_plans describe_scaling_plan_resources","url":"aws_api/auto_scaling_plans.html#describe_scaling_plan_resources"},{"doc":"aws_api/auto_scaling_plans","title":"describe_scaling_plans","content":"pub fn describe_scaling_plans(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling_plans.describe_scaling_plans\naws_api/auto_scaling_plans describe_scaling_plans","url":"aws_api/auto_scaling_plans.html#describe_scaling_plans"},{"doc":"aws_api/auto_scaling_plans","title":"get_scaling_plan_resource_forecast_data","content":"pub fn get_scaling_plan_resource_forecast_data(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling_plans.get_scaling_plan_resource_forecast_data\naws_api/auto_scaling_plans get_scaling_plan_resource_forecast_data","url":"aws_api/auto_scaling_plans.html#get_scaling_plan_resource_forecast_data"},{"doc":"aws_api/auto_scaling_plans","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/auto_scaling_plans.new\naws_api/auto_scaling_plans new","url":"aws_api/auto_scaling_plans.html#new"},{"doc":"aws_api/auto_scaling_plans","title":"update_scaling_plan","content":"pub fn update_scaling_plan(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/auto_scaling_plans.update_scaling_plan\naws_api/auto_scaling_plans update_scaling_plan","url":"aws_api/auto_scaling_plans.html#update_scaling_plan"},{"doc":"aws_api/auto_scaling_plans","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/auto_scaling_plans.with_custom_endpoint\naws_api/auto_scaling_plans with_custom_endpoint","url":"aws_api/auto_scaling_plans.html#with_custom_endpoint"},{"doc":"aws_api/auto_scaling_plans","title":"aws_api/auto_scaling_plans","content":"","url":"aws_api/auto_scaling_plans.html"},{"doc":"aws_api/backup","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/backup.Client\naws_api/backup Client","url":"aws_api/backup.html#Client"},{"doc":"aws_api/backup","title":"cancel_legal_hold","content":"pub fn cancel_legal_hold(\n  client: Client,\n  legal_hold_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.cancel_legal_hold\naws_api/backup cancel_legal_hold","url":"aws_api/backup.html#cancel_legal_hold"},{"doc":"aws_api/backup","title":"create_backup_plan","content":"pub fn create_backup_plan(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.create_backup_plan\naws_api/backup create_backup_plan","url":"aws_api/backup.html#create_backup_plan"},{"doc":"aws_api/backup","title":"create_backup_selection","content":"pub fn create_backup_selection(\n  client: Client,\n  backup_plan_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.create_backup_selection\naws_api/backup create_backup_selection","url":"aws_api/backup.html#create_backup_selection"},{"doc":"aws_api/backup","title":"create_backup_vault","content":"pub fn create_backup_vault(\n  client: Client,\n  backup_vault_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.create_backup_vault\naws_api/backup create_backup_vault","url":"aws_api/backup.html#create_backup_vault"},{"doc":"aws_api/backup","title":"create_framework","content":"pub fn create_framework(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.create_framework\naws_api/backup create_framework","url":"aws_api/backup.html#create_framework"},{"doc":"aws_api/backup","title":"create_legal_hold","content":"pub fn create_legal_hold(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.create_legal_hold\naws_api/backup create_legal_hold","url":"aws_api/backup.html#create_legal_hold"},{"doc":"aws_api/backup","title":"create_logically_air_gapped_backup_vault","content":"pub fn create_logically_air_gapped_backup_vault(\n  client: Client,\n  backup_vault_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.create_logically_air_gapped_backup_vault\naws_api/backup create_logically_air_gapped_backup_vault","url":"aws_api/backup.html#create_logically_air_gapped_backup_vault"},{"doc":"aws_api/backup","title":"create_report_plan","content":"pub fn create_report_plan(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.create_report_plan\naws_api/backup create_report_plan","url":"aws_api/backup.html#create_report_plan"},{"doc":"aws_api/backup","title":"create_restore_testing_plan","content":"pub fn create_restore_testing_plan(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.create_restore_testing_plan\naws_api/backup create_restore_testing_plan","url":"aws_api/backup.html#create_restore_testing_plan"},{"doc":"aws_api/backup","title":"create_restore_testing_selection","content":"pub fn create_restore_testing_selection(\n  client: Client,\n  restore_testing_plan_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.create_restore_testing_selection\naws_api/backup create_restore_testing_selection","url":"aws_api/backup.html#create_restore_testing_selection"},{"doc":"aws_api/backup","title":"delete_backup_plan","content":"pub fn delete_backup_plan(\n  client: Client,\n  backup_plan_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.delete_backup_plan\naws_api/backup delete_backup_plan","url":"aws_api/backup.html#delete_backup_plan"},{"doc":"aws_api/backup","title":"delete_backup_selection","content":"pub fn delete_backup_selection(\n  client: Client,\n  backup_plan_id: String,\n  selection_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.delete_backup_selection\naws_api/backup delete_backup_selection","url":"aws_api/backup.html#delete_backup_selection"},{"doc":"aws_api/backup","title":"delete_backup_vault","content":"pub fn delete_backup_vault(\n  client: Client,\n  backup_vault_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.delete_backup_vault\naws_api/backup delete_backup_vault","url":"aws_api/backup.html#delete_backup_vault"},{"doc":"aws_api/backup","title":"delete_backup_vault_access_policy","content":"pub fn delete_backup_vault_access_policy(\n  client: Client,\n  backup_vault_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.delete_backup_vault_access_policy\naws_api/backup delete_backup_vault_access_policy","url":"aws_api/backup.html#delete_backup_vault_access_policy"},{"doc":"aws_api/backup","title":"delete_backup_vault_lock_configuration","content":"pub fn delete_backup_vault_lock_configuration(\n  client: Client,\n  backup_vault_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.delete_backup_vault_lock_configuration\naws_api/backup delete_backup_vault_lock_configuration","url":"aws_api/backup.html#delete_backup_vault_lock_configuration"},{"doc":"aws_api/backup","title":"delete_backup_vault_notifications","content":"pub fn delete_backup_vault_notifications(\n  client: Client,\n  backup_vault_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.delete_backup_vault_notifications\naws_api/backup delete_backup_vault_notifications","url":"aws_api/backup.html#delete_backup_vault_notifications"},{"doc":"aws_api/backup","title":"delete_framework","content":"pub fn delete_framework(\n  client: Client,\n  framework_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.delete_framework\naws_api/backup delete_framework","url":"aws_api/backup.html#delete_framework"},{"doc":"aws_api/backup","title":"delete_recovery_point","content":"pub fn delete_recovery_point(\n  client: Client,\n  backup_vault_name: String,\n  recovery_point_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.delete_recovery_point\naws_api/backup delete_recovery_point","url":"aws_api/backup.html#delete_recovery_point"},{"doc":"aws_api/backup","title":"delete_report_plan","content":"pub fn delete_report_plan(\n  client: Client,\n  report_plan_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.delete_report_plan\naws_api/backup delete_report_plan","url":"aws_api/backup.html#delete_report_plan"},{"doc":"aws_api/backup","title":"delete_restore_testing_plan","content":"pub fn delete_restore_testing_plan(\n  client: Client,\n  restore_testing_plan_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.delete_restore_testing_plan\naws_api/backup delete_restore_testing_plan","url":"aws_api/backup.html#delete_restore_testing_plan"},{"doc":"aws_api/backup","title":"delete_restore_testing_selection","content":"pub fn delete_restore_testing_selection(\n  client: Client,\n  restore_testing_plan_name: String,\n  restore_testing_selection_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.delete_restore_testing_selection\naws_api/backup delete_restore_testing_selection","url":"aws_api/backup.html#delete_restore_testing_selection"},{"doc":"aws_api/backup","title":"describe_backup_job","content":"pub fn describe_backup_job(\n  client: Client,\n  backup_job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.describe_backup_job\naws_api/backup describe_backup_job","url":"aws_api/backup.html#describe_backup_job"},{"doc":"aws_api/backup","title":"describe_backup_vault","content":"pub fn describe_backup_vault(\n  client: Client,\n  backup_vault_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.describe_backup_vault\naws_api/backup describe_backup_vault","url":"aws_api/backup.html#describe_backup_vault"},{"doc":"aws_api/backup","title":"describe_copy_job","content":"pub fn describe_copy_job(\n  client: Client,\n  copy_job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.describe_copy_job\naws_api/backup describe_copy_job","url":"aws_api/backup.html#describe_copy_job"},{"doc":"aws_api/backup","title":"describe_framework","content":"pub fn describe_framework(\n  client: Client,\n  framework_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.describe_framework\naws_api/backup describe_framework","url":"aws_api/backup.html#describe_framework"},{"doc":"aws_api/backup","title":"describe_global_settings","content":"pub fn describe_global_settings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.describe_global_settings\naws_api/backup describe_global_settings","url":"aws_api/backup.html#describe_global_settings"},{"doc":"aws_api/backup","title":"describe_protected_resource","content":"pub fn describe_protected_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.describe_protected_resource\naws_api/backup describe_protected_resource","url":"aws_api/backup.html#describe_protected_resource"},{"doc":"aws_api/backup","title":"describe_recovery_point","content":"pub fn describe_recovery_point(\n  client: Client,\n  backup_vault_name: String,\n  recovery_point_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.describe_recovery_point\naws_api/backup describe_recovery_point","url":"aws_api/backup.html#describe_recovery_point"},{"doc":"aws_api/backup","title":"describe_region_settings","content":"pub fn describe_region_settings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.describe_region_settings\naws_api/backup describe_region_settings","url":"aws_api/backup.html#describe_region_settings"},{"doc":"aws_api/backup","title":"describe_report_job","content":"pub fn describe_report_job(\n  client: Client,\n  report_job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.describe_report_job\naws_api/backup describe_report_job","url":"aws_api/backup.html#describe_report_job"},{"doc":"aws_api/backup","title":"describe_report_plan","content":"pub fn describe_report_plan(\n  client: Client,\n  report_plan_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.describe_report_plan\naws_api/backup describe_report_plan","url":"aws_api/backup.html#describe_report_plan"},{"doc":"aws_api/backup","title":"describe_restore_job","content":"pub fn describe_restore_job(\n  client: Client,\n  restore_job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.describe_restore_job\naws_api/backup describe_restore_job","url":"aws_api/backup.html#describe_restore_job"},{"doc":"aws_api/backup","title":"disassociate_recovery_point","content":"pub fn disassociate_recovery_point(\n  client: Client,\n  backup_vault_name: String,\n  recovery_point_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.disassociate_recovery_point\naws_api/backup disassociate_recovery_point","url":"aws_api/backup.html#disassociate_recovery_point"},{"doc":"aws_api/backup","title":"disassociate_recovery_point_from_parent","content":"pub fn disassociate_recovery_point_from_parent(\n  client: Client,\n  backup_vault_name: String,\n  recovery_point_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.disassociate_recovery_point_from_parent\naws_api/backup disassociate_recovery_point_from_parent","url":"aws_api/backup.html#disassociate_recovery_point_from_parent"},{"doc":"aws_api/backup","title":"export_backup_plan_template","content":"pub fn export_backup_plan_template(\n  client: Client,\n  backup_plan_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.export_backup_plan_template\naws_api/backup export_backup_plan_template","url":"aws_api/backup.html#export_backup_plan_template"},{"doc":"aws_api/backup","title":"get_backup_plan","content":"pub fn get_backup_plan(\n  client: Client,\n  backup_plan_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.get_backup_plan\naws_api/backup get_backup_plan","url":"aws_api/backup.html#get_backup_plan"},{"doc":"aws_api/backup","title":"get_backup_plan_from_json","content":"pub fn get_backup_plan_from_json(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.get_backup_plan_from_json\naws_api/backup get_backup_plan_from_json","url":"aws_api/backup.html#get_backup_plan_from_json"},{"doc":"aws_api/backup","title":"get_backup_plan_from_template","content":"pub fn get_backup_plan_from_template(\n  client: Client,\n  backup_plan_template_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.get_backup_plan_from_template\naws_api/backup get_backup_plan_from_template","url":"aws_api/backup.html#get_backup_plan_from_template"},{"doc":"aws_api/backup","title":"get_backup_selection","content":"pub fn get_backup_selection(\n  client: Client,\n  backup_plan_id: String,\n  selection_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.get_backup_selection\naws_api/backup get_backup_selection","url":"aws_api/backup.html#get_backup_selection"},{"doc":"aws_api/backup","title":"get_backup_vault_access_policy","content":"pub fn get_backup_vault_access_policy(\n  client: Client,\n  backup_vault_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.get_backup_vault_access_policy\naws_api/backup get_backup_vault_access_policy","url":"aws_api/backup.html#get_backup_vault_access_policy"},{"doc":"aws_api/backup","title":"get_backup_vault_notifications","content":"pub fn get_backup_vault_notifications(\n  client: Client,\n  backup_vault_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.get_backup_vault_notifications\naws_api/backup get_backup_vault_notifications","url":"aws_api/backup.html#get_backup_vault_notifications"},{"doc":"aws_api/backup","title":"get_legal_hold","content":"pub fn get_legal_hold(\n  client: Client,\n  legal_hold_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.get_legal_hold\naws_api/backup get_legal_hold","url":"aws_api/backup.html#get_legal_hold"},{"doc":"aws_api/backup","title":"get_recovery_point_restore_metadata","content":"pub fn get_recovery_point_restore_metadata(\n  client: Client,\n  backup_vault_name: String,\n  recovery_point_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.get_recovery_point_restore_metadata\naws_api/backup get_recovery_point_restore_metadata","url":"aws_api/backup.html#get_recovery_point_restore_metadata"},{"doc":"aws_api/backup","title":"get_restore_job_metadata","content":"pub fn get_restore_job_metadata(\n  client: Client,\n  restore_job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.get_restore_job_metadata\naws_api/backup get_restore_job_metadata","url":"aws_api/backup.html#get_restore_job_metadata"},{"doc":"aws_api/backup","title":"get_restore_testing_inferred_metadata","content":"pub fn get_restore_testing_inferred_metadata(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.get_restore_testing_inferred_metadata\naws_api/backup get_restore_testing_inferred_metadata","url":"aws_api/backup.html#get_restore_testing_inferred_metadata"},{"doc":"aws_api/backup","title":"get_restore_testing_plan","content":"pub fn get_restore_testing_plan(\n  client: Client,\n  restore_testing_plan_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.get_restore_testing_plan\naws_api/backup get_restore_testing_plan","url":"aws_api/backup.html#get_restore_testing_plan"},{"doc":"aws_api/backup","title":"get_restore_testing_selection","content":"pub fn get_restore_testing_selection(\n  client: Client,\n  restore_testing_plan_name: String,\n  restore_testing_selection_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.get_restore_testing_selection\naws_api/backup get_restore_testing_selection","url":"aws_api/backup.html#get_restore_testing_selection"},{"doc":"aws_api/backup","title":"get_supported_resource_types","content":"pub fn get_supported_resource_types(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.get_supported_resource_types\naws_api/backup get_supported_resource_types","url":"aws_api/backup.html#get_supported_resource_types"},{"doc":"aws_api/backup","title":"list_backup_job_summaries","content":"pub fn list_backup_job_summaries(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.list_backup_job_summaries\naws_api/backup list_backup_job_summaries","url":"aws_api/backup.html#list_backup_job_summaries"},{"doc":"aws_api/backup","title":"list_backup_jobs","content":"pub fn list_backup_jobs(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.list_backup_jobs\naws_api/backup list_backup_jobs","url":"aws_api/backup.html#list_backup_jobs"},{"doc":"aws_api/backup","title":"list_backup_plan_templates","content":"pub fn list_backup_plan_templates(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.list_backup_plan_templates\naws_api/backup list_backup_plan_templates","url":"aws_api/backup.html#list_backup_plan_templates"},{"doc":"aws_api/backup","title":"list_backup_plan_versions","content":"pub fn list_backup_plan_versions(\n  client: Client,\n  backup_plan_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.list_backup_plan_versions\naws_api/backup list_backup_plan_versions","url":"aws_api/backup.html#list_backup_plan_versions"},{"doc":"aws_api/backup","title":"list_backup_plans","content":"pub fn list_backup_plans(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.list_backup_plans\naws_api/backup list_backup_plans","url":"aws_api/backup.html#list_backup_plans"},{"doc":"aws_api/backup","title":"list_backup_selections","content":"pub fn list_backup_selections(\n  client: Client,\n  backup_plan_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.list_backup_selections\naws_api/backup list_backup_selections","url":"aws_api/backup.html#list_backup_selections"},{"doc":"aws_api/backup","title":"list_backup_vaults","content":"pub fn list_backup_vaults(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.list_backup_vaults\naws_api/backup list_backup_vaults","url":"aws_api/backup.html#list_backup_vaults"},{"doc":"aws_api/backup","title":"list_copy_job_summaries","content":"pub fn list_copy_job_summaries(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.list_copy_job_summaries\naws_api/backup list_copy_job_summaries","url":"aws_api/backup.html#list_copy_job_summaries"},{"doc":"aws_api/backup","title":"list_copy_jobs","content":"pub fn list_copy_jobs(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.list_copy_jobs\naws_api/backup list_copy_jobs","url":"aws_api/backup.html#list_copy_jobs"},{"doc":"aws_api/backup","title":"list_frameworks","content":"pub fn list_frameworks(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.list_frameworks\naws_api/backup list_frameworks","url":"aws_api/backup.html#list_frameworks"},{"doc":"aws_api/backup","title":"list_legal_holds","content":"pub fn list_legal_holds(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.list_legal_holds\naws_api/backup list_legal_holds","url":"aws_api/backup.html#list_legal_holds"},{"doc":"aws_api/backup","title":"list_protected_resources","content":"pub fn list_protected_resources(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.list_protected_resources\naws_api/backup list_protected_resources","url":"aws_api/backup.html#list_protected_resources"},{"doc":"aws_api/backup","title":"list_protected_resources_by_backup_vault","content":"pub fn list_protected_resources_by_backup_vault(\n  client: Client,\n  backup_vault_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.list_protected_resources_by_backup_vault\naws_api/backup list_protected_resources_by_backup_vault","url":"aws_api/backup.html#list_protected_resources_by_backup_vault"},{"doc":"aws_api/backup","title":"list_recovery_points_by_backup_vault","content":"pub fn list_recovery_points_by_backup_vault(\n  client: Client,\n  backup_vault_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.list_recovery_points_by_backup_vault\naws_api/backup list_recovery_points_by_backup_vault","url":"aws_api/backup.html#list_recovery_points_by_backup_vault"},{"doc":"aws_api/backup","title":"list_recovery_points_by_legal_hold","content":"pub fn list_recovery_points_by_legal_hold(\n  client: Client,\n  legal_hold_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.list_recovery_points_by_legal_hold\naws_api/backup list_recovery_points_by_legal_hold","url":"aws_api/backup.html#list_recovery_points_by_legal_hold"},{"doc":"aws_api/backup","title":"list_recovery_points_by_resource","content":"pub fn list_recovery_points_by_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.list_recovery_points_by_resource\naws_api/backup list_recovery_points_by_resource","url":"aws_api/backup.html#list_recovery_points_by_resource"},{"doc":"aws_api/backup","title":"list_report_jobs","content":"pub fn list_report_jobs(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.list_report_jobs\naws_api/backup list_report_jobs","url":"aws_api/backup.html#list_report_jobs"},{"doc":"aws_api/backup","title":"list_report_plans","content":"pub fn list_report_plans(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.list_report_plans\naws_api/backup list_report_plans","url":"aws_api/backup.html#list_report_plans"},{"doc":"aws_api/backup","title":"list_restore_job_summaries","content":"pub fn list_restore_job_summaries(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.list_restore_job_summaries\naws_api/backup list_restore_job_summaries","url":"aws_api/backup.html#list_restore_job_summaries"},{"doc":"aws_api/backup","title":"list_restore_jobs","content":"pub fn list_restore_jobs(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.list_restore_jobs\naws_api/backup list_restore_jobs","url":"aws_api/backup.html#list_restore_jobs"},{"doc":"aws_api/backup","title":"list_restore_jobs_by_protected_resource","content":"pub fn list_restore_jobs_by_protected_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.list_restore_jobs_by_protected_resource\naws_api/backup list_restore_jobs_by_protected_resource","url":"aws_api/backup.html#list_restore_jobs_by_protected_resource"},{"doc":"aws_api/backup","title":"list_restore_testing_plans","content":"pub fn list_restore_testing_plans(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.list_restore_testing_plans\naws_api/backup list_restore_testing_plans","url":"aws_api/backup.html#list_restore_testing_plans"},{"doc":"aws_api/backup","title":"list_restore_testing_selections","content":"pub fn list_restore_testing_selections(\n  client: Client,\n  restore_testing_plan_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.list_restore_testing_selections\naws_api/backup list_restore_testing_selections","url":"aws_api/backup.html#list_restore_testing_selections"},{"doc":"aws_api/backup","title":"list_tags","content":"pub fn list_tags(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.list_tags\naws_api/backup list_tags","url":"aws_api/backup.html#list_tags"},{"doc":"aws_api/backup","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/backup.new\naws_api/backup new","url":"aws_api/backup.html#new"},{"doc":"aws_api/backup","title":"put_backup_vault_access_policy","content":"pub fn put_backup_vault_access_policy(\n  client: Client,\n  backup_vault_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.put_backup_vault_access_policy\naws_api/backup put_backup_vault_access_policy","url":"aws_api/backup.html#put_backup_vault_access_policy"},{"doc":"aws_api/backup","title":"put_backup_vault_lock_configuration","content":"pub fn put_backup_vault_lock_configuration(\n  client: Client,\n  backup_vault_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.put_backup_vault_lock_configuration\naws_api/backup put_backup_vault_lock_configuration","url":"aws_api/backup.html#put_backup_vault_lock_configuration"},{"doc":"aws_api/backup","title":"put_backup_vault_notifications","content":"pub fn put_backup_vault_notifications(\n  client: Client,\n  backup_vault_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.put_backup_vault_notifications\naws_api/backup put_backup_vault_notifications","url":"aws_api/backup.html#put_backup_vault_notifications"},{"doc":"aws_api/backup","title":"put_restore_validation_result","content":"pub fn put_restore_validation_result(\n  client: Client,\n  restore_job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.put_restore_validation_result\naws_api/backup put_restore_validation_result","url":"aws_api/backup.html#put_restore_validation_result"},{"doc":"aws_api/backup","title":"start_backup_job","content":"pub fn start_backup_job(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.start_backup_job\naws_api/backup start_backup_job","url":"aws_api/backup.html#start_backup_job"},{"doc":"aws_api/backup","title":"start_copy_job","content":"pub fn start_copy_job(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.start_copy_job\naws_api/backup start_copy_job","url":"aws_api/backup.html#start_copy_job"},{"doc":"aws_api/backup","title":"start_report_job","content":"pub fn start_report_job(\n  client: Client,\n  report_plan_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.start_report_job\naws_api/backup start_report_job","url":"aws_api/backup.html#start_report_job"},{"doc":"aws_api/backup","title":"start_restore_job","content":"pub fn start_restore_job(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.start_restore_job\naws_api/backup start_restore_job","url":"aws_api/backup.html#start_restore_job"},{"doc":"aws_api/backup","title":"stop_backup_job","content":"pub fn stop_backup_job(\n  client: Client,\n  backup_job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.stop_backup_job\naws_api/backup stop_backup_job","url":"aws_api/backup.html#stop_backup_job"},{"doc":"aws_api/backup","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.tag_resource\naws_api/backup tag_resource","url":"aws_api/backup.html#tag_resource"},{"doc":"aws_api/backup","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.untag_resource\naws_api/backup untag_resource","url":"aws_api/backup.html#untag_resource"},{"doc":"aws_api/backup","title":"update_backup_plan","content":"pub fn update_backup_plan(\n  client: Client,\n  backup_plan_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.update_backup_plan\naws_api/backup update_backup_plan","url":"aws_api/backup.html#update_backup_plan"},{"doc":"aws_api/backup","title":"update_framework","content":"pub fn update_framework(\n  client: Client,\n  framework_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.update_framework\naws_api/backup update_framework","url":"aws_api/backup.html#update_framework"},{"doc":"aws_api/backup","title":"update_global_settings","content":"pub fn update_global_settings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.update_global_settings\naws_api/backup update_global_settings","url":"aws_api/backup.html#update_global_settings"},{"doc":"aws_api/backup","title":"update_recovery_point_lifecycle","content":"pub fn update_recovery_point_lifecycle(\n  client: Client,\n  backup_vault_name: String,\n  recovery_point_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.update_recovery_point_lifecycle\naws_api/backup update_recovery_point_lifecycle","url":"aws_api/backup.html#update_recovery_point_lifecycle"},{"doc":"aws_api/backup","title":"update_region_settings","content":"pub fn update_region_settings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.update_region_settings\naws_api/backup update_region_settings","url":"aws_api/backup.html#update_region_settings"},{"doc":"aws_api/backup","title":"update_report_plan","content":"pub fn update_report_plan(\n  client: Client,\n  report_plan_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.update_report_plan\naws_api/backup update_report_plan","url":"aws_api/backup.html#update_report_plan"},{"doc":"aws_api/backup","title":"update_restore_testing_plan","content":"pub fn update_restore_testing_plan(\n  client: Client,\n  restore_testing_plan_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.update_restore_testing_plan\naws_api/backup update_restore_testing_plan","url":"aws_api/backup.html#update_restore_testing_plan"},{"doc":"aws_api/backup","title":"update_restore_testing_selection","content":"pub fn update_restore_testing_selection(\n  client: Client,\n  restore_testing_plan_name: String,\n  restore_testing_selection_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup.update_restore_testing_selection\naws_api/backup update_restore_testing_selection","url":"aws_api/backup.html#update_restore_testing_selection"},{"doc":"aws_api/backup","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/backup.with_custom_endpoint\naws_api/backup with_custom_endpoint","url":"aws_api/backup.html#with_custom_endpoint"},{"doc":"aws_api/backup","title":"aws_api/backup","content":"","url":"aws_api/backup.html"},{"doc":"aws_api/backup_gateway","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/backup_gateway.Client\naws_api/backup_gateway Client","url":"aws_api/backup_gateway.html#Client"},{"doc":"aws_api/backup_gateway","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup_gateway.list_tags_for_resource\naws_api/backup_gateway list_tags_for_resource","url":"aws_api/backup_gateway.html#list_tags_for_resource"},{"doc":"aws_api/backup_gateway","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/backup_gateway.new\naws_api/backup_gateway new","url":"aws_api/backup_gateway.html#new"},{"doc":"aws_api/backup_gateway","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup_gateway.tag_resource\naws_api/backup_gateway tag_resource","url":"aws_api/backup_gateway.html#tag_resource"},{"doc":"aws_api/backup_gateway","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/backup_gateway.untag_resource\naws_api/backup_gateway untag_resource","url":"aws_api/backup_gateway.html#untag_resource"},{"doc":"aws_api/backup_gateway","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/backup_gateway.with_custom_endpoint\naws_api/backup_gateway with_custom_endpoint","url":"aws_api/backup_gateway.html#with_custom_endpoint"},{"doc":"aws_api/backup_gateway","title":"aws_api/backup_gateway","content":"","url":"aws_api/backup_gateway.html"},{"doc":"aws_api/batch","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/batch.Client\naws_api/batch Client","url":"aws_api/batch.html#Client"},{"doc":"aws_api/batch","title":"cancel_job","content":"pub fn cancel_job(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/batch.cancel_job\naws_api/batch cancel_job","url":"aws_api/batch.html#cancel_job"},{"doc":"aws_api/batch","title":"create_compute_environment","content":"pub fn create_compute_environment(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/batch.create_compute_environment\naws_api/batch create_compute_environment","url":"aws_api/batch.html#create_compute_environment"},{"doc":"aws_api/batch","title":"create_job_queue","content":"pub fn create_job_queue(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/batch.create_job_queue\naws_api/batch create_job_queue","url":"aws_api/batch.html#create_job_queue"},{"doc":"aws_api/batch","title":"create_scheduling_policy","content":"pub fn create_scheduling_policy(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/batch.create_scheduling_policy\naws_api/batch create_scheduling_policy","url":"aws_api/batch.html#create_scheduling_policy"},{"doc":"aws_api/batch","title":"delete_compute_environment","content":"pub fn delete_compute_environment(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/batch.delete_compute_environment\naws_api/batch delete_compute_environment","url":"aws_api/batch.html#delete_compute_environment"},{"doc":"aws_api/batch","title":"delete_job_queue","content":"pub fn delete_job_queue(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/batch.delete_job_queue\naws_api/batch delete_job_queue","url":"aws_api/batch.html#delete_job_queue"},{"doc":"aws_api/batch","title":"delete_scheduling_policy","content":"pub fn delete_scheduling_policy(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/batch.delete_scheduling_policy\naws_api/batch delete_scheduling_policy","url":"aws_api/batch.html#delete_scheduling_policy"},{"doc":"aws_api/batch","title":"deregister_job_definition","content":"pub fn deregister_job_definition(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/batch.deregister_job_definition\naws_api/batch deregister_job_definition","url":"aws_api/batch.html#deregister_job_definition"},{"doc":"aws_api/batch","title":"describe_compute_environments","content":"pub fn describe_compute_environments(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/batch.describe_compute_environments\naws_api/batch describe_compute_environments","url":"aws_api/batch.html#describe_compute_environments"},{"doc":"aws_api/batch","title":"describe_job_definitions","content":"pub fn describe_job_definitions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/batch.describe_job_definitions\naws_api/batch describe_job_definitions","url":"aws_api/batch.html#describe_job_definitions"},{"doc":"aws_api/batch","title":"describe_job_queues","content":"pub fn describe_job_queues(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/batch.describe_job_queues\naws_api/batch describe_job_queues","url":"aws_api/batch.html#describe_job_queues"},{"doc":"aws_api/batch","title":"describe_jobs","content":"pub fn describe_jobs(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/batch.describe_jobs\naws_api/batch describe_jobs","url":"aws_api/batch.html#describe_jobs"},{"doc":"aws_api/batch","title":"describe_scheduling_policies","content":"pub fn describe_scheduling_policies(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/batch.describe_scheduling_policies\naws_api/batch describe_scheduling_policies","url":"aws_api/batch.html#describe_scheduling_policies"},{"doc":"aws_api/batch","title":"get_job_queue_snapshot","content":"pub fn get_job_queue_snapshot(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/batch.get_job_queue_snapshot\naws_api/batch get_job_queue_snapshot","url":"aws_api/batch.html#get_job_queue_snapshot"},{"doc":"aws_api/batch","title":"list_jobs","content":"pub fn list_jobs(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/batch.list_jobs\naws_api/batch list_jobs","url":"aws_api/batch.html#list_jobs"},{"doc":"aws_api/batch","title":"list_scheduling_policies","content":"pub fn list_scheduling_policies(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/batch.list_scheduling_policies\naws_api/batch list_scheduling_policies","url":"aws_api/batch.html#list_scheduling_policies"},{"doc":"aws_api/batch","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/batch.list_tags_for_resource\naws_api/batch list_tags_for_resource","url":"aws_api/batch.html#list_tags_for_resource"},{"doc":"aws_api/batch","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/batch.new\naws_api/batch new","url":"aws_api/batch.html#new"},{"doc":"aws_api/batch","title":"register_job_definition","content":"pub fn register_job_definition(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/batch.register_job_definition\naws_api/batch register_job_definition","url":"aws_api/batch.html#register_job_definition"},{"doc":"aws_api/batch","title":"submit_job","content":"pub fn submit_job(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/batch.submit_job\naws_api/batch submit_job","url":"aws_api/batch.html#submit_job"},{"doc":"aws_api/batch","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/batch.tag_resource\naws_api/batch tag_resource","url":"aws_api/batch.html#tag_resource"},{"doc":"aws_api/batch","title":"terminate_job","content":"pub fn terminate_job(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/batch.terminate_job\naws_api/batch terminate_job","url":"aws_api/batch.html#terminate_job"},{"doc":"aws_api/batch","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/batch.untag_resource\naws_api/batch untag_resource","url":"aws_api/batch.html#untag_resource"},{"doc":"aws_api/batch","title":"update_compute_environment","content":"pub fn update_compute_environment(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/batch.update_compute_environment\naws_api/batch update_compute_environment","url":"aws_api/batch.html#update_compute_environment"},{"doc":"aws_api/batch","title":"update_job_queue","content":"pub fn update_job_queue(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/batch.update_job_queue\naws_api/batch update_job_queue","url":"aws_api/batch.html#update_job_queue"},{"doc":"aws_api/batch","title":"update_scheduling_policy","content":"pub fn update_scheduling_policy(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/batch.update_scheduling_policy\naws_api/batch update_scheduling_policy","url":"aws_api/batch.html#update_scheduling_policy"},{"doc":"aws_api/batch","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/batch.with_custom_endpoint\naws_api/batch with_custom_endpoint","url":"aws_api/batch.html#with_custom_endpoint"},{"doc":"aws_api/batch","title":"aws_api/batch","content":"","url":"aws_api/batch.html"},{"doc":"aws_api/billingconductor","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/billingconductor.Client\naws_api/billingconductor Client","url":"aws_api/billingconductor.html#Client"},{"doc":"aws_api/billingconductor","title":"get_billing_group_cost_report","content":"pub fn get_billing_group_cost_report(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/billingconductor.get_billing_group_cost_report\naws_api/billingconductor get_billing_group_cost_report","url":"aws_api/billingconductor.html#get_billing_group_cost_report"},{"doc":"aws_api/billingconductor","title":"list_account_associations","content":"pub fn list_account_associations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/billingconductor.list_account_associations\naws_api/billingconductor list_account_associations","url":"aws_api/billingconductor.html#list_account_associations"},{"doc":"aws_api/billingconductor","title":"list_billing_group_cost_reports","content":"pub fn list_billing_group_cost_reports(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/billingconductor.list_billing_group_cost_reports\naws_api/billingconductor list_billing_group_cost_reports","url":"aws_api/billingconductor.html#list_billing_group_cost_reports"},{"doc":"aws_api/billingconductor","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/billingconductor.list_tags_for_resource\naws_api/billingconductor list_tags_for_resource","url":"aws_api/billingconductor.html#list_tags_for_resource"},{"doc":"aws_api/billingconductor","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/billingconductor.new\naws_api/billingconductor new","url":"aws_api/billingconductor.html#new"},{"doc":"aws_api/billingconductor","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/billingconductor.tag_resource\naws_api/billingconductor tag_resource","url":"aws_api/billingconductor.html#tag_resource"},{"doc":"aws_api/billingconductor","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/billingconductor.untag_resource\naws_api/billingconductor untag_resource","url":"aws_api/billingconductor.html#untag_resource"},{"doc":"aws_api/billingconductor","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/billingconductor.with_custom_endpoint\naws_api/billingconductor with_custom_endpoint","url":"aws_api/billingconductor.html#with_custom_endpoint"},{"doc":"aws_api/billingconductor","title":"aws_api/billingconductor","content":"","url":"aws_api/billingconductor.html"},{"doc":"aws_api/braket","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/braket.Client\naws_api/braket Client","url":"aws_api/braket.html#Client"},{"doc":"aws_api/braket","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/braket.list_tags_for_resource\naws_api/braket list_tags_for_resource","url":"aws_api/braket.html#list_tags_for_resource"},{"doc":"aws_api/braket","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/braket.new\naws_api/braket new","url":"aws_api/braket.html#new"},{"doc":"aws_api/braket","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/braket.tag_resource\naws_api/braket tag_resource","url":"aws_api/braket.html#tag_resource"},{"doc":"aws_api/braket","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/braket.untag_resource\naws_api/braket untag_resource","url":"aws_api/braket.html#untag_resource"},{"doc":"aws_api/braket","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/braket.with_custom_endpoint\naws_api/braket with_custom_endpoint","url":"aws_api/braket.html#with_custom_endpoint"},{"doc":"aws_api/braket","title":"aws_api/braket","content":"","url":"aws_api/braket.html"},{"doc":"aws_api/budgets","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/budgets.Client\naws_api/budgets Client","url":"aws_api/budgets.html#Client"},{"doc":"aws_api/budgets","title":"create_budget","content":"pub fn create_budget(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/budgets.create_budget\naws_api/budgets create_budget","url":"aws_api/budgets.html#create_budget"},{"doc":"aws_api/budgets","title":"create_budget_action","content":"pub fn create_budget_action(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/budgets.create_budget_action\naws_api/budgets create_budget_action","url":"aws_api/budgets.html#create_budget_action"},{"doc":"aws_api/budgets","title":"create_notification","content":"pub fn create_notification(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/budgets.create_notification\naws_api/budgets create_notification","url":"aws_api/budgets.html#create_notification"},{"doc":"aws_api/budgets","title":"create_subscriber","content":"pub fn create_subscriber(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/budgets.create_subscriber\naws_api/budgets create_subscriber","url":"aws_api/budgets.html#create_subscriber"},{"doc":"aws_api/budgets","title":"delete_budget","content":"pub fn delete_budget(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/budgets.delete_budget\naws_api/budgets delete_budget","url":"aws_api/budgets.html#delete_budget"},{"doc":"aws_api/budgets","title":"delete_budget_action","content":"pub fn delete_budget_action(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/budgets.delete_budget_action\naws_api/budgets delete_budget_action","url":"aws_api/budgets.html#delete_budget_action"},{"doc":"aws_api/budgets","title":"delete_notification","content":"pub fn delete_notification(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/budgets.delete_notification\naws_api/budgets delete_notification","url":"aws_api/budgets.html#delete_notification"},{"doc":"aws_api/budgets","title":"delete_subscriber","content":"pub fn delete_subscriber(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/budgets.delete_subscriber\naws_api/budgets delete_subscriber","url":"aws_api/budgets.html#delete_subscriber"},{"doc":"aws_api/budgets","title":"describe_budget","content":"pub fn describe_budget(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/budgets.describe_budget\naws_api/budgets describe_budget","url":"aws_api/budgets.html#describe_budget"},{"doc":"aws_api/budgets","title":"describe_budget_action","content":"pub fn describe_budget_action(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/budgets.describe_budget_action\naws_api/budgets describe_budget_action","url":"aws_api/budgets.html#describe_budget_action"},{"doc":"aws_api/budgets","title":"describe_budget_action_histories","content":"pub fn describe_budget_action_histories(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/budgets.describe_budget_action_histories\naws_api/budgets describe_budget_action_histories","url":"aws_api/budgets.html#describe_budget_action_histories"},{"doc":"aws_api/budgets","title":"describe_budget_actions_for_account","content":"pub fn describe_budget_actions_for_account(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/budgets.describe_budget_actions_for_account\naws_api/budgets describe_budget_actions_for_account","url":"aws_api/budgets.html#describe_budget_actions_for_account"},{"doc":"aws_api/budgets","title":"describe_budget_actions_for_budget","content":"pub fn describe_budget_actions_for_budget(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/budgets.describe_budget_actions_for_budget\naws_api/budgets describe_budget_actions_for_budget","url":"aws_api/budgets.html#describe_budget_actions_for_budget"},{"doc":"aws_api/budgets","title":"describe_budget_notifications_for_account","content":"pub fn describe_budget_notifications_for_account(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/budgets.describe_budget_notifications_for_account\naws_api/budgets describe_budget_notifications_for_account","url":"aws_api/budgets.html#describe_budget_notifications_for_account"},{"doc":"aws_api/budgets","title":"describe_budget_performance_history","content":"pub fn describe_budget_performance_history(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/budgets.describe_budget_performance_history\naws_api/budgets describe_budget_performance_history","url":"aws_api/budgets.html#describe_budget_performance_history"},{"doc":"aws_api/budgets","title":"describe_budgets","content":"pub fn describe_budgets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/budgets.describe_budgets\naws_api/budgets describe_budgets","url":"aws_api/budgets.html#describe_budgets"},{"doc":"aws_api/budgets","title":"describe_notifications_for_budget","content":"pub fn describe_notifications_for_budget(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/budgets.describe_notifications_for_budget\naws_api/budgets describe_notifications_for_budget","url":"aws_api/budgets.html#describe_notifications_for_budget"},{"doc":"aws_api/budgets","title":"describe_subscribers_for_notification","content":"pub fn describe_subscribers_for_notification(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/budgets.describe_subscribers_for_notification\naws_api/budgets describe_subscribers_for_notification","url":"aws_api/budgets.html#describe_subscribers_for_notification"},{"doc":"aws_api/budgets","title":"execute_budget_action","content":"pub fn execute_budget_action(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/budgets.execute_budget_action\naws_api/budgets execute_budget_action","url":"aws_api/budgets.html#execute_budget_action"},{"doc":"aws_api/budgets","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/budgets.list_tags_for_resource\naws_api/budgets list_tags_for_resource","url":"aws_api/budgets.html#list_tags_for_resource"},{"doc":"aws_api/budgets","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/budgets.new\naws_api/budgets new","url":"aws_api/budgets.html#new"},{"doc":"aws_api/budgets","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/budgets.tag_resource\naws_api/budgets tag_resource","url":"aws_api/budgets.html#tag_resource"},{"doc":"aws_api/budgets","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/budgets.untag_resource\naws_api/budgets untag_resource","url":"aws_api/budgets.html#untag_resource"},{"doc":"aws_api/budgets","title":"update_budget","content":"pub fn update_budget(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/budgets.update_budget\naws_api/budgets update_budget","url":"aws_api/budgets.html#update_budget"},{"doc":"aws_api/budgets","title":"update_budget_action","content":"pub fn update_budget_action(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/budgets.update_budget_action\naws_api/budgets update_budget_action","url":"aws_api/budgets.html#update_budget_action"},{"doc":"aws_api/budgets","title":"update_notification","content":"pub fn update_notification(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/budgets.update_notification\naws_api/budgets update_notification","url":"aws_api/budgets.html#update_notification"},{"doc":"aws_api/budgets","title":"update_subscriber","content":"pub fn update_subscriber(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/budgets.update_subscriber\naws_api/budgets update_subscriber","url":"aws_api/budgets.html#update_subscriber"},{"doc":"aws_api/budgets","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/budgets.with_custom_endpoint\naws_api/budgets with_custom_endpoint","url":"aws_api/budgets.html#with_custom_endpoint"},{"doc":"aws_api/budgets","title":"aws_api/budgets","content":"","url":"aws_api/budgets.html"},{"doc":"aws_api/chime","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/chime.Client\naws_api/chime Client","url":"aws_api/chime.html#Client"},{"doc":"aws_api/chime","title":"associate_phone_number_with_user","content":"pub fn associate_phone_number_with_user(\n  client: Client,\n  account_id: String,\n  user_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.associate_phone_number_with_user\naws_api/chime associate_phone_number_with_user","url":"aws_api/chime.html#associate_phone_number_with_user"},{"doc":"aws_api/chime","title":"associate_phone_numbers_with_voice_connector","content":"pub fn associate_phone_numbers_with_voice_connector(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.associate_phone_numbers_with_voice_connector\naws_api/chime associate_phone_numbers_with_voice_connector","url":"aws_api/chime.html#associate_phone_numbers_with_voice_connector"},{"doc":"aws_api/chime","title":"associate_phone_numbers_with_voice_connector_group","content":"pub fn associate_phone_numbers_with_voice_connector_group(\n  client: Client,\n  voice_connector_group_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.associate_phone_numbers_with_voice_connector_group\naws_api/chime associate_phone_numbers_with_voice_connector_group","url":"aws_api/chime.html#associate_phone_numbers_with_voice_connector_group"},{"doc":"aws_api/chime","title":"associate_signin_delegate_groups_with_account","content":"pub fn associate_signin_delegate_groups_with_account(\n  client: Client,\n  account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.associate_signin_delegate_groups_with_account\naws_api/chime associate_signin_delegate_groups_with_account","url":"aws_api/chime.html#associate_signin_delegate_groups_with_account"},{"doc":"aws_api/chime","title":"batch_create_attendee","content":"pub fn batch_create_attendee(\n  client: Client,\n  meeting_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.batch_create_attendee\naws_api/chime batch_create_attendee","url":"aws_api/chime.html#batch_create_attendee"},{"doc":"aws_api/chime","title":"batch_create_channel_membership","content":"pub fn batch_create_channel_membership(\n  client: Client,\n  channel_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.batch_create_channel_membership\naws_api/chime batch_create_channel_membership","url":"aws_api/chime.html#batch_create_channel_membership"},{"doc":"aws_api/chime","title":"batch_create_room_membership","content":"pub fn batch_create_room_membership(\n  client: Client,\n  account_id: String,\n  room_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.batch_create_room_membership\naws_api/chime batch_create_room_membership","url":"aws_api/chime.html#batch_create_room_membership"},{"doc":"aws_api/chime","title":"batch_delete_phone_number","content":"pub fn batch_delete_phone_number(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.batch_delete_phone_number\naws_api/chime batch_delete_phone_number","url":"aws_api/chime.html#batch_delete_phone_number"},{"doc":"aws_api/chime","title":"batch_suspend_user","content":"pub fn batch_suspend_user(\n  client: Client,\n  account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.batch_suspend_user\naws_api/chime batch_suspend_user","url":"aws_api/chime.html#batch_suspend_user"},{"doc":"aws_api/chime","title":"batch_unsuspend_user","content":"pub fn batch_unsuspend_user(\n  client: Client,\n  account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.batch_unsuspend_user\naws_api/chime batch_unsuspend_user","url":"aws_api/chime.html#batch_unsuspend_user"},{"doc":"aws_api/chime","title":"batch_update_phone_number","content":"pub fn batch_update_phone_number(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.batch_update_phone_number\naws_api/chime batch_update_phone_number","url":"aws_api/chime.html#batch_update_phone_number"},{"doc":"aws_api/chime","title":"batch_update_user","content":"pub fn batch_update_user(\n  client: Client,\n  account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.batch_update_user\naws_api/chime batch_update_user","url":"aws_api/chime.html#batch_update_user"},{"doc":"aws_api/chime","title":"create_account","content":"pub fn create_account(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.create_account\naws_api/chime create_account","url":"aws_api/chime.html#create_account"},{"doc":"aws_api/chime","title":"create_app_instance","content":"pub fn create_app_instance(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.create_app_instance\naws_api/chime create_app_instance","url":"aws_api/chime.html#create_app_instance"},{"doc":"aws_api/chime","title":"create_app_instance_admin","content":"pub fn create_app_instance_admin(\n  client: Client,\n  app_instance_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.create_app_instance_admin\naws_api/chime create_app_instance_admin","url":"aws_api/chime.html#create_app_instance_admin"},{"doc":"aws_api/chime","title":"create_app_instance_user","content":"pub fn create_app_instance_user(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.create_app_instance_user\naws_api/chime create_app_instance_user","url":"aws_api/chime.html#create_app_instance_user"},{"doc":"aws_api/chime","title":"create_attendee","content":"pub fn create_attendee(\n  client: Client,\n  meeting_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.create_attendee\naws_api/chime create_attendee","url":"aws_api/chime.html#create_attendee"},{"doc":"aws_api/chime","title":"create_bot","content":"pub fn create_bot(\n  client: Client,\n  account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.create_bot\naws_api/chime create_bot","url":"aws_api/chime.html#create_bot"},{"doc":"aws_api/chime","title":"create_channel","content":"pub fn create_channel(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.create_channel\naws_api/chime create_channel","url":"aws_api/chime.html#create_channel"},{"doc":"aws_api/chime","title":"create_channel_ban","content":"pub fn create_channel_ban(\n  client: Client,\n  channel_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.create_channel_ban\naws_api/chime create_channel_ban","url":"aws_api/chime.html#create_channel_ban"},{"doc":"aws_api/chime","title":"create_channel_membership","content":"pub fn create_channel_membership(\n  client: Client,\n  channel_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.create_channel_membership\naws_api/chime create_channel_membership","url":"aws_api/chime.html#create_channel_membership"},{"doc":"aws_api/chime","title":"create_channel_moderator","content":"pub fn create_channel_moderator(\n  client: Client,\n  channel_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.create_channel_moderator\naws_api/chime create_channel_moderator","url":"aws_api/chime.html#create_channel_moderator"},{"doc":"aws_api/chime","title":"create_media_capture_pipeline","content":"pub fn create_media_capture_pipeline(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.create_media_capture_pipeline\naws_api/chime create_media_capture_pipeline","url":"aws_api/chime.html#create_media_capture_pipeline"},{"doc":"aws_api/chime","title":"create_meeting","content":"pub fn create_meeting(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.create_meeting\naws_api/chime create_meeting","url":"aws_api/chime.html#create_meeting"},{"doc":"aws_api/chime","title":"create_meeting_dial_out","content":"pub fn create_meeting_dial_out(\n  client: Client,\n  meeting_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.create_meeting_dial_out\naws_api/chime create_meeting_dial_out","url":"aws_api/chime.html#create_meeting_dial_out"},{"doc":"aws_api/chime","title":"create_meeting_with_attendees","content":"pub fn create_meeting_with_attendees(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.create_meeting_with_attendees\naws_api/chime create_meeting_with_attendees","url":"aws_api/chime.html#create_meeting_with_attendees"},{"doc":"aws_api/chime","title":"create_phone_number_order","content":"pub fn create_phone_number_order(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.create_phone_number_order\naws_api/chime create_phone_number_order","url":"aws_api/chime.html#create_phone_number_order"},{"doc":"aws_api/chime","title":"create_proxy_session","content":"pub fn create_proxy_session(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.create_proxy_session\naws_api/chime create_proxy_session","url":"aws_api/chime.html#create_proxy_session"},{"doc":"aws_api/chime","title":"create_room","content":"pub fn create_room(\n  client: Client,\n  account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.create_room\naws_api/chime create_room","url":"aws_api/chime.html#create_room"},{"doc":"aws_api/chime","title":"create_room_membership","content":"pub fn create_room_membership(\n  client: Client,\n  account_id: String,\n  room_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.create_room_membership\naws_api/chime create_room_membership","url":"aws_api/chime.html#create_room_membership"},{"doc":"aws_api/chime","title":"create_sip_media_application","content":"pub fn create_sip_media_application(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.create_sip_media_application\naws_api/chime create_sip_media_application","url":"aws_api/chime.html#create_sip_media_application"},{"doc":"aws_api/chime","title":"create_sip_media_application_call","content":"pub fn create_sip_media_application_call(\n  client: Client,\n  sip_media_application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.create_sip_media_application_call\naws_api/chime create_sip_media_application_call","url":"aws_api/chime.html#create_sip_media_application_call"},{"doc":"aws_api/chime","title":"create_sip_rule","content":"pub fn create_sip_rule(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.create_sip_rule\naws_api/chime create_sip_rule","url":"aws_api/chime.html#create_sip_rule"},{"doc":"aws_api/chime","title":"create_user","content":"pub fn create_user(\n  client: Client,\n  account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.create_user\naws_api/chime create_user","url":"aws_api/chime.html#create_user"},{"doc":"aws_api/chime","title":"create_voice_connector","content":"pub fn create_voice_connector(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.create_voice_connector\naws_api/chime create_voice_connector","url":"aws_api/chime.html#create_voice_connector"},{"doc":"aws_api/chime","title":"create_voice_connector_group","content":"pub fn create_voice_connector_group(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.create_voice_connector_group\naws_api/chime create_voice_connector_group","url":"aws_api/chime.html#create_voice_connector_group"},{"doc":"aws_api/chime","title":"delete_account","content":"pub fn delete_account(\n  client: Client,\n  account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.delete_account\naws_api/chime delete_account","url":"aws_api/chime.html#delete_account"},{"doc":"aws_api/chime","title":"delete_app_instance","content":"pub fn delete_app_instance(\n  client: Client,\n  app_instance_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.delete_app_instance\naws_api/chime delete_app_instance","url":"aws_api/chime.html#delete_app_instance"},{"doc":"aws_api/chime","title":"delete_app_instance_admin","content":"pub fn delete_app_instance_admin(\n  client: Client,\n  app_instance_arn: String,\n  app_instance_admin_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.delete_app_instance_admin\naws_api/chime delete_app_instance_admin","url":"aws_api/chime.html#delete_app_instance_admin"},{"doc":"aws_api/chime","title":"delete_app_instance_streaming_configurations","content":"pub fn delete_app_instance_streaming_configurations(\n  client: Client,\n  app_instance_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.delete_app_instance_streaming_configurations\naws_api/chime delete_app_instance_streaming_configurations","url":"aws_api/chime.html#delete_app_instance_streaming_configurations"},{"doc":"aws_api/chime","title":"delete_app_instance_user","content":"pub fn delete_app_instance_user(\n  client: Client,\n  app_instance_user_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.delete_app_instance_user\naws_api/chime delete_app_instance_user","url":"aws_api/chime.html#delete_app_instance_user"},{"doc":"aws_api/chime","title":"delete_attendee","content":"pub fn delete_attendee(\n  client: Client,\n  meeting_id: String,\n  attendee_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.delete_attendee\naws_api/chime delete_attendee","url":"aws_api/chime.html#delete_attendee"},{"doc":"aws_api/chime","title":"delete_channel","content":"pub fn delete_channel(\n  client: Client,\n  channel_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.delete_channel\naws_api/chime delete_channel","url":"aws_api/chime.html#delete_channel"},{"doc":"aws_api/chime","title":"delete_channel_ban","content":"pub fn delete_channel_ban(\n  client: Client,\n  channel_arn: String,\n  member_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.delete_channel_ban\naws_api/chime delete_channel_ban","url":"aws_api/chime.html#delete_channel_ban"},{"doc":"aws_api/chime","title":"delete_channel_membership","content":"pub fn delete_channel_membership(\n  client: Client,\n  channel_arn: String,\n  member_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.delete_channel_membership\naws_api/chime delete_channel_membership","url":"aws_api/chime.html#delete_channel_membership"},{"doc":"aws_api/chime","title":"delete_channel_message","content":"pub fn delete_channel_message(\n  client: Client,\n  channel_arn: String,\n  message_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.delete_channel_message\naws_api/chime delete_channel_message","url":"aws_api/chime.html#delete_channel_message"},{"doc":"aws_api/chime","title":"delete_channel_moderator","content":"pub fn delete_channel_moderator(\n  client: Client,\n  channel_arn: String,\n  channel_moderator_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.delete_channel_moderator\naws_api/chime delete_channel_moderator","url":"aws_api/chime.html#delete_channel_moderator"},{"doc":"aws_api/chime","title":"delete_events_configuration","content":"pub fn delete_events_configuration(\n  client: Client,\n  account_id: String,\n  bot_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.delete_events_configuration\naws_api/chime delete_events_configuration","url":"aws_api/chime.html#delete_events_configuration"},{"doc":"aws_api/chime","title":"delete_media_capture_pipeline","content":"pub fn delete_media_capture_pipeline(\n  client: Client,\n  media_pipeline_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.delete_media_capture_pipeline\naws_api/chime delete_media_capture_pipeline","url":"aws_api/chime.html#delete_media_capture_pipeline"},{"doc":"aws_api/chime","title":"delete_meeting","content":"pub fn delete_meeting(\n  client: Client,\n  meeting_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.delete_meeting\naws_api/chime delete_meeting","url":"aws_api/chime.html#delete_meeting"},{"doc":"aws_api/chime","title":"delete_phone_number","content":"pub fn delete_phone_number(\n  client: Client,\n  phone_number_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.delete_phone_number\naws_api/chime delete_phone_number","url":"aws_api/chime.html#delete_phone_number"},{"doc":"aws_api/chime","title":"delete_proxy_session","content":"pub fn delete_proxy_session(\n  client: Client,\n  voice_connector_id: String,\n  proxy_session_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.delete_proxy_session\naws_api/chime delete_proxy_session","url":"aws_api/chime.html#delete_proxy_session"},{"doc":"aws_api/chime","title":"delete_room","content":"pub fn delete_room(\n  client: Client,\n  account_id: String,\n  room_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.delete_room\naws_api/chime delete_room","url":"aws_api/chime.html#delete_room"},{"doc":"aws_api/chime","title":"delete_room_membership","content":"pub fn delete_room_membership(\n  client: Client,\n  account_id: String,\n  room_id: String,\n  member_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.delete_room_membership\naws_api/chime delete_room_membership","url":"aws_api/chime.html#delete_room_membership"},{"doc":"aws_api/chime","title":"delete_sip_media_application","content":"pub fn delete_sip_media_application(\n  client: Client,\n  sip_media_application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.delete_sip_media_application\naws_api/chime delete_sip_media_application","url":"aws_api/chime.html#delete_sip_media_application"},{"doc":"aws_api/chime","title":"delete_sip_rule","content":"pub fn delete_sip_rule(\n  client: Client,\n  sip_rule_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.delete_sip_rule\naws_api/chime delete_sip_rule","url":"aws_api/chime.html#delete_sip_rule"},{"doc":"aws_api/chime","title":"delete_voice_connector","content":"pub fn delete_voice_connector(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.delete_voice_connector\naws_api/chime delete_voice_connector","url":"aws_api/chime.html#delete_voice_connector"},{"doc":"aws_api/chime","title":"delete_voice_connector_emergency_calling_configuration","content":"pub fn delete_voice_connector_emergency_calling_configuration(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.delete_voice_connector_emergency_calling_configuration\naws_api/chime delete_voice_connector_emergency_calling_configuration","url":"aws_api/chime.html#delete_voice_connector_emergency_calling_configuration"},{"doc":"aws_api/chime","title":"delete_voice_connector_group","content":"pub fn delete_voice_connector_group(\n  client: Client,\n  voice_connector_group_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.delete_voice_connector_group\naws_api/chime delete_voice_connector_group","url":"aws_api/chime.html#delete_voice_connector_group"},{"doc":"aws_api/chime","title":"delete_voice_connector_origination","content":"pub fn delete_voice_connector_origination(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.delete_voice_connector_origination\naws_api/chime delete_voice_connector_origination","url":"aws_api/chime.html#delete_voice_connector_origination"},{"doc":"aws_api/chime","title":"delete_voice_connector_proxy","content":"pub fn delete_voice_connector_proxy(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.delete_voice_connector_proxy\naws_api/chime delete_voice_connector_proxy","url":"aws_api/chime.html#delete_voice_connector_proxy"},{"doc":"aws_api/chime","title":"delete_voice_connector_streaming_configuration","content":"pub fn delete_voice_connector_streaming_configuration(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.delete_voice_connector_streaming_configuration\naws_api/chime delete_voice_connector_streaming_configuration","url":"aws_api/chime.html#delete_voice_connector_streaming_configuration"},{"doc":"aws_api/chime","title":"delete_voice_connector_termination","content":"pub fn delete_voice_connector_termination(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.delete_voice_connector_termination\naws_api/chime delete_voice_connector_termination","url":"aws_api/chime.html#delete_voice_connector_termination"},{"doc":"aws_api/chime","title":"delete_voice_connector_termination_credentials","content":"pub fn delete_voice_connector_termination_credentials(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.delete_voice_connector_termination_credentials\naws_api/chime delete_voice_connector_termination_credentials","url":"aws_api/chime.html#delete_voice_connector_termination_credentials"},{"doc":"aws_api/chime","title":"describe_app_instance","content":"pub fn describe_app_instance(\n  client: Client,\n  app_instance_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.describe_app_instance\naws_api/chime describe_app_instance","url":"aws_api/chime.html#describe_app_instance"},{"doc":"aws_api/chime","title":"describe_app_instance_admin","content":"pub fn describe_app_instance_admin(\n  client: Client,\n  app_instance_arn: String,\n  app_instance_admin_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.describe_app_instance_admin\naws_api/chime describe_app_instance_admin","url":"aws_api/chime.html#describe_app_instance_admin"},{"doc":"aws_api/chime","title":"describe_app_instance_user","content":"pub fn describe_app_instance_user(\n  client: Client,\n  app_instance_user_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.describe_app_instance_user\naws_api/chime describe_app_instance_user","url":"aws_api/chime.html#describe_app_instance_user"},{"doc":"aws_api/chime","title":"describe_channel","content":"pub fn describe_channel(\n  client: Client,\n  channel_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.describe_channel\naws_api/chime describe_channel","url":"aws_api/chime.html#describe_channel"},{"doc":"aws_api/chime","title":"describe_channel_ban","content":"pub fn describe_channel_ban(\n  client: Client,\n  channel_arn: String,\n  member_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.describe_channel_ban\naws_api/chime describe_channel_ban","url":"aws_api/chime.html#describe_channel_ban"},{"doc":"aws_api/chime","title":"describe_channel_membership","content":"pub fn describe_channel_membership(\n  client: Client,\n  channel_arn: String,\n  member_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.describe_channel_membership\naws_api/chime describe_channel_membership","url":"aws_api/chime.html#describe_channel_membership"},{"doc":"aws_api/chime","title":"describe_channel_membership_for_app_instance_user","content":"pub fn describe_channel_membership_for_app_instance_user(\n  client: Client,\n  channel_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.describe_channel_membership_for_app_instance_user\naws_api/chime describe_channel_membership_for_app_instance_user","url":"aws_api/chime.html#describe_channel_membership_for_app_instance_user"},{"doc":"aws_api/chime","title":"describe_channel_moderated_by_app_instance_user","content":"pub fn describe_channel_moderated_by_app_instance_user(\n  client: Client,\n  channel_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.describe_channel_moderated_by_app_instance_user\naws_api/chime describe_channel_moderated_by_app_instance_user","url":"aws_api/chime.html#describe_channel_moderated_by_app_instance_user"},{"doc":"aws_api/chime","title":"describe_channel_moderator","content":"pub fn describe_channel_moderator(\n  client: Client,\n  channel_arn: String,\n  channel_moderator_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.describe_channel_moderator\naws_api/chime describe_channel_moderator","url":"aws_api/chime.html#describe_channel_moderator"},{"doc":"aws_api/chime","title":"disassociate_phone_number_from_user","content":"pub fn disassociate_phone_number_from_user(\n  client: Client,\n  account_id: String,\n  user_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.disassociate_phone_number_from_user\naws_api/chime disassociate_phone_number_from_user","url":"aws_api/chime.html#disassociate_phone_number_from_user"},{"doc":"aws_api/chime","title":"disassociate_phone_numbers_from_voice_connector","content":"pub fn disassociate_phone_numbers_from_voice_connector(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.disassociate_phone_numbers_from_voice_connector\naws_api/chime disassociate_phone_numbers_from_voice_connector","url":"aws_api/chime.html#disassociate_phone_numbers_from_voice_connector"},{"doc":"aws_api/chime","title":"disassociate_phone_numbers_from_voice_connector_group","content":"pub fn disassociate_phone_numbers_from_voice_connector_group(\n  client: Client,\n  voice_connector_group_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.disassociate_phone_numbers_from_voice_connector_group\naws_api/chime disassociate_phone_numbers_from_voice_connector_group","url":"aws_api/chime.html#disassociate_phone_numbers_from_voice_connector_group"},{"doc":"aws_api/chime","title":"disassociate_signin_delegate_groups_from_account","content":"pub fn disassociate_signin_delegate_groups_from_account(\n  client: Client,\n  account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.disassociate_signin_delegate_groups_from_account\naws_api/chime disassociate_signin_delegate_groups_from_account","url":"aws_api/chime.html#disassociate_signin_delegate_groups_from_account"},{"doc":"aws_api/chime","title":"get_account","content":"pub fn get_account(\n  client: Client,\n  account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.get_account\naws_api/chime get_account","url":"aws_api/chime.html#get_account"},{"doc":"aws_api/chime","title":"get_account_settings","content":"pub fn get_account_settings(\n  client: Client,\n  account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.get_account_settings\naws_api/chime get_account_settings","url":"aws_api/chime.html#get_account_settings"},{"doc":"aws_api/chime","title":"get_app_instance_retention_settings","content":"pub fn get_app_instance_retention_settings(\n  client: Client,\n  app_instance_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.get_app_instance_retention_settings\naws_api/chime get_app_instance_retention_settings","url":"aws_api/chime.html#get_app_instance_retention_settings"},{"doc":"aws_api/chime","title":"get_app_instance_streaming_configurations","content":"pub fn get_app_instance_streaming_configurations(\n  client: Client,\n  app_instance_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.get_app_instance_streaming_configurations\naws_api/chime get_app_instance_streaming_configurations","url":"aws_api/chime.html#get_app_instance_streaming_configurations"},{"doc":"aws_api/chime","title":"get_attendee","content":"pub fn get_attendee(\n  client: Client,\n  meeting_id: String,\n  attendee_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.get_attendee\naws_api/chime get_attendee","url":"aws_api/chime.html#get_attendee"},{"doc":"aws_api/chime","title":"get_bot","content":"pub fn get_bot(\n  client: Client,\n  account_id: String,\n  bot_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.get_bot\naws_api/chime get_bot","url":"aws_api/chime.html#get_bot"},{"doc":"aws_api/chime","title":"get_channel_message","content":"pub fn get_channel_message(\n  client: Client,\n  channel_arn: String,\n  message_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.get_channel_message\naws_api/chime get_channel_message","url":"aws_api/chime.html#get_channel_message"},{"doc":"aws_api/chime","title":"get_events_configuration","content":"pub fn get_events_configuration(\n  client: Client,\n  account_id: String,\n  bot_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.get_events_configuration\naws_api/chime get_events_configuration","url":"aws_api/chime.html#get_events_configuration"},{"doc":"aws_api/chime","title":"get_global_settings","content":"pub fn get_global_settings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.get_global_settings\naws_api/chime get_global_settings","url":"aws_api/chime.html#get_global_settings"},{"doc":"aws_api/chime","title":"get_media_capture_pipeline","content":"pub fn get_media_capture_pipeline(\n  client: Client,\n  media_pipeline_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.get_media_capture_pipeline\naws_api/chime get_media_capture_pipeline","url":"aws_api/chime.html#get_media_capture_pipeline"},{"doc":"aws_api/chime","title":"get_meeting","content":"pub fn get_meeting(\n  client: Client,\n  meeting_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.get_meeting\naws_api/chime get_meeting","url":"aws_api/chime.html#get_meeting"},{"doc":"aws_api/chime","title":"get_messaging_session_endpoint","content":"pub fn get_messaging_session_endpoint(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.get_messaging_session_endpoint\naws_api/chime get_messaging_session_endpoint","url":"aws_api/chime.html#get_messaging_session_endpoint"},{"doc":"aws_api/chime","title":"get_phone_number","content":"pub fn get_phone_number(\n  client: Client,\n  phone_number_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.get_phone_number\naws_api/chime get_phone_number","url":"aws_api/chime.html#get_phone_number"},{"doc":"aws_api/chime","title":"get_phone_number_order","content":"pub fn get_phone_number_order(\n  client: Client,\n  phone_number_order_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.get_phone_number_order\naws_api/chime get_phone_number_order","url":"aws_api/chime.html#get_phone_number_order"},{"doc":"aws_api/chime","title":"get_phone_number_settings","content":"pub fn get_phone_number_settings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.get_phone_number_settings\naws_api/chime get_phone_number_settings","url":"aws_api/chime.html#get_phone_number_settings"},{"doc":"aws_api/chime","title":"get_proxy_session","content":"pub fn get_proxy_session(\n  client: Client,\n  voice_connector_id: String,\n  proxy_session_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.get_proxy_session\naws_api/chime get_proxy_session","url":"aws_api/chime.html#get_proxy_session"},{"doc":"aws_api/chime","title":"get_retention_settings","content":"pub fn get_retention_settings(\n  client: Client,\n  account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.get_retention_settings\naws_api/chime get_retention_settings","url":"aws_api/chime.html#get_retention_settings"},{"doc":"aws_api/chime","title":"get_room","content":"pub fn get_room(\n  client: Client,\n  account_id: String,\n  room_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.get_room\naws_api/chime get_room","url":"aws_api/chime.html#get_room"},{"doc":"aws_api/chime","title":"get_sip_media_application","content":"pub fn get_sip_media_application(\n  client: Client,\n  sip_media_application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.get_sip_media_application\naws_api/chime get_sip_media_application","url":"aws_api/chime.html#get_sip_media_application"},{"doc":"aws_api/chime","title":"get_sip_media_application_logging_configuration","content":"pub fn get_sip_media_application_logging_configuration(\n  client: Client,\n  sip_media_application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.get_sip_media_application_logging_configuration\naws_api/chime get_sip_media_application_logging_configuration","url":"aws_api/chime.html#get_sip_media_application_logging_configuration"},{"doc":"aws_api/chime","title":"get_sip_rule","content":"pub fn get_sip_rule(\n  client: Client,\n  sip_rule_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.get_sip_rule\naws_api/chime get_sip_rule","url":"aws_api/chime.html#get_sip_rule"},{"doc":"aws_api/chime","title":"get_user","content":"pub fn get_user(\n  client: Client,\n  account_id: String,\n  user_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.get_user\naws_api/chime get_user","url":"aws_api/chime.html#get_user"},{"doc":"aws_api/chime","title":"get_user_settings","content":"pub fn get_user_settings(\n  client: Client,\n  account_id: String,\n  user_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.get_user_settings\naws_api/chime get_user_settings","url":"aws_api/chime.html#get_user_settings"},{"doc":"aws_api/chime","title":"get_voice_connector","content":"pub fn get_voice_connector(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.get_voice_connector\naws_api/chime get_voice_connector","url":"aws_api/chime.html#get_voice_connector"},{"doc":"aws_api/chime","title":"get_voice_connector_emergency_calling_configuration","content":"pub fn get_voice_connector_emergency_calling_configuration(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.get_voice_connector_emergency_calling_configuration\naws_api/chime get_voice_connector_emergency_calling_configuration","url":"aws_api/chime.html#get_voice_connector_emergency_calling_configuration"},{"doc":"aws_api/chime","title":"get_voice_connector_group","content":"pub fn get_voice_connector_group(\n  client: Client,\n  voice_connector_group_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.get_voice_connector_group\naws_api/chime get_voice_connector_group","url":"aws_api/chime.html#get_voice_connector_group"},{"doc":"aws_api/chime","title":"get_voice_connector_logging_configuration","content":"pub fn get_voice_connector_logging_configuration(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.get_voice_connector_logging_configuration\naws_api/chime get_voice_connector_logging_configuration","url":"aws_api/chime.html#get_voice_connector_logging_configuration"},{"doc":"aws_api/chime","title":"get_voice_connector_origination","content":"pub fn get_voice_connector_origination(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.get_voice_connector_origination\naws_api/chime get_voice_connector_origination","url":"aws_api/chime.html#get_voice_connector_origination"},{"doc":"aws_api/chime","title":"get_voice_connector_proxy","content":"pub fn get_voice_connector_proxy(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.get_voice_connector_proxy\naws_api/chime get_voice_connector_proxy","url":"aws_api/chime.html#get_voice_connector_proxy"},{"doc":"aws_api/chime","title":"get_voice_connector_streaming_configuration","content":"pub fn get_voice_connector_streaming_configuration(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.get_voice_connector_streaming_configuration\naws_api/chime get_voice_connector_streaming_configuration","url":"aws_api/chime.html#get_voice_connector_streaming_configuration"},{"doc":"aws_api/chime","title":"get_voice_connector_termination","content":"pub fn get_voice_connector_termination(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.get_voice_connector_termination\naws_api/chime get_voice_connector_termination","url":"aws_api/chime.html#get_voice_connector_termination"},{"doc":"aws_api/chime","title":"get_voice_connector_termination_health","content":"pub fn get_voice_connector_termination_health(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.get_voice_connector_termination_health\naws_api/chime get_voice_connector_termination_health","url":"aws_api/chime.html#get_voice_connector_termination_health"},{"doc":"aws_api/chime","title":"invite_users","content":"pub fn invite_users(\n  client: Client,\n  account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.invite_users\naws_api/chime invite_users","url":"aws_api/chime.html#invite_users"},{"doc":"aws_api/chime","title":"list_accounts","content":"pub fn list_accounts(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.list_accounts\naws_api/chime list_accounts","url":"aws_api/chime.html#list_accounts"},{"doc":"aws_api/chime","title":"list_app_instance_admins","content":"pub fn list_app_instance_admins(\n  client: Client,\n  app_instance_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.list_app_instance_admins\naws_api/chime list_app_instance_admins","url":"aws_api/chime.html#list_app_instance_admins"},{"doc":"aws_api/chime","title":"list_app_instance_users","content":"pub fn list_app_instance_users(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.list_app_instance_users\naws_api/chime list_app_instance_users","url":"aws_api/chime.html#list_app_instance_users"},{"doc":"aws_api/chime","title":"list_app_instances","content":"pub fn list_app_instances(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.list_app_instances\naws_api/chime list_app_instances","url":"aws_api/chime.html#list_app_instances"},{"doc":"aws_api/chime","title":"list_attendee_tags","content":"pub fn list_attendee_tags(\n  client: Client,\n  meeting_id: String,\n  attendee_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.list_attendee_tags\naws_api/chime list_attendee_tags","url":"aws_api/chime.html#list_attendee_tags"},{"doc":"aws_api/chime","title":"list_attendees","content":"pub fn list_attendees(\n  client: Client,\n  meeting_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.list_attendees\naws_api/chime list_attendees","url":"aws_api/chime.html#list_attendees"},{"doc":"aws_api/chime","title":"list_bots","content":"pub fn list_bots(\n  client: Client,\n  account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.list_bots\naws_api/chime list_bots","url":"aws_api/chime.html#list_bots"},{"doc":"aws_api/chime","title":"list_channel_bans","content":"pub fn list_channel_bans(\n  client: Client,\n  channel_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.list_channel_bans\naws_api/chime list_channel_bans","url":"aws_api/chime.html#list_channel_bans"},{"doc":"aws_api/chime","title":"list_channel_memberships","content":"pub fn list_channel_memberships(\n  client: Client,\n  channel_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.list_channel_memberships\naws_api/chime list_channel_memberships","url":"aws_api/chime.html#list_channel_memberships"},{"doc":"aws_api/chime","title":"list_channel_memberships_for_app_instance_user","content":"pub fn list_channel_memberships_for_app_instance_user(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.list_channel_memberships_for_app_instance_user\naws_api/chime list_channel_memberships_for_app_instance_user","url":"aws_api/chime.html#list_channel_memberships_for_app_instance_user"},{"doc":"aws_api/chime","title":"list_channel_messages","content":"pub fn list_channel_messages(\n  client: Client,\n  channel_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.list_channel_messages\naws_api/chime list_channel_messages","url":"aws_api/chime.html#list_channel_messages"},{"doc":"aws_api/chime","title":"list_channel_moderators","content":"pub fn list_channel_moderators(\n  client: Client,\n  channel_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.list_channel_moderators\naws_api/chime list_channel_moderators","url":"aws_api/chime.html#list_channel_moderators"},{"doc":"aws_api/chime","title":"list_channels","content":"pub fn list_channels(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.list_channels\naws_api/chime list_channels","url":"aws_api/chime.html#list_channels"},{"doc":"aws_api/chime","title":"list_channels_moderated_by_app_instance_user","content":"pub fn list_channels_moderated_by_app_instance_user(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.list_channels_moderated_by_app_instance_user\naws_api/chime list_channels_moderated_by_app_instance_user","url":"aws_api/chime.html#list_channels_moderated_by_app_instance_user"},{"doc":"aws_api/chime","title":"list_media_capture_pipelines","content":"pub fn list_media_capture_pipelines(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.list_media_capture_pipelines\naws_api/chime list_media_capture_pipelines","url":"aws_api/chime.html#list_media_capture_pipelines"},{"doc":"aws_api/chime","title":"list_meeting_tags","content":"pub fn list_meeting_tags(\n  client: Client,\n  meeting_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.list_meeting_tags\naws_api/chime list_meeting_tags","url":"aws_api/chime.html#list_meeting_tags"},{"doc":"aws_api/chime","title":"list_meetings","content":"pub fn list_meetings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.list_meetings\naws_api/chime list_meetings","url":"aws_api/chime.html#list_meetings"},{"doc":"aws_api/chime","title":"list_phone_number_orders","content":"pub fn list_phone_number_orders(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.list_phone_number_orders\naws_api/chime list_phone_number_orders","url":"aws_api/chime.html#list_phone_number_orders"},{"doc":"aws_api/chime","title":"list_phone_numbers","content":"pub fn list_phone_numbers(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.list_phone_numbers\naws_api/chime list_phone_numbers","url":"aws_api/chime.html#list_phone_numbers"},{"doc":"aws_api/chime","title":"list_proxy_sessions","content":"pub fn list_proxy_sessions(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.list_proxy_sessions\naws_api/chime list_proxy_sessions","url":"aws_api/chime.html#list_proxy_sessions"},{"doc":"aws_api/chime","title":"list_room_memberships","content":"pub fn list_room_memberships(\n  client: Client,\n  account_id: String,\n  room_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.list_room_memberships\naws_api/chime list_room_memberships","url":"aws_api/chime.html#list_room_memberships"},{"doc":"aws_api/chime","title":"list_rooms","content":"pub fn list_rooms(\n  client: Client,\n  account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.list_rooms\naws_api/chime list_rooms","url":"aws_api/chime.html#list_rooms"},{"doc":"aws_api/chime","title":"list_sip_media_applications","content":"pub fn list_sip_media_applications(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.list_sip_media_applications\naws_api/chime list_sip_media_applications","url":"aws_api/chime.html#list_sip_media_applications"},{"doc":"aws_api/chime","title":"list_sip_rules","content":"pub fn list_sip_rules(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.list_sip_rules\naws_api/chime list_sip_rules","url":"aws_api/chime.html#list_sip_rules"},{"doc":"aws_api/chime","title":"list_supported_phone_number_countries","content":"pub fn list_supported_phone_number_countries(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.list_supported_phone_number_countries\naws_api/chime list_supported_phone_number_countries","url":"aws_api/chime.html#list_supported_phone_number_countries"},{"doc":"aws_api/chime","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.list_tags_for_resource\naws_api/chime list_tags_for_resource","url":"aws_api/chime.html#list_tags_for_resource"},{"doc":"aws_api/chime","title":"list_users","content":"pub fn list_users(\n  client: Client,\n  account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.list_users\naws_api/chime list_users","url":"aws_api/chime.html#list_users"},{"doc":"aws_api/chime","title":"list_voice_connector_groups","content":"pub fn list_voice_connector_groups(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.list_voice_connector_groups\naws_api/chime list_voice_connector_groups","url":"aws_api/chime.html#list_voice_connector_groups"},{"doc":"aws_api/chime","title":"list_voice_connector_termination_credentials","content":"pub fn list_voice_connector_termination_credentials(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.list_voice_connector_termination_credentials\naws_api/chime list_voice_connector_termination_credentials","url":"aws_api/chime.html#list_voice_connector_termination_credentials"},{"doc":"aws_api/chime","title":"list_voice_connectors","content":"pub fn list_voice_connectors(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.list_voice_connectors\naws_api/chime list_voice_connectors","url":"aws_api/chime.html#list_voice_connectors"},{"doc":"aws_api/chime","title":"logout_user","content":"pub fn logout_user(\n  client: Client,\n  account_id: String,\n  user_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.logout_user\naws_api/chime logout_user","url":"aws_api/chime.html#logout_user"},{"doc":"aws_api/chime","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/chime.new\naws_api/chime new","url":"aws_api/chime.html#new"},{"doc":"aws_api/chime","title":"put_app_instance_retention_settings","content":"pub fn put_app_instance_retention_settings(\n  client: Client,\n  app_instance_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.put_app_instance_retention_settings\naws_api/chime put_app_instance_retention_settings","url":"aws_api/chime.html#put_app_instance_retention_settings"},{"doc":"aws_api/chime","title":"put_app_instance_streaming_configurations","content":"pub fn put_app_instance_streaming_configurations(\n  client: Client,\n  app_instance_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.put_app_instance_streaming_configurations\naws_api/chime put_app_instance_streaming_configurations","url":"aws_api/chime.html#put_app_instance_streaming_configurations"},{"doc":"aws_api/chime","title":"put_events_configuration","content":"pub fn put_events_configuration(\n  client: Client,\n  account_id: String,\n  bot_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.put_events_configuration\naws_api/chime put_events_configuration","url":"aws_api/chime.html#put_events_configuration"},{"doc":"aws_api/chime","title":"put_retention_settings","content":"pub fn put_retention_settings(\n  client: Client,\n  account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.put_retention_settings\naws_api/chime put_retention_settings","url":"aws_api/chime.html#put_retention_settings"},{"doc":"aws_api/chime","title":"put_sip_media_application_logging_configuration","content":"pub fn put_sip_media_application_logging_configuration(\n  client: Client,\n  sip_media_application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.put_sip_media_application_logging_configuration\naws_api/chime put_sip_media_application_logging_configuration","url":"aws_api/chime.html#put_sip_media_application_logging_configuration"},{"doc":"aws_api/chime","title":"put_voice_connector_emergency_calling_configuration","content":"pub fn put_voice_connector_emergency_calling_configuration(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.put_voice_connector_emergency_calling_configuration\naws_api/chime put_voice_connector_emergency_calling_configuration","url":"aws_api/chime.html#put_voice_connector_emergency_calling_configuration"},{"doc":"aws_api/chime","title":"put_voice_connector_logging_configuration","content":"pub fn put_voice_connector_logging_configuration(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.put_voice_connector_logging_configuration\naws_api/chime put_voice_connector_logging_configuration","url":"aws_api/chime.html#put_voice_connector_logging_configuration"},{"doc":"aws_api/chime","title":"put_voice_connector_origination","content":"pub fn put_voice_connector_origination(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.put_voice_connector_origination\naws_api/chime put_voice_connector_origination","url":"aws_api/chime.html#put_voice_connector_origination"},{"doc":"aws_api/chime","title":"put_voice_connector_proxy","content":"pub fn put_voice_connector_proxy(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.put_voice_connector_proxy\naws_api/chime put_voice_connector_proxy","url":"aws_api/chime.html#put_voice_connector_proxy"},{"doc":"aws_api/chime","title":"put_voice_connector_streaming_configuration","content":"pub fn put_voice_connector_streaming_configuration(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.put_voice_connector_streaming_configuration\naws_api/chime put_voice_connector_streaming_configuration","url":"aws_api/chime.html#put_voice_connector_streaming_configuration"},{"doc":"aws_api/chime","title":"put_voice_connector_termination","content":"pub fn put_voice_connector_termination(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.put_voice_connector_termination\naws_api/chime put_voice_connector_termination","url":"aws_api/chime.html#put_voice_connector_termination"},{"doc":"aws_api/chime","title":"put_voice_connector_termination_credentials","content":"pub fn put_voice_connector_termination_credentials(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.put_voice_connector_termination_credentials\naws_api/chime put_voice_connector_termination_credentials","url":"aws_api/chime.html#put_voice_connector_termination_credentials"},{"doc":"aws_api/chime","title":"redact_channel_message","content":"pub fn redact_channel_message(\n  client: Client,\n  channel_arn: String,\n  message_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.redact_channel_message\naws_api/chime redact_channel_message","url":"aws_api/chime.html#redact_channel_message"},{"doc":"aws_api/chime","title":"redact_conversation_message","content":"pub fn redact_conversation_message(\n  client: Client,\n  account_id: String,\n  conversation_id: String,\n  message_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.redact_conversation_message\naws_api/chime redact_conversation_message","url":"aws_api/chime.html#redact_conversation_message"},{"doc":"aws_api/chime","title":"redact_room_message","content":"pub fn redact_room_message(\n  client: Client,\n  account_id: String,\n  room_id: String,\n  message_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.redact_room_message\naws_api/chime redact_room_message","url":"aws_api/chime.html#redact_room_message"},{"doc":"aws_api/chime","title":"regenerate_security_token","content":"pub fn regenerate_security_token(\n  client: Client,\n  account_id: String,\n  bot_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.regenerate_security_token\naws_api/chime regenerate_security_token","url":"aws_api/chime.html#regenerate_security_token"},{"doc":"aws_api/chime","title":"reset_personal_pin","content":"pub fn reset_personal_pin(\n  client: Client,\n  account_id: String,\n  user_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.reset_personal_pin\naws_api/chime reset_personal_pin","url":"aws_api/chime.html#reset_personal_pin"},{"doc":"aws_api/chime","title":"restore_phone_number","content":"pub fn restore_phone_number(\n  client: Client,\n  phone_number_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.restore_phone_number\naws_api/chime restore_phone_number","url":"aws_api/chime.html#restore_phone_number"},{"doc":"aws_api/chime","title":"search_available_phone_numbers","content":"pub fn search_available_phone_numbers(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.search_available_phone_numbers\naws_api/chime search_available_phone_numbers","url":"aws_api/chime.html#search_available_phone_numbers"},{"doc":"aws_api/chime","title":"send_channel_message","content":"pub fn send_channel_message(\n  client: Client,\n  channel_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.send_channel_message\naws_api/chime send_channel_message","url":"aws_api/chime.html#send_channel_message"},{"doc":"aws_api/chime","title":"start_meeting_transcription","content":"pub fn start_meeting_transcription(\n  client: Client,\n  meeting_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.start_meeting_transcription\naws_api/chime start_meeting_transcription","url":"aws_api/chime.html#start_meeting_transcription"},{"doc":"aws_api/chime","title":"stop_meeting_transcription","content":"pub fn stop_meeting_transcription(\n  client: Client,\n  meeting_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.stop_meeting_transcription\naws_api/chime stop_meeting_transcription","url":"aws_api/chime.html#stop_meeting_transcription"},{"doc":"aws_api/chime","title":"tag_attendee","content":"pub fn tag_attendee(\n  client: Client,\n  meeting_id: String,\n  attendee_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.tag_attendee\naws_api/chime tag_attendee","url":"aws_api/chime.html#tag_attendee"},{"doc":"aws_api/chime","title":"tag_meeting","content":"pub fn tag_meeting(\n  client: Client,\n  meeting_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.tag_meeting\naws_api/chime tag_meeting","url":"aws_api/chime.html#tag_meeting"},{"doc":"aws_api/chime","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.tag_resource\naws_api/chime tag_resource","url":"aws_api/chime.html#tag_resource"},{"doc":"aws_api/chime","title":"untag_attendee","content":"pub fn untag_attendee(\n  client: Client,\n  meeting_id: String,\n  attendee_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.untag_attendee\naws_api/chime untag_attendee","url":"aws_api/chime.html#untag_attendee"},{"doc":"aws_api/chime","title":"untag_meeting","content":"pub fn untag_meeting(\n  client: Client,\n  meeting_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.untag_meeting\naws_api/chime untag_meeting","url":"aws_api/chime.html#untag_meeting"},{"doc":"aws_api/chime","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.untag_resource\naws_api/chime untag_resource","url":"aws_api/chime.html#untag_resource"},{"doc":"aws_api/chime","title":"update_account","content":"pub fn update_account(\n  client: Client,\n  account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.update_account\naws_api/chime update_account","url":"aws_api/chime.html#update_account"},{"doc":"aws_api/chime","title":"update_account_settings","content":"pub fn update_account_settings(\n  client: Client,\n  account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.update_account_settings\naws_api/chime update_account_settings","url":"aws_api/chime.html#update_account_settings"},{"doc":"aws_api/chime","title":"update_app_instance","content":"pub fn update_app_instance(\n  client: Client,\n  app_instance_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.update_app_instance\naws_api/chime update_app_instance","url":"aws_api/chime.html#update_app_instance"},{"doc":"aws_api/chime","title":"update_app_instance_user","content":"pub fn update_app_instance_user(\n  client: Client,\n  app_instance_user_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.update_app_instance_user\naws_api/chime update_app_instance_user","url":"aws_api/chime.html#update_app_instance_user"},{"doc":"aws_api/chime","title":"update_bot","content":"pub fn update_bot(\n  client: Client,\n  account_id: String,\n  bot_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.update_bot\naws_api/chime update_bot","url":"aws_api/chime.html#update_bot"},{"doc":"aws_api/chime","title":"update_channel","content":"pub fn update_channel(\n  client: Client,\n  channel_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.update_channel\naws_api/chime update_channel","url":"aws_api/chime.html#update_channel"},{"doc":"aws_api/chime","title":"update_channel_message","content":"pub fn update_channel_message(\n  client: Client,\n  channel_arn: String,\n  message_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.update_channel_message\naws_api/chime update_channel_message","url":"aws_api/chime.html#update_channel_message"},{"doc":"aws_api/chime","title":"update_channel_read_marker","content":"pub fn update_channel_read_marker(\n  client: Client,\n  channel_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.update_channel_read_marker\naws_api/chime update_channel_read_marker","url":"aws_api/chime.html#update_channel_read_marker"},{"doc":"aws_api/chime","title":"update_global_settings","content":"pub fn update_global_settings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.update_global_settings\naws_api/chime update_global_settings","url":"aws_api/chime.html#update_global_settings"},{"doc":"aws_api/chime","title":"update_phone_number","content":"pub fn update_phone_number(\n  client: Client,\n  phone_number_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.update_phone_number\naws_api/chime update_phone_number","url":"aws_api/chime.html#update_phone_number"},{"doc":"aws_api/chime","title":"update_phone_number_settings","content":"pub fn update_phone_number_settings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.update_phone_number_settings\naws_api/chime update_phone_number_settings","url":"aws_api/chime.html#update_phone_number_settings"},{"doc":"aws_api/chime","title":"update_proxy_session","content":"pub fn update_proxy_session(\n  client: Client,\n  voice_connector_id: String,\n  proxy_session_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.update_proxy_session\naws_api/chime update_proxy_session","url":"aws_api/chime.html#update_proxy_session"},{"doc":"aws_api/chime","title":"update_room","content":"pub fn update_room(\n  client: Client,\n  account_id: String,\n  room_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.update_room\naws_api/chime update_room","url":"aws_api/chime.html#update_room"},{"doc":"aws_api/chime","title":"update_room_membership","content":"pub fn update_room_membership(\n  client: Client,\n  account_id: String,\n  room_id: String,\n  member_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.update_room_membership\naws_api/chime update_room_membership","url":"aws_api/chime.html#update_room_membership"},{"doc":"aws_api/chime","title":"update_sip_media_application","content":"pub fn update_sip_media_application(\n  client: Client,\n  sip_media_application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.update_sip_media_application\naws_api/chime update_sip_media_application","url":"aws_api/chime.html#update_sip_media_application"},{"doc":"aws_api/chime","title":"update_sip_media_application_call","content":"pub fn update_sip_media_application_call(\n  client: Client,\n  sip_media_application_id: String,\n  transaction_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.update_sip_media_application_call\naws_api/chime update_sip_media_application_call","url":"aws_api/chime.html#update_sip_media_application_call"},{"doc":"aws_api/chime","title":"update_sip_rule","content":"pub fn update_sip_rule(\n  client: Client,\n  sip_rule_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.update_sip_rule\naws_api/chime update_sip_rule","url":"aws_api/chime.html#update_sip_rule"},{"doc":"aws_api/chime","title":"update_user","content":"pub fn update_user(\n  client: Client,\n  account_id: String,\n  user_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.update_user\naws_api/chime update_user","url":"aws_api/chime.html#update_user"},{"doc":"aws_api/chime","title":"update_user_settings","content":"pub fn update_user_settings(\n  client: Client,\n  account_id: String,\n  user_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.update_user_settings\naws_api/chime update_user_settings","url":"aws_api/chime.html#update_user_settings"},{"doc":"aws_api/chime","title":"update_voice_connector","content":"pub fn update_voice_connector(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.update_voice_connector\naws_api/chime update_voice_connector","url":"aws_api/chime.html#update_voice_connector"},{"doc":"aws_api/chime","title":"update_voice_connector_group","content":"pub fn update_voice_connector_group(\n  client: Client,\n  voice_connector_group_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.update_voice_connector_group\naws_api/chime update_voice_connector_group","url":"aws_api/chime.html#update_voice_connector_group"},{"doc":"aws_api/chime","title":"validate_e911_address","content":"pub fn validate_e911_address(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime.validate_e911_address\naws_api/chime validate_e911_address","url":"aws_api/chime.html#validate_e911_address"},{"doc":"aws_api/chime","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/chime.with_custom_endpoint\naws_api/chime with_custom_endpoint","url":"aws_api/chime.html#with_custom_endpoint"},{"doc":"aws_api/chime","title":"aws_api/chime","content":"","url":"aws_api/chime.html"},{"doc":"aws_api/chime_sdk_identity","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/chime_sdk_identity.Client\naws_api/chime_sdk_identity Client","url":"aws_api/chime_sdk_identity.html#Client"},{"doc":"aws_api/chime_sdk_identity","title":"create_app_instance","content":"pub fn create_app_instance(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_identity.create_app_instance\naws_api/chime_sdk_identity create_app_instance","url":"aws_api/chime_sdk_identity.html#create_app_instance"},{"doc":"aws_api/chime_sdk_identity","title":"create_app_instance_admin","content":"pub fn create_app_instance_admin(\n  client: Client,\n  app_instance_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_identity.create_app_instance_admin\naws_api/chime_sdk_identity create_app_instance_admin","url":"aws_api/chime_sdk_identity.html#create_app_instance_admin"},{"doc":"aws_api/chime_sdk_identity","title":"create_app_instance_bot","content":"pub fn create_app_instance_bot(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_identity.create_app_instance_bot\naws_api/chime_sdk_identity create_app_instance_bot","url":"aws_api/chime_sdk_identity.html#create_app_instance_bot"},{"doc":"aws_api/chime_sdk_identity","title":"create_app_instance_user","content":"pub fn create_app_instance_user(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_identity.create_app_instance_user\naws_api/chime_sdk_identity create_app_instance_user","url":"aws_api/chime_sdk_identity.html#create_app_instance_user"},{"doc":"aws_api/chime_sdk_identity","title":"delete_app_instance","content":"pub fn delete_app_instance(\n  client: Client,\n  app_instance_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_identity.delete_app_instance\naws_api/chime_sdk_identity delete_app_instance","url":"aws_api/chime_sdk_identity.html#delete_app_instance"},{"doc":"aws_api/chime_sdk_identity","title":"delete_app_instance_admin","content":"pub fn delete_app_instance_admin(\n  client: Client,\n  app_instance_arn: String,\n  app_instance_admin_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_identity.delete_app_instance_admin\naws_api/chime_sdk_identity delete_app_instance_admin","url":"aws_api/chime_sdk_identity.html#delete_app_instance_admin"},{"doc":"aws_api/chime_sdk_identity","title":"delete_app_instance_bot","content":"pub fn delete_app_instance_bot(\n  client: Client,\n  app_instance_bot_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_identity.delete_app_instance_bot\naws_api/chime_sdk_identity delete_app_instance_bot","url":"aws_api/chime_sdk_identity.html#delete_app_instance_bot"},{"doc":"aws_api/chime_sdk_identity","title":"delete_app_instance_user","content":"pub fn delete_app_instance_user(\n  client: Client,\n  app_instance_user_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_identity.delete_app_instance_user\naws_api/chime_sdk_identity delete_app_instance_user","url":"aws_api/chime_sdk_identity.html#delete_app_instance_user"},{"doc":"aws_api/chime_sdk_identity","title":"deregister_app_instance_user_endpoint","content":"pub fn deregister_app_instance_user_endpoint(\n  client: Client,\n  app_instance_user_arn: String,\n  endpoint_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_identity.deregister_app_instance_user_endpoint\naws_api/chime_sdk_identity deregister_app_instance_user_endpoint","url":"aws_api/chime_sdk_identity.html#deregister_app_instance_user_endpoint"},{"doc":"aws_api/chime_sdk_identity","title":"describe_app_instance","content":"pub fn describe_app_instance(\n  client: Client,\n  app_instance_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_identity.describe_app_instance\naws_api/chime_sdk_identity describe_app_instance","url":"aws_api/chime_sdk_identity.html#describe_app_instance"},{"doc":"aws_api/chime_sdk_identity","title":"describe_app_instance_admin","content":"pub fn describe_app_instance_admin(\n  client: Client,\n  app_instance_arn: String,\n  app_instance_admin_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_identity.describe_app_instance_admin\naws_api/chime_sdk_identity describe_app_instance_admin","url":"aws_api/chime_sdk_identity.html#describe_app_instance_admin"},{"doc":"aws_api/chime_sdk_identity","title":"describe_app_instance_bot","content":"pub fn describe_app_instance_bot(\n  client: Client,\n  app_instance_bot_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_identity.describe_app_instance_bot\naws_api/chime_sdk_identity describe_app_instance_bot","url":"aws_api/chime_sdk_identity.html#describe_app_instance_bot"},{"doc":"aws_api/chime_sdk_identity","title":"describe_app_instance_user","content":"pub fn describe_app_instance_user(\n  client: Client,\n  app_instance_user_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_identity.describe_app_instance_user\naws_api/chime_sdk_identity describe_app_instance_user","url":"aws_api/chime_sdk_identity.html#describe_app_instance_user"},{"doc":"aws_api/chime_sdk_identity","title":"describe_app_instance_user_endpoint","content":"pub fn describe_app_instance_user_endpoint(\n  client: Client,\n  app_instance_user_arn: String,\n  endpoint_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_identity.describe_app_instance_user_endpoint\naws_api/chime_sdk_identity describe_app_instance_user_endpoint","url":"aws_api/chime_sdk_identity.html#describe_app_instance_user_endpoint"},{"doc":"aws_api/chime_sdk_identity","title":"get_app_instance_retention_settings","content":"pub fn get_app_instance_retention_settings(\n  client: Client,\n  app_instance_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_identity.get_app_instance_retention_settings\naws_api/chime_sdk_identity get_app_instance_retention_settings","url":"aws_api/chime_sdk_identity.html#get_app_instance_retention_settings"},{"doc":"aws_api/chime_sdk_identity","title":"list_app_instance_admins","content":"pub fn list_app_instance_admins(\n  client: Client,\n  app_instance_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_identity.list_app_instance_admins\naws_api/chime_sdk_identity list_app_instance_admins","url":"aws_api/chime_sdk_identity.html#list_app_instance_admins"},{"doc":"aws_api/chime_sdk_identity","title":"list_app_instance_bots","content":"pub fn list_app_instance_bots(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_identity.list_app_instance_bots\naws_api/chime_sdk_identity list_app_instance_bots","url":"aws_api/chime_sdk_identity.html#list_app_instance_bots"},{"doc":"aws_api/chime_sdk_identity","title":"list_app_instance_user_endpoints","content":"pub fn list_app_instance_user_endpoints(\n  client: Client,\n  app_instance_user_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_identity.list_app_instance_user_endpoints\naws_api/chime_sdk_identity list_app_instance_user_endpoints","url":"aws_api/chime_sdk_identity.html#list_app_instance_user_endpoints"},{"doc":"aws_api/chime_sdk_identity","title":"list_app_instance_users","content":"pub fn list_app_instance_users(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_identity.list_app_instance_users\naws_api/chime_sdk_identity list_app_instance_users","url":"aws_api/chime_sdk_identity.html#list_app_instance_users"},{"doc":"aws_api/chime_sdk_identity","title":"list_app_instances","content":"pub fn list_app_instances(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_identity.list_app_instances\naws_api/chime_sdk_identity list_app_instances","url":"aws_api/chime_sdk_identity.html#list_app_instances"},{"doc":"aws_api/chime_sdk_identity","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_identity.list_tags_for_resource\naws_api/chime_sdk_identity list_tags_for_resource","url":"aws_api/chime_sdk_identity.html#list_tags_for_resource"},{"doc":"aws_api/chime_sdk_identity","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/chime_sdk_identity.new\naws_api/chime_sdk_identity new","url":"aws_api/chime_sdk_identity.html#new"},{"doc":"aws_api/chime_sdk_identity","title":"put_app_instance_retention_settings","content":"pub fn put_app_instance_retention_settings(\n  client: Client,\n  app_instance_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_identity.put_app_instance_retention_settings\naws_api/chime_sdk_identity put_app_instance_retention_settings","url":"aws_api/chime_sdk_identity.html#put_app_instance_retention_settings"},{"doc":"aws_api/chime_sdk_identity","title":"put_app_instance_user_expiration_settings","content":"pub fn put_app_instance_user_expiration_settings(\n  client: Client,\n  app_instance_user_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_identity.put_app_instance_user_expiration_settings\naws_api/chime_sdk_identity put_app_instance_user_expiration_settings","url":"aws_api/chime_sdk_identity.html#put_app_instance_user_expiration_settings"},{"doc":"aws_api/chime_sdk_identity","title":"register_app_instance_user_endpoint","content":"pub fn register_app_instance_user_endpoint(\n  client: Client,\n  app_instance_user_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_identity.register_app_instance_user_endpoint\naws_api/chime_sdk_identity register_app_instance_user_endpoint","url":"aws_api/chime_sdk_identity.html#register_app_instance_user_endpoint"},{"doc":"aws_api/chime_sdk_identity","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_identity.tag_resource\naws_api/chime_sdk_identity tag_resource","url":"aws_api/chime_sdk_identity.html#tag_resource"},{"doc":"aws_api/chime_sdk_identity","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_identity.untag_resource\naws_api/chime_sdk_identity untag_resource","url":"aws_api/chime_sdk_identity.html#untag_resource"},{"doc":"aws_api/chime_sdk_identity","title":"update_app_instance","content":"pub fn update_app_instance(\n  client: Client,\n  app_instance_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_identity.update_app_instance\naws_api/chime_sdk_identity update_app_instance","url":"aws_api/chime_sdk_identity.html#update_app_instance"},{"doc":"aws_api/chime_sdk_identity","title":"update_app_instance_bot","content":"pub fn update_app_instance_bot(\n  client: Client,\n  app_instance_bot_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_identity.update_app_instance_bot\naws_api/chime_sdk_identity update_app_instance_bot","url":"aws_api/chime_sdk_identity.html#update_app_instance_bot"},{"doc":"aws_api/chime_sdk_identity","title":"update_app_instance_user","content":"pub fn update_app_instance_user(\n  client: Client,\n  app_instance_user_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_identity.update_app_instance_user\naws_api/chime_sdk_identity update_app_instance_user","url":"aws_api/chime_sdk_identity.html#update_app_instance_user"},{"doc":"aws_api/chime_sdk_identity","title":"update_app_instance_user_endpoint","content":"pub fn update_app_instance_user_endpoint(\n  client: Client,\n  app_instance_user_arn: String,\n  endpoint_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_identity.update_app_instance_user_endpoint\naws_api/chime_sdk_identity update_app_instance_user_endpoint","url":"aws_api/chime_sdk_identity.html#update_app_instance_user_endpoint"},{"doc":"aws_api/chime_sdk_identity","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/chime_sdk_identity.with_custom_endpoint\naws_api/chime_sdk_identity with_custom_endpoint","url":"aws_api/chime_sdk_identity.html#with_custom_endpoint"},{"doc":"aws_api/chime_sdk_identity","title":"aws_api/chime_sdk_identity","content":"","url":"aws_api/chime_sdk_identity.html"},{"doc":"aws_api/chime_sdk_media_pipelines","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/chime_sdk_media_pipelines.Client\naws_api/chime_sdk_media_pipelines Client","url":"aws_api/chime_sdk_media_pipelines.html#Client"},{"doc":"aws_api/chime_sdk_media_pipelines","title":"create_media_capture_pipeline","content":"pub fn create_media_capture_pipeline(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_media_pipelines.create_media_capture_pipeline\naws_api/chime_sdk_media_pipelines create_media_capture_pipeline","url":"aws_api/chime_sdk_media_pipelines.html#create_media_capture_pipeline"},{"doc":"aws_api/chime_sdk_media_pipelines","title":"create_media_concatenation_pipeline","content":"pub fn create_media_concatenation_pipeline(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_media_pipelines.create_media_concatenation_pipeline\naws_api/chime_sdk_media_pipelines create_media_concatenation_pipeline","url":"aws_api/chime_sdk_media_pipelines.html#create_media_concatenation_pipeline"},{"doc":"aws_api/chime_sdk_media_pipelines","title":"create_media_insights_pipeline","content":"pub fn create_media_insights_pipeline(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_media_pipelines.create_media_insights_pipeline\naws_api/chime_sdk_media_pipelines create_media_insights_pipeline","url":"aws_api/chime_sdk_media_pipelines.html#create_media_insights_pipeline"},{"doc":"aws_api/chime_sdk_media_pipelines","title":"create_media_insights_pipeline_configuration","content":"pub fn create_media_insights_pipeline_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_media_pipelines.create_media_insights_pipeline_configuration\naws_api/chime_sdk_media_pipelines create_media_insights_pipeline_configuration","url":"aws_api/chime_sdk_media_pipelines.html#create_media_insights_pipeline_configuration"},{"doc":"aws_api/chime_sdk_media_pipelines","title":"create_media_live_connector_pipeline","content":"pub fn create_media_live_connector_pipeline(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_media_pipelines.create_media_live_connector_pipeline\naws_api/chime_sdk_media_pipelines create_media_live_connector_pipeline","url":"aws_api/chime_sdk_media_pipelines.html#create_media_live_connector_pipeline"},{"doc":"aws_api/chime_sdk_media_pipelines","title":"create_media_pipeline_kinesis_video_stream_pool","content":"pub fn create_media_pipeline_kinesis_video_stream_pool(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_media_pipelines.create_media_pipeline_kinesis_video_stream_pool\naws_api/chime_sdk_media_pipelines create_media_pipeline_kinesis_video_stream_pool","url":"aws_api/chime_sdk_media_pipelines.html#create_media_pipeline_kinesis_video_stream_pool"},{"doc":"aws_api/chime_sdk_media_pipelines","title":"create_media_stream_pipeline","content":"pub fn create_media_stream_pipeline(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_media_pipelines.create_media_stream_pipeline\naws_api/chime_sdk_media_pipelines create_media_stream_pipeline","url":"aws_api/chime_sdk_media_pipelines.html#create_media_stream_pipeline"},{"doc":"aws_api/chime_sdk_media_pipelines","title":"delete_media_capture_pipeline","content":"pub fn delete_media_capture_pipeline(\n  client: Client,\n  media_pipeline_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_media_pipelines.delete_media_capture_pipeline\naws_api/chime_sdk_media_pipelines delete_media_capture_pipeline","url":"aws_api/chime_sdk_media_pipelines.html#delete_media_capture_pipeline"},{"doc":"aws_api/chime_sdk_media_pipelines","title":"delete_media_insights_pipeline_configuration","content":"pub fn delete_media_insights_pipeline_configuration(\n  client: Client,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_media_pipelines.delete_media_insights_pipeline_configuration\naws_api/chime_sdk_media_pipelines delete_media_insights_pipeline_configuration","url":"aws_api/chime_sdk_media_pipelines.html#delete_media_insights_pipeline_configuration"},{"doc":"aws_api/chime_sdk_media_pipelines","title":"delete_media_pipeline","content":"pub fn delete_media_pipeline(\n  client: Client,\n  media_pipeline_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_media_pipelines.delete_media_pipeline\naws_api/chime_sdk_media_pipelines delete_media_pipeline","url":"aws_api/chime_sdk_media_pipelines.html#delete_media_pipeline"},{"doc":"aws_api/chime_sdk_media_pipelines","title":"delete_media_pipeline_kinesis_video_stream_pool","content":"pub fn delete_media_pipeline_kinesis_video_stream_pool(\n  client: Client,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_media_pipelines.delete_media_pipeline_kinesis_video_stream_pool\naws_api/chime_sdk_media_pipelines delete_media_pipeline_kinesis_video_stream_pool","url":"aws_api/chime_sdk_media_pipelines.html#delete_media_pipeline_kinesis_video_stream_pool"},{"doc":"aws_api/chime_sdk_media_pipelines","title":"get_media_capture_pipeline","content":"pub fn get_media_capture_pipeline(\n  client: Client,\n  media_pipeline_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_media_pipelines.get_media_capture_pipeline\naws_api/chime_sdk_media_pipelines get_media_capture_pipeline","url":"aws_api/chime_sdk_media_pipelines.html#get_media_capture_pipeline"},{"doc":"aws_api/chime_sdk_media_pipelines","title":"get_media_insights_pipeline_configuration","content":"pub fn get_media_insights_pipeline_configuration(\n  client: Client,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_media_pipelines.get_media_insights_pipeline_configuration\naws_api/chime_sdk_media_pipelines get_media_insights_pipeline_configuration","url":"aws_api/chime_sdk_media_pipelines.html#get_media_insights_pipeline_configuration"},{"doc":"aws_api/chime_sdk_media_pipelines","title":"get_media_pipeline","content":"pub fn get_media_pipeline(\n  client: Client,\n  media_pipeline_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_media_pipelines.get_media_pipeline\naws_api/chime_sdk_media_pipelines get_media_pipeline","url":"aws_api/chime_sdk_media_pipelines.html#get_media_pipeline"},{"doc":"aws_api/chime_sdk_media_pipelines","title":"get_media_pipeline_kinesis_video_stream_pool","content":"pub fn get_media_pipeline_kinesis_video_stream_pool(\n  client: Client,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_media_pipelines.get_media_pipeline_kinesis_video_stream_pool\naws_api/chime_sdk_media_pipelines get_media_pipeline_kinesis_video_stream_pool","url":"aws_api/chime_sdk_media_pipelines.html#get_media_pipeline_kinesis_video_stream_pool"},{"doc":"aws_api/chime_sdk_media_pipelines","title":"get_speaker_search_task","content":"pub fn get_speaker_search_task(\n  client: Client,\n  identifier: String,\n  speaker_search_task_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_media_pipelines.get_speaker_search_task\naws_api/chime_sdk_media_pipelines get_speaker_search_task","url":"aws_api/chime_sdk_media_pipelines.html#get_speaker_search_task"},{"doc":"aws_api/chime_sdk_media_pipelines","title":"get_voice_tone_analysis_task","content":"pub fn get_voice_tone_analysis_task(\n  client: Client,\n  identifier: String,\n  voice_tone_analysis_task_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_media_pipelines.get_voice_tone_analysis_task\naws_api/chime_sdk_media_pipelines get_voice_tone_analysis_task","url":"aws_api/chime_sdk_media_pipelines.html#get_voice_tone_analysis_task"},{"doc":"aws_api/chime_sdk_media_pipelines","title":"list_media_capture_pipelines","content":"pub fn list_media_capture_pipelines(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_media_pipelines.list_media_capture_pipelines\naws_api/chime_sdk_media_pipelines list_media_capture_pipelines","url":"aws_api/chime_sdk_media_pipelines.html#list_media_capture_pipelines"},{"doc":"aws_api/chime_sdk_media_pipelines","title":"list_media_insights_pipeline_configurations","content":"pub fn list_media_insights_pipeline_configurations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_media_pipelines.list_media_insights_pipeline_configurations\naws_api/chime_sdk_media_pipelines list_media_insights_pipeline_configurations","url":"aws_api/chime_sdk_media_pipelines.html#list_media_insights_pipeline_configurations"},{"doc":"aws_api/chime_sdk_media_pipelines","title":"list_media_pipeline_kinesis_video_stream_pools","content":"pub fn list_media_pipeline_kinesis_video_stream_pools(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_media_pipelines.list_media_pipeline_kinesis_video_stream_pools\naws_api/chime_sdk_media_pipelines list_media_pipeline_kinesis_video_stream_pools","url":"aws_api/chime_sdk_media_pipelines.html#list_media_pipeline_kinesis_video_stream_pools"},{"doc":"aws_api/chime_sdk_media_pipelines","title":"list_media_pipelines","content":"pub fn list_media_pipelines(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_media_pipelines.list_media_pipelines\naws_api/chime_sdk_media_pipelines list_media_pipelines","url":"aws_api/chime_sdk_media_pipelines.html#list_media_pipelines"},{"doc":"aws_api/chime_sdk_media_pipelines","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_media_pipelines.list_tags_for_resource\naws_api/chime_sdk_media_pipelines list_tags_for_resource","url":"aws_api/chime_sdk_media_pipelines.html#list_tags_for_resource"},{"doc":"aws_api/chime_sdk_media_pipelines","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/chime_sdk_media_pipelines.new\naws_api/chime_sdk_media_pipelines new","url":"aws_api/chime_sdk_media_pipelines.html#new"},{"doc":"aws_api/chime_sdk_media_pipelines","title":"start_speaker_search_task","content":"pub fn start_speaker_search_task(\n  client: Client,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_media_pipelines.start_speaker_search_task\naws_api/chime_sdk_media_pipelines start_speaker_search_task","url":"aws_api/chime_sdk_media_pipelines.html#start_speaker_search_task"},{"doc":"aws_api/chime_sdk_media_pipelines","title":"start_voice_tone_analysis_task","content":"pub fn start_voice_tone_analysis_task(\n  client: Client,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_media_pipelines.start_voice_tone_analysis_task\naws_api/chime_sdk_media_pipelines start_voice_tone_analysis_task","url":"aws_api/chime_sdk_media_pipelines.html#start_voice_tone_analysis_task"},{"doc":"aws_api/chime_sdk_media_pipelines","title":"stop_speaker_search_task","content":"pub fn stop_speaker_search_task(\n  client: Client,\n  identifier: String,\n  speaker_search_task_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_media_pipelines.stop_speaker_search_task\naws_api/chime_sdk_media_pipelines stop_speaker_search_task","url":"aws_api/chime_sdk_media_pipelines.html#stop_speaker_search_task"},{"doc":"aws_api/chime_sdk_media_pipelines","title":"stop_voice_tone_analysis_task","content":"pub fn stop_voice_tone_analysis_task(\n  client: Client,\n  identifier: String,\n  voice_tone_analysis_task_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_media_pipelines.stop_voice_tone_analysis_task\naws_api/chime_sdk_media_pipelines stop_voice_tone_analysis_task","url":"aws_api/chime_sdk_media_pipelines.html#stop_voice_tone_analysis_task"},{"doc":"aws_api/chime_sdk_media_pipelines","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_media_pipelines.tag_resource\naws_api/chime_sdk_media_pipelines tag_resource","url":"aws_api/chime_sdk_media_pipelines.html#tag_resource"},{"doc":"aws_api/chime_sdk_media_pipelines","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_media_pipelines.untag_resource\naws_api/chime_sdk_media_pipelines untag_resource","url":"aws_api/chime_sdk_media_pipelines.html#untag_resource"},{"doc":"aws_api/chime_sdk_media_pipelines","title":"update_media_insights_pipeline_configuration","content":"pub fn update_media_insights_pipeline_configuration(\n  client: Client,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_media_pipelines.update_media_insights_pipeline_configuration\naws_api/chime_sdk_media_pipelines update_media_insights_pipeline_configuration","url":"aws_api/chime_sdk_media_pipelines.html#update_media_insights_pipeline_configuration"},{"doc":"aws_api/chime_sdk_media_pipelines","title":"update_media_insights_pipeline_status","content":"pub fn update_media_insights_pipeline_status(\n  client: Client,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_media_pipelines.update_media_insights_pipeline_status\naws_api/chime_sdk_media_pipelines update_media_insights_pipeline_status","url":"aws_api/chime_sdk_media_pipelines.html#update_media_insights_pipeline_status"},{"doc":"aws_api/chime_sdk_media_pipelines","title":"update_media_pipeline_kinesis_video_stream_pool","content":"pub fn update_media_pipeline_kinesis_video_stream_pool(\n  client: Client,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_media_pipelines.update_media_pipeline_kinesis_video_stream_pool\naws_api/chime_sdk_media_pipelines update_media_pipeline_kinesis_video_stream_pool","url":"aws_api/chime_sdk_media_pipelines.html#update_media_pipeline_kinesis_video_stream_pool"},{"doc":"aws_api/chime_sdk_media_pipelines","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/chime_sdk_media_pipelines.with_custom_endpoint\naws_api/chime_sdk_media_pipelines with_custom_endpoint","url":"aws_api/chime_sdk_media_pipelines.html#with_custom_endpoint"},{"doc":"aws_api/chime_sdk_media_pipelines","title":"aws_api/chime_sdk_media_pipelines","content":"","url":"aws_api/chime_sdk_media_pipelines.html"},{"doc":"aws_api/chime_sdk_meetings","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/chime_sdk_meetings.Client\naws_api/chime_sdk_meetings Client","url":"aws_api/chime_sdk_meetings.html#Client"},{"doc":"aws_api/chime_sdk_meetings","title":"batch_create_attendee","content":"pub fn batch_create_attendee(\n  client: Client,\n  meeting_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_meetings.batch_create_attendee\naws_api/chime_sdk_meetings batch_create_attendee","url":"aws_api/chime_sdk_meetings.html#batch_create_attendee"},{"doc":"aws_api/chime_sdk_meetings","title":"batch_update_attendee_capabilities_except","content":"pub fn batch_update_attendee_capabilities_except(\n  client: Client,\n  meeting_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_meetings.batch_update_attendee_capabilities_except\naws_api/chime_sdk_meetings batch_update_attendee_capabilities_except","url":"aws_api/chime_sdk_meetings.html#batch_update_attendee_capabilities_except"},{"doc":"aws_api/chime_sdk_meetings","title":"create_attendee","content":"pub fn create_attendee(\n  client: Client,\n  meeting_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_meetings.create_attendee\naws_api/chime_sdk_meetings create_attendee","url":"aws_api/chime_sdk_meetings.html#create_attendee"},{"doc":"aws_api/chime_sdk_meetings","title":"create_meeting","content":"pub fn create_meeting(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_meetings.create_meeting\naws_api/chime_sdk_meetings create_meeting","url":"aws_api/chime_sdk_meetings.html#create_meeting"},{"doc":"aws_api/chime_sdk_meetings","title":"create_meeting_with_attendees","content":"pub fn create_meeting_with_attendees(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_meetings.create_meeting_with_attendees\naws_api/chime_sdk_meetings create_meeting_with_attendees","url":"aws_api/chime_sdk_meetings.html#create_meeting_with_attendees"},{"doc":"aws_api/chime_sdk_meetings","title":"delete_attendee","content":"pub fn delete_attendee(\n  client: Client,\n  meeting_id: String,\n  attendee_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_meetings.delete_attendee\naws_api/chime_sdk_meetings delete_attendee","url":"aws_api/chime_sdk_meetings.html#delete_attendee"},{"doc":"aws_api/chime_sdk_meetings","title":"delete_meeting","content":"pub fn delete_meeting(\n  client: Client,\n  meeting_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_meetings.delete_meeting\naws_api/chime_sdk_meetings delete_meeting","url":"aws_api/chime_sdk_meetings.html#delete_meeting"},{"doc":"aws_api/chime_sdk_meetings","title":"get_attendee","content":"pub fn get_attendee(\n  client: Client,\n  meeting_id: String,\n  attendee_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_meetings.get_attendee\naws_api/chime_sdk_meetings get_attendee","url":"aws_api/chime_sdk_meetings.html#get_attendee"},{"doc":"aws_api/chime_sdk_meetings","title":"get_meeting","content":"pub fn get_meeting(\n  client: Client,\n  meeting_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_meetings.get_meeting\naws_api/chime_sdk_meetings get_meeting","url":"aws_api/chime_sdk_meetings.html#get_meeting"},{"doc":"aws_api/chime_sdk_meetings","title":"list_attendees","content":"pub fn list_attendees(\n  client: Client,\n  meeting_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_meetings.list_attendees\naws_api/chime_sdk_meetings list_attendees","url":"aws_api/chime_sdk_meetings.html#list_attendees"},{"doc":"aws_api/chime_sdk_meetings","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_meetings.list_tags_for_resource\naws_api/chime_sdk_meetings list_tags_for_resource","url":"aws_api/chime_sdk_meetings.html#list_tags_for_resource"},{"doc":"aws_api/chime_sdk_meetings","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/chime_sdk_meetings.new\naws_api/chime_sdk_meetings new","url":"aws_api/chime_sdk_meetings.html#new"},{"doc":"aws_api/chime_sdk_meetings","title":"start_meeting_transcription","content":"pub fn start_meeting_transcription(\n  client: Client,\n  meeting_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_meetings.start_meeting_transcription\naws_api/chime_sdk_meetings start_meeting_transcription","url":"aws_api/chime_sdk_meetings.html#start_meeting_transcription"},{"doc":"aws_api/chime_sdk_meetings","title":"stop_meeting_transcription","content":"pub fn stop_meeting_transcription(\n  client: Client,\n  meeting_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_meetings.stop_meeting_transcription\naws_api/chime_sdk_meetings stop_meeting_transcription","url":"aws_api/chime_sdk_meetings.html#stop_meeting_transcription"},{"doc":"aws_api/chime_sdk_meetings","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_meetings.tag_resource\naws_api/chime_sdk_meetings tag_resource","url":"aws_api/chime_sdk_meetings.html#tag_resource"},{"doc":"aws_api/chime_sdk_meetings","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_meetings.untag_resource\naws_api/chime_sdk_meetings untag_resource","url":"aws_api/chime_sdk_meetings.html#untag_resource"},{"doc":"aws_api/chime_sdk_meetings","title":"update_attendee_capabilities","content":"pub fn update_attendee_capabilities(\n  client: Client,\n  meeting_id: String,\n  attendee_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_meetings.update_attendee_capabilities\naws_api/chime_sdk_meetings update_attendee_capabilities","url":"aws_api/chime_sdk_meetings.html#update_attendee_capabilities"},{"doc":"aws_api/chime_sdk_meetings","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/chime_sdk_meetings.with_custom_endpoint\naws_api/chime_sdk_meetings with_custom_endpoint","url":"aws_api/chime_sdk_meetings.html#with_custom_endpoint"},{"doc":"aws_api/chime_sdk_meetings","title":"aws_api/chime_sdk_meetings","content":"","url":"aws_api/chime_sdk_meetings.html"},{"doc":"aws_api/chime_sdk_messaging","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/chime_sdk_messaging.Client\naws_api/chime_sdk_messaging Client","url":"aws_api/chime_sdk_messaging.html#Client"},{"doc":"aws_api/chime_sdk_messaging","title":"associate_channel_flow","content":"pub fn associate_channel_flow(\n  client: Client,\n  channel_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.associate_channel_flow\naws_api/chime_sdk_messaging associate_channel_flow","url":"aws_api/chime_sdk_messaging.html#associate_channel_flow"},{"doc":"aws_api/chime_sdk_messaging","title":"batch_create_channel_membership","content":"pub fn batch_create_channel_membership(\n  client: Client,\n  channel_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.batch_create_channel_membership\naws_api/chime_sdk_messaging batch_create_channel_membership","url":"aws_api/chime_sdk_messaging.html#batch_create_channel_membership"},{"doc":"aws_api/chime_sdk_messaging","title":"channel_flow_callback","content":"pub fn channel_flow_callback(\n  client: Client,\n  channel_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.channel_flow_callback\naws_api/chime_sdk_messaging channel_flow_callback","url":"aws_api/chime_sdk_messaging.html#channel_flow_callback"},{"doc":"aws_api/chime_sdk_messaging","title":"create_channel","content":"pub fn create_channel(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.create_channel\naws_api/chime_sdk_messaging create_channel","url":"aws_api/chime_sdk_messaging.html#create_channel"},{"doc":"aws_api/chime_sdk_messaging","title":"create_channel_ban","content":"pub fn create_channel_ban(\n  client: Client,\n  channel_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.create_channel_ban\naws_api/chime_sdk_messaging create_channel_ban","url":"aws_api/chime_sdk_messaging.html#create_channel_ban"},{"doc":"aws_api/chime_sdk_messaging","title":"create_channel_flow","content":"pub fn create_channel_flow(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.create_channel_flow\naws_api/chime_sdk_messaging create_channel_flow","url":"aws_api/chime_sdk_messaging.html#create_channel_flow"},{"doc":"aws_api/chime_sdk_messaging","title":"create_channel_membership","content":"pub fn create_channel_membership(\n  client: Client,\n  channel_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.create_channel_membership\naws_api/chime_sdk_messaging create_channel_membership","url":"aws_api/chime_sdk_messaging.html#create_channel_membership"},{"doc":"aws_api/chime_sdk_messaging","title":"create_channel_moderator","content":"pub fn create_channel_moderator(\n  client: Client,\n  channel_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.create_channel_moderator\naws_api/chime_sdk_messaging create_channel_moderator","url":"aws_api/chime_sdk_messaging.html#create_channel_moderator"},{"doc":"aws_api/chime_sdk_messaging","title":"delete_channel","content":"pub fn delete_channel(\n  client: Client,\n  channel_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.delete_channel\naws_api/chime_sdk_messaging delete_channel","url":"aws_api/chime_sdk_messaging.html#delete_channel"},{"doc":"aws_api/chime_sdk_messaging","title":"delete_channel_ban","content":"pub fn delete_channel_ban(\n  client: Client,\n  channel_arn: String,\n  member_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.delete_channel_ban\naws_api/chime_sdk_messaging delete_channel_ban","url":"aws_api/chime_sdk_messaging.html#delete_channel_ban"},{"doc":"aws_api/chime_sdk_messaging","title":"delete_channel_flow","content":"pub fn delete_channel_flow(\n  client: Client,\n  channel_flow_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.delete_channel_flow\naws_api/chime_sdk_messaging delete_channel_flow","url":"aws_api/chime_sdk_messaging.html#delete_channel_flow"},{"doc":"aws_api/chime_sdk_messaging","title":"delete_channel_membership","content":"pub fn delete_channel_membership(\n  client: Client,\n  channel_arn: String,\n  member_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.delete_channel_membership\naws_api/chime_sdk_messaging delete_channel_membership","url":"aws_api/chime_sdk_messaging.html#delete_channel_membership"},{"doc":"aws_api/chime_sdk_messaging","title":"delete_channel_message","content":"pub fn delete_channel_message(\n  client: Client,\n  channel_arn: String,\n  message_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.delete_channel_message\naws_api/chime_sdk_messaging delete_channel_message","url":"aws_api/chime_sdk_messaging.html#delete_channel_message"},{"doc":"aws_api/chime_sdk_messaging","title":"delete_channel_moderator","content":"pub fn delete_channel_moderator(\n  client: Client,\n  channel_arn: String,\n  channel_moderator_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.delete_channel_moderator\naws_api/chime_sdk_messaging delete_channel_moderator","url":"aws_api/chime_sdk_messaging.html#delete_channel_moderator"},{"doc":"aws_api/chime_sdk_messaging","title":"delete_messaging_streaming_configurations","content":"pub fn delete_messaging_streaming_configurations(\n  client: Client,\n  app_instance_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.delete_messaging_streaming_configurations\naws_api/chime_sdk_messaging delete_messaging_streaming_configurations","url":"aws_api/chime_sdk_messaging.html#delete_messaging_streaming_configurations"},{"doc":"aws_api/chime_sdk_messaging","title":"describe_channel","content":"pub fn describe_channel(\n  client: Client,\n  channel_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.describe_channel\naws_api/chime_sdk_messaging describe_channel","url":"aws_api/chime_sdk_messaging.html#describe_channel"},{"doc":"aws_api/chime_sdk_messaging","title":"describe_channel_ban","content":"pub fn describe_channel_ban(\n  client: Client,\n  channel_arn: String,\n  member_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.describe_channel_ban\naws_api/chime_sdk_messaging describe_channel_ban","url":"aws_api/chime_sdk_messaging.html#describe_channel_ban"},{"doc":"aws_api/chime_sdk_messaging","title":"describe_channel_flow","content":"pub fn describe_channel_flow(\n  client: Client,\n  channel_flow_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.describe_channel_flow\naws_api/chime_sdk_messaging describe_channel_flow","url":"aws_api/chime_sdk_messaging.html#describe_channel_flow"},{"doc":"aws_api/chime_sdk_messaging","title":"describe_channel_membership","content":"pub fn describe_channel_membership(\n  client: Client,\n  channel_arn: String,\n  member_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.describe_channel_membership\naws_api/chime_sdk_messaging describe_channel_membership","url":"aws_api/chime_sdk_messaging.html#describe_channel_membership"},{"doc":"aws_api/chime_sdk_messaging","title":"describe_channel_membership_for_app_instance_user","content":"pub fn describe_channel_membership_for_app_instance_user(\n  client: Client,\n  channel_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.describe_channel_membership_for_app_instance_user\naws_api/chime_sdk_messaging describe_channel_membership_for_app_instance_user","url":"aws_api/chime_sdk_messaging.html#describe_channel_membership_for_app_instance_user"},{"doc":"aws_api/chime_sdk_messaging","title":"describe_channel_moderated_by_app_instance_user","content":"pub fn describe_channel_moderated_by_app_instance_user(\n  client: Client,\n  channel_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.describe_channel_moderated_by_app_instance_user\naws_api/chime_sdk_messaging describe_channel_moderated_by_app_instance_user","url":"aws_api/chime_sdk_messaging.html#describe_channel_moderated_by_app_instance_user"},{"doc":"aws_api/chime_sdk_messaging","title":"describe_channel_moderator","content":"pub fn describe_channel_moderator(\n  client: Client,\n  channel_arn: String,\n  channel_moderator_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.describe_channel_moderator\naws_api/chime_sdk_messaging describe_channel_moderator","url":"aws_api/chime_sdk_messaging.html#describe_channel_moderator"},{"doc":"aws_api/chime_sdk_messaging","title":"disassociate_channel_flow","content":"pub fn disassociate_channel_flow(\n  client: Client,\n  channel_arn: String,\n  channel_flow_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.disassociate_channel_flow\naws_api/chime_sdk_messaging disassociate_channel_flow","url":"aws_api/chime_sdk_messaging.html#disassociate_channel_flow"},{"doc":"aws_api/chime_sdk_messaging","title":"get_channel_membership_preferences","content":"pub fn get_channel_membership_preferences(\n  client: Client,\n  channel_arn: String,\n  member_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.get_channel_membership_preferences\naws_api/chime_sdk_messaging get_channel_membership_preferences","url":"aws_api/chime_sdk_messaging.html#get_channel_membership_preferences"},{"doc":"aws_api/chime_sdk_messaging","title":"get_channel_message","content":"pub fn get_channel_message(\n  client: Client,\n  channel_arn: String,\n  message_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.get_channel_message\naws_api/chime_sdk_messaging get_channel_message","url":"aws_api/chime_sdk_messaging.html#get_channel_message"},{"doc":"aws_api/chime_sdk_messaging","title":"get_channel_message_status","content":"pub fn get_channel_message_status(\n  client: Client,\n  channel_arn: String,\n  message_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.get_channel_message_status\naws_api/chime_sdk_messaging get_channel_message_status","url":"aws_api/chime_sdk_messaging.html#get_channel_message_status"},{"doc":"aws_api/chime_sdk_messaging","title":"get_messaging_session_endpoint","content":"pub fn get_messaging_session_endpoint(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.get_messaging_session_endpoint\naws_api/chime_sdk_messaging get_messaging_session_endpoint","url":"aws_api/chime_sdk_messaging.html#get_messaging_session_endpoint"},{"doc":"aws_api/chime_sdk_messaging","title":"get_messaging_streaming_configurations","content":"pub fn get_messaging_streaming_configurations(\n  client: Client,\n  app_instance_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.get_messaging_streaming_configurations\naws_api/chime_sdk_messaging get_messaging_streaming_configurations","url":"aws_api/chime_sdk_messaging.html#get_messaging_streaming_configurations"},{"doc":"aws_api/chime_sdk_messaging","title":"list_channel_bans","content":"pub fn list_channel_bans(\n  client: Client,\n  channel_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.list_channel_bans\naws_api/chime_sdk_messaging list_channel_bans","url":"aws_api/chime_sdk_messaging.html#list_channel_bans"},{"doc":"aws_api/chime_sdk_messaging","title":"list_channel_flows","content":"pub fn list_channel_flows(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.list_channel_flows\naws_api/chime_sdk_messaging list_channel_flows","url":"aws_api/chime_sdk_messaging.html#list_channel_flows"},{"doc":"aws_api/chime_sdk_messaging","title":"list_channel_memberships","content":"pub fn list_channel_memberships(\n  client: Client,\n  channel_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.list_channel_memberships\naws_api/chime_sdk_messaging list_channel_memberships","url":"aws_api/chime_sdk_messaging.html#list_channel_memberships"},{"doc":"aws_api/chime_sdk_messaging","title":"list_channel_memberships_for_app_instance_user","content":"pub fn list_channel_memberships_for_app_instance_user(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.list_channel_memberships_for_app_instance_user\naws_api/chime_sdk_messaging list_channel_memberships_for_app_instance_user","url":"aws_api/chime_sdk_messaging.html#list_channel_memberships_for_app_instance_user"},{"doc":"aws_api/chime_sdk_messaging","title":"list_channel_messages","content":"pub fn list_channel_messages(\n  client: Client,\n  channel_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.list_channel_messages\naws_api/chime_sdk_messaging list_channel_messages","url":"aws_api/chime_sdk_messaging.html#list_channel_messages"},{"doc":"aws_api/chime_sdk_messaging","title":"list_channel_moderators","content":"pub fn list_channel_moderators(\n  client: Client,\n  channel_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.list_channel_moderators\naws_api/chime_sdk_messaging list_channel_moderators","url":"aws_api/chime_sdk_messaging.html#list_channel_moderators"},{"doc":"aws_api/chime_sdk_messaging","title":"list_channels","content":"pub fn list_channels(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.list_channels\naws_api/chime_sdk_messaging list_channels","url":"aws_api/chime_sdk_messaging.html#list_channels"},{"doc":"aws_api/chime_sdk_messaging","title":"list_channels_associated_with_channel_flow","content":"pub fn list_channels_associated_with_channel_flow(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.list_channels_associated_with_channel_flow\naws_api/chime_sdk_messaging list_channels_associated_with_channel_flow","url":"aws_api/chime_sdk_messaging.html#list_channels_associated_with_channel_flow"},{"doc":"aws_api/chime_sdk_messaging","title":"list_channels_moderated_by_app_instance_user","content":"pub fn list_channels_moderated_by_app_instance_user(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.list_channels_moderated_by_app_instance_user\naws_api/chime_sdk_messaging list_channels_moderated_by_app_instance_user","url":"aws_api/chime_sdk_messaging.html#list_channels_moderated_by_app_instance_user"},{"doc":"aws_api/chime_sdk_messaging","title":"list_sub_channels","content":"pub fn list_sub_channels(\n  client: Client,\n  channel_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.list_sub_channels\naws_api/chime_sdk_messaging list_sub_channels","url":"aws_api/chime_sdk_messaging.html#list_sub_channels"},{"doc":"aws_api/chime_sdk_messaging","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.list_tags_for_resource\naws_api/chime_sdk_messaging list_tags_for_resource","url":"aws_api/chime_sdk_messaging.html#list_tags_for_resource"},{"doc":"aws_api/chime_sdk_messaging","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/chime_sdk_messaging.new\naws_api/chime_sdk_messaging new","url":"aws_api/chime_sdk_messaging.html#new"},{"doc":"aws_api/chime_sdk_messaging","title":"put_channel_expiration_settings","content":"pub fn put_channel_expiration_settings(\n  client: Client,\n  channel_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.put_channel_expiration_settings\naws_api/chime_sdk_messaging put_channel_expiration_settings","url":"aws_api/chime_sdk_messaging.html#put_channel_expiration_settings"},{"doc":"aws_api/chime_sdk_messaging","title":"put_channel_membership_preferences","content":"pub fn put_channel_membership_preferences(\n  client: Client,\n  channel_arn: String,\n  member_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.put_channel_membership_preferences\naws_api/chime_sdk_messaging put_channel_membership_preferences","url":"aws_api/chime_sdk_messaging.html#put_channel_membership_preferences"},{"doc":"aws_api/chime_sdk_messaging","title":"put_messaging_streaming_configurations","content":"pub fn put_messaging_streaming_configurations(\n  client: Client,\n  app_instance_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.put_messaging_streaming_configurations\naws_api/chime_sdk_messaging put_messaging_streaming_configurations","url":"aws_api/chime_sdk_messaging.html#put_messaging_streaming_configurations"},{"doc":"aws_api/chime_sdk_messaging","title":"redact_channel_message","content":"pub fn redact_channel_message(\n  client: Client,\n  channel_arn: String,\n  message_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.redact_channel_message\naws_api/chime_sdk_messaging redact_channel_message","url":"aws_api/chime_sdk_messaging.html#redact_channel_message"},{"doc":"aws_api/chime_sdk_messaging","title":"search_channels","content":"pub fn search_channels(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.search_channels\naws_api/chime_sdk_messaging search_channels","url":"aws_api/chime_sdk_messaging.html#search_channels"},{"doc":"aws_api/chime_sdk_messaging","title":"send_channel_message","content":"pub fn send_channel_message(\n  client: Client,\n  channel_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.send_channel_message\naws_api/chime_sdk_messaging send_channel_message","url":"aws_api/chime_sdk_messaging.html#send_channel_message"},{"doc":"aws_api/chime_sdk_messaging","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.tag_resource\naws_api/chime_sdk_messaging tag_resource","url":"aws_api/chime_sdk_messaging.html#tag_resource"},{"doc":"aws_api/chime_sdk_messaging","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.untag_resource\naws_api/chime_sdk_messaging untag_resource","url":"aws_api/chime_sdk_messaging.html#untag_resource"},{"doc":"aws_api/chime_sdk_messaging","title":"update_channel","content":"pub fn update_channel(\n  client: Client,\n  channel_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.update_channel\naws_api/chime_sdk_messaging update_channel","url":"aws_api/chime_sdk_messaging.html#update_channel"},{"doc":"aws_api/chime_sdk_messaging","title":"update_channel_flow","content":"pub fn update_channel_flow(\n  client: Client,\n  channel_flow_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.update_channel_flow\naws_api/chime_sdk_messaging update_channel_flow","url":"aws_api/chime_sdk_messaging.html#update_channel_flow"},{"doc":"aws_api/chime_sdk_messaging","title":"update_channel_message","content":"pub fn update_channel_message(\n  client: Client,\n  channel_arn: String,\n  message_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.update_channel_message\naws_api/chime_sdk_messaging update_channel_message","url":"aws_api/chime_sdk_messaging.html#update_channel_message"},{"doc":"aws_api/chime_sdk_messaging","title":"update_channel_read_marker","content":"pub fn update_channel_read_marker(\n  client: Client,\n  channel_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_messaging.update_channel_read_marker\naws_api/chime_sdk_messaging update_channel_read_marker","url":"aws_api/chime_sdk_messaging.html#update_channel_read_marker"},{"doc":"aws_api/chime_sdk_messaging","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/chime_sdk_messaging.with_custom_endpoint\naws_api/chime_sdk_messaging with_custom_endpoint","url":"aws_api/chime_sdk_messaging.html#with_custom_endpoint"},{"doc":"aws_api/chime_sdk_messaging","title":"aws_api/chime_sdk_messaging","content":"","url":"aws_api/chime_sdk_messaging.html"},{"doc":"aws_api/chime_sdk_voice","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/chime_sdk_voice.Client\naws_api/chime_sdk_voice Client","url":"aws_api/chime_sdk_voice.html#Client"},{"doc":"aws_api/chime_sdk_voice","title":"associate_phone_numbers_with_voice_connector","content":"pub fn associate_phone_numbers_with_voice_connector(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.associate_phone_numbers_with_voice_connector\naws_api/chime_sdk_voice associate_phone_numbers_with_voice_connector","url":"aws_api/chime_sdk_voice.html#associate_phone_numbers_with_voice_connector"},{"doc":"aws_api/chime_sdk_voice","title":"associate_phone_numbers_with_voice_connector_group","content":"pub fn associate_phone_numbers_with_voice_connector_group(\n  client: Client,\n  voice_connector_group_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.associate_phone_numbers_with_voice_connector_group\naws_api/chime_sdk_voice associate_phone_numbers_with_voice_connector_group","url":"aws_api/chime_sdk_voice.html#associate_phone_numbers_with_voice_connector_group"},{"doc":"aws_api/chime_sdk_voice","title":"batch_delete_phone_number","content":"pub fn batch_delete_phone_number(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.batch_delete_phone_number\naws_api/chime_sdk_voice batch_delete_phone_number","url":"aws_api/chime_sdk_voice.html#batch_delete_phone_number"},{"doc":"aws_api/chime_sdk_voice","title":"batch_update_phone_number","content":"pub fn batch_update_phone_number(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.batch_update_phone_number\naws_api/chime_sdk_voice batch_update_phone_number","url":"aws_api/chime_sdk_voice.html#batch_update_phone_number"},{"doc":"aws_api/chime_sdk_voice","title":"create_phone_number_order","content":"pub fn create_phone_number_order(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.create_phone_number_order\naws_api/chime_sdk_voice create_phone_number_order","url":"aws_api/chime_sdk_voice.html#create_phone_number_order"},{"doc":"aws_api/chime_sdk_voice","title":"create_proxy_session","content":"pub fn create_proxy_session(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.create_proxy_session\naws_api/chime_sdk_voice create_proxy_session","url":"aws_api/chime_sdk_voice.html#create_proxy_session"},{"doc":"aws_api/chime_sdk_voice","title":"create_sip_media_application","content":"pub fn create_sip_media_application(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.create_sip_media_application\naws_api/chime_sdk_voice create_sip_media_application","url":"aws_api/chime_sdk_voice.html#create_sip_media_application"},{"doc":"aws_api/chime_sdk_voice","title":"create_sip_media_application_call","content":"pub fn create_sip_media_application_call(\n  client: Client,\n  sip_media_application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.create_sip_media_application_call\naws_api/chime_sdk_voice create_sip_media_application_call","url":"aws_api/chime_sdk_voice.html#create_sip_media_application_call"},{"doc":"aws_api/chime_sdk_voice","title":"create_sip_rule","content":"pub fn create_sip_rule(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.create_sip_rule\naws_api/chime_sdk_voice create_sip_rule","url":"aws_api/chime_sdk_voice.html#create_sip_rule"},{"doc":"aws_api/chime_sdk_voice","title":"create_voice_connector","content":"pub fn create_voice_connector(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.create_voice_connector\naws_api/chime_sdk_voice create_voice_connector","url":"aws_api/chime_sdk_voice.html#create_voice_connector"},{"doc":"aws_api/chime_sdk_voice","title":"create_voice_connector_group","content":"pub fn create_voice_connector_group(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.create_voice_connector_group\naws_api/chime_sdk_voice create_voice_connector_group","url":"aws_api/chime_sdk_voice.html#create_voice_connector_group"},{"doc":"aws_api/chime_sdk_voice","title":"create_voice_profile","content":"pub fn create_voice_profile(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.create_voice_profile\naws_api/chime_sdk_voice create_voice_profile","url":"aws_api/chime_sdk_voice.html#create_voice_profile"},{"doc":"aws_api/chime_sdk_voice","title":"create_voice_profile_domain","content":"pub fn create_voice_profile_domain(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.create_voice_profile_domain\naws_api/chime_sdk_voice create_voice_profile_domain","url":"aws_api/chime_sdk_voice.html#create_voice_profile_domain"},{"doc":"aws_api/chime_sdk_voice","title":"delete_phone_number","content":"pub fn delete_phone_number(\n  client: Client,\n  phone_number_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.delete_phone_number\naws_api/chime_sdk_voice delete_phone_number","url":"aws_api/chime_sdk_voice.html#delete_phone_number"},{"doc":"aws_api/chime_sdk_voice","title":"delete_proxy_session","content":"pub fn delete_proxy_session(\n  client: Client,\n  voice_connector_id: String,\n  proxy_session_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.delete_proxy_session\naws_api/chime_sdk_voice delete_proxy_session","url":"aws_api/chime_sdk_voice.html#delete_proxy_session"},{"doc":"aws_api/chime_sdk_voice","title":"delete_sip_media_application","content":"pub fn delete_sip_media_application(\n  client: Client,\n  sip_media_application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.delete_sip_media_application\naws_api/chime_sdk_voice delete_sip_media_application","url":"aws_api/chime_sdk_voice.html#delete_sip_media_application"},{"doc":"aws_api/chime_sdk_voice","title":"delete_sip_rule","content":"pub fn delete_sip_rule(\n  client: Client,\n  sip_rule_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.delete_sip_rule\naws_api/chime_sdk_voice delete_sip_rule","url":"aws_api/chime_sdk_voice.html#delete_sip_rule"},{"doc":"aws_api/chime_sdk_voice","title":"delete_voice_connector","content":"pub fn delete_voice_connector(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.delete_voice_connector\naws_api/chime_sdk_voice delete_voice_connector","url":"aws_api/chime_sdk_voice.html#delete_voice_connector"},{"doc":"aws_api/chime_sdk_voice","title":"delete_voice_connector_emergency_calling_configuration","content":"pub fn delete_voice_connector_emergency_calling_configuration(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.delete_voice_connector_emergency_calling_configuration\naws_api/chime_sdk_voice delete_voice_connector_emergency_calling_configuration","url":"aws_api/chime_sdk_voice.html#delete_voice_connector_emergency_calling_configuration"},{"doc":"aws_api/chime_sdk_voice","title":"delete_voice_connector_group","content":"pub fn delete_voice_connector_group(\n  client: Client,\n  voice_connector_group_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.delete_voice_connector_group\naws_api/chime_sdk_voice delete_voice_connector_group","url":"aws_api/chime_sdk_voice.html#delete_voice_connector_group"},{"doc":"aws_api/chime_sdk_voice","title":"delete_voice_connector_origination","content":"pub fn delete_voice_connector_origination(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.delete_voice_connector_origination\naws_api/chime_sdk_voice delete_voice_connector_origination","url":"aws_api/chime_sdk_voice.html#delete_voice_connector_origination"},{"doc":"aws_api/chime_sdk_voice","title":"delete_voice_connector_proxy","content":"pub fn delete_voice_connector_proxy(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.delete_voice_connector_proxy\naws_api/chime_sdk_voice delete_voice_connector_proxy","url":"aws_api/chime_sdk_voice.html#delete_voice_connector_proxy"},{"doc":"aws_api/chime_sdk_voice","title":"delete_voice_connector_streaming_configuration","content":"pub fn delete_voice_connector_streaming_configuration(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.delete_voice_connector_streaming_configuration\naws_api/chime_sdk_voice delete_voice_connector_streaming_configuration","url":"aws_api/chime_sdk_voice.html#delete_voice_connector_streaming_configuration"},{"doc":"aws_api/chime_sdk_voice","title":"delete_voice_connector_termination","content":"pub fn delete_voice_connector_termination(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.delete_voice_connector_termination\naws_api/chime_sdk_voice delete_voice_connector_termination","url":"aws_api/chime_sdk_voice.html#delete_voice_connector_termination"},{"doc":"aws_api/chime_sdk_voice","title":"delete_voice_connector_termination_credentials","content":"pub fn delete_voice_connector_termination_credentials(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.delete_voice_connector_termination_credentials\naws_api/chime_sdk_voice delete_voice_connector_termination_credentials","url":"aws_api/chime_sdk_voice.html#delete_voice_connector_termination_credentials"},{"doc":"aws_api/chime_sdk_voice","title":"delete_voice_profile","content":"pub fn delete_voice_profile(\n  client: Client,\n  voice_profile_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.delete_voice_profile\naws_api/chime_sdk_voice delete_voice_profile","url":"aws_api/chime_sdk_voice.html#delete_voice_profile"},{"doc":"aws_api/chime_sdk_voice","title":"delete_voice_profile_domain","content":"pub fn delete_voice_profile_domain(\n  client: Client,\n  voice_profile_domain_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.delete_voice_profile_domain\naws_api/chime_sdk_voice delete_voice_profile_domain","url":"aws_api/chime_sdk_voice.html#delete_voice_profile_domain"},{"doc":"aws_api/chime_sdk_voice","title":"disassociate_phone_numbers_from_voice_connector","content":"pub fn disassociate_phone_numbers_from_voice_connector(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.disassociate_phone_numbers_from_voice_connector\naws_api/chime_sdk_voice disassociate_phone_numbers_from_voice_connector","url":"aws_api/chime_sdk_voice.html#disassociate_phone_numbers_from_voice_connector"},{"doc":"aws_api/chime_sdk_voice","title":"disassociate_phone_numbers_from_voice_connector_group","content":"pub fn disassociate_phone_numbers_from_voice_connector_group(\n  client: Client,\n  voice_connector_group_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.disassociate_phone_numbers_from_voice_connector_group\naws_api/chime_sdk_voice disassociate_phone_numbers_from_voice_connector_group","url":"aws_api/chime_sdk_voice.html#disassociate_phone_numbers_from_voice_connector_group"},{"doc":"aws_api/chime_sdk_voice","title":"get_global_settings","content":"pub fn get_global_settings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.get_global_settings\naws_api/chime_sdk_voice get_global_settings","url":"aws_api/chime_sdk_voice.html#get_global_settings"},{"doc":"aws_api/chime_sdk_voice","title":"get_phone_number","content":"pub fn get_phone_number(\n  client: Client,\n  phone_number_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.get_phone_number\naws_api/chime_sdk_voice get_phone_number","url":"aws_api/chime_sdk_voice.html#get_phone_number"},{"doc":"aws_api/chime_sdk_voice","title":"get_phone_number_order","content":"pub fn get_phone_number_order(\n  client: Client,\n  phone_number_order_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.get_phone_number_order\naws_api/chime_sdk_voice get_phone_number_order","url":"aws_api/chime_sdk_voice.html#get_phone_number_order"},{"doc":"aws_api/chime_sdk_voice","title":"get_phone_number_settings","content":"pub fn get_phone_number_settings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.get_phone_number_settings\naws_api/chime_sdk_voice get_phone_number_settings","url":"aws_api/chime_sdk_voice.html#get_phone_number_settings"},{"doc":"aws_api/chime_sdk_voice","title":"get_proxy_session","content":"pub fn get_proxy_session(\n  client: Client,\n  voice_connector_id: String,\n  proxy_session_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.get_proxy_session\naws_api/chime_sdk_voice get_proxy_session","url":"aws_api/chime_sdk_voice.html#get_proxy_session"},{"doc":"aws_api/chime_sdk_voice","title":"get_sip_media_application","content":"pub fn get_sip_media_application(\n  client: Client,\n  sip_media_application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.get_sip_media_application\naws_api/chime_sdk_voice get_sip_media_application","url":"aws_api/chime_sdk_voice.html#get_sip_media_application"},{"doc":"aws_api/chime_sdk_voice","title":"get_sip_media_application_alexa_skill_configuration","content":"pub fn get_sip_media_application_alexa_skill_configuration(\n  client: Client,\n  sip_media_application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.get_sip_media_application_alexa_skill_configuration\naws_api/chime_sdk_voice get_sip_media_application_alexa_skill_configuration","url":"aws_api/chime_sdk_voice.html#get_sip_media_application_alexa_skill_configuration"},{"doc":"aws_api/chime_sdk_voice","title":"get_sip_media_application_logging_configuration","content":"pub fn get_sip_media_application_logging_configuration(\n  client: Client,\n  sip_media_application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.get_sip_media_application_logging_configuration\naws_api/chime_sdk_voice get_sip_media_application_logging_configuration","url":"aws_api/chime_sdk_voice.html#get_sip_media_application_logging_configuration"},{"doc":"aws_api/chime_sdk_voice","title":"get_sip_rule","content":"pub fn get_sip_rule(\n  client: Client,\n  sip_rule_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.get_sip_rule\naws_api/chime_sdk_voice get_sip_rule","url":"aws_api/chime_sdk_voice.html#get_sip_rule"},{"doc":"aws_api/chime_sdk_voice","title":"get_speaker_search_task","content":"pub fn get_speaker_search_task(\n  client: Client,\n  voice_connector_id: String,\n  speaker_search_task_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.get_speaker_search_task\naws_api/chime_sdk_voice get_speaker_search_task","url":"aws_api/chime_sdk_voice.html#get_speaker_search_task"},{"doc":"aws_api/chime_sdk_voice","title":"get_voice_connector","content":"pub fn get_voice_connector(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.get_voice_connector\naws_api/chime_sdk_voice get_voice_connector","url":"aws_api/chime_sdk_voice.html#get_voice_connector"},{"doc":"aws_api/chime_sdk_voice","title":"get_voice_connector_emergency_calling_configuration","content":"pub fn get_voice_connector_emergency_calling_configuration(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.get_voice_connector_emergency_calling_configuration\naws_api/chime_sdk_voice get_voice_connector_emergency_calling_configuration","url":"aws_api/chime_sdk_voice.html#get_voice_connector_emergency_calling_configuration"},{"doc":"aws_api/chime_sdk_voice","title":"get_voice_connector_group","content":"pub fn get_voice_connector_group(\n  client: Client,\n  voice_connector_group_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.get_voice_connector_group\naws_api/chime_sdk_voice get_voice_connector_group","url":"aws_api/chime_sdk_voice.html#get_voice_connector_group"},{"doc":"aws_api/chime_sdk_voice","title":"get_voice_connector_logging_configuration","content":"pub fn get_voice_connector_logging_configuration(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.get_voice_connector_logging_configuration\naws_api/chime_sdk_voice get_voice_connector_logging_configuration","url":"aws_api/chime_sdk_voice.html#get_voice_connector_logging_configuration"},{"doc":"aws_api/chime_sdk_voice","title":"get_voice_connector_origination","content":"pub fn get_voice_connector_origination(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.get_voice_connector_origination\naws_api/chime_sdk_voice get_voice_connector_origination","url":"aws_api/chime_sdk_voice.html#get_voice_connector_origination"},{"doc":"aws_api/chime_sdk_voice","title":"get_voice_connector_proxy","content":"pub fn get_voice_connector_proxy(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.get_voice_connector_proxy\naws_api/chime_sdk_voice get_voice_connector_proxy","url":"aws_api/chime_sdk_voice.html#get_voice_connector_proxy"},{"doc":"aws_api/chime_sdk_voice","title":"get_voice_connector_streaming_configuration","content":"pub fn get_voice_connector_streaming_configuration(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.get_voice_connector_streaming_configuration\naws_api/chime_sdk_voice get_voice_connector_streaming_configuration","url":"aws_api/chime_sdk_voice.html#get_voice_connector_streaming_configuration"},{"doc":"aws_api/chime_sdk_voice","title":"get_voice_connector_termination","content":"pub fn get_voice_connector_termination(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.get_voice_connector_termination\naws_api/chime_sdk_voice get_voice_connector_termination","url":"aws_api/chime_sdk_voice.html#get_voice_connector_termination"},{"doc":"aws_api/chime_sdk_voice","title":"get_voice_connector_termination_health","content":"pub fn get_voice_connector_termination_health(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.get_voice_connector_termination_health\naws_api/chime_sdk_voice get_voice_connector_termination_health","url":"aws_api/chime_sdk_voice.html#get_voice_connector_termination_health"},{"doc":"aws_api/chime_sdk_voice","title":"get_voice_profile","content":"pub fn get_voice_profile(\n  client: Client,\n  voice_profile_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.get_voice_profile\naws_api/chime_sdk_voice get_voice_profile","url":"aws_api/chime_sdk_voice.html#get_voice_profile"},{"doc":"aws_api/chime_sdk_voice","title":"get_voice_profile_domain","content":"pub fn get_voice_profile_domain(\n  client: Client,\n  voice_profile_domain_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.get_voice_profile_domain\naws_api/chime_sdk_voice get_voice_profile_domain","url":"aws_api/chime_sdk_voice.html#get_voice_profile_domain"},{"doc":"aws_api/chime_sdk_voice","title":"get_voice_tone_analysis_task","content":"pub fn get_voice_tone_analysis_task(\n  client: Client,\n  voice_connector_id: String,\n  voice_tone_analysis_task_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.get_voice_tone_analysis_task\naws_api/chime_sdk_voice get_voice_tone_analysis_task","url":"aws_api/chime_sdk_voice.html#get_voice_tone_analysis_task"},{"doc":"aws_api/chime_sdk_voice","title":"list_available_voice_connector_regions","content":"pub fn list_available_voice_connector_regions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.list_available_voice_connector_regions\naws_api/chime_sdk_voice list_available_voice_connector_regions","url":"aws_api/chime_sdk_voice.html#list_available_voice_connector_regions"},{"doc":"aws_api/chime_sdk_voice","title":"list_phone_number_orders","content":"pub fn list_phone_number_orders(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.list_phone_number_orders\naws_api/chime_sdk_voice list_phone_number_orders","url":"aws_api/chime_sdk_voice.html#list_phone_number_orders"},{"doc":"aws_api/chime_sdk_voice","title":"list_phone_numbers","content":"pub fn list_phone_numbers(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.list_phone_numbers\naws_api/chime_sdk_voice list_phone_numbers","url":"aws_api/chime_sdk_voice.html#list_phone_numbers"},{"doc":"aws_api/chime_sdk_voice","title":"list_proxy_sessions","content":"pub fn list_proxy_sessions(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.list_proxy_sessions\naws_api/chime_sdk_voice list_proxy_sessions","url":"aws_api/chime_sdk_voice.html#list_proxy_sessions"},{"doc":"aws_api/chime_sdk_voice","title":"list_sip_media_applications","content":"pub fn list_sip_media_applications(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.list_sip_media_applications\naws_api/chime_sdk_voice list_sip_media_applications","url":"aws_api/chime_sdk_voice.html#list_sip_media_applications"},{"doc":"aws_api/chime_sdk_voice","title":"list_sip_rules","content":"pub fn list_sip_rules(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.list_sip_rules\naws_api/chime_sdk_voice list_sip_rules","url":"aws_api/chime_sdk_voice.html#list_sip_rules"},{"doc":"aws_api/chime_sdk_voice","title":"list_supported_phone_number_countries","content":"pub fn list_supported_phone_number_countries(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.list_supported_phone_number_countries\naws_api/chime_sdk_voice list_supported_phone_number_countries","url":"aws_api/chime_sdk_voice.html#list_supported_phone_number_countries"},{"doc":"aws_api/chime_sdk_voice","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.list_tags_for_resource\naws_api/chime_sdk_voice list_tags_for_resource","url":"aws_api/chime_sdk_voice.html#list_tags_for_resource"},{"doc":"aws_api/chime_sdk_voice","title":"list_voice_connector_groups","content":"pub fn list_voice_connector_groups(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.list_voice_connector_groups\naws_api/chime_sdk_voice list_voice_connector_groups","url":"aws_api/chime_sdk_voice.html#list_voice_connector_groups"},{"doc":"aws_api/chime_sdk_voice","title":"list_voice_connector_termination_credentials","content":"pub fn list_voice_connector_termination_credentials(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.list_voice_connector_termination_credentials\naws_api/chime_sdk_voice list_voice_connector_termination_credentials","url":"aws_api/chime_sdk_voice.html#list_voice_connector_termination_credentials"},{"doc":"aws_api/chime_sdk_voice","title":"list_voice_connectors","content":"pub fn list_voice_connectors(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.list_voice_connectors\naws_api/chime_sdk_voice list_voice_connectors","url":"aws_api/chime_sdk_voice.html#list_voice_connectors"},{"doc":"aws_api/chime_sdk_voice","title":"list_voice_profile_domains","content":"pub fn list_voice_profile_domains(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.list_voice_profile_domains\naws_api/chime_sdk_voice list_voice_profile_domains","url":"aws_api/chime_sdk_voice.html#list_voice_profile_domains"},{"doc":"aws_api/chime_sdk_voice","title":"list_voice_profiles","content":"pub fn list_voice_profiles(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.list_voice_profiles\naws_api/chime_sdk_voice list_voice_profiles","url":"aws_api/chime_sdk_voice.html#list_voice_profiles"},{"doc":"aws_api/chime_sdk_voice","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/chime_sdk_voice.new\naws_api/chime_sdk_voice new","url":"aws_api/chime_sdk_voice.html#new"},{"doc":"aws_api/chime_sdk_voice","title":"put_sip_media_application_alexa_skill_configuration","content":"pub fn put_sip_media_application_alexa_skill_configuration(\n  client: Client,\n  sip_media_application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.put_sip_media_application_alexa_skill_configuration\naws_api/chime_sdk_voice put_sip_media_application_alexa_skill_configuration","url":"aws_api/chime_sdk_voice.html#put_sip_media_application_alexa_skill_configuration"},{"doc":"aws_api/chime_sdk_voice","title":"put_sip_media_application_logging_configuration","content":"pub fn put_sip_media_application_logging_configuration(\n  client: Client,\n  sip_media_application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.put_sip_media_application_logging_configuration\naws_api/chime_sdk_voice put_sip_media_application_logging_configuration","url":"aws_api/chime_sdk_voice.html#put_sip_media_application_logging_configuration"},{"doc":"aws_api/chime_sdk_voice","title":"put_voice_connector_emergency_calling_configuration","content":"pub fn put_voice_connector_emergency_calling_configuration(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.put_voice_connector_emergency_calling_configuration\naws_api/chime_sdk_voice put_voice_connector_emergency_calling_configuration","url":"aws_api/chime_sdk_voice.html#put_voice_connector_emergency_calling_configuration"},{"doc":"aws_api/chime_sdk_voice","title":"put_voice_connector_logging_configuration","content":"pub fn put_voice_connector_logging_configuration(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.put_voice_connector_logging_configuration\naws_api/chime_sdk_voice put_voice_connector_logging_configuration","url":"aws_api/chime_sdk_voice.html#put_voice_connector_logging_configuration"},{"doc":"aws_api/chime_sdk_voice","title":"put_voice_connector_origination","content":"pub fn put_voice_connector_origination(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.put_voice_connector_origination\naws_api/chime_sdk_voice put_voice_connector_origination","url":"aws_api/chime_sdk_voice.html#put_voice_connector_origination"},{"doc":"aws_api/chime_sdk_voice","title":"put_voice_connector_proxy","content":"pub fn put_voice_connector_proxy(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.put_voice_connector_proxy\naws_api/chime_sdk_voice put_voice_connector_proxy","url":"aws_api/chime_sdk_voice.html#put_voice_connector_proxy"},{"doc":"aws_api/chime_sdk_voice","title":"put_voice_connector_streaming_configuration","content":"pub fn put_voice_connector_streaming_configuration(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.put_voice_connector_streaming_configuration\naws_api/chime_sdk_voice put_voice_connector_streaming_configuration","url":"aws_api/chime_sdk_voice.html#put_voice_connector_streaming_configuration"},{"doc":"aws_api/chime_sdk_voice","title":"put_voice_connector_termination","content":"pub fn put_voice_connector_termination(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.put_voice_connector_termination\naws_api/chime_sdk_voice put_voice_connector_termination","url":"aws_api/chime_sdk_voice.html#put_voice_connector_termination"},{"doc":"aws_api/chime_sdk_voice","title":"put_voice_connector_termination_credentials","content":"pub fn put_voice_connector_termination_credentials(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.put_voice_connector_termination_credentials\naws_api/chime_sdk_voice put_voice_connector_termination_credentials","url":"aws_api/chime_sdk_voice.html#put_voice_connector_termination_credentials"},{"doc":"aws_api/chime_sdk_voice","title":"restore_phone_number","content":"pub fn restore_phone_number(\n  client: Client,\n  phone_number_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.restore_phone_number\naws_api/chime_sdk_voice restore_phone_number","url":"aws_api/chime_sdk_voice.html#restore_phone_number"},{"doc":"aws_api/chime_sdk_voice","title":"search_available_phone_numbers","content":"pub fn search_available_phone_numbers(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.search_available_phone_numbers\naws_api/chime_sdk_voice search_available_phone_numbers","url":"aws_api/chime_sdk_voice.html#search_available_phone_numbers"},{"doc":"aws_api/chime_sdk_voice","title":"start_speaker_search_task","content":"pub fn start_speaker_search_task(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.start_speaker_search_task\naws_api/chime_sdk_voice start_speaker_search_task","url":"aws_api/chime_sdk_voice.html#start_speaker_search_task"},{"doc":"aws_api/chime_sdk_voice","title":"start_voice_tone_analysis_task","content":"pub fn start_voice_tone_analysis_task(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.start_voice_tone_analysis_task\naws_api/chime_sdk_voice start_voice_tone_analysis_task","url":"aws_api/chime_sdk_voice.html#start_voice_tone_analysis_task"},{"doc":"aws_api/chime_sdk_voice","title":"stop_speaker_search_task","content":"pub fn stop_speaker_search_task(\n  client: Client,\n  voice_connector_id: String,\n  speaker_search_task_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.stop_speaker_search_task\naws_api/chime_sdk_voice stop_speaker_search_task","url":"aws_api/chime_sdk_voice.html#stop_speaker_search_task"},{"doc":"aws_api/chime_sdk_voice","title":"stop_voice_tone_analysis_task","content":"pub fn stop_voice_tone_analysis_task(\n  client: Client,\n  voice_connector_id: String,\n  voice_tone_analysis_task_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.stop_voice_tone_analysis_task\naws_api/chime_sdk_voice stop_voice_tone_analysis_task","url":"aws_api/chime_sdk_voice.html#stop_voice_tone_analysis_task"},{"doc":"aws_api/chime_sdk_voice","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.tag_resource\naws_api/chime_sdk_voice tag_resource","url":"aws_api/chime_sdk_voice.html#tag_resource"},{"doc":"aws_api/chime_sdk_voice","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.untag_resource\naws_api/chime_sdk_voice untag_resource","url":"aws_api/chime_sdk_voice.html#untag_resource"},{"doc":"aws_api/chime_sdk_voice","title":"update_global_settings","content":"pub fn update_global_settings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.update_global_settings\naws_api/chime_sdk_voice update_global_settings","url":"aws_api/chime_sdk_voice.html#update_global_settings"},{"doc":"aws_api/chime_sdk_voice","title":"update_phone_number","content":"pub fn update_phone_number(\n  client: Client,\n  phone_number_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.update_phone_number\naws_api/chime_sdk_voice update_phone_number","url":"aws_api/chime_sdk_voice.html#update_phone_number"},{"doc":"aws_api/chime_sdk_voice","title":"update_phone_number_settings","content":"pub fn update_phone_number_settings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.update_phone_number_settings\naws_api/chime_sdk_voice update_phone_number_settings","url":"aws_api/chime_sdk_voice.html#update_phone_number_settings"},{"doc":"aws_api/chime_sdk_voice","title":"update_proxy_session","content":"pub fn update_proxy_session(\n  client: Client,\n  voice_connector_id: String,\n  proxy_session_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.update_proxy_session\naws_api/chime_sdk_voice update_proxy_session","url":"aws_api/chime_sdk_voice.html#update_proxy_session"},{"doc":"aws_api/chime_sdk_voice","title":"update_sip_media_application","content":"pub fn update_sip_media_application(\n  client: Client,\n  sip_media_application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.update_sip_media_application\naws_api/chime_sdk_voice update_sip_media_application","url":"aws_api/chime_sdk_voice.html#update_sip_media_application"},{"doc":"aws_api/chime_sdk_voice","title":"update_sip_media_application_call","content":"pub fn update_sip_media_application_call(\n  client: Client,\n  sip_media_application_id: String,\n  transaction_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.update_sip_media_application_call\naws_api/chime_sdk_voice update_sip_media_application_call","url":"aws_api/chime_sdk_voice.html#update_sip_media_application_call"},{"doc":"aws_api/chime_sdk_voice","title":"update_sip_rule","content":"pub fn update_sip_rule(\n  client: Client,\n  sip_rule_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.update_sip_rule\naws_api/chime_sdk_voice update_sip_rule","url":"aws_api/chime_sdk_voice.html#update_sip_rule"},{"doc":"aws_api/chime_sdk_voice","title":"update_voice_connector","content":"pub fn update_voice_connector(\n  client: Client,\n  voice_connector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.update_voice_connector\naws_api/chime_sdk_voice update_voice_connector","url":"aws_api/chime_sdk_voice.html#update_voice_connector"},{"doc":"aws_api/chime_sdk_voice","title":"update_voice_connector_group","content":"pub fn update_voice_connector_group(\n  client: Client,\n  voice_connector_group_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.update_voice_connector_group\naws_api/chime_sdk_voice update_voice_connector_group","url":"aws_api/chime_sdk_voice.html#update_voice_connector_group"},{"doc":"aws_api/chime_sdk_voice","title":"update_voice_profile","content":"pub fn update_voice_profile(\n  client: Client,\n  voice_profile_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.update_voice_profile\naws_api/chime_sdk_voice update_voice_profile","url":"aws_api/chime_sdk_voice.html#update_voice_profile"},{"doc":"aws_api/chime_sdk_voice","title":"update_voice_profile_domain","content":"pub fn update_voice_profile_domain(\n  client: Client,\n  voice_profile_domain_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.update_voice_profile_domain\naws_api/chime_sdk_voice update_voice_profile_domain","url":"aws_api/chime_sdk_voice.html#update_voice_profile_domain"},{"doc":"aws_api/chime_sdk_voice","title":"validate_e911_address","content":"pub fn validate_e911_address(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/chime_sdk_voice.validate_e911_address\naws_api/chime_sdk_voice validate_e911_address","url":"aws_api/chime_sdk_voice.html#validate_e911_address"},{"doc":"aws_api/chime_sdk_voice","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/chime_sdk_voice.with_custom_endpoint\naws_api/chime_sdk_voice with_custom_endpoint","url":"aws_api/chime_sdk_voice.html#with_custom_endpoint"},{"doc":"aws_api/chime_sdk_voice","title":"aws_api/chime_sdk_voice","content":"","url":"aws_api/chime_sdk_voice.html"},{"doc":"aws_api/cleanrooms","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/cleanrooms.Client\naws_api/cleanrooms Client","url":"aws_api/cleanrooms.html#Client"},{"doc":"aws_api/cleanrooms","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cleanrooms.list_tags_for_resource\naws_api/cleanrooms list_tags_for_resource","url":"aws_api/cleanrooms.html#list_tags_for_resource"},{"doc":"aws_api/cleanrooms","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/cleanrooms.new\naws_api/cleanrooms new","url":"aws_api/cleanrooms.html#new"},{"doc":"aws_api/cleanrooms","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cleanrooms.tag_resource\naws_api/cleanrooms tag_resource","url":"aws_api/cleanrooms.html#tag_resource"},{"doc":"aws_api/cleanrooms","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cleanrooms.untag_resource\naws_api/cleanrooms untag_resource","url":"aws_api/cleanrooms.html#untag_resource"},{"doc":"aws_api/cleanrooms","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/cleanrooms.with_custom_endpoint\naws_api/cleanrooms with_custom_endpoint","url":"aws_api/cleanrooms.html#with_custom_endpoint"},{"doc":"aws_api/cleanrooms","title":"aws_api/cleanrooms","content":"","url":"aws_api/cleanrooms.html"},{"doc":"aws_api/cloud9","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/cloud9.Client\naws_api/cloud9 Client","url":"aws_api/cloud9.html#Client"},{"doc":"aws_api/cloud9","title":"create_environment_ec2","content":"pub fn create_environment_ec2(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloud9.create_environment_ec2\naws_api/cloud9 create_environment_ec2","url":"aws_api/cloud9.html#create_environment_ec2"},{"doc":"aws_api/cloud9","title":"create_environment_membership","content":"pub fn create_environment_membership(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloud9.create_environment_membership\naws_api/cloud9 create_environment_membership","url":"aws_api/cloud9.html#create_environment_membership"},{"doc":"aws_api/cloud9","title":"delete_environment","content":"pub fn delete_environment(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloud9.delete_environment\naws_api/cloud9 delete_environment","url":"aws_api/cloud9.html#delete_environment"},{"doc":"aws_api/cloud9","title":"delete_environment_membership","content":"pub fn delete_environment_membership(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloud9.delete_environment_membership\naws_api/cloud9 delete_environment_membership","url":"aws_api/cloud9.html#delete_environment_membership"},{"doc":"aws_api/cloud9","title":"describe_environment_memberships","content":"pub fn describe_environment_memberships(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloud9.describe_environment_memberships\naws_api/cloud9 describe_environment_memberships","url":"aws_api/cloud9.html#describe_environment_memberships"},{"doc":"aws_api/cloud9","title":"describe_environment_status","content":"pub fn describe_environment_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloud9.describe_environment_status\naws_api/cloud9 describe_environment_status","url":"aws_api/cloud9.html#describe_environment_status"},{"doc":"aws_api/cloud9","title":"describe_environments","content":"pub fn describe_environments(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloud9.describe_environments\naws_api/cloud9 describe_environments","url":"aws_api/cloud9.html#describe_environments"},{"doc":"aws_api/cloud9","title":"list_environments","content":"pub fn list_environments(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloud9.list_environments\naws_api/cloud9 list_environments","url":"aws_api/cloud9.html#list_environments"},{"doc":"aws_api/cloud9","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloud9.list_tags_for_resource\naws_api/cloud9 list_tags_for_resource","url":"aws_api/cloud9.html#list_tags_for_resource"},{"doc":"aws_api/cloud9","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/cloud9.new\naws_api/cloud9 new","url":"aws_api/cloud9.html#new"},{"doc":"aws_api/cloud9","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloud9.tag_resource\naws_api/cloud9 tag_resource","url":"aws_api/cloud9.html#tag_resource"},{"doc":"aws_api/cloud9","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloud9.untag_resource\naws_api/cloud9 untag_resource","url":"aws_api/cloud9.html#untag_resource"},{"doc":"aws_api/cloud9","title":"update_environment","content":"pub fn update_environment(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloud9.update_environment\naws_api/cloud9 update_environment","url":"aws_api/cloud9.html#update_environment"},{"doc":"aws_api/cloud9","title":"update_environment_membership","content":"pub fn update_environment_membership(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloud9.update_environment_membership\naws_api/cloud9 update_environment_membership","url":"aws_api/cloud9.html#update_environment_membership"},{"doc":"aws_api/cloud9","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/cloud9.with_custom_endpoint\naws_api/cloud9 with_custom_endpoint","url":"aws_api/cloud9.html#with_custom_endpoint"},{"doc":"aws_api/cloud9","title":"aws_api/cloud9","content":"","url":"aws_api/cloud9.html"},{"doc":"aws_api/cloudcontrol","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/cloudcontrol.Client\naws_api/cloudcontrol Client","url":"aws_api/cloudcontrol.html#Client"},{"doc":"aws_api/cloudcontrol","title":"cancel_resource_request","content":"pub fn cancel_resource_request(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudcontrol.cancel_resource_request\naws_api/cloudcontrol cancel_resource_request","url":"aws_api/cloudcontrol.html#cancel_resource_request"},{"doc":"aws_api/cloudcontrol","title":"create_resource","content":"pub fn create_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudcontrol.create_resource\naws_api/cloudcontrol create_resource","url":"aws_api/cloudcontrol.html#create_resource"},{"doc":"aws_api/cloudcontrol","title":"delete_resource","content":"pub fn delete_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudcontrol.delete_resource\naws_api/cloudcontrol delete_resource","url":"aws_api/cloudcontrol.html#delete_resource"},{"doc":"aws_api/cloudcontrol","title":"get_resource","content":"pub fn get_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudcontrol.get_resource\naws_api/cloudcontrol get_resource","url":"aws_api/cloudcontrol.html#get_resource"},{"doc":"aws_api/cloudcontrol","title":"get_resource_request_status","content":"pub fn get_resource_request_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudcontrol.get_resource_request_status\naws_api/cloudcontrol get_resource_request_status","url":"aws_api/cloudcontrol.html#get_resource_request_status"},{"doc":"aws_api/cloudcontrol","title":"list_resource_requests","content":"pub fn list_resource_requests(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudcontrol.list_resource_requests\naws_api/cloudcontrol list_resource_requests","url":"aws_api/cloudcontrol.html#list_resource_requests"},{"doc":"aws_api/cloudcontrol","title":"list_resources","content":"pub fn list_resources(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudcontrol.list_resources\naws_api/cloudcontrol list_resources","url":"aws_api/cloudcontrol.html#list_resources"},{"doc":"aws_api/cloudcontrol","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/cloudcontrol.new\naws_api/cloudcontrol new","url":"aws_api/cloudcontrol.html#new"},{"doc":"aws_api/cloudcontrol","title":"update_resource","content":"pub fn update_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudcontrol.update_resource\naws_api/cloudcontrol update_resource","url":"aws_api/cloudcontrol.html#update_resource"},{"doc":"aws_api/cloudcontrol","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/cloudcontrol.with_custom_endpoint\naws_api/cloudcontrol with_custom_endpoint","url":"aws_api/cloudcontrol.html#with_custom_endpoint"},{"doc":"aws_api/cloudcontrol","title":"aws_api/cloudcontrol","content":"","url":"aws_api/cloudcontrol.html"},{"doc":"aws_api/clouddirectory","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/clouddirectory.Client\naws_api/clouddirectory Client","url":"aws_api/clouddirectory.html#Client"},{"doc":"aws_api/clouddirectory","title":"add_facet_to_object","content":"pub fn add_facet_to_object(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.add_facet_to_object\naws_api/clouddirectory add_facet_to_object","url":"aws_api/clouddirectory.html#add_facet_to_object"},{"doc":"aws_api/clouddirectory","title":"apply_schema","content":"pub fn apply_schema(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.apply_schema\naws_api/clouddirectory apply_schema","url":"aws_api/clouddirectory.html#apply_schema"},{"doc":"aws_api/clouddirectory","title":"attach_object","content":"pub fn attach_object(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.attach_object\naws_api/clouddirectory attach_object","url":"aws_api/clouddirectory.html#attach_object"},{"doc":"aws_api/clouddirectory","title":"attach_policy","content":"pub fn attach_policy(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.attach_policy\naws_api/clouddirectory attach_policy","url":"aws_api/clouddirectory.html#attach_policy"},{"doc":"aws_api/clouddirectory","title":"attach_to_index","content":"pub fn attach_to_index(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.attach_to_index\naws_api/clouddirectory attach_to_index","url":"aws_api/clouddirectory.html#attach_to_index"},{"doc":"aws_api/clouddirectory","title":"attach_typed_link","content":"pub fn attach_typed_link(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.attach_typed_link\naws_api/clouddirectory attach_typed_link","url":"aws_api/clouddirectory.html#attach_typed_link"},{"doc":"aws_api/clouddirectory","title":"batch_read","content":"pub fn batch_read(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.batch_read\naws_api/clouddirectory batch_read","url":"aws_api/clouddirectory.html#batch_read"},{"doc":"aws_api/clouddirectory","title":"batch_write","content":"pub fn batch_write(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.batch_write\naws_api/clouddirectory batch_write","url":"aws_api/clouddirectory.html#batch_write"},{"doc":"aws_api/clouddirectory","title":"create_directory","content":"pub fn create_directory(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.create_directory\naws_api/clouddirectory create_directory","url":"aws_api/clouddirectory.html#create_directory"},{"doc":"aws_api/clouddirectory","title":"create_facet","content":"pub fn create_facet(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.create_facet\naws_api/clouddirectory create_facet","url":"aws_api/clouddirectory.html#create_facet"},{"doc":"aws_api/clouddirectory","title":"create_index","content":"pub fn create_index(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.create_index\naws_api/clouddirectory create_index","url":"aws_api/clouddirectory.html#create_index"},{"doc":"aws_api/clouddirectory","title":"create_object","content":"pub fn create_object(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.create_object\naws_api/clouddirectory create_object","url":"aws_api/clouddirectory.html#create_object"},{"doc":"aws_api/clouddirectory","title":"create_schema","content":"pub fn create_schema(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.create_schema\naws_api/clouddirectory create_schema","url":"aws_api/clouddirectory.html#create_schema"},{"doc":"aws_api/clouddirectory","title":"create_typed_link_facet","content":"pub fn create_typed_link_facet(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.create_typed_link_facet\naws_api/clouddirectory create_typed_link_facet","url":"aws_api/clouddirectory.html#create_typed_link_facet"},{"doc":"aws_api/clouddirectory","title":"delete_directory","content":"pub fn delete_directory(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.delete_directory\naws_api/clouddirectory delete_directory","url":"aws_api/clouddirectory.html#delete_directory"},{"doc":"aws_api/clouddirectory","title":"delete_facet","content":"pub fn delete_facet(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.delete_facet\naws_api/clouddirectory delete_facet","url":"aws_api/clouddirectory.html#delete_facet"},{"doc":"aws_api/clouddirectory","title":"delete_object","content":"pub fn delete_object(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.delete_object\naws_api/clouddirectory delete_object","url":"aws_api/clouddirectory.html#delete_object"},{"doc":"aws_api/clouddirectory","title":"delete_schema","content":"pub fn delete_schema(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.delete_schema\naws_api/clouddirectory delete_schema","url":"aws_api/clouddirectory.html#delete_schema"},{"doc":"aws_api/clouddirectory","title":"delete_typed_link_facet","content":"pub fn delete_typed_link_facet(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.delete_typed_link_facet\naws_api/clouddirectory delete_typed_link_facet","url":"aws_api/clouddirectory.html#delete_typed_link_facet"},{"doc":"aws_api/clouddirectory","title":"detach_from_index","content":"pub fn detach_from_index(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.detach_from_index\naws_api/clouddirectory detach_from_index","url":"aws_api/clouddirectory.html#detach_from_index"},{"doc":"aws_api/clouddirectory","title":"detach_object","content":"pub fn detach_object(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.detach_object\naws_api/clouddirectory detach_object","url":"aws_api/clouddirectory.html#detach_object"},{"doc":"aws_api/clouddirectory","title":"detach_policy","content":"pub fn detach_policy(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.detach_policy\naws_api/clouddirectory detach_policy","url":"aws_api/clouddirectory.html#detach_policy"},{"doc":"aws_api/clouddirectory","title":"detach_typed_link","content":"pub fn detach_typed_link(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.detach_typed_link\naws_api/clouddirectory detach_typed_link","url":"aws_api/clouddirectory.html#detach_typed_link"},{"doc":"aws_api/clouddirectory","title":"disable_directory","content":"pub fn disable_directory(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.disable_directory\naws_api/clouddirectory disable_directory","url":"aws_api/clouddirectory.html#disable_directory"},{"doc":"aws_api/clouddirectory","title":"enable_directory","content":"pub fn enable_directory(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.enable_directory\naws_api/clouddirectory enable_directory","url":"aws_api/clouddirectory.html#enable_directory"},{"doc":"aws_api/clouddirectory","title":"get_applied_schema_version","content":"pub fn get_applied_schema_version(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.get_applied_schema_version\naws_api/clouddirectory get_applied_schema_version","url":"aws_api/clouddirectory.html#get_applied_schema_version"},{"doc":"aws_api/clouddirectory","title":"get_directory","content":"pub fn get_directory(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.get_directory\naws_api/clouddirectory get_directory","url":"aws_api/clouddirectory.html#get_directory"},{"doc":"aws_api/clouddirectory","title":"get_facet","content":"pub fn get_facet(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.get_facet\naws_api/clouddirectory get_facet","url":"aws_api/clouddirectory.html#get_facet"},{"doc":"aws_api/clouddirectory","title":"get_link_attributes","content":"pub fn get_link_attributes(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.get_link_attributes\naws_api/clouddirectory get_link_attributes","url":"aws_api/clouddirectory.html#get_link_attributes"},{"doc":"aws_api/clouddirectory","title":"get_object_attributes","content":"pub fn get_object_attributes(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.get_object_attributes\naws_api/clouddirectory get_object_attributes","url":"aws_api/clouddirectory.html#get_object_attributes"},{"doc":"aws_api/clouddirectory","title":"get_object_information","content":"pub fn get_object_information(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.get_object_information\naws_api/clouddirectory get_object_information","url":"aws_api/clouddirectory.html#get_object_information"},{"doc":"aws_api/clouddirectory","title":"get_schema_as_json","content":"pub fn get_schema_as_json(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.get_schema_as_json\naws_api/clouddirectory get_schema_as_json","url":"aws_api/clouddirectory.html#get_schema_as_json"},{"doc":"aws_api/clouddirectory","title":"get_typed_link_facet_information","content":"pub fn get_typed_link_facet_information(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.get_typed_link_facet_information\naws_api/clouddirectory get_typed_link_facet_information","url":"aws_api/clouddirectory.html#get_typed_link_facet_information"},{"doc":"aws_api/clouddirectory","title":"list_applied_schema_arns","content":"pub fn list_applied_schema_arns(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.list_applied_schema_arns\naws_api/clouddirectory list_applied_schema_arns","url":"aws_api/clouddirectory.html#list_applied_schema_arns"},{"doc":"aws_api/clouddirectory","title":"list_attached_indices","content":"pub fn list_attached_indices(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.list_attached_indices\naws_api/clouddirectory list_attached_indices","url":"aws_api/clouddirectory.html#list_attached_indices"},{"doc":"aws_api/clouddirectory","title":"list_development_schema_arns","content":"pub fn list_development_schema_arns(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.list_development_schema_arns\naws_api/clouddirectory list_development_schema_arns","url":"aws_api/clouddirectory.html#list_development_schema_arns"},{"doc":"aws_api/clouddirectory","title":"list_directories","content":"pub fn list_directories(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.list_directories\naws_api/clouddirectory list_directories","url":"aws_api/clouddirectory.html#list_directories"},{"doc":"aws_api/clouddirectory","title":"list_facet_attributes","content":"pub fn list_facet_attributes(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.list_facet_attributes\naws_api/clouddirectory list_facet_attributes","url":"aws_api/clouddirectory.html#list_facet_attributes"},{"doc":"aws_api/clouddirectory","title":"list_facet_names","content":"pub fn list_facet_names(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.list_facet_names\naws_api/clouddirectory list_facet_names","url":"aws_api/clouddirectory.html#list_facet_names"},{"doc":"aws_api/clouddirectory","title":"list_incoming_typed_links","content":"pub fn list_incoming_typed_links(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.list_incoming_typed_links\naws_api/clouddirectory list_incoming_typed_links","url":"aws_api/clouddirectory.html#list_incoming_typed_links"},{"doc":"aws_api/clouddirectory","title":"list_index","content":"pub fn list_index(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.list_index\naws_api/clouddirectory list_index","url":"aws_api/clouddirectory.html#list_index"},{"doc":"aws_api/clouddirectory","title":"list_managed_schema_arns","content":"pub fn list_managed_schema_arns(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.list_managed_schema_arns\naws_api/clouddirectory list_managed_schema_arns","url":"aws_api/clouddirectory.html#list_managed_schema_arns"},{"doc":"aws_api/clouddirectory","title":"list_object_attributes","content":"pub fn list_object_attributes(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.list_object_attributes\naws_api/clouddirectory list_object_attributes","url":"aws_api/clouddirectory.html#list_object_attributes"},{"doc":"aws_api/clouddirectory","title":"list_object_children","content":"pub fn list_object_children(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.list_object_children\naws_api/clouddirectory list_object_children","url":"aws_api/clouddirectory.html#list_object_children"},{"doc":"aws_api/clouddirectory","title":"list_object_parent_paths","content":"pub fn list_object_parent_paths(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.list_object_parent_paths\naws_api/clouddirectory list_object_parent_paths","url":"aws_api/clouddirectory.html#list_object_parent_paths"},{"doc":"aws_api/clouddirectory","title":"list_object_parents","content":"pub fn list_object_parents(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.list_object_parents\naws_api/clouddirectory list_object_parents","url":"aws_api/clouddirectory.html#list_object_parents"},{"doc":"aws_api/clouddirectory","title":"list_object_policies","content":"pub fn list_object_policies(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.list_object_policies\naws_api/clouddirectory list_object_policies","url":"aws_api/clouddirectory.html#list_object_policies"},{"doc":"aws_api/clouddirectory","title":"list_outgoing_typed_links","content":"pub fn list_outgoing_typed_links(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.list_outgoing_typed_links\naws_api/clouddirectory list_outgoing_typed_links","url":"aws_api/clouddirectory.html#list_outgoing_typed_links"},{"doc":"aws_api/clouddirectory","title":"list_policy_attachments","content":"pub fn list_policy_attachments(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.list_policy_attachments\naws_api/clouddirectory list_policy_attachments","url":"aws_api/clouddirectory.html#list_policy_attachments"},{"doc":"aws_api/clouddirectory","title":"list_published_schema_arns","content":"pub fn list_published_schema_arns(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.list_published_schema_arns\naws_api/clouddirectory list_published_schema_arns","url":"aws_api/clouddirectory.html#list_published_schema_arns"},{"doc":"aws_api/clouddirectory","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.list_tags_for_resource\naws_api/clouddirectory list_tags_for_resource","url":"aws_api/clouddirectory.html#list_tags_for_resource"},{"doc":"aws_api/clouddirectory","title":"list_typed_link_facet_attributes","content":"pub fn list_typed_link_facet_attributes(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.list_typed_link_facet_attributes\naws_api/clouddirectory list_typed_link_facet_attributes","url":"aws_api/clouddirectory.html#list_typed_link_facet_attributes"},{"doc":"aws_api/clouddirectory","title":"list_typed_link_facet_names","content":"pub fn list_typed_link_facet_names(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.list_typed_link_facet_names\naws_api/clouddirectory list_typed_link_facet_names","url":"aws_api/clouddirectory.html#list_typed_link_facet_names"},{"doc":"aws_api/clouddirectory","title":"lookup_policy","content":"pub fn lookup_policy(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.lookup_policy\naws_api/clouddirectory lookup_policy","url":"aws_api/clouddirectory.html#lookup_policy"},{"doc":"aws_api/clouddirectory","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/clouddirectory.new\naws_api/clouddirectory new","url":"aws_api/clouddirectory.html#new"},{"doc":"aws_api/clouddirectory","title":"publish_schema","content":"pub fn publish_schema(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.publish_schema\naws_api/clouddirectory publish_schema","url":"aws_api/clouddirectory.html#publish_schema"},{"doc":"aws_api/clouddirectory","title":"put_schema_from_json","content":"pub fn put_schema_from_json(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.put_schema_from_json\naws_api/clouddirectory put_schema_from_json","url":"aws_api/clouddirectory.html#put_schema_from_json"},{"doc":"aws_api/clouddirectory","title":"remove_facet_from_object","content":"pub fn remove_facet_from_object(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.remove_facet_from_object\naws_api/clouddirectory remove_facet_from_object","url":"aws_api/clouddirectory.html#remove_facet_from_object"},{"doc":"aws_api/clouddirectory","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.tag_resource\naws_api/clouddirectory tag_resource","url":"aws_api/clouddirectory.html#tag_resource"},{"doc":"aws_api/clouddirectory","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.untag_resource\naws_api/clouddirectory untag_resource","url":"aws_api/clouddirectory.html#untag_resource"},{"doc":"aws_api/clouddirectory","title":"update_facet","content":"pub fn update_facet(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.update_facet\naws_api/clouddirectory update_facet","url":"aws_api/clouddirectory.html#update_facet"},{"doc":"aws_api/clouddirectory","title":"update_link_attributes","content":"pub fn update_link_attributes(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.update_link_attributes\naws_api/clouddirectory update_link_attributes","url":"aws_api/clouddirectory.html#update_link_attributes"},{"doc":"aws_api/clouddirectory","title":"update_object_attributes","content":"pub fn update_object_attributes(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.update_object_attributes\naws_api/clouddirectory update_object_attributes","url":"aws_api/clouddirectory.html#update_object_attributes"},{"doc":"aws_api/clouddirectory","title":"update_schema","content":"pub fn update_schema(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.update_schema\naws_api/clouddirectory update_schema","url":"aws_api/clouddirectory.html#update_schema"},{"doc":"aws_api/clouddirectory","title":"update_typed_link_facet","content":"pub fn update_typed_link_facet(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.update_typed_link_facet\naws_api/clouddirectory update_typed_link_facet","url":"aws_api/clouddirectory.html#update_typed_link_facet"},{"doc":"aws_api/clouddirectory","title":"upgrade_applied_schema","content":"pub fn upgrade_applied_schema(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.upgrade_applied_schema\naws_api/clouddirectory upgrade_applied_schema","url":"aws_api/clouddirectory.html#upgrade_applied_schema"},{"doc":"aws_api/clouddirectory","title":"upgrade_published_schema","content":"pub fn upgrade_published_schema(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/clouddirectory.upgrade_published_schema\naws_api/clouddirectory upgrade_published_schema","url":"aws_api/clouddirectory.html#upgrade_published_schema"},{"doc":"aws_api/clouddirectory","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/clouddirectory.with_custom_endpoint\naws_api/clouddirectory with_custom_endpoint","url":"aws_api/clouddirectory.html#with_custom_endpoint"},{"doc":"aws_api/clouddirectory","title":"aws_api/clouddirectory","content":"","url":"aws_api/clouddirectory.html"},{"doc":"aws_api/cloudformation","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/cloudformation.Client\naws_api/cloudformation Client","url":"aws_api/cloudformation.html#Client"},{"doc":"aws_api/cloudformation","title":"activate_organizations_access","content":"pub fn activate_organizations_access(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.activate_organizations_access\naws_api/cloudformation activate_organizations_access","url":"aws_api/cloudformation.html#activate_organizations_access"},{"doc":"aws_api/cloudformation","title":"activate_type","content":"pub fn activate_type(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.activate_type\naws_api/cloudformation activate_type","url":"aws_api/cloudformation.html#activate_type"},{"doc":"aws_api/cloudformation","title":"batch_describe_type_configurations","content":"pub fn batch_describe_type_configurations(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.batch_describe_type_configurations\naws_api/cloudformation batch_describe_type_configurations","url":"aws_api/cloudformation.html#batch_describe_type_configurations"},{"doc":"aws_api/cloudformation","title":"cancel_update_stack","content":"pub fn cancel_update_stack(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.cancel_update_stack\naws_api/cloudformation cancel_update_stack","url":"aws_api/cloudformation.html#cancel_update_stack"},{"doc":"aws_api/cloudformation","title":"continue_update_rollback","content":"pub fn continue_update_rollback(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.continue_update_rollback\naws_api/cloudformation continue_update_rollback","url":"aws_api/cloudformation.html#continue_update_rollback"},{"doc":"aws_api/cloudformation","title":"create_change_set","content":"pub fn create_change_set(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.create_change_set\naws_api/cloudformation create_change_set","url":"aws_api/cloudformation.html#create_change_set"},{"doc":"aws_api/cloudformation","title":"create_generated_template","content":"pub fn create_generated_template(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.create_generated_template\naws_api/cloudformation create_generated_template","url":"aws_api/cloudformation.html#create_generated_template"},{"doc":"aws_api/cloudformation","title":"create_stack","content":"pub fn create_stack(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.create_stack\naws_api/cloudformation create_stack","url":"aws_api/cloudformation.html#create_stack"},{"doc":"aws_api/cloudformation","title":"create_stack_instances","content":"pub fn create_stack_instances(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.create_stack_instances\naws_api/cloudformation create_stack_instances","url":"aws_api/cloudformation.html#create_stack_instances"},{"doc":"aws_api/cloudformation","title":"create_stack_set","content":"pub fn create_stack_set(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.create_stack_set\naws_api/cloudformation create_stack_set","url":"aws_api/cloudformation.html#create_stack_set"},{"doc":"aws_api/cloudformation","title":"deactivate_organizations_access","content":"pub fn deactivate_organizations_access(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.deactivate_organizations_access\naws_api/cloudformation deactivate_organizations_access","url":"aws_api/cloudformation.html#deactivate_organizations_access"},{"doc":"aws_api/cloudformation","title":"deactivate_type","content":"pub fn deactivate_type(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.deactivate_type\naws_api/cloudformation deactivate_type","url":"aws_api/cloudformation.html#deactivate_type"},{"doc":"aws_api/cloudformation","title":"delete_change_set","content":"pub fn delete_change_set(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.delete_change_set\naws_api/cloudformation delete_change_set","url":"aws_api/cloudformation.html#delete_change_set"},{"doc":"aws_api/cloudformation","title":"delete_generated_template","content":"pub fn delete_generated_template(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.delete_generated_template\naws_api/cloudformation delete_generated_template","url":"aws_api/cloudformation.html#delete_generated_template"},{"doc":"aws_api/cloudformation","title":"delete_stack","content":"pub fn delete_stack(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.delete_stack\naws_api/cloudformation delete_stack","url":"aws_api/cloudformation.html#delete_stack"},{"doc":"aws_api/cloudformation","title":"delete_stack_instances","content":"pub fn delete_stack_instances(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.delete_stack_instances\naws_api/cloudformation delete_stack_instances","url":"aws_api/cloudformation.html#delete_stack_instances"},{"doc":"aws_api/cloudformation","title":"delete_stack_set","content":"pub fn delete_stack_set(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.delete_stack_set\naws_api/cloudformation delete_stack_set","url":"aws_api/cloudformation.html#delete_stack_set"},{"doc":"aws_api/cloudformation","title":"deregister_type","content":"pub fn deregister_type(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.deregister_type\naws_api/cloudformation deregister_type","url":"aws_api/cloudformation.html#deregister_type"},{"doc":"aws_api/cloudformation","title":"describe_account_limits","content":"pub fn describe_account_limits(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.describe_account_limits\naws_api/cloudformation describe_account_limits","url":"aws_api/cloudformation.html#describe_account_limits"},{"doc":"aws_api/cloudformation","title":"describe_change_set","content":"pub fn describe_change_set(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.describe_change_set\naws_api/cloudformation describe_change_set","url":"aws_api/cloudformation.html#describe_change_set"},{"doc":"aws_api/cloudformation","title":"describe_change_set_hooks","content":"pub fn describe_change_set_hooks(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.describe_change_set_hooks\naws_api/cloudformation describe_change_set_hooks","url":"aws_api/cloudformation.html#describe_change_set_hooks"},{"doc":"aws_api/cloudformation","title":"describe_generated_template","content":"pub fn describe_generated_template(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.describe_generated_template\naws_api/cloudformation describe_generated_template","url":"aws_api/cloudformation.html#describe_generated_template"},{"doc":"aws_api/cloudformation","title":"describe_organizations_access","content":"pub fn describe_organizations_access(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.describe_organizations_access\naws_api/cloudformation describe_organizations_access","url":"aws_api/cloudformation.html#describe_organizations_access"},{"doc":"aws_api/cloudformation","title":"describe_publisher","content":"pub fn describe_publisher(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.describe_publisher\naws_api/cloudformation describe_publisher","url":"aws_api/cloudformation.html#describe_publisher"},{"doc":"aws_api/cloudformation","title":"describe_resource_scan","content":"pub fn describe_resource_scan(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.describe_resource_scan\naws_api/cloudformation describe_resource_scan","url":"aws_api/cloudformation.html#describe_resource_scan"},{"doc":"aws_api/cloudformation","title":"describe_stack_drift_detection_status","content":"pub fn describe_stack_drift_detection_status(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.describe_stack_drift_detection_status\naws_api/cloudformation describe_stack_drift_detection_status","url":"aws_api/cloudformation.html#describe_stack_drift_detection_status"},{"doc":"aws_api/cloudformation","title":"describe_stack_events","content":"pub fn describe_stack_events(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.describe_stack_events\naws_api/cloudformation describe_stack_events","url":"aws_api/cloudformation.html#describe_stack_events"},{"doc":"aws_api/cloudformation","title":"describe_stack_instance","content":"pub fn describe_stack_instance(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.describe_stack_instance\naws_api/cloudformation describe_stack_instance","url":"aws_api/cloudformation.html#describe_stack_instance"},{"doc":"aws_api/cloudformation","title":"describe_stack_resource","content":"pub fn describe_stack_resource(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.describe_stack_resource\naws_api/cloudformation describe_stack_resource","url":"aws_api/cloudformation.html#describe_stack_resource"},{"doc":"aws_api/cloudformation","title":"describe_stack_resource_drifts","content":"pub fn describe_stack_resource_drifts(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.describe_stack_resource_drifts\naws_api/cloudformation describe_stack_resource_drifts","url":"aws_api/cloudformation.html#describe_stack_resource_drifts"},{"doc":"aws_api/cloudformation","title":"describe_stack_resources","content":"pub fn describe_stack_resources(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.describe_stack_resources\naws_api/cloudformation describe_stack_resources","url":"aws_api/cloudformation.html#describe_stack_resources"},{"doc":"aws_api/cloudformation","title":"describe_stack_set","content":"pub fn describe_stack_set(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.describe_stack_set\naws_api/cloudformation describe_stack_set","url":"aws_api/cloudformation.html#describe_stack_set"},{"doc":"aws_api/cloudformation","title":"describe_stack_set_operation","content":"pub fn describe_stack_set_operation(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.describe_stack_set_operation\naws_api/cloudformation describe_stack_set_operation","url":"aws_api/cloudformation.html#describe_stack_set_operation"},{"doc":"aws_api/cloudformation","title":"describe_stacks","content":"pub fn describe_stacks(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.describe_stacks\naws_api/cloudformation describe_stacks","url":"aws_api/cloudformation.html#describe_stacks"},{"doc":"aws_api/cloudformation","title":"describe_type","content":"pub fn describe_type(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.describe_type\naws_api/cloudformation describe_type","url":"aws_api/cloudformation.html#describe_type"},{"doc":"aws_api/cloudformation","title":"describe_type_registration","content":"pub fn describe_type_registration(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.describe_type_registration\naws_api/cloudformation describe_type_registration","url":"aws_api/cloudformation.html#describe_type_registration"},{"doc":"aws_api/cloudformation","title":"detect_stack_drift","content":"pub fn detect_stack_drift(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.detect_stack_drift\naws_api/cloudformation detect_stack_drift","url":"aws_api/cloudformation.html#detect_stack_drift"},{"doc":"aws_api/cloudformation","title":"detect_stack_resource_drift","content":"pub fn detect_stack_resource_drift(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.detect_stack_resource_drift\naws_api/cloudformation detect_stack_resource_drift","url":"aws_api/cloudformation.html#detect_stack_resource_drift"},{"doc":"aws_api/cloudformation","title":"detect_stack_set_drift","content":"pub fn detect_stack_set_drift(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.detect_stack_set_drift\naws_api/cloudformation detect_stack_set_drift","url":"aws_api/cloudformation.html#detect_stack_set_drift"},{"doc":"aws_api/cloudformation","title":"estimate_template_cost","content":"pub fn estimate_template_cost(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.estimate_template_cost\naws_api/cloudformation estimate_template_cost","url":"aws_api/cloudformation.html#estimate_template_cost"},{"doc":"aws_api/cloudformation","title":"execute_change_set","content":"pub fn execute_change_set(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.execute_change_set\naws_api/cloudformation execute_change_set","url":"aws_api/cloudformation.html#execute_change_set"},{"doc":"aws_api/cloudformation","title":"get_generated_template","content":"pub fn get_generated_template(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.get_generated_template\naws_api/cloudformation get_generated_template","url":"aws_api/cloudformation.html#get_generated_template"},{"doc":"aws_api/cloudformation","title":"get_stack_policy","content":"pub fn get_stack_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.get_stack_policy\naws_api/cloudformation get_stack_policy","url":"aws_api/cloudformation.html#get_stack_policy"},{"doc":"aws_api/cloudformation","title":"get_template","content":"pub fn get_template(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.get_template\naws_api/cloudformation get_template","url":"aws_api/cloudformation.html#get_template"},{"doc":"aws_api/cloudformation","title":"get_template_summary","content":"pub fn get_template_summary(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.get_template_summary\naws_api/cloudformation get_template_summary","url":"aws_api/cloudformation.html#get_template_summary"},{"doc":"aws_api/cloudformation","title":"import_stacks_to_stack_set","content":"pub fn import_stacks_to_stack_set(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.import_stacks_to_stack_set\naws_api/cloudformation import_stacks_to_stack_set","url":"aws_api/cloudformation.html#import_stacks_to_stack_set"},{"doc":"aws_api/cloudformation","title":"list_change_sets","content":"pub fn list_change_sets(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.list_change_sets\naws_api/cloudformation list_change_sets","url":"aws_api/cloudformation.html#list_change_sets"},{"doc":"aws_api/cloudformation","title":"list_exports","content":"pub fn list_exports(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.list_exports\naws_api/cloudformation list_exports","url":"aws_api/cloudformation.html#list_exports"},{"doc":"aws_api/cloudformation","title":"list_generated_templates","content":"pub fn list_generated_templates(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.list_generated_templates\naws_api/cloudformation list_generated_templates","url":"aws_api/cloudformation.html#list_generated_templates"},{"doc":"aws_api/cloudformation","title":"list_imports","content":"pub fn list_imports(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.list_imports\naws_api/cloudformation list_imports","url":"aws_api/cloudformation.html#list_imports"},{"doc":"aws_api/cloudformation","title":"list_resource_scan_related_resources","content":"pub fn list_resource_scan_related_resources(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.list_resource_scan_related_resources\naws_api/cloudformation list_resource_scan_related_resources","url":"aws_api/cloudformation.html#list_resource_scan_related_resources"},{"doc":"aws_api/cloudformation","title":"list_resource_scan_resources","content":"pub fn list_resource_scan_resources(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.list_resource_scan_resources\naws_api/cloudformation list_resource_scan_resources","url":"aws_api/cloudformation.html#list_resource_scan_resources"},{"doc":"aws_api/cloudformation","title":"list_resource_scans","content":"pub fn list_resource_scans(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.list_resource_scans\naws_api/cloudformation list_resource_scans","url":"aws_api/cloudformation.html#list_resource_scans"},{"doc":"aws_api/cloudformation","title":"list_stack_instance_resource_drifts","content":"pub fn list_stack_instance_resource_drifts(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.list_stack_instance_resource_drifts\naws_api/cloudformation list_stack_instance_resource_drifts","url":"aws_api/cloudformation.html#list_stack_instance_resource_drifts"},{"doc":"aws_api/cloudformation","title":"list_stack_instances","content":"pub fn list_stack_instances(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.list_stack_instances\naws_api/cloudformation list_stack_instances","url":"aws_api/cloudformation.html#list_stack_instances"},{"doc":"aws_api/cloudformation","title":"list_stack_resources","content":"pub fn list_stack_resources(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.list_stack_resources\naws_api/cloudformation list_stack_resources","url":"aws_api/cloudformation.html#list_stack_resources"},{"doc":"aws_api/cloudformation","title":"list_stack_set_auto_deployment_targets","content":"pub fn list_stack_set_auto_deployment_targets(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.list_stack_set_auto_deployment_targets\naws_api/cloudformation list_stack_set_auto_deployment_targets","url":"aws_api/cloudformation.html#list_stack_set_auto_deployment_targets"},{"doc":"aws_api/cloudformation","title":"list_stack_set_operation_results","content":"pub fn list_stack_set_operation_results(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.list_stack_set_operation_results\naws_api/cloudformation list_stack_set_operation_results","url":"aws_api/cloudformation.html#list_stack_set_operation_results"},{"doc":"aws_api/cloudformation","title":"list_stack_set_operations","content":"pub fn list_stack_set_operations(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.list_stack_set_operations\naws_api/cloudformation list_stack_set_operations","url":"aws_api/cloudformation.html#list_stack_set_operations"},{"doc":"aws_api/cloudformation","title":"list_stack_sets","content":"pub fn list_stack_sets(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.list_stack_sets\naws_api/cloudformation list_stack_sets","url":"aws_api/cloudformation.html#list_stack_sets"},{"doc":"aws_api/cloudformation","title":"list_stacks","content":"pub fn list_stacks(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.list_stacks\naws_api/cloudformation list_stacks","url":"aws_api/cloudformation.html#list_stacks"},{"doc":"aws_api/cloudformation","title":"list_type_registrations","content":"pub fn list_type_registrations(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.list_type_registrations\naws_api/cloudformation list_type_registrations","url":"aws_api/cloudformation.html#list_type_registrations"},{"doc":"aws_api/cloudformation","title":"list_type_versions","content":"pub fn list_type_versions(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.list_type_versions\naws_api/cloudformation list_type_versions","url":"aws_api/cloudformation.html#list_type_versions"},{"doc":"aws_api/cloudformation","title":"list_types","content":"pub fn list_types(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.list_types\naws_api/cloudformation list_types","url":"aws_api/cloudformation.html#list_types"},{"doc":"aws_api/cloudformation","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/cloudformation.new\naws_api/cloudformation new","url":"aws_api/cloudformation.html#new"},{"doc":"aws_api/cloudformation","title":"publish_type","content":"pub fn publish_type(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.publish_type\naws_api/cloudformation publish_type","url":"aws_api/cloudformation.html#publish_type"},{"doc":"aws_api/cloudformation","title":"record_handler_progress","content":"pub fn record_handler_progress(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.record_handler_progress\naws_api/cloudformation record_handler_progress","url":"aws_api/cloudformation.html#record_handler_progress"},{"doc":"aws_api/cloudformation","title":"register_publisher","content":"pub fn register_publisher(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.register_publisher\naws_api/cloudformation register_publisher","url":"aws_api/cloudformation.html#register_publisher"},{"doc":"aws_api/cloudformation","title":"register_type","content":"pub fn register_type(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.register_type\naws_api/cloudformation register_type","url":"aws_api/cloudformation.html#register_type"},{"doc":"aws_api/cloudformation","title":"rollback_stack","content":"pub fn rollback_stack(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.rollback_stack\naws_api/cloudformation rollback_stack","url":"aws_api/cloudformation.html#rollback_stack"},{"doc":"aws_api/cloudformation","title":"set_stack_policy","content":"pub fn set_stack_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.set_stack_policy\naws_api/cloudformation set_stack_policy","url":"aws_api/cloudformation.html#set_stack_policy"},{"doc":"aws_api/cloudformation","title":"set_type_configuration","content":"pub fn set_type_configuration(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.set_type_configuration\naws_api/cloudformation set_type_configuration","url":"aws_api/cloudformation.html#set_type_configuration"},{"doc":"aws_api/cloudformation","title":"set_type_default_version","content":"pub fn set_type_default_version(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.set_type_default_version\naws_api/cloudformation set_type_default_version","url":"aws_api/cloudformation.html#set_type_default_version"},{"doc":"aws_api/cloudformation","title":"signal_resource","content":"pub fn signal_resource(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.signal_resource\naws_api/cloudformation signal_resource","url":"aws_api/cloudformation.html#signal_resource"},{"doc":"aws_api/cloudformation","title":"start_resource_scan","content":"pub fn start_resource_scan(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.start_resource_scan\naws_api/cloudformation start_resource_scan","url":"aws_api/cloudformation.html#start_resource_scan"},{"doc":"aws_api/cloudformation","title":"stop_stack_set_operation","content":"pub fn stop_stack_set_operation(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.stop_stack_set_operation\naws_api/cloudformation stop_stack_set_operation","url":"aws_api/cloudformation.html#stop_stack_set_operation"},{"doc":"aws_api/cloudformation","title":"test_type","content":"pub fn test_type(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.test_type\naws_api/cloudformation test_type","url":"aws_api/cloudformation.html#test_type"},{"doc":"aws_api/cloudformation","title":"update_generated_template","content":"pub fn update_generated_template(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.update_generated_template\naws_api/cloudformation update_generated_template","url":"aws_api/cloudformation.html#update_generated_template"},{"doc":"aws_api/cloudformation","title":"update_stack","content":"pub fn update_stack(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.update_stack\naws_api/cloudformation update_stack","url":"aws_api/cloudformation.html#update_stack"},{"doc":"aws_api/cloudformation","title":"update_stack_instances","content":"pub fn update_stack_instances(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.update_stack_instances\naws_api/cloudformation update_stack_instances","url":"aws_api/cloudformation.html#update_stack_instances"},{"doc":"aws_api/cloudformation","title":"update_stack_set","content":"pub fn update_stack_set(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.update_stack_set\naws_api/cloudformation update_stack_set","url":"aws_api/cloudformation.html#update_stack_set"},{"doc":"aws_api/cloudformation","title":"update_termination_protection","content":"pub fn update_termination_protection(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.update_termination_protection\naws_api/cloudformation update_termination_protection","url":"aws_api/cloudformation.html#update_termination_protection"},{"doc":"aws_api/cloudformation","title":"validate_template","content":"pub fn validate_template(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudformation.validate_template\naws_api/cloudformation validate_template","url":"aws_api/cloudformation.html#validate_template"},{"doc":"aws_api/cloudformation","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/cloudformation.with_custom_endpoint\naws_api/cloudformation with_custom_endpoint","url":"aws_api/cloudformation.html#with_custom_endpoint"},{"doc":"aws_api/cloudformation","title":"aws_api/cloudformation","content":"","url":"aws_api/cloudformation.html"},{"doc":"aws_api/cloudfront","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/cloudfront.Client\naws_api/cloudfront Client","url":"aws_api/cloudfront.html#Client"},{"doc":"aws_api/cloudfront","title":"associate_alias","content":"pub fn associate_alias(\n  client: Client,\n  target_distribution_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.associate_alias\naws_api/cloudfront associate_alias","url":"aws_api/cloudfront.html#associate_alias"},{"doc":"aws_api/cloudfront","title":"copy_distribution","content":"pub fn copy_distribution(\n  client: Client,\n  primary_distribution_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.copy_distribution\naws_api/cloudfront copy_distribution","url":"aws_api/cloudfront.html#copy_distribution"},{"doc":"aws_api/cloudfront","title":"create_cache_policy","content":"pub fn create_cache_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.create_cache_policy\naws_api/cloudfront create_cache_policy","url":"aws_api/cloudfront.html#create_cache_policy"},{"doc":"aws_api/cloudfront","title":"create_cloud_front_origin_access_identity","content":"pub fn create_cloud_front_origin_access_identity(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.create_cloud_front_origin_access_identity\naws_api/cloudfront create_cloud_front_origin_access_identity","url":"aws_api/cloudfront.html#create_cloud_front_origin_access_identity"},{"doc":"aws_api/cloudfront","title":"create_continuous_deployment_policy","content":"pub fn create_continuous_deployment_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.create_continuous_deployment_policy\naws_api/cloudfront create_continuous_deployment_policy","url":"aws_api/cloudfront.html#create_continuous_deployment_policy"},{"doc":"aws_api/cloudfront","title":"create_distribution","content":"pub fn create_distribution(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.create_distribution\naws_api/cloudfront create_distribution","url":"aws_api/cloudfront.html#create_distribution"},{"doc":"aws_api/cloudfront","title":"create_distribution_with_tags","content":"pub fn create_distribution_with_tags(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.create_distribution_with_tags\naws_api/cloudfront create_distribution_with_tags","url":"aws_api/cloudfront.html#create_distribution_with_tags"},{"doc":"aws_api/cloudfront","title":"create_field_level_encryption_config","content":"pub fn create_field_level_encryption_config(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.create_field_level_encryption_config\naws_api/cloudfront create_field_level_encryption_config","url":"aws_api/cloudfront.html#create_field_level_encryption_config"},{"doc":"aws_api/cloudfront","title":"create_field_level_encryption_profile","content":"pub fn create_field_level_encryption_profile(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.create_field_level_encryption_profile\naws_api/cloudfront create_field_level_encryption_profile","url":"aws_api/cloudfront.html#create_field_level_encryption_profile"},{"doc":"aws_api/cloudfront","title":"create_function","content":"pub fn create_function(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.create_function\naws_api/cloudfront create_function","url":"aws_api/cloudfront.html#create_function"},{"doc":"aws_api/cloudfront","title":"create_invalidation","content":"pub fn create_invalidation(\n  client: Client,\n  distribution_id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.create_invalidation\naws_api/cloudfront create_invalidation","url":"aws_api/cloudfront.html#create_invalidation"},{"doc":"aws_api/cloudfront","title":"create_key_group","content":"pub fn create_key_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.create_key_group\naws_api/cloudfront create_key_group","url":"aws_api/cloudfront.html#create_key_group"},{"doc":"aws_api/cloudfront","title":"create_key_value_store","content":"pub fn create_key_value_store(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.create_key_value_store\naws_api/cloudfront create_key_value_store","url":"aws_api/cloudfront.html#create_key_value_store"},{"doc":"aws_api/cloudfront","title":"create_monitoring_subscription","content":"pub fn create_monitoring_subscription(\n  client: Client,\n  distribution_id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.create_monitoring_subscription\naws_api/cloudfront create_monitoring_subscription","url":"aws_api/cloudfront.html#create_monitoring_subscription"},{"doc":"aws_api/cloudfront","title":"create_origin_access_control","content":"pub fn create_origin_access_control(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.create_origin_access_control\naws_api/cloudfront create_origin_access_control","url":"aws_api/cloudfront.html#create_origin_access_control"},{"doc":"aws_api/cloudfront","title":"create_origin_request_policy","content":"pub fn create_origin_request_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.create_origin_request_policy\naws_api/cloudfront create_origin_request_policy","url":"aws_api/cloudfront.html#create_origin_request_policy"},{"doc":"aws_api/cloudfront","title":"create_public_key","content":"pub fn create_public_key(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.create_public_key\naws_api/cloudfront create_public_key","url":"aws_api/cloudfront.html#create_public_key"},{"doc":"aws_api/cloudfront","title":"create_realtime_log_config","content":"pub fn create_realtime_log_config(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.create_realtime_log_config\naws_api/cloudfront create_realtime_log_config","url":"aws_api/cloudfront.html#create_realtime_log_config"},{"doc":"aws_api/cloudfront","title":"create_response_headers_policy","content":"pub fn create_response_headers_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.create_response_headers_policy\naws_api/cloudfront create_response_headers_policy","url":"aws_api/cloudfront.html#create_response_headers_policy"},{"doc":"aws_api/cloudfront","title":"create_streaming_distribution","content":"pub fn create_streaming_distribution(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.create_streaming_distribution\naws_api/cloudfront create_streaming_distribution","url":"aws_api/cloudfront.html#create_streaming_distribution"},{"doc":"aws_api/cloudfront","title":"create_streaming_distribution_with_tags","content":"pub fn create_streaming_distribution_with_tags(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.create_streaming_distribution_with_tags\naws_api/cloudfront create_streaming_distribution_with_tags","url":"aws_api/cloudfront.html#create_streaming_distribution_with_tags"},{"doc":"aws_api/cloudfront","title":"delete_cache_policy","content":"pub fn delete_cache_policy(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.delete_cache_policy\naws_api/cloudfront delete_cache_policy","url":"aws_api/cloudfront.html#delete_cache_policy"},{"doc":"aws_api/cloudfront","title":"delete_cloud_front_origin_access_identity","content":"pub fn delete_cloud_front_origin_access_identity(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.delete_cloud_front_origin_access_identity\naws_api/cloudfront delete_cloud_front_origin_access_identity","url":"aws_api/cloudfront.html#delete_cloud_front_origin_access_identity"},{"doc":"aws_api/cloudfront","title":"delete_continuous_deployment_policy","content":"pub fn delete_continuous_deployment_policy(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.delete_continuous_deployment_policy\naws_api/cloudfront delete_continuous_deployment_policy","url":"aws_api/cloudfront.html#delete_continuous_deployment_policy"},{"doc":"aws_api/cloudfront","title":"delete_distribution","content":"pub fn delete_distribution(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.delete_distribution\naws_api/cloudfront delete_distribution","url":"aws_api/cloudfront.html#delete_distribution"},{"doc":"aws_api/cloudfront","title":"delete_field_level_encryption_config","content":"pub fn delete_field_level_encryption_config(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.delete_field_level_encryption_config\naws_api/cloudfront delete_field_level_encryption_config","url":"aws_api/cloudfront.html#delete_field_level_encryption_config"},{"doc":"aws_api/cloudfront","title":"delete_field_level_encryption_profile","content":"pub fn delete_field_level_encryption_profile(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.delete_field_level_encryption_profile\naws_api/cloudfront delete_field_level_encryption_profile","url":"aws_api/cloudfront.html#delete_field_level_encryption_profile"},{"doc":"aws_api/cloudfront","title":"delete_function","content":"pub fn delete_function(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.delete_function\naws_api/cloudfront delete_function","url":"aws_api/cloudfront.html#delete_function"},{"doc":"aws_api/cloudfront","title":"delete_key_group","content":"pub fn delete_key_group(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.delete_key_group\naws_api/cloudfront delete_key_group","url":"aws_api/cloudfront.html#delete_key_group"},{"doc":"aws_api/cloudfront","title":"delete_key_value_store","content":"pub fn delete_key_value_store(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.delete_key_value_store\naws_api/cloudfront delete_key_value_store","url":"aws_api/cloudfront.html#delete_key_value_store"},{"doc":"aws_api/cloudfront","title":"delete_monitoring_subscription","content":"pub fn delete_monitoring_subscription(\n  client: Client,\n  distribution_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.delete_monitoring_subscription\naws_api/cloudfront delete_monitoring_subscription","url":"aws_api/cloudfront.html#delete_monitoring_subscription"},{"doc":"aws_api/cloudfront","title":"delete_origin_access_control","content":"pub fn delete_origin_access_control(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.delete_origin_access_control\naws_api/cloudfront delete_origin_access_control","url":"aws_api/cloudfront.html#delete_origin_access_control"},{"doc":"aws_api/cloudfront","title":"delete_origin_request_policy","content":"pub fn delete_origin_request_policy(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.delete_origin_request_policy\naws_api/cloudfront delete_origin_request_policy","url":"aws_api/cloudfront.html#delete_origin_request_policy"},{"doc":"aws_api/cloudfront","title":"delete_public_key","content":"pub fn delete_public_key(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.delete_public_key\naws_api/cloudfront delete_public_key","url":"aws_api/cloudfront.html#delete_public_key"},{"doc":"aws_api/cloudfront","title":"delete_realtime_log_config","content":"pub fn delete_realtime_log_config(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.delete_realtime_log_config\naws_api/cloudfront delete_realtime_log_config","url":"aws_api/cloudfront.html#delete_realtime_log_config"},{"doc":"aws_api/cloudfront","title":"delete_response_headers_policy","content":"pub fn delete_response_headers_policy(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.delete_response_headers_policy\naws_api/cloudfront delete_response_headers_policy","url":"aws_api/cloudfront.html#delete_response_headers_policy"},{"doc":"aws_api/cloudfront","title":"delete_streaming_distribution","content":"pub fn delete_streaming_distribution(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.delete_streaming_distribution\naws_api/cloudfront delete_streaming_distribution","url":"aws_api/cloudfront.html#delete_streaming_distribution"},{"doc":"aws_api/cloudfront","title":"describe_function","content":"pub fn describe_function(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.describe_function\naws_api/cloudfront describe_function","url":"aws_api/cloudfront.html#describe_function"},{"doc":"aws_api/cloudfront","title":"describe_key_value_store","content":"pub fn describe_key_value_store(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.describe_key_value_store\naws_api/cloudfront describe_key_value_store","url":"aws_api/cloudfront.html#describe_key_value_store"},{"doc":"aws_api/cloudfront","title":"get_cache_policy","content":"pub fn get_cache_policy(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.get_cache_policy\naws_api/cloudfront get_cache_policy","url":"aws_api/cloudfront.html#get_cache_policy"},{"doc":"aws_api/cloudfront","title":"get_cache_policy_config","content":"pub fn get_cache_policy_config(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.get_cache_policy_config\naws_api/cloudfront get_cache_policy_config","url":"aws_api/cloudfront.html#get_cache_policy_config"},{"doc":"aws_api/cloudfront","title":"get_cloud_front_origin_access_identity","content":"pub fn get_cloud_front_origin_access_identity(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.get_cloud_front_origin_access_identity\naws_api/cloudfront get_cloud_front_origin_access_identity","url":"aws_api/cloudfront.html#get_cloud_front_origin_access_identity"},{"doc":"aws_api/cloudfront","title":"get_cloud_front_origin_access_identity_config","content":"pub fn get_cloud_front_origin_access_identity_config(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.get_cloud_front_origin_access_identity_config\naws_api/cloudfront get_cloud_front_origin_access_identity_config","url":"aws_api/cloudfront.html#get_cloud_front_origin_access_identity_config"},{"doc":"aws_api/cloudfront","title":"get_continuous_deployment_policy","content":"pub fn get_continuous_deployment_policy(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.get_continuous_deployment_policy\naws_api/cloudfront get_continuous_deployment_policy","url":"aws_api/cloudfront.html#get_continuous_deployment_policy"},{"doc":"aws_api/cloudfront","title":"get_continuous_deployment_policy_config","content":"pub fn get_continuous_deployment_policy_config(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.get_continuous_deployment_policy_config\naws_api/cloudfront get_continuous_deployment_policy_config","url":"aws_api/cloudfront.html#get_continuous_deployment_policy_config"},{"doc":"aws_api/cloudfront","title":"get_distribution","content":"pub fn get_distribution(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.get_distribution\naws_api/cloudfront get_distribution","url":"aws_api/cloudfront.html#get_distribution"},{"doc":"aws_api/cloudfront","title":"get_distribution_config","content":"pub fn get_distribution_config(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.get_distribution_config\naws_api/cloudfront get_distribution_config","url":"aws_api/cloudfront.html#get_distribution_config"},{"doc":"aws_api/cloudfront","title":"get_field_level_encryption","content":"pub fn get_field_level_encryption(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.get_field_level_encryption\naws_api/cloudfront get_field_level_encryption","url":"aws_api/cloudfront.html#get_field_level_encryption"},{"doc":"aws_api/cloudfront","title":"get_field_level_encryption_config","content":"pub fn get_field_level_encryption_config(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.get_field_level_encryption_config\naws_api/cloudfront get_field_level_encryption_config","url":"aws_api/cloudfront.html#get_field_level_encryption_config"},{"doc":"aws_api/cloudfront","title":"get_field_level_encryption_profile","content":"pub fn get_field_level_encryption_profile(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.get_field_level_encryption_profile\naws_api/cloudfront get_field_level_encryption_profile","url":"aws_api/cloudfront.html#get_field_level_encryption_profile"},{"doc":"aws_api/cloudfront","title":"get_field_level_encryption_profile_config","content":"pub fn get_field_level_encryption_profile_config(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.get_field_level_encryption_profile_config\naws_api/cloudfront get_field_level_encryption_profile_config","url":"aws_api/cloudfront.html#get_field_level_encryption_profile_config"},{"doc":"aws_api/cloudfront","title":"get_function","content":"pub fn get_function(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.get_function\naws_api/cloudfront get_function","url":"aws_api/cloudfront.html#get_function"},{"doc":"aws_api/cloudfront","title":"get_invalidation","content":"pub fn get_invalidation(\n  client: Client,\n  distribution_id: String,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.get_invalidation\naws_api/cloudfront get_invalidation","url":"aws_api/cloudfront.html#get_invalidation"},{"doc":"aws_api/cloudfront","title":"get_key_group","content":"pub fn get_key_group(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.get_key_group\naws_api/cloudfront get_key_group","url":"aws_api/cloudfront.html#get_key_group"},{"doc":"aws_api/cloudfront","title":"get_key_group_config","content":"pub fn get_key_group_config(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.get_key_group_config\naws_api/cloudfront get_key_group_config","url":"aws_api/cloudfront.html#get_key_group_config"},{"doc":"aws_api/cloudfront","title":"get_monitoring_subscription","content":"pub fn get_monitoring_subscription(\n  client: Client,\n  distribution_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.get_monitoring_subscription\naws_api/cloudfront get_monitoring_subscription","url":"aws_api/cloudfront.html#get_monitoring_subscription"},{"doc":"aws_api/cloudfront","title":"get_origin_access_control","content":"pub fn get_origin_access_control(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.get_origin_access_control\naws_api/cloudfront get_origin_access_control","url":"aws_api/cloudfront.html#get_origin_access_control"},{"doc":"aws_api/cloudfront","title":"get_origin_access_control_config","content":"pub fn get_origin_access_control_config(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.get_origin_access_control_config\naws_api/cloudfront get_origin_access_control_config","url":"aws_api/cloudfront.html#get_origin_access_control_config"},{"doc":"aws_api/cloudfront","title":"get_origin_request_policy","content":"pub fn get_origin_request_policy(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.get_origin_request_policy\naws_api/cloudfront get_origin_request_policy","url":"aws_api/cloudfront.html#get_origin_request_policy"},{"doc":"aws_api/cloudfront","title":"get_origin_request_policy_config","content":"pub fn get_origin_request_policy_config(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.get_origin_request_policy_config\naws_api/cloudfront get_origin_request_policy_config","url":"aws_api/cloudfront.html#get_origin_request_policy_config"},{"doc":"aws_api/cloudfront","title":"get_public_key","content":"pub fn get_public_key(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.get_public_key\naws_api/cloudfront get_public_key","url":"aws_api/cloudfront.html#get_public_key"},{"doc":"aws_api/cloudfront","title":"get_public_key_config","content":"pub fn get_public_key_config(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.get_public_key_config\naws_api/cloudfront get_public_key_config","url":"aws_api/cloudfront.html#get_public_key_config"},{"doc":"aws_api/cloudfront","title":"get_realtime_log_config","content":"pub fn get_realtime_log_config(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.get_realtime_log_config\naws_api/cloudfront get_realtime_log_config","url":"aws_api/cloudfront.html#get_realtime_log_config"},{"doc":"aws_api/cloudfront","title":"get_response_headers_policy","content":"pub fn get_response_headers_policy(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.get_response_headers_policy\naws_api/cloudfront get_response_headers_policy","url":"aws_api/cloudfront.html#get_response_headers_policy"},{"doc":"aws_api/cloudfront","title":"get_response_headers_policy_config","content":"pub fn get_response_headers_policy_config(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.get_response_headers_policy_config\naws_api/cloudfront get_response_headers_policy_config","url":"aws_api/cloudfront.html#get_response_headers_policy_config"},{"doc":"aws_api/cloudfront","title":"get_streaming_distribution","content":"pub fn get_streaming_distribution(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.get_streaming_distribution\naws_api/cloudfront get_streaming_distribution","url":"aws_api/cloudfront.html#get_streaming_distribution"},{"doc":"aws_api/cloudfront","title":"get_streaming_distribution_config","content":"pub fn get_streaming_distribution_config(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.get_streaming_distribution_config\naws_api/cloudfront get_streaming_distribution_config","url":"aws_api/cloudfront.html#get_streaming_distribution_config"},{"doc":"aws_api/cloudfront","title":"list_cache_policies","content":"pub fn list_cache_policies(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.list_cache_policies\naws_api/cloudfront list_cache_policies","url":"aws_api/cloudfront.html#list_cache_policies"},{"doc":"aws_api/cloudfront","title":"list_cloud_front_origin_access_identities","content":"pub fn list_cloud_front_origin_access_identities(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.list_cloud_front_origin_access_identities\naws_api/cloudfront list_cloud_front_origin_access_identities","url":"aws_api/cloudfront.html#list_cloud_front_origin_access_identities"},{"doc":"aws_api/cloudfront","title":"list_conflicting_aliases","content":"pub fn list_conflicting_aliases(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.list_conflicting_aliases\naws_api/cloudfront list_conflicting_aliases","url":"aws_api/cloudfront.html#list_conflicting_aliases"},{"doc":"aws_api/cloudfront","title":"list_continuous_deployment_policies","content":"pub fn list_continuous_deployment_policies(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.list_continuous_deployment_policies\naws_api/cloudfront list_continuous_deployment_policies","url":"aws_api/cloudfront.html#list_continuous_deployment_policies"},{"doc":"aws_api/cloudfront","title":"list_distributions","content":"pub fn list_distributions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.list_distributions\naws_api/cloudfront list_distributions","url":"aws_api/cloudfront.html#list_distributions"},{"doc":"aws_api/cloudfront","title":"list_distributions_by_cache_policy_id","content":"pub fn list_distributions_by_cache_policy_id(\n  client: Client,\n  cache_policy_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.list_distributions_by_cache_policy_id\naws_api/cloudfront list_distributions_by_cache_policy_id","url":"aws_api/cloudfront.html#list_distributions_by_cache_policy_id"},{"doc":"aws_api/cloudfront","title":"list_distributions_by_key_group","content":"pub fn list_distributions_by_key_group(\n  client: Client,\n  key_group_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.list_distributions_by_key_group\naws_api/cloudfront list_distributions_by_key_group","url":"aws_api/cloudfront.html#list_distributions_by_key_group"},{"doc":"aws_api/cloudfront","title":"list_distributions_by_origin_request_policy_id","content":"pub fn list_distributions_by_origin_request_policy_id(\n  client: Client,\n  origin_request_policy_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.list_distributions_by_origin_request_policy_id\naws_api/cloudfront list_distributions_by_origin_request_policy_id","url":"aws_api/cloudfront.html#list_distributions_by_origin_request_policy_id"},{"doc":"aws_api/cloudfront","title":"list_distributions_by_realtime_log_config","content":"pub fn list_distributions_by_realtime_log_config(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.list_distributions_by_realtime_log_config\naws_api/cloudfront list_distributions_by_realtime_log_config","url":"aws_api/cloudfront.html#list_distributions_by_realtime_log_config"},{"doc":"aws_api/cloudfront","title":"list_distributions_by_response_headers_policy_id","content":"pub fn list_distributions_by_response_headers_policy_id(\n  client: Client,\n  response_headers_policy_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.list_distributions_by_response_headers_policy_id\naws_api/cloudfront list_distributions_by_response_headers_policy_id","url":"aws_api/cloudfront.html#list_distributions_by_response_headers_policy_id"},{"doc":"aws_api/cloudfront","title":"list_distributions_by_web_acl_id","content":"pub fn list_distributions_by_web_acl_id(\n  client: Client,\n  web_acl_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.list_distributions_by_web_acl_id\naws_api/cloudfront list_distributions_by_web_acl_id","url":"aws_api/cloudfront.html#list_distributions_by_web_acl_id"},{"doc":"aws_api/cloudfront","title":"list_field_level_encryption_configs","content":"pub fn list_field_level_encryption_configs(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.list_field_level_encryption_configs\naws_api/cloudfront list_field_level_encryption_configs","url":"aws_api/cloudfront.html#list_field_level_encryption_configs"},{"doc":"aws_api/cloudfront","title":"list_field_level_encryption_profiles","content":"pub fn list_field_level_encryption_profiles(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.list_field_level_encryption_profiles\naws_api/cloudfront list_field_level_encryption_profiles","url":"aws_api/cloudfront.html#list_field_level_encryption_profiles"},{"doc":"aws_api/cloudfront","title":"list_functions","content":"pub fn list_functions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.list_functions\naws_api/cloudfront list_functions","url":"aws_api/cloudfront.html#list_functions"},{"doc":"aws_api/cloudfront","title":"list_invalidations","content":"pub fn list_invalidations(\n  client: Client,\n  distribution_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.list_invalidations\naws_api/cloudfront list_invalidations","url":"aws_api/cloudfront.html#list_invalidations"},{"doc":"aws_api/cloudfront","title":"list_key_groups","content":"pub fn list_key_groups(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.list_key_groups\naws_api/cloudfront list_key_groups","url":"aws_api/cloudfront.html#list_key_groups"},{"doc":"aws_api/cloudfront","title":"list_key_value_stores","content":"pub fn list_key_value_stores(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.list_key_value_stores\naws_api/cloudfront list_key_value_stores","url":"aws_api/cloudfront.html#list_key_value_stores"},{"doc":"aws_api/cloudfront","title":"list_origin_access_controls","content":"pub fn list_origin_access_controls(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.list_origin_access_controls\naws_api/cloudfront list_origin_access_controls","url":"aws_api/cloudfront.html#list_origin_access_controls"},{"doc":"aws_api/cloudfront","title":"list_origin_request_policies","content":"pub fn list_origin_request_policies(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.list_origin_request_policies\naws_api/cloudfront list_origin_request_policies","url":"aws_api/cloudfront.html#list_origin_request_policies"},{"doc":"aws_api/cloudfront","title":"list_public_keys","content":"pub fn list_public_keys(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.list_public_keys\naws_api/cloudfront list_public_keys","url":"aws_api/cloudfront.html#list_public_keys"},{"doc":"aws_api/cloudfront","title":"list_realtime_log_configs","content":"pub fn list_realtime_log_configs(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.list_realtime_log_configs\naws_api/cloudfront list_realtime_log_configs","url":"aws_api/cloudfront.html#list_realtime_log_configs"},{"doc":"aws_api/cloudfront","title":"list_response_headers_policies","content":"pub fn list_response_headers_policies(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.list_response_headers_policies\naws_api/cloudfront list_response_headers_policies","url":"aws_api/cloudfront.html#list_response_headers_policies"},{"doc":"aws_api/cloudfront","title":"list_streaming_distributions","content":"pub fn list_streaming_distributions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.list_streaming_distributions\naws_api/cloudfront list_streaming_distributions","url":"aws_api/cloudfront.html#list_streaming_distributions"},{"doc":"aws_api/cloudfront","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.list_tags_for_resource\naws_api/cloudfront list_tags_for_resource","url":"aws_api/cloudfront.html#list_tags_for_resource"},{"doc":"aws_api/cloudfront","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/cloudfront.new\naws_api/cloudfront new","url":"aws_api/cloudfront.html#new"},{"doc":"aws_api/cloudfront","title":"publish_function","content":"pub fn publish_function(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.publish_function\naws_api/cloudfront publish_function","url":"aws_api/cloudfront.html#publish_function"},{"doc":"aws_api/cloudfront","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.tag_resource\naws_api/cloudfront tag_resource","url":"aws_api/cloudfront.html#tag_resource"},{"doc":"aws_api/cloudfront","title":"test_function","content":"pub fn test_function(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.test_function\naws_api/cloudfront test_function","url":"aws_api/cloudfront.html#test_function"},{"doc":"aws_api/cloudfront","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.untag_resource\naws_api/cloudfront untag_resource","url":"aws_api/cloudfront.html#untag_resource"},{"doc":"aws_api/cloudfront","title":"update_cache_policy","content":"pub fn update_cache_policy(\n  client: Client,\n  id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.update_cache_policy\naws_api/cloudfront update_cache_policy","url":"aws_api/cloudfront.html#update_cache_policy"},{"doc":"aws_api/cloudfront","title":"update_cloud_front_origin_access_identity","content":"pub fn update_cloud_front_origin_access_identity(\n  client: Client,\n  id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.update_cloud_front_origin_access_identity\naws_api/cloudfront update_cloud_front_origin_access_identity","url":"aws_api/cloudfront.html#update_cloud_front_origin_access_identity"},{"doc":"aws_api/cloudfront","title":"update_continuous_deployment_policy","content":"pub fn update_continuous_deployment_policy(\n  client: Client,\n  id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.update_continuous_deployment_policy\naws_api/cloudfront update_continuous_deployment_policy","url":"aws_api/cloudfront.html#update_continuous_deployment_policy"},{"doc":"aws_api/cloudfront","title":"update_distribution","content":"pub fn update_distribution(\n  client: Client,\n  id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.update_distribution\naws_api/cloudfront update_distribution","url":"aws_api/cloudfront.html#update_distribution"},{"doc":"aws_api/cloudfront","title":"update_distribution_with_staging_config","content":"pub fn update_distribution_with_staging_config(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.update_distribution_with_staging_config\naws_api/cloudfront update_distribution_with_staging_config","url":"aws_api/cloudfront.html#update_distribution_with_staging_config"},{"doc":"aws_api/cloudfront","title":"update_field_level_encryption_config","content":"pub fn update_field_level_encryption_config(\n  client: Client,\n  id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.update_field_level_encryption_config\naws_api/cloudfront update_field_level_encryption_config","url":"aws_api/cloudfront.html#update_field_level_encryption_config"},{"doc":"aws_api/cloudfront","title":"update_field_level_encryption_profile","content":"pub fn update_field_level_encryption_profile(\n  client: Client,\n  id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.update_field_level_encryption_profile\naws_api/cloudfront update_field_level_encryption_profile","url":"aws_api/cloudfront.html#update_field_level_encryption_profile"},{"doc":"aws_api/cloudfront","title":"update_function","content":"pub fn update_function(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.update_function\naws_api/cloudfront update_function","url":"aws_api/cloudfront.html#update_function"},{"doc":"aws_api/cloudfront","title":"update_key_group","content":"pub fn update_key_group(\n  client: Client,\n  id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.update_key_group\naws_api/cloudfront update_key_group","url":"aws_api/cloudfront.html#update_key_group"},{"doc":"aws_api/cloudfront","title":"update_key_value_store","content":"pub fn update_key_value_store(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.update_key_value_store\naws_api/cloudfront update_key_value_store","url":"aws_api/cloudfront.html#update_key_value_store"},{"doc":"aws_api/cloudfront","title":"update_origin_access_control","content":"pub fn update_origin_access_control(\n  client: Client,\n  id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.update_origin_access_control\naws_api/cloudfront update_origin_access_control","url":"aws_api/cloudfront.html#update_origin_access_control"},{"doc":"aws_api/cloudfront","title":"update_origin_request_policy","content":"pub fn update_origin_request_policy(\n  client: Client,\n  id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.update_origin_request_policy\naws_api/cloudfront update_origin_request_policy","url":"aws_api/cloudfront.html#update_origin_request_policy"},{"doc":"aws_api/cloudfront","title":"update_public_key","content":"pub fn update_public_key(\n  client: Client,\n  id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.update_public_key\naws_api/cloudfront update_public_key","url":"aws_api/cloudfront.html#update_public_key"},{"doc":"aws_api/cloudfront","title":"update_realtime_log_config","content":"pub fn update_realtime_log_config(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.update_realtime_log_config\naws_api/cloudfront update_realtime_log_config","url":"aws_api/cloudfront.html#update_realtime_log_config"},{"doc":"aws_api/cloudfront","title":"update_response_headers_policy","content":"pub fn update_response_headers_policy(\n  client: Client,\n  id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.update_response_headers_policy\naws_api/cloudfront update_response_headers_policy","url":"aws_api/cloudfront.html#update_response_headers_policy"},{"doc":"aws_api/cloudfront","title":"update_streaming_distribution","content":"pub fn update_streaming_distribution(\n  client: Client,\n  id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudfront.update_streaming_distribution\naws_api/cloudfront update_streaming_distribution","url":"aws_api/cloudfront.html#update_streaming_distribution"},{"doc":"aws_api/cloudfront","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/cloudfront.with_custom_endpoint\naws_api/cloudfront with_custom_endpoint","url":"aws_api/cloudfront.html#with_custom_endpoint"},{"doc":"aws_api/cloudfront","title":"aws_api/cloudfront","content":"","url":"aws_api/cloudfront.html"},{"doc":"aws_api/cloudhsm","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/cloudhsm.Client\naws_api/cloudhsm Client","url":"aws_api/cloudhsm.html#Client"},{"doc":"aws_api/cloudhsm","title":"add_tags_to_resource","content":"pub fn add_tags_to_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudhsm.add_tags_to_resource\naws_api/cloudhsm add_tags_to_resource","url":"aws_api/cloudhsm.html#add_tags_to_resource"},{"doc":"aws_api/cloudhsm","title":"create_hapg","content":"pub fn create_hapg(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudhsm.create_hapg\naws_api/cloudhsm create_hapg","url":"aws_api/cloudhsm.html#create_hapg"},{"doc":"aws_api/cloudhsm","title":"create_hsm","content":"pub fn create_hsm(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudhsm.create_hsm\naws_api/cloudhsm create_hsm","url":"aws_api/cloudhsm.html#create_hsm"},{"doc":"aws_api/cloudhsm","title":"create_luna_client","content":"pub fn create_luna_client(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudhsm.create_luna_client\naws_api/cloudhsm create_luna_client","url":"aws_api/cloudhsm.html#create_luna_client"},{"doc":"aws_api/cloudhsm","title":"delete_hapg","content":"pub fn delete_hapg(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudhsm.delete_hapg\naws_api/cloudhsm delete_hapg","url":"aws_api/cloudhsm.html#delete_hapg"},{"doc":"aws_api/cloudhsm","title":"delete_hsm","content":"pub fn delete_hsm(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudhsm.delete_hsm\naws_api/cloudhsm delete_hsm","url":"aws_api/cloudhsm.html#delete_hsm"},{"doc":"aws_api/cloudhsm","title":"delete_luna_client","content":"pub fn delete_luna_client(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudhsm.delete_luna_client\naws_api/cloudhsm delete_luna_client","url":"aws_api/cloudhsm.html#delete_luna_client"},{"doc":"aws_api/cloudhsm","title":"describe_hapg","content":"pub fn describe_hapg(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudhsm.describe_hapg\naws_api/cloudhsm describe_hapg","url":"aws_api/cloudhsm.html#describe_hapg"},{"doc":"aws_api/cloudhsm","title":"describe_hsm","content":"pub fn describe_hsm(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudhsm.describe_hsm\naws_api/cloudhsm describe_hsm","url":"aws_api/cloudhsm.html#describe_hsm"},{"doc":"aws_api/cloudhsm","title":"describe_luna_client","content":"pub fn describe_luna_client(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudhsm.describe_luna_client\naws_api/cloudhsm describe_luna_client","url":"aws_api/cloudhsm.html#describe_luna_client"},{"doc":"aws_api/cloudhsm","title":"get_config","content":"pub fn get_config(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudhsm.get_config\naws_api/cloudhsm get_config","url":"aws_api/cloudhsm.html#get_config"},{"doc":"aws_api/cloudhsm","title":"list_available_zones","content":"pub fn list_available_zones(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudhsm.list_available_zones\naws_api/cloudhsm list_available_zones","url":"aws_api/cloudhsm.html#list_available_zones"},{"doc":"aws_api/cloudhsm","title":"list_hapgs","content":"pub fn list_hapgs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudhsm.list_hapgs\naws_api/cloudhsm list_hapgs","url":"aws_api/cloudhsm.html#list_hapgs"},{"doc":"aws_api/cloudhsm","title":"list_hsms","content":"pub fn list_hsms(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudhsm.list_hsms\naws_api/cloudhsm list_hsms","url":"aws_api/cloudhsm.html#list_hsms"},{"doc":"aws_api/cloudhsm","title":"list_luna_clients","content":"pub fn list_luna_clients(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudhsm.list_luna_clients\naws_api/cloudhsm list_luna_clients","url":"aws_api/cloudhsm.html#list_luna_clients"},{"doc":"aws_api/cloudhsm","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudhsm.list_tags_for_resource\naws_api/cloudhsm list_tags_for_resource","url":"aws_api/cloudhsm.html#list_tags_for_resource"},{"doc":"aws_api/cloudhsm","title":"modify_hapg","content":"pub fn modify_hapg(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudhsm.modify_hapg\naws_api/cloudhsm modify_hapg","url":"aws_api/cloudhsm.html#modify_hapg"},{"doc":"aws_api/cloudhsm","title":"modify_hsm","content":"pub fn modify_hsm(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudhsm.modify_hsm\naws_api/cloudhsm modify_hsm","url":"aws_api/cloudhsm.html#modify_hsm"},{"doc":"aws_api/cloudhsm","title":"modify_luna_client","content":"pub fn modify_luna_client(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudhsm.modify_luna_client\naws_api/cloudhsm modify_luna_client","url":"aws_api/cloudhsm.html#modify_luna_client"},{"doc":"aws_api/cloudhsm","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/cloudhsm.new\naws_api/cloudhsm new","url":"aws_api/cloudhsm.html#new"},{"doc":"aws_api/cloudhsm","title":"remove_tags_from_resource","content":"pub fn remove_tags_from_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudhsm.remove_tags_from_resource\naws_api/cloudhsm remove_tags_from_resource","url":"aws_api/cloudhsm.html#remove_tags_from_resource"},{"doc":"aws_api/cloudhsm","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/cloudhsm.with_custom_endpoint\naws_api/cloudhsm with_custom_endpoint","url":"aws_api/cloudhsm.html#with_custom_endpoint"},{"doc":"aws_api/cloudhsm","title":"aws_api/cloudhsm","content":"","url":"aws_api/cloudhsm.html"},{"doc":"aws_api/cloudhsm_v2","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/cloudhsm_v2.Client\naws_api/cloudhsm_v2 Client","url":"aws_api/cloudhsm_v2.html#Client"},{"doc":"aws_api/cloudhsm_v2","title":"copy_backup_to_region","content":"pub fn copy_backup_to_region(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudhsm_v2.copy_backup_to_region\naws_api/cloudhsm_v2 copy_backup_to_region","url":"aws_api/cloudhsm_v2.html#copy_backup_to_region"},{"doc":"aws_api/cloudhsm_v2","title":"create_cluster","content":"pub fn create_cluster(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudhsm_v2.create_cluster\naws_api/cloudhsm_v2 create_cluster","url":"aws_api/cloudhsm_v2.html#create_cluster"},{"doc":"aws_api/cloudhsm_v2","title":"create_hsm","content":"pub fn create_hsm(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudhsm_v2.create_hsm\naws_api/cloudhsm_v2 create_hsm","url":"aws_api/cloudhsm_v2.html#create_hsm"},{"doc":"aws_api/cloudhsm_v2","title":"delete_backup","content":"pub fn delete_backup(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudhsm_v2.delete_backup\naws_api/cloudhsm_v2 delete_backup","url":"aws_api/cloudhsm_v2.html#delete_backup"},{"doc":"aws_api/cloudhsm_v2","title":"delete_cluster","content":"pub fn delete_cluster(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudhsm_v2.delete_cluster\naws_api/cloudhsm_v2 delete_cluster","url":"aws_api/cloudhsm_v2.html#delete_cluster"},{"doc":"aws_api/cloudhsm_v2","title":"delete_hsm","content":"pub fn delete_hsm(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudhsm_v2.delete_hsm\naws_api/cloudhsm_v2 delete_hsm","url":"aws_api/cloudhsm_v2.html#delete_hsm"},{"doc":"aws_api/cloudhsm_v2","title":"delete_resource_policy","content":"pub fn delete_resource_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudhsm_v2.delete_resource_policy\naws_api/cloudhsm_v2 delete_resource_policy","url":"aws_api/cloudhsm_v2.html#delete_resource_policy"},{"doc":"aws_api/cloudhsm_v2","title":"describe_backups","content":"pub fn describe_backups(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudhsm_v2.describe_backups\naws_api/cloudhsm_v2 describe_backups","url":"aws_api/cloudhsm_v2.html#describe_backups"},{"doc":"aws_api/cloudhsm_v2","title":"describe_clusters","content":"pub fn describe_clusters(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudhsm_v2.describe_clusters\naws_api/cloudhsm_v2 describe_clusters","url":"aws_api/cloudhsm_v2.html#describe_clusters"},{"doc":"aws_api/cloudhsm_v2","title":"get_resource_policy","content":"pub fn get_resource_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudhsm_v2.get_resource_policy\naws_api/cloudhsm_v2 get_resource_policy","url":"aws_api/cloudhsm_v2.html#get_resource_policy"},{"doc":"aws_api/cloudhsm_v2","title":"initialize_cluster","content":"pub fn initialize_cluster(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudhsm_v2.initialize_cluster\naws_api/cloudhsm_v2 initialize_cluster","url":"aws_api/cloudhsm_v2.html#initialize_cluster"},{"doc":"aws_api/cloudhsm_v2","title":"list_tags","content":"pub fn list_tags(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudhsm_v2.list_tags\naws_api/cloudhsm_v2 list_tags","url":"aws_api/cloudhsm_v2.html#list_tags"},{"doc":"aws_api/cloudhsm_v2","title":"modify_backup_attributes","content":"pub fn modify_backup_attributes(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudhsm_v2.modify_backup_attributes\naws_api/cloudhsm_v2 modify_backup_attributes","url":"aws_api/cloudhsm_v2.html#modify_backup_attributes"},{"doc":"aws_api/cloudhsm_v2","title":"modify_cluster","content":"pub fn modify_cluster(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudhsm_v2.modify_cluster\naws_api/cloudhsm_v2 modify_cluster","url":"aws_api/cloudhsm_v2.html#modify_cluster"},{"doc":"aws_api/cloudhsm_v2","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/cloudhsm_v2.new\naws_api/cloudhsm_v2 new","url":"aws_api/cloudhsm_v2.html#new"},{"doc":"aws_api/cloudhsm_v2","title":"put_resource_policy","content":"pub fn put_resource_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudhsm_v2.put_resource_policy\naws_api/cloudhsm_v2 put_resource_policy","url":"aws_api/cloudhsm_v2.html#put_resource_policy"},{"doc":"aws_api/cloudhsm_v2","title":"restore_backup","content":"pub fn restore_backup(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudhsm_v2.restore_backup\naws_api/cloudhsm_v2 restore_backup","url":"aws_api/cloudhsm_v2.html#restore_backup"},{"doc":"aws_api/cloudhsm_v2","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudhsm_v2.tag_resource\naws_api/cloudhsm_v2 tag_resource","url":"aws_api/cloudhsm_v2.html#tag_resource"},{"doc":"aws_api/cloudhsm_v2","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudhsm_v2.untag_resource\naws_api/cloudhsm_v2 untag_resource","url":"aws_api/cloudhsm_v2.html#untag_resource"},{"doc":"aws_api/cloudhsm_v2","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/cloudhsm_v2.with_custom_endpoint\naws_api/cloudhsm_v2 with_custom_endpoint","url":"aws_api/cloudhsm_v2.html#with_custom_endpoint"},{"doc":"aws_api/cloudhsm_v2","title":"aws_api/cloudhsm_v2","content":"","url":"aws_api/cloudhsm_v2.html"},{"doc":"aws_api/cloudsearch","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/cloudsearch.Client\naws_api/cloudsearch Client","url":"aws_api/cloudsearch.html#Client"},{"doc":"aws_api/cloudsearch","title":"build_suggesters","content":"pub fn build_suggesters(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudsearch.build_suggesters\naws_api/cloudsearch build_suggesters","url":"aws_api/cloudsearch.html#build_suggesters"},{"doc":"aws_api/cloudsearch","title":"create_domain","content":"pub fn create_domain(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudsearch.create_domain\naws_api/cloudsearch create_domain","url":"aws_api/cloudsearch.html#create_domain"},{"doc":"aws_api/cloudsearch","title":"define_analysis_scheme","content":"pub fn define_analysis_scheme(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudsearch.define_analysis_scheme\naws_api/cloudsearch define_analysis_scheme","url":"aws_api/cloudsearch.html#define_analysis_scheme"},{"doc":"aws_api/cloudsearch","title":"define_expression","content":"pub fn define_expression(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudsearch.define_expression\naws_api/cloudsearch define_expression","url":"aws_api/cloudsearch.html#define_expression"},{"doc":"aws_api/cloudsearch","title":"define_index_field","content":"pub fn define_index_field(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudsearch.define_index_field\naws_api/cloudsearch define_index_field","url":"aws_api/cloudsearch.html#define_index_field"},{"doc":"aws_api/cloudsearch","title":"define_suggester","content":"pub fn define_suggester(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudsearch.define_suggester\naws_api/cloudsearch define_suggester","url":"aws_api/cloudsearch.html#define_suggester"},{"doc":"aws_api/cloudsearch","title":"delete_analysis_scheme","content":"pub fn delete_analysis_scheme(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudsearch.delete_analysis_scheme\naws_api/cloudsearch delete_analysis_scheme","url":"aws_api/cloudsearch.html#delete_analysis_scheme"},{"doc":"aws_api/cloudsearch","title":"delete_domain","content":"pub fn delete_domain(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudsearch.delete_domain\naws_api/cloudsearch delete_domain","url":"aws_api/cloudsearch.html#delete_domain"},{"doc":"aws_api/cloudsearch","title":"delete_expression","content":"pub fn delete_expression(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudsearch.delete_expression\naws_api/cloudsearch delete_expression","url":"aws_api/cloudsearch.html#delete_expression"},{"doc":"aws_api/cloudsearch","title":"delete_index_field","content":"pub fn delete_index_field(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudsearch.delete_index_field\naws_api/cloudsearch delete_index_field","url":"aws_api/cloudsearch.html#delete_index_field"},{"doc":"aws_api/cloudsearch","title":"delete_suggester","content":"pub fn delete_suggester(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudsearch.delete_suggester\naws_api/cloudsearch delete_suggester","url":"aws_api/cloudsearch.html#delete_suggester"},{"doc":"aws_api/cloudsearch","title":"describe_analysis_schemes","content":"pub fn describe_analysis_schemes(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudsearch.describe_analysis_schemes\naws_api/cloudsearch describe_analysis_schemes","url":"aws_api/cloudsearch.html#describe_analysis_schemes"},{"doc":"aws_api/cloudsearch","title":"describe_availability_options","content":"pub fn describe_availability_options(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudsearch.describe_availability_options\naws_api/cloudsearch describe_availability_options","url":"aws_api/cloudsearch.html#describe_availability_options"},{"doc":"aws_api/cloudsearch","title":"describe_domain_endpoint_options","content":"pub fn describe_domain_endpoint_options(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudsearch.describe_domain_endpoint_options\naws_api/cloudsearch describe_domain_endpoint_options","url":"aws_api/cloudsearch.html#describe_domain_endpoint_options"},{"doc":"aws_api/cloudsearch","title":"describe_domains","content":"pub fn describe_domains(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudsearch.describe_domains\naws_api/cloudsearch describe_domains","url":"aws_api/cloudsearch.html#describe_domains"},{"doc":"aws_api/cloudsearch","title":"describe_expressions","content":"pub fn describe_expressions(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudsearch.describe_expressions\naws_api/cloudsearch describe_expressions","url":"aws_api/cloudsearch.html#describe_expressions"},{"doc":"aws_api/cloudsearch","title":"describe_index_fields","content":"pub fn describe_index_fields(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudsearch.describe_index_fields\naws_api/cloudsearch describe_index_fields","url":"aws_api/cloudsearch.html#describe_index_fields"},{"doc":"aws_api/cloudsearch","title":"describe_scaling_parameters","content":"pub fn describe_scaling_parameters(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudsearch.describe_scaling_parameters\naws_api/cloudsearch describe_scaling_parameters","url":"aws_api/cloudsearch.html#describe_scaling_parameters"},{"doc":"aws_api/cloudsearch","title":"describe_service_access_policies","content":"pub fn describe_service_access_policies(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudsearch.describe_service_access_policies\naws_api/cloudsearch describe_service_access_policies","url":"aws_api/cloudsearch.html#describe_service_access_policies"},{"doc":"aws_api/cloudsearch","title":"describe_suggesters","content":"pub fn describe_suggesters(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudsearch.describe_suggesters\naws_api/cloudsearch describe_suggesters","url":"aws_api/cloudsearch.html#describe_suggesters"},{"doc":"aws_api/cloudsearch","title":"index_documents","content":"pub fn index_documents(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudsearch.index_documents\naws_api/cloudsearch index_documents","url":"aws_api/cloudsearch.html#index_documents"},{"doc":"aws_api/cloudsearch","title":"list_domain_names","content":"pub fn list_domain_names(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudsearch.list_domain_names\naws_api/cloudsearch list_domain_names","url":"aws_api/cloudsearch.html#list_domain_names"},{"doc":"aws_api/cloudsearch","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/cloudsearch.new\naws_api/cloudsearch new","url":"aws_api/cloudsearch.html#new"},{"doc":"aws_api/cloudsearch","title":"update_availability_options","content":"pub fn update_availability_options(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudsearch.update_availability_options\naws_api/cloudsearch update_availability_options","url":"aws_api/cloudsearch.html#update_availability_options"},{"doc":"aws_api/cloudsearch","title":"update_domain_endpoint_options","content":"pub fn update_domain_endpoint_options(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudsearch.update_domain_endpoint_options\naws_api/cloudsearch update_domain_endpoint_options","url":"aws_api/cloudsearch.html#update_domain_endpoint_options"},{"doc":"aws_api/cloudsearch","title":"update_scaling_parameters","content":"pub fn update_scaling_parameters(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudsearch.update_scaling_parameters\naws_api/cloudsearch update_scaling_parameters","url":"aws_api/cloudsearch.html#update_scaling_parameters"},{"doc":"aws_api/cloudsearch","title":"update_service_access_policies","content":"pub fn update_service_access_policies(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudsearch.update_service_access_policies\naws_api/cloudsearch update_service_access_policies","url":"aws_api/cloudsearch.html#update_service_access_policies"},{"doc":"aws_api/cloudsearch","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/cloudsearch.with_custom_endpoint\naws_api/cloudsearch with_custom_endpoint","url":"aws_api/cloudsearch.html#with_custom_endpoint"},{"doc":"aws_api/cloudsearch","title":"aws_api/cloudsearch","content":"","url":"aws_api/cloudsearch.html"},{"doc":"aws_api/cloudtrail","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/cloudtrail.Client\naws_api/cloudtrail Client","url":"aws_api/cloudtrail.html#Client"},{"doc":"aws_api/cloudtrail","title":"add_tags","content":"pub fn add_tags(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudtrail.add_tags\naws_api/cloudtrail add_tags","url":"aws_api/cloudtrail.html#add_tags"},{"doc":"aws_api/cloudtrail","title":"cancel_query","content":"pub fn cancel_query(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudtrail.cancel_query\naws_api/cloudtrail cancel_query","url":"aws_api/cloudtrail.html#cancel_query"},{"doc":"aws_api/cloudtrail","title":"create_channel","content":"pub fn create_channel(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudtrail.create_channel\naws_api/cloudtrail create_channel","url":"aws_api/cloudtrail.html#create_channel"},{"doc":"aws_api/cloudtrail","title":"create_event_data_store","content":"pub fn create_event_data_store(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudtrail.create_event_data_store\naws_api/cloudtrail create_event_data_store","url":"aws_api/cloudtrail.html#create_event_data_store"},{"doc":"aws_api/cloudtrail","title":"create_trail","content":"pub fn create_trail(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudtrail.create_trail\naws_api/cloudtrail create_trail","url":"aws_api/cloudtrail.html#create_trail"},{"doc":"aws_api/cloudtrail","title":"delete_channel","content":"pub fn delete_channel(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudtrail.delete_channel\naws_api/cloudtrail delete_channel","url":"aws_api/cloudtrail.html#delete_channel"},{"doc":"aws_api/cloudtrail","title":"delete_event_data_store","content":"pub fn delete_event_data_store(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudtrail.delete_event_data_store\naws_api/cloudtrail delete_event_data_store","url":"aws_api/cloudtrail.html#delete_event_data_store"},{"doc":"aws_api/cloudtrail","title":"delete_resource_policy","content":"pub fn delete_resource_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudtrail.delete_resource_policy\naws_api/cloudtrail delete_resource_policy","url":"aws_api/cloudtrail.html#delete_resource_policy"},{"doc":"aws_api/cloudtrail","title":"delete_trail","content":"pub fn delete_trail(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudtrail.delete_trail\naws_api/cloudtrail delete_trail","url":"aws_api/cloudtrail.html#delete_trail"},{"doc":"aws_api/cloudtrail","title":"deregister_organization_delegated_admin","content":"pub fn deregister_organization_delegated_admin(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudtrail.deregister_organization_delegated_admin\naws_api/cloudtrail deregister_organization_delegated_admin","url":"aws_api/cloudtrail.html#deregister_organization_delegated_admin"},{"doc":"aws_api/cloudtrail","title":"describe_query","content":"pub fn describe_query(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudtrail.describe_query\naws_api/cloudtrail describe_query","url":"aws_api/cloudtrail.html#describe_query"},{"doc":"aws_api/cloudtrail","title":"describe_trails","content":"pub fn describe_trails(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudtrail.describe_trails\naws_api/cloudtrail describe_trails","url":"aws_api/cloudtrail.html#describe_trails"},{"doc":"aws_api/cloudtrail","title":"disable_federation","content":"pub fn disable_federation(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudtrail.disable_federation\naws_api/cloudtrail disable_federation","url":"aws_api/cloudtrail.html#disable_federation"},{"doc":"aws_api/cloudtrail","title":"enable_federation","content":"pub fn enable_federation(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudtrail.enable_federation\naws_api/cloudtrail enable_federation","url":"aws_api/cloudtrail.html#enable_federation"},{"doc":"aws_api/cloudtrail","title":"get_channel","content":"pub fn get_channel(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudtrail.get_channel\naws_api/cloudtrail get_channel","url":"aws_api/cloudtrail.html#get_channel"},{"doc":"aws_api/cloudtrail","title":"get_event_data_store","content":"pub fn get_event_data_store(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudtrail.get_event_data_store\naws_api/cloudtrail get_event_data_store","url":"aws_api/cloudtrail.html#get_event_data_store"},{"doc":"aws_api/cloudtrail","title":"get_event_selectors","content":"pub fn get_event_selectors(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudtrail.get_event_selectors\naws_api/cloudtrail get_event_selectors","url":"aws_api/cloudtrail.html#get_event_selectors"},{"doc":"aws_api/cloudtrail","title":"get_import","content":"pub fn get_import(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudtrail.get_import\naws_api/cloudtrail get_import","url":"aws_api/cloudtrail.html#get_import"},{"doc":"aws_api/cloudtrail","title":"get_insight_selectors","content":"pub fn get_insight_selectors(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudtrail.get_insight_selectors\naws_api/cloudtrail get_insight_selectors","url":"aws_api/cloudtrail.html#get_insight_selectors"},{"doc":"aws_api/cloudtrail","title":"get_query_results","content":"pub fn get_query_results(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudtrail.get_query_results\naws_api/cloudtrail get_query_results","url":"aws_api/cloudtrail.html#get_query_results"},{"doc":"aws_api/cloudtrail","title":"get_resource_policy","content":"pub fn get_resource_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudtrail.get_resource_policy\naws_api/cloudtrail get_resource_policy","url":"aws_api/cloudtrail.html#get_resource_policy"},{"doc":"aws_api/cloudtrail","title":"get_trail","content":"pub fn get_trail(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudtrail.get_trail\naws_api/cloudtrail get_trail","url":"aws_api/cloudtrail.html#get_trail"},{"doc":"aws_api/cloudtrail","title":"get_trail_status","content":"pub fn get_trail_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudtrail.get_trail_status\naws_api/cloudtrail get_trail_status","url":"aws_api/cloudtrail.html#get_trail_status"},{"doc":"aws_api/cloudtrail","title":"list_channels","content":"pub fn list_channels(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudtrail.list_channels\naws_api/cloudtrail list_channels","url":"aws_api/cloudtrail.html#list_channels"},{"doc":"aws_api/cloudtrail","title":"list_event_data_stores","content":"pub fn list_event_data_stores(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudtrail.list_event_data_stores\naws_api/cloudtrail list_event_data_stores","url":"aws_api/cloudtrail.html#list_event_data_stores"},{"doc":"aws_api/cloudtrail","title":"list_import_failures","content":"pub fn list_import_failures(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudtrail.list_import_failures\naws_api/cloudtrail list_import_failures","url":"aws_api/cloudtrail.html#list_import_failures"},{"doc":"aws_api/cloudtrail","title":"list_imports","content":"pub fn list_imports(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudtrail.list_imports\naws_api/cloudtrail list_imports","url":"aws_api/cloudtrail.html#list_imports"},{"doc":"aws_api/cloudtrail","title":"list_insights_metric_data","content":"pub fn list_insights_metric_data(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudtrail.list_insights_metric_data\naws_api/cloudtrail list_insights_metric_data","url":"aws_api/cloudtrail.html#list_insights_metric_data"},{"doc":"aws_api/cloudtrail","title":"list_public_keys","content":"pub fn list_public_keys(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudtrail.list_public_keys\naws_api/cloudtrail list_public_keys","url":"aws_api/cloudtrail.html#list_public_keys"},{"doc":"aws_api/cloudtrail","title":"list_queries","content":"pub fn list_queries(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudtrail.list_queries\naws_api/cloudtrail list_queries","url":"aws_api/cloudtrail.html#list_queries"},{"doc":"aws_api/cloudtrail","title":"list_tags","content":"pub fn list_tags(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudtrail.list_tags\naws_api/cloudtrail list_tags","url":"aws_api/cloudtrail.html#list_tags"},{"doc":"aws_api/cloudtrail","title":"list_trails","content":"pub fn list_trails(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudtrail.list_trails\naws_api/cloudtrail list_trails","url":"aws_api/cloudtrail.html#list_trails"},{"doc":"aws_api/cloudtrail","title":"lookup_events","content":"pub fn lookup_events(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudtrail.lookup_events\naws_api/cloudtrail lookup_events","url":"aws_api/cloudtrail.html#lookup_events"},{"doc":"aws_api/cloudtrail","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/cloudtrail.new\naws_api/cloudtrail new","url":"aws_api/cloudtrail.html#new"},{"doc":"aws_api/cloudtrail","title":"put_event_selectors","content":"pub fn put_event_selectors(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudtrail.put_event_selectors\naws_api/cloudtrail put_event_selectors","url":"aws_api/cloudtrail.html#put_event_selectors"},{"doc":"aws_api/cloudtrail","title":"put_insight_selectors","content":"pub fn put_insight_selectors(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudtrail.put_insight_selectors\naws_api/cloudtrail put_insight_selectors","url":"aws_api/cloudtrail.html#put_insight_selectors"},{"doc":"aws_api/cloudtrail","title":"put_resource_policy","content":"pub fn put_resource_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudtrail.put_resource_policy\naws_api/cloudtrail put_resource_policy","url":"aws_api/cloudtrail.html#put_resource_policy"},{"doc":"aws_api/cloudtrail","title":"register_organization_delegated_admin","content":"pub fn register_organization_delegated_admin(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudtrail.register_organization_delegated_admin\naws_api/cloudtrail register_organization_delegated_admin","url":"aws_api/cloudtrail.html#register_organization_delegated_admin"},{"doc":"aws_api/cloudtrail","title":"remove_tags","content":"pub fn remove_tags(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudtrail.remove_tags\naws_api/cloudtrail remove_tags","url":"aws_api/cloudtrail.html#remove_tags"},{"doc":"aws_api/cloudtrail","title":"restore_event_data_store","content":"pub fn restore_event_data_store(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudtrail.restore_event_data_store\naws_api/cloudtrail restore_event_data_store","url":"aws_api/cloudtrail.html#restore_event_data_store"},{"doc":"aws_api/cloudtrail","title":"start_event_data_store_ingestion","content":"pub fn start_event_data_store_ingestion(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudtrail.start_event_data_store_ingestion\naws_api/cloudtrail start_event_data_store_ingestion","url":"aws_api/cloudtrail.html#start_event_data_store_ingestion"},{"doc":"aws_api/cloudtrail","title":"start_import","content":"pub fn start_import(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudtrail.start_import\naws_api/cloudtrail start_import","url":"aws_api/cloudtrail.html#start_import"},{"doc":"aws_api/cloudtrail","title":"start_logging","content":"pub fn start_logging(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudtrail.start_logging\naws_api/cloudtrail start_logging","url":"aws_api/cloudtrail.html#start_logging"},{"doc":"aws_api/cloudtrail","title":"start_query","content":"pub fn start_query(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudtrail.start_query\naws_api/cloudtrail start_query","url":"aws_api/cloudtrail.html#start_query"},{"doc":"aws_api/cloudtrail","title":"stop_event_data_store_ingestion","content":"pub fn stop_event_data_store_ingestion(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudtrail.stop_event_data_store_ingestion\naws_api/cloudtrail stop_event_data_store_ingestion","url":"aws_api/cloudtrail.html#stop_event_data_store_ingestion"},{"doc":"aws_api/cloudtrail","title":"stop_import","content":"pub fn stop_import(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudtrail.stop_import\naws_api/cloudtrail stop_import","url":"aws_api/cloudtrail.html#stop_import"},{"doc":"aws_api/cloudtrail","title":"stop_logging","content":"pub fn stop_logging(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudtrail.stop_logging\naws_api/cloudtrail stop_logging","url":"aws_api/cloudtrail.html#stop_logging"},{"doc":"aws_api/cloudtrail","title":"update_channel","content":"pub fn update_channel(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudtrail.update_channel\naws_api/cloudtrail update_channel","url":"aws_api/cloudtrail.html#update_channel"},{"doc":"aws_api/cloudtrail","title":"update_event_data_store","content":"pub fn update_event_data_store(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudtrail.update_event_data_store\naws_api/cloudtrail update_event_data_store","url":"aws_api/cloudtrail.html#update_event_data_store"},{"doc":"aws_api/cloudtrail","title":"update_trail","content":"pub fn update_trail(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudtrail.update_trail\naws_api/cloudtrail update_trail","url":"aws_api/cloudtrail.html#update_trail"},{"doc":"aws_api/cloudtrail","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/cloudtrail.with_custom_endpoint\naws_api/cloudtrail with_custom_endpoint","url":"aws_api/cloudtrail.html#with_custom_endpoint"},{"doc":"aws_api/cloudtrail","title":"aws_api/cloudtrail","content":"","url":"aws_api/cloudtrail.html"},{"doc":"aws_api/cloudtrail_data","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/cloudtrail_data.Client\naws_api/cloudtrail_data Client","url":"aws_api/cloudtrail_data.html#Client"},{"doc":"aws_api/cloudtrail_data","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/cloudtrail_data.new\naws_api/cloudtrail_data new","url":"aws_api/cloudtrail_data.html#new"},{"doc":"aws_api/cloudtrail_data","title":"put_audit_events","content":"pub fn put_audit_events(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudtrail_data.put_audit_events\naws_api/cloudtrail_data put_audit_events","url":"aws_api/cloudtrail_data.html#put_audit_events"},{"doc":"aws_api/cloudtrail_data","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/cloudtrail_data.with_custom_endpoint\naws_api/cloudtrail_data with_custom_endpoint","url":"aws_api/cloudtrail_data.html#with_custom_endpoint"},{"doc":"aws_api/cloudtrail_data","title":"aws_api/cloudtrail_data","content":"","url":"aws_api/cloudtrail_data.html"},{"doc":"aws_api/cloudwatch","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/cloudwatch.Client\naws_api/cloudwatch Client","url":"aws_api/cloudwatch.html#Client"},{"doc":"aws_api/cloudwatch","title":"delete_alarms","content":"pub fn delete_alarms(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch.delete_alarms\naws_api/cloudwatch delete_alarms","url":"aws_api/cloudwatch.html#delete_alarms"},{"doc":"aws_api/cloudwatch","title":"delete_anomaly_detector","content":"pub fn delete_anomaly_detector(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch.delete_anomaly_detector\naws_api/cloudwatch delete_anomaly_detector","url":"aws_api/cloudwatch.html#delete_anomaly_detector"},{"doc":"aws_api/cloudwatch","title":"delete_dashboards","content":"pub fn delete_dashboards(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch.delete_dashboards\naws_api/cloudwatch delete_dashboards","url":"aws_api/cloudwatch.html#delete_dashboards"},{"doc":"aws_api/cloudwatch","title":"delete_insight_rules","content":"pub fn delete_insight_rules(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch.delete_insight_rules\naws_api/cloudwatch delete_insight_rules","url":"aws_api/cloudwatch.html#delete_insight_rules"},{"doc":"aws_api/cloudwatch","title":"delete_metric_stream","content":"pub fn delete_metric_stream(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch.delete_metric_stream\naws_api/cloudwatch delete_metric_stream","url":"aws_api/cloudwatch.html#delete_metric_stream"},{"doc":"aws_api/cloudwatch","title":"describe_alarm_history","content":"pub fn describe_alarm_history(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch.describe_alarm_history\naws_api/cloudwatch describe_alarm_history","url":"aws_api/cloudwatch.html#describe_alarm_history"},{"doc":"aws_api/cloudwatch","title":"describe_alarms","content":"pub fn describe_alarms(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch.describe_alarms\naws_api/cloudwatch describe_alarms","url":"aws_api/cloudwatch.html#describe_alarms"},{"doc":"aws_api/cloudwatch","title":"describe_alarms_for_metric","content":"pub fn describe_alarms_for_metric(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch.describe_alarms_for_metric\naws_api/cloudwatch describe_alarms_for_metric","url":"aws_api/cloudwatch.html#describe_alarms_for_metric"},{"doc":"aws_api/cloudwatch","title":"describe_anomaly_detectors","content":"pub fn describe_anomaly_detectors(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch.describe_anomaly_detectors\naws_api/cloudwatch describe_anomaly_detectors","url":"aws_api/cloudwatch.html#describe_anomaly_detectors"},{"doc":"aws_api/cloudwatch","title":"describe_insight_rules","content":"pub fn describe_insight_rules(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch.describe_insight_rules\naws_api/cloudwatch describe_insight_rules","url":"aws_api/cloudwatch.html#describe_insight_rules"},{"doc":"aws_api/cloudwatch","title":"disable_alarm_actions","content":"pub fn disable_alarm_actions(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch.disable_alarm_actions\naws_api/cloudwatch disable_alarm_actions","url":"aws_api/cloudwatch.html#disable_alarm_actions"},{"doc":"aws_api/cloudwatch","title":"disable_insight_rules","content":"pub fn disable_insight_rules(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch.disable_insight_rules\naws_api/cloudwatch disable_insight_rules","url":"aws_api/cloudwatch.html#disable_insight_rules"},{"doc":"aws_api/cloudwatch","title":"enable_alarm_actions","content":"pub fn enable_alarm_actions(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch.enable_alarm_actions\naws_api/cloudwatch enable_alarm_actions","url":"aws_api/cloudwatch.html#enable_alarm_actions"},{"doc":"aws_api/cloudwatch","title":"enable_insight_rules","content":"pub fn enable_insight_rules(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch.enable_insight_rules\naws_api/cloudwatch enable_insight_rules","url":"aws_api/cloudwatch.html#enable_insight_rules"},{"doc":"aws_api/cloudwatch","title":"get_dashboard","content":"pub fn get_dashboard(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch.get_dashboard\naws_api/cloudwatch get_dashboard","url":"aws_api/cloudwatch.html#get_dashboard"},{"doc":"aws_api/cloudwatch","title":"get_insight_rule_report","content":"pub fn get_insight_rule_report(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch.get_insight_rule_report\naws_api/cloudwatch get_insight_rule_report","url":"aws_api/cloudwatch.html#get_insight_rule_report"},{"doc":"aws_api/cloudwatch","title":"get_metric_data","content":"pub fn get_metric_data(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch.get_metric_data\naws_api/cloudwatch get_metric_data","url":"aws_api/cloudwatch.html#get_metric_data"},{"doc":"aws_api/cloudwatch","title":"get_metric_statistics","content":"pub fn get_metric_statistics(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch.get_metric_statistics\naws_api/cloudwatch get_metric_statistics","url":"aws_api/cloudwatch.html#get_metric_statistics"},{"doc":"aws_api/cloudwatch","title":"get_metric_stream","content":"pub fn get_metric_stream(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch.get_metric_stream\naws_api/cloudwatch get_metric_stream","url":"aws_api/cloudwatch.html#get_metric_stream"},{"doc":"aws_api/cloudwatch","title":"get_metric_widget_image","content":"pub fn get_metric_widget_image(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch.get_metric_widget_image\naws_api/cloudwatch get_metric_widget_image","url":"aws_api/cloudwatch.html#get_metric_widget_image"},{"doc":"aws_api/cloudwatch","title":"list_dashboards","content":"pub fn list_dashboards(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch.list_dashboards\naws_api/cloudwatch list_dashboards","url":"aws_api/cloudwatch.html#list_dashboards"},{"doc":"aws_api/cloudwatch","title":"list_managed_insight_rules","content":"pub fn list_managed_insight_rules(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch.list_managed_insight_rules\naws_api/cloudwatch list_managed_insight_rules","url":"aws_api/cloudwatch.html#list_managed_insight_rules"},{"doc":"aws_api/cloudwatch","title":"list_metric_streams","content":"pub fn list_metric_streams(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch.list_metric_streams\naws_api/cloudwatch list_metric_streams","url":"aws_api/cloudwatch.html#list_metric_streams"},{"doc":"aws_api/cloudwatch","title":"list_metrics","content":"pub fn list_metrics(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch.list_metrics\naws_api/cloudwatch list_metrics","url":"aws_api/cloudwatch.html#list_metrics"},{"doc":"aws_api/cloudwatch","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch.list_tags_for_resource\naws_api/cloudwatch list_tags_for_resource","url":"aws_api/cloudwatch.html#list_tags_for_resource"},{"doc":"aws_api/cloudwatch","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/cloudwatch.new\naws_api/cloudwatch new","url":"aws_api/cloudwatch.html#new"},{"doc":"aws_api/cloudwatch","title":"put_anomaly_detector","content":"pub fn put_anomaly_detector(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch.put_anomaly_detector\naws_api/cloudwatch put_anomaly_detector","url":"aws_api/cloudwatch.html#put_anomaly_detector"},{"doc":"aws_api/cloudwatch","title":"put_composite_alarm","content":"pub fn put_composite_alarm(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch.put_composite_alarm\naws_api/cloudwatch put_composite_alarm","url":"aws_api/cloudwatch.html#put_composite_alarm"},{"doc":"aws_api/cloudwatch","title":"put_dashboard","content":"pub fn put_dashboard(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch.put_dashboard\naws_api/cloudwatch put_dashboard","url":"aws_api/cloudwatch.html#put_dashboard"},{"doc":"aws_api/cloudwatch","title":"put_insight_rule","content":"pub fn put_insight_rule(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch.put_insight_rule\naws_api/cloudwatch put_insight_rule","url":"aws_api/cloudwatch.html#put_insight_rule"},{"doc":"aws_api/cloudwatch","title":"put_managed_insight_rules","content":"pub fn put_managed_insight_rules(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch.put_managed_insight_rules\naws_api/cloudwatch put_managed_insight_rules","url":"aws_api/cloudwatch.html#put_managed_insight_rules"},{"doc":"aws_api/cloudwatch","title":"put_metric_alarm","content":"pub fn put_metric_alarm(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch.put_metric_alarm\naws_api/cloudwatch put_metric_alarm","url":"aws_api/cloudwatch.html#put_metric_alarm"},{"doc":"aws_api/cloudwatch","title":"put_metric_data","content":"pub fn put_metric_data(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch.put_metric_data\naws_api/cloudwatch put_metric_data","url":"aws_api/cloudwatch.html#put_metric_data"},{"doc":"aws_api/cloudwatch","title":"put_metric_stream","content":"pub fn put_metric_stream(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch.put_metric_stream\naws_api/cloudwatch put_metric_stream","url":"aws_api/cloudwatch.html#put_metric_stream"},{"doc":"aws_api/cloudwatch","title":"set_alarm_state","content":"pub fn set_alarm_state(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch.set_alarm_state\naws_api/cloudwatch set_alarm_state","url":"aws_api/cloudwatch.html#set_alarm_state"},{"doc":"aws_api/cloudwatch","title":"start_metric_streams","content":"pub fn start_metric_streams(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch.start_metric_streams\naws_api/cloudwatch start_metric_streams","url":"aws_api/cloudwatch.html#start_metric_streams"},{"doc":"aws_api/cloudwatch","title":"stop_metric_streams","content":"pub fn stop_metric_streams(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch.stop_metric_streams\naws_api/cloudwatch stop_metric_streams","url":"aws_api/cloudwatch.html#stop_metric_streams"},{"doc":"aws_api/cloudwatch","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch.tag_resource\naws_api/cloudwatch tag_resource","url":"aws_api/cloudwatch.html#tag_resource"},{"doc":"aws_api/cloudwatch","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch.untag_resource\naws_api/cloudwatch untag_resource","url":"aws_api/cloudwatch.html#untag_resource"},{"doc":"aws_api/cloudwatch","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/cloudwatch.with_custom_endpoint\naws_api/cloudwatch with_custom_endpoint","url":"aws_api/cloudwatch.html#with_custom_endpoint"},{"doc":"aws_api/cloudwatch","title":"aws_api/cloudwatch","content":"","url":"aws_api/cloudwatch.html"},{"doc":"aws_api/cloudwatch_events","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/cloudwatch_events.Client\naws_api/cloudwatch_events Client","url":"aws_api/cloudwatch_events.html#Client"},{"doc":"aws_api/cloudwatch_events","title":"activate_event_source","content":"pub fn activate_event_source(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.activate_event_source\naws_api/cloudwatch_events activate_event_source","url":"aws_api/cloudwatch_events.html#activate_event_source"},{"doc":"aws_api/cloudwatch_events","title":"cancel_replay","content":"pub fn cancel_replay(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.cancel_replay\naws_api/cloudwatch_events cancel_replay","url":"aws_api/cloudwatch_events.html#cancel_replay"},{"doc":"aws_api/cloudwatch_events","title":"create_api_destination","content":"pub fn create_api_destination(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.create_api_destination\naws_api/cloudwatch_events create_api_destination","url":"aws_api/cloudwatch_events.html#create_api_destination"},{"doc":"aws_api/cloudwatch_events","title":"create_archive","content":"pub fn create_archive(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.create_archive\naws_api/cloudwatch_events create_archive","url":"aws_api/cloudwatch_events.html#create_archive"},{"doc":"aws_api/cloudwatch_events","title":"create_connection","content":"pub fn create_connection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.create_connection\naws_api/cloudwatch_events create_connection","url":"aws_api/cloudwatch_events.html#create_connection"},{"doc":"aws_api/cloudwatch_events","title":"create_event_bus","content":"pub fn create_event_bus(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.create_event_bus\naws_api/cloudwatch_events create_event_bus","url":"aws_api/cloudwatch_events.html#create_event_bus"},{"doc":"aws_api/cloudwatch_events","title":"create_partner_event_source","content":"pub fn create_partner_event_source(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.create_partner_event_source\naws_api/cloudwatch_events create_partner_event_source","url":"aws_api/cloudwatch_events.html#create_partner_event_source"},{"doc":"aws_api/cloudwatch_events","title":"deactivate_event_source","content":"pub fn deactivate_event_source(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.deactivate_event_source\naws_api/cloudwatch_events deactivate_event_source","url":"aws_api/cloudwatch_events.html#deactivate_event_source"},{"doc":"aws_api/cloudwatch_events","title":"deauthorize_connection","content":"pub fn deauthorize_connection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.deauthorize_connection\naws_api/cloudwatch_events deauthorize_connection","url":"aws_api/cloudwatch_events.html#deauthorize_connection"},{"doc":"aws_api/cloudwatch_events","title":"delete_api_destination","content":"pub fn delete_api_destination(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.delete_api_destination\naws_api/cloudwatch_events delete_api_destination","url":"aws_api/cloudwatch_events.html#delete_api_destination"},{"doc":"aws_api/cloudwatch_events","title":"delete_archive","content":"pub fn delete_archive(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.delete_archive\naws_api/cloudwatch_events delete_archive","url":"aws_api/cloudwatch_events.html#delete_archive"},{"doc":"aws_api/cloudwatch_events","title":"delete_connection","content":"pub fn delete_connection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.delete_connection\naws_api/cloudwatch_events delete_connection","url":"aws_api/cloudwatch_events.html#delete_connection"},{"doc":"aws_api/cloudwatch_events","title":"delete_event_bus","content":"pub fn delete_event_bus(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.delete_event_bus\naws_api/cloudwatch_events delete_event_bus","url":"aws_api/cloudwatch_events.html#delete_event_bus"},{"doc":"aws_api/cloudwatch_events","title":"delete_partner_event_source","content":"pub fn delete_partner_event_source(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.delete_partner_event_source\naws_api/cloudwatch_events delete_partner_event_source","url":"aws_api/cloudwatch_events.html#delete_partner_event_source"},{"doc":"aws_api/cloudwatch_events","title":"delete_rule","content":"pub fn delete_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.delete_rule\naws_api/cloudwatch_events delete_rule","url":"aws_api/cloudwatch_events.html#delete_rule"},{"doc":"aws_api/cloudwatch_events","title":"describe_api_destination","content":"pub fn describe_api_destination(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.describe_api_destination\naws_api/cloudwatch_events describe_api_destination","url":"aws_api/cloudwatch_events.html#describe_api_destination"},{"doc":"aws_api/cloudwatch_events","title":"describe_archive","content":"pub fn describe_archive(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.describe_archive\naws_api/cloudwatch_events describe_archive","url":"aws_api/cloudwatch_events.html#describe_archive"},{"doc":"aws_api/cloudwatch_events","title":"describe_connection","content":"pub fn describe_connection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.describe_connection\naws_api/cloudwatch_events describe_connection","url":"aws_api/cloudwatch_events.html#describe_connection"},{"doc":"aws_api/cloudwatch_events","title":"describe_event_bus","content":"pub fn describe_event_bus(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.describe_event_bus\naws_api/cloudwatch_events describe_event_bus","url":"aws_api/cloudwatch_events.html#describe_event_bus"},{"doc":"aws_api/cloudwatch_events","title":"describe_event_source","content":"pub fn describe_event_source(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.describe_event_source\naws_api/cloudwatch_events describe_event_source","url":"aws_api/cloudwatch_events.html#describe_event_source"},{"doc":"aws_api/cloudwatch_events","title":"describe_partner_event_source","content":"pub fn describe_partner_event_source(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.describe_partner_event_source\naws_api/cloudwatch_events describe_partner_event_source","url":"aws_api/cloudwatch_events.html#describe_partner_event_source"},{"doc":"aws_api/cloudwatch_events","title":"describe_replay","content":"pub fn describe_replay(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.describe_replay\naws_api/cloudwatch_events describe_replay","url":"aws_api/cloudwatch_events.html#describe_replay"},{"doc":"aws_api/cloudwatch_events","title":"describe_rule","content":"pub fn describe_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.describe_rule\naws_api/cloudwatch_events describe_rule","url":"aws_api/cloudwatch_events.html#describe_rule"},{"doc":"aws_api/cloudwatch_events","title":"disable_rule","content":"pub fn disable_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.disable_rule\naws_api/cloudwatch_events disable_rule","url":"aws_api/cloudwatch_events.html#disable_rule"},{"doc":"aws_api/cloudwatch_events","title":"enable_rule","content":"pub fn enable_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.enable_rule\naws_api/cloudwatch_events enable_rule","url":"aws_api/cloudwatch_events.html#enable_rule"},{"doc":"aws_api/cloudwatch_events","title":"list_api_destinations","content":"pub fn list_api_destinations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.list_api_destinations\naws_api/cloudwatch_events list_api_destinations","url":"aws_api/cloudwatch_events.html#list_api_destinations"},{"doc":"aws_api/cloudwatch_events","title":"list_archives","content":"pub fn list_archives(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.list_archives\naws_api/cloudwatch_events list_archives","url":"aws_api/cloudwatch_events.html#list_archives"},{"doc":"aws_api/cloudwatch_events","title":"list_connections","content":"pub fn list_connections(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.list_connections\naws_api/cloudwatch_events list_connections","url":"aws_api/cloudwatch_events.html#list_connections"},{"doc":"aws_api/cloudwatch_events","title":"list_event_buses","content":"pub fn list_event_buses(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.list_event_buses\naws_api/cloudwatch_events list_event_buses","url":"aws_api/cloudwatch_events.html#list_event_buses"},{"doc":"aws_api/cloudwatch_events","title":"list_event_sources","content":"pub fn list_event_sources(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.list_event_sources\naws_api/cloudwatch_events list_event_sources","url":"aws_api/cloudwatch_events.html#list_event_sources"},{"doc":"aws_api/cloudwatch_events","title":"list_partner_event_source_accounts","content":"pub fn list_partner_event_source_accounts(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.list_partner_event_source_accounts\naws_api/cloudwatch_events list_partner_event_source_accounts","url":"aws_api/cloudwatch_events.html#list_partner_event_source_accounts"},{"doc":"aws_api/cloudwatch_events","title":"list_partner_event_sources","content":"pub fn list_partner_event_sources(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.list_partner_event_sources\naws_api/cloudwatch_events list_partner_event_sources","url":"aws_api/cloudwatch_events.html#list_partner_event_sources"},{"doc":"aws_api/cloudwatch_events","title":"list_replays","content":"pub fn list_replays(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.list_replays\naws_api/cloudwatch_events list_replays","url":"aws_api/cloudwatch_events.html#list_replays"},{"doc":"aws_api/cloudwatch_events","title":"list_rule_names_by_target","content":"pub fn list_rule_names_by_target(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.list_rule_names_by_target\naws_api/cloudwatch_events list_rule_names_by_target","url":"aws_api/cloudwatch_events.html#list_rule_names_by_target"},{"doc":"aws_api/cloudwatch_events","title":"list_rules","content":"pub fn list_rules(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.list_rules\naws_api/cloudwatch_events list_rules","url":"aws_api/cloudwatch_events.html#list_rules"},{"doc":"aws_api/cloudwatch_events","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.list_tags_for_resource\naws_api/cloudwatch_events list_tags_for_resource","url":"aws_api/cloudwatch_events.html#list_tags_for_resource"},{"doc":"aws_api/cloudwatch_events","title":"list_targets_by_rule","content":"pub fn list_targets_by_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.list_targets_by_rule\naws_api/cloudwatch_events list_targets_by_rule","url":"aws_api/cloudwatch_events.html#list_targets_by_rule"},{"doc":"aws_api/cloudwatch_events","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/cloudwatch_events.new\naws_api/cloudwatch_events new","url":"aws_api/cloudwatch_events.html#new"},{"doc":"aws_api/cloudwatch_events","title":"put_events","content":"pub fn put_events(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.put_events\naws_api/cloudwatch_events put_events","url":"aws_api/cloudwatch_events.html#put_events"},{"doc":"aws_api/cloudwatch_events","title":"put_partner_events","content":"pub fn put_partner_events(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.put_partner_events\naws_api/cloudwatch_events put_partner_events","url":"aws_api/cloudwatch_events.html#put_partner_events"},{"doc":"aws_api/cloudwatch_events","title":"put_permission","content":"pub fn put_permission(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.put_permission\naws_api/cloudwatch_events put_permission","url":"aws_api/cloudwatch_events.html#put_permission"},{"doc":"aws_api/cloudwatch_events","title":"put_rule","content":"pub fn put_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.put_rule\naws_api/cloudwatch_events put_rule","url":"aws_api/cloudwatch_events.html#put_rule"},{"doc":"aws_api/cloudwatch_events","title":"put_targets","content":"pub fn put_targets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.put_targets\naws_api/cloudwatch_events put_targets","url":"aws_api/cloudwatch_events.html#put_targets"},{"doc":"aws_api/cloudwatch_events","title":"remove_permission","content":"pub fn remove_permission(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.remove_permission\naws_api/cloudwatch_events remove_permission","url":"aws_api/cloudwatch_events.html#remove_permission"},{"doc":"aws_api/cloudwatch_events","title":"remove_targets","content":"pub fn remove_targets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.remove_targets\naws_api/cloudwatch_events remove_targets","url":"aws_api/cloudwatch_events.html#remove_targets"},{"doc":"aws_api/cloudwatch_events","title":"start_replay","content":"pub fn start_replay(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.start_replay\naws_api/cloudwatch_events start_replay","url":"aws_api/cloudwatch_events.html#start_replay"},{"doc":"aws_api/cloudwatch_events","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.tag_resource\naws_api/cloudwatch_events tag_resource","url":"aws_api/cloudwatch_events.html#tag_resource"},{"doc":"aws_api/cloudwatch_events","title":"test_event_pattern","content":"pub fn test_event_pattern(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.test_event_pattern\naws_api/cloudwatch_events test_event_pattern","url":"aws_api/cloudwatch_events.html#test_event_pattern"},{"doc":"aws_api/cloudwatch_events","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.untag_resource\naws_api/cloudwatch_events untag_resource","url":"aws_api/cloudwatch_events.html#untag_resource"},{"doc":"aws_api/cloudwatch_events","title":"update_api_destination","content":"pub fn update_api_destination(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.update_api_destination\naws_api/cloudwatch_events update_api_destination","url":"aws_api/cloudwatch_events.html#update_api_destination"},{"doc":"aws_api/cloudwatch_events","title":"update_archive","content":"pub fn update_archive(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.update_archive\naws_api/cloudwatch_events update_archive","url":"aws_api/cloudwatch_events.html#update_archive"},{"doc":"aws_api/cloudwatch_events","title":"update_connection","content":"pub fn update_connection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_events.update_connection\naws_api/cloudwatch_events update_connection","url":"aws_api/cloudwatch_events.html#update_connection"},{"doc":"aws_api/cloudwatch_events","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/cloudwatch_events.with_custom_endpoint\naws_api/cloudwatch_events with_custom_endpoint","url":"aws_api/cloudwatch_events.html#with_custom_endpoint"},{"doc":"aws_api/cloudwatch_events","title":"aws_api/cloudwatch_events","content":"","url":"aws_api/cloudwatch_events.html"},{"doc":"aws_api/cloudwatch_logs","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/cloudwatch_logs.Client\naws_api/cloudwatch_logs Client","url":"aws_api/cloudwatch_logs.html#Client"},{"doc":"aws_api/cloudwatch_logs","title":"associate_kms_key","content":"pub fn associate_kms_key(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.associate_kms_key\naws_api/cloudwatch_logs associate_kms_key","url":"aws_api/cloudwatch_logs.html#associate_kms_key"},{"doc":"aws_api/cloudwatch_logs","title":"cancel_export_task","content":"pub fn cancel_export_task(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.cancel_export_task\naws_api/cloudwatch_logs cancel_export_task","url":"aws_api/cloudwatch_logs.html#cancel_export_task"},{"doc":"aws_api/cloudwatch_logs","title":"create_delivery","content":"pub fn create_delivery(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.create_delivery\naws_api/cloudwatch_logs create_delivery","url":"aws_api/cloudwatch_logs.html#create_delivery"},{"doc":"aws_api/cloudwatch_logs","title":"create_export_task","content":"pub fn create_export_task(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.create_export_task\naws_api/cloudwatch_logs create_export_task","url":"aws_api/cloudwatch_logs.html#create_export_task"},{"doc":"aws_api/cloudwatch_logs","title":"create_log_anomaly_detector","content":"pub fn create_log_anomaly_detector(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.create_log_anomaly_detector\naws_api/cloudwatch_logs create_log_anomaly_detector","url":"aws_api/cloudwatch_logs.html#create_log_anomaly_detector"},{"doc":"aws_api/cloudwatch_logs","title":"create_log_group","content":"pub fn create_log_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.create_log_group\naws_api/cloudwatch_logs create_log_group","url":"aws_api/cloudwatch_logs.html#create_log_group"},{"doc":"aws_api/cloudwatch_logs","title":"create_log_stream","content":"pub fn create_log_stream(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.create_log_stream\naws_api/cloudwatch_logs create_log_stream","url":"aws_api/cloudwatch_logs.html#create_log_stream"},{"doc":"aws_api/cloudwatch_logs","title":"delete_account_policy","content":"pub fn delete_account_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.delete_account_policy\naws_api/cloudwatch_logs delete_account_policy","url":"aws_api/cloudwatch_logs.html#delete_account_policy"},{"doc":"aws_api/cloudwatch_logs","title":"delete_data_protection_policy","content":"pub fn delete_data_protection_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.delete_data_protection_policy\naws_api/cloudwatch_logs delete_data_protection_policy","url":"aws_api/cloudwatch_logs.html#delete_data_protection_policy"},{"doc":"aws_api/cloudwatch_logs","title":"delete_delivery","content":"pub fn delete_delivery(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.delete_delivery\naws_api/cloudwatch_logs delete_delivery","url":"aws_api/cloudwatch_logs.html#delete_delivery"},{"doc":"aws_api/cloudwatch_logs","title":"delete_delivery_destination","content":"pub fn delete_delivery_destination(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.delete_delivery_destination\naws_api/cloudwatch_logs delete_delivery_destination","url":"aws_api/cloudwatch_logs.html#delete_delivery_destination"},{"doc":"aws_api/cloudwatch_logs","title":"delete_delivery_destination_policy","content":"pub fn delete_delivery_destination_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.delete_delivery_destination_policy\naws_api/cloudwatch_logs delete_delivery_destination_policy","url":"aws_api/cloudwatch_logs.html#delete_delivery_destination_policy"},{"doc":"aws_api/cloudwatch_logs","title":"delete_delivery_source","content":"pub fn delete_delivery_source(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.delete_delivery_source\naws_api/cloudwatch_logs delete_delivery_source","url":"aws_api/cloudwatch_logs.html#delete_delivery_source"},{"doc":"aws_api/cloudwatch_logs","title":"delete_destination","content":"pub fn delete_destination(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.delete_destination\naws_api/cloudwatch_logs delete_destination","url":"aws_api/cloudwatch_logs.html#delete_destination"},{"doc":"aws_api/cloudwatch_logs","title":"delete_log_anomaly_detector","content":"pub fn delete_log_anomaly_detector(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.delete_log_anomaly_detector\naws_api/cloudwatch_logs delete_log_anomaly_detector","url":"aws_api/cloudwatch_logs.html#delete_log_anomaly_detector"},{"doc":"aws_api/cloudwatch_logs","title":"delete_log_group","content":"pub fn delete_log_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.delete_log_group\naws_api/cloudwatch_logs delete_log_group","url":"aws_api/cloudwatch_logs.html#delete_log_group"},{"doc":"aws_api/cloudwatch_logs","title":"delete_log_stream","content":"pub fn delete_log_stream(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.delete_log_stream\naws_api/cloudwatch_logs delete_log_stream","url":"aws_api/cloudwatch_logs.html#delete_log_stream"},{"doc":"aws_api/cloudwatch_logs","title":"delete_metric_filter","content":"pub fn delete_metric_filter(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.delete_metric_filter\naws_api/cloudwatch_logs delete_metric_filter","url":"aws_api/cloudwatch_logs.html#delete_metric_filter"},{"doc":"aws_api/cloudwatch_logs","title":"delete_query_definition","content":"pub fn delete_query_definition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.delete_query_definition\naws_api/cloudwatch_logs delete_query_definition","url":"aws_api/cloudwatch_logs.html#delete_query_definition"},{"doc":"aws_api/cloudwatch_logs","title":"delete_resource_policy","content":"pub fn delete_resource_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.delete_resource_policy\naws_api/cloudwatch_logs delete_resource_policy","url":"aws_api/cloudwatch_logs.html#delete_resource_policy"},{"doc":"aws_api/cloudwatch_logs","title":"delete_retention_policy","content":"pub fn delete_retention_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.delete_retention_policy\naws_api/cloudwatch_logs delete_retention_policy","url":"aws_api/cloudwatch_logs.html#delete_retention_policy"},{"doc":"aws_api/cloudwatch_logs","title":"delete_subscription_filter","content":"pub fn delete_subscription_filter(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.delete_subscription_filter\naws_api/cloudwatch_logs delete_subscription_filter","url":"aws_api/cloudwatch_logs.html#delete_subscription_filter"},{"doc":"aws_api/cloudwatch_logs","title":"describe_account_policies","content":"pub fn describe_account_policies(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.describe_account_policies\naws_api/cloudwatch_logs describe_account_policies","url":"aws_api/cloudwatch_logs.html#describe_account_policies"},{"doc":"aws_api/cloudwatch_logs","title":"describe_deliveries","content":"pub fn describe_deliveries(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.describe_deliveries\naws_api/cloudwatch_logs describe_deliveries","url":"aws_api/cloudwatch_logs.html#describe_deliveries"},{"doc":"aws_api/cloudwatch_logs","title":"describe_delivery_destinations","content":"pub fn describe_delivery_destinations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.describe_delivery_destinations\naws_api/cloudwatch_logs describe_delivery_destinations","url":"aws_api/cloudwatch_logs.html#describe_delivery_destinations"},{"doc":"aws_api/cloudwatch_logs","title":"describe_delivery_sources","content":"pub fn describe_delivery_sources(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.describe_delivery_sources\naws_api/cloudwatch_logs describe_delivery_sources","url":"aws_api/cloudwatch_logs.html#describe_delivery_sources"},{"doc":"aws_api/cloudwatch_logs","title":"describe_destinations","content":"pub fn describe_destinations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.describe_destinations\naws_api/cloudwatch_logs describe_destinations","url":"aws_api/cloudwatch_logs.html#describe_destinations"},{"doc":"aws_api/cloudwatch_logs","title":"describe_export_tasks","content":"pub fn describe_export_tasks(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.describe_export_tasks\naws_api/cloudwatch_logs describe_export_tasks","url":"aws_api/cloudwatch_logs.html#describe_export_tasks"},{"doc":"aws_api/cloudwatch_logs","title":"describe_log_groups","content":"pub fn describe_log_groups(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.describe_log_groups\naws_api/cloudwatch_logs describe_log_groups","url":"aws_api/cloudwatch_logs.html#describe_log_groups"},{"doc":"aws_api/cloudwatch_logs","title":"describe_log_streams","content":"pub fn describe_log_streams(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.describe_log_streams\naws_api/cloudwatch_logs describe_log_streams","url":"aws_api/cloudwatch_logs.html#describe_log_streams"},{"doc":"aws_api/cloudwatch_logs","title":"describe_metric_filters","content":"pub fn describe_metric_filters(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.describe_metric_filters\naws_api/cloudwatch_logs describe_metric_filters","url":"aws_api/cloudwatch_logs.html#describe_metric_filters"},{"doc":"aws_api/cloudwatch_logs","title":"describe_queries","content":"pub fn describe_queries(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.describe_queries\naws_api/cloudwatch_logs describe_queries","url":"aws_api/cloudwatch_logs.html#describe_queries"},{"doc":"aws_api/cloudwatch_logs","title":"describe_query_definitions","content":"pub fn describe_query_definitions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.describe_query_definitions\naws_api/cloudwatch_logs describe_query_definitions","url":"aws_api/cloudwatch_logs.html#describe_query_definitions"},{"doc":"aws_api/cloudwatch_logs","title":"describe_resource_policies","content":"pub fn describe_resource_policies(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.describe_resource_policies\naws_api/cloudwatch_logs describe_resource_policies","url":"aws_api/cloudwatch_logs.html#describe_resource_policies"},{"doc":"aws_api/cloudwatch_logs","title":"describe_subscription_filters","content":"pub fn describe_subscription_filters(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.describe_subscription_filters\naws_api/cloudwatch_logs describe_subscription_filters","url":"aws_api/cloudwatch_logs.html#describe_subscription_filters"},{"doc":"aws_api/cloudwatch_logs","title":"disassociate_kms_key","content":"pub fn disassociate_kms_key(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.disassociate_kms_key\naws_api/cloudwatch_logs disassociate_kms_key","url":"aws_api/cloudwatch_logs.html#disassociate_kms_key"},{"doc":"aws_api/cloudwatch_logs","title":"filter_log_events","content":"pub fn filter_log_events(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.filter_log_events\naws_api/cloudwatch_logs filter_log_events","url":"aws_api/cloudwatch_logs.html#filter_log_events"},{"doc":"aws_api/cloudwatch_logs","title":"get_data_protection_policy","content":"pub fn get_data_protection_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.get_data_protection_policy\naws_api/cloudwatch_logs get_data_protection_policy","url":"aws_api/cloudwatch_logs.html#get_data_protection_policy"},{"doc":"aws_api/cloudwatch_logs","title":"get_delivery","content":"pub fn get_delivery(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.get_delivery\naws_api/cloudwatch_logs get_delivery","url":"aws_api/cloudwatch_logs.html#get_delivery"},{"doc":"aws_api/cloudwatch_logs","title":"get_delivery_destination","content":"pub fn get_delivery_destination(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.get_delivery_destination\naws_api/cloudwatch_logs get_delivery_destination","url":"aws_api/cloudwatch_logs.html#get_delivery_destination"},{"doc":"aws_api/cloudwatch_logs","title":"get_delivery_destination_policy","content":"pub fn get_delivery_destination_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.get_delivery_destination_policy\naws_api/cloudwatch_logs get_delivery_destination_policy","url":"aws_api/cloudwatch_logs.html#get_delivery_destination_policy"},{"doc":"aws_api/cloudwatch_logs","title":"get_delivery_source","content":"pub fn get_delivery_source(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.get_delivery_source\naws_api/cloudwatch_logs get_delivery_source","url":"aws_api/cloudwatch_logs.html#get_delivery_source"},{"doc":"aws_api/cloudwatch_logs","title":"get_log_anomaly_detector","content":"pub fn get_log_anomaly_detector(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.get_log_anomaly_detector\naws_api/cloudwatch_logs get_log_anomaly_detector","url":"aws_api/cloudwatch_logs.html#get_log_anomaly_detector"},{"doc":"aws_api/cloudwatch_logs","title":"get_log_events","content":"pub fn get_log_events(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.get_log_events\naws_api/cloudwatch_logs get_log_events","url":"aws_api/cloudwatch_logs.html#get_log_events"},{"doc":"aws_api/cloudwatch_logs","title":"get_log_group_fields","content":"pub fn get_log_group_fields(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.get_log_group_fields\naws_api/cloudwatch_logs get_log_group_fields","url":"aws_api/cloudwatch_logs.html#get_log_group_fields"},{"doc":"aws_api/cloudwatch_logs","title":"get_log_record","content":"pub fn get_log_record(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.get_log_record\naws_api/cloudwatch_logs get_log_record","url":"aws_api/cloudwatch_logs.html#get_log_record"},{"doc":"aws_api/cloudwatch_logs","title":"get_query_results","content":"pub fn get_query_results(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.get_query_results\naws_api/cloudwatch_logs get_query_results","url":"aws_api/cloudwatch_logs.html#get_query_results"},{"doc":"aws_api/cloudwatch_logs","title":"list_anomalies","content":"pub fn list_anomalies(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.list_anomalies\naws_api/cloudwatch_logs list_anomalies","url":"aws_api/cloudwatch_logs.html#list_anomalies"},{"doc":"aws_api/cloudwatch_logs","title":"list_log_anomaly_detectors","content":"pub fn list_log_anomaly_detectors(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.list_log_anomaly_detectors\naws_api/cloudwatch_logs list_log_anomaly_detectors","url":"aws_api/cloudwatch_logs.html#list_log_anomaly_detectors"},{"doc":"aws_api/cloudwatch_logs","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.list_tags_for_resource\naws_api/cloudwatch_logs list_tags_for_resource","url":"aws_api/cloudwatch_logs.html#list_tags_for_resource"},{"doc":"aws_api/cloudwatch_logs","title":"list_tags_log_group","content":"pub fn list_tags_log_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.list_tags_log_group\naws_api/cloudwatch_logs list_tags_log_group","url":"aws_api/cloudwatch_logs.html#list_tags_log_group"},{"doc":"aws_api/cloudwatch_logs","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/cloudwatch_logs.new\naws_api/cloudwatch_logs new","url":"aws_api/cloudwatch_logs.html#new"},{"doc":"aws_api/cloudwatch_logs","title":"put_account_policy","content":"pub fn put_account_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.put_account_policy\naws_api/cloudwatch_logs put_account_policy","url":"aws_api/cloudwatch_logs.html#put_account_policy"},{"doc":"aws_api/cloudwatch_logs","title":"put_data_protection_policy","content":"pub fn put_data_protection_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.put_data_protection_policy\naws_api/cloudwatch_logs put_data_protection_policy","url":"aws_api/cloudwatch_logs.html#put_data_protection_policy"},{"doc":"aws_api/cloudwatch_logs","title":"put_delivery_destination","content":"pub fn put_delivery_destination(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.put_delivery_destination\naws_api/cloudwatch_logs put_delivery_destination","url":"aws_api/cloudwatch_logs.html#put_delivery_destination"},{"doc":"aws_api/cloudwatch_logs","title":"put_delivery_destination_policy","content":"pub fn put_delivery_destination_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.put_delivery_destination_policy\naws_api/cloudwatch_logs put_delivery_destination_policy","url":"aws_api/cloudwatch_logs.html#put_delivery_destination_policy"},{"doc":"aws_api/cloudwatch_logs","title":"put_delivery_source","content":"pub fn put_delivery_source(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.put_delivery_source\naws_api/cloudwatch_logs put_delivery_source","url":"aws_api/cloudwatch_logs.html#put_delivery_source"},{"doc":"aws_api/cloudwatch_logs","title":"put_destination","content":"pub fn put_destination(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.put_destination\naws_api/cloudwatch_logs put_destination","url":"aws_api/cloudwatch_logs.html#put_destination"},{"doc":"aws_api/cloudwatch_logs","title":"put_destination_policy","content":"pub fn put_destination_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.put_destination_policy\naws_api/cloudwatch_logs put_destination_policy","url":"aws_api/cloudwatch_logs.html#put_destination_policy"},{"doc":"aws_api/cloudwatch_logs","title":"put_log_events","content":"pub fn put_log_events(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.put_log_events\naws_api/cloudwatch_logs put_log_events","url":"aws_api/cloudwatch_logs.html#put_log_events"},{"doc":"aws_api/cloudwatch_logs","title":"put_metric_filter","content":"pub fn put_metric_filter(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.put_metric_filter\naws_api/cloudwatch_logs put_metric_filter","url":"aws_api/cloudwatch_logs.html#put_metric_filter"},{"doc":"aws_api/cloudwatch_logs","title":"put_query_definition","content":"pub fn put_query_definition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.put_query_definition\naws_api/cloudwatch_logs put_query_definition","url":"aws_api/cloudwatch_logs.html#put_query_definition"},{"doc":"aws_api/cloudwatch_logs","title":"put_resource_policy","content":"pub fn put_resource_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.put_resource_policy\naws_api/cloudwatch_logs put_resource_policy","url":"aws_api/cloudwatch_logs.html#put_resource_policy"},{"doc":"aws_api/cloudwatch_logs","title":"put_retention_policy","content":"pub fn put_retention_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.put_retention_policy\naws_api/cloudwatch_logs put_retention_policy","url":"aws_api/cloudwatch_logs.html#put_retention_policy"},{"doc":"aws_api/cloudwatch_logs","title":"put_subscription_filter","content":"pub fn put_subscription_filter(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.put_subscription_filter\naws_api/cloudwatch_logs put_subscription_filter","url":"aws_api/cloudwatch_logs.html#put_subscription_filter"},{"doc":"aws_api/cloudwatch_logs","title":"start_live_tail","content":"pub fn start_live_tail(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.start_live_tail\naws_api/cloudwatch_logs start_live_tail","url":"aws_api/cloudwatch_logs.html#start_live_tail"},{"doc":"aws_api/cloudwatch_logs","title":"start_query","content":"pub fn start_query(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.start_query\naws_api/cloudwatch_logs start_query","url":"aws_api/cloudwatch_logs.html#start_query"},{"doc":"aws_api/cloudwatch_logs","title":"stop_query","content":"pub fn stop_query(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.stop_query\naws_api/cloudwatch_logs stop_query","url":"aws_api/cloudwatch_logs.html#stop_query"},{"doc":"aws_api/cloudwatch_logs","title":"tag_log_group","content":"pub fn tag_log_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.tag_log_group\naws_api/cloudwatch_logs tag_log_group","url":"aws_api/cloudwatch_logs.html#tag_log_group"},{"doc":"aws_api/cloudwatch_logs","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.tag_resource\naws_api/cloudwatch_logs tag_resource","url":"aws_api/cloudwatch_logs.html#tag_resource"},{"doc":"aws_api/cloudwatch_logs","title":"test_metric_filter","content":"pub fn test_metric_filter(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.test_metric_filter\naws_api/cloudwatch_logs test_metric_filter","url":"aws_api/cloudwatch_logs.html#test_metric_filter"},{"doc":"aws_api/cloudwatch_logs","title":"untag_log_group","content":"pub fn untag_log_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.untag_log_group\naws_api/cloudwatch_logs untag_log_group","url":"aws_api/cloudwatch_logs.html#untag_log_group"},{"doc":"aws_api/cloudwatch_logs","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.untag_resource\naws_api/cloudwatch_logs untag_resource","url":"aws_api/cloudwatch_logs.html#untag_resource"},{"doc":"aws_api/cloudwatch_logs","title":"update_anomaly","content":"pub fn update_anomaly(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.update_anomaly\naws_api/cloudwatch_logs update_anomaly","url":"aws_api/cloudwatch_logs.html#update_anomaly"},{"doc":"aws_api/cloudwatch_logs","title":"update_log_anomaly_detector","content":"pub fn update_log_anomaly_detector(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cloudwatch_logs.update_log_anomaly_detector\naws_api/cloudwatch_logs update_log_anomaly_detector","url":"aws_api/cloudwatch_logs.html#update_log_anomaly_detector"},{"doc":"aws_api/cloudwatch_logs","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/cloudwatch_logs.with_custom_endpoint\naws_api/cloudwatch_logs with_custom_endpoint","url":"aws_api/cloudwatch_logs.html#with_custom_endpoint"},{"doc":"aws_api/cloudwatch_logs","title":"aws_api/cloudwatch_logs","content":"","url":"aws_api/cloudwatch_logs.html"},{"doc":"aws_api/codeartifact","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/codeartifact.Client\naws_api/codeartifact Client","url":"aws_api/codeartifact.html#Client"},{"doc":"aws_api/codeartifact","title":"associate_external_connection","content":"pub fn associate_external_connection(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeartifact.associate_external_connection\naws_api/codeartifact associate_external_connection","url":"aws_api/codeartifact.html#associate_external_connection"},{"doc":"aws_api/codeartifact","title":"copy_package_versions","content":"pub fn copy_package_versions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeartifact.copy_package_versions\naws_api/codeartifact copy_package_versions","url":"aws_api/codeartifact.html#copy_package_versions"},{"doc":"aws_api/codeartifact","title":"create_domain","content":"pub fn create_domain(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeartifact.create_domain\naws_api/codeartifact create_domain","url":"aws_api/codeartifact.html#create_domain"},{"doc":"aws_api/codeartifact","title":"create_package_group","content":"pub fn create_package_group(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeartifact.create_package_group\naws_api/codeartifact create_package_group","url":"aws_api/codeartifact.html#create_package_group"},{"doc":"aws_api/codeartifact","title":"create_repository","content":"pub fn create_repository(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeartifact.create_repository\naws_api/codeartifact create_repository","url":"aws_api/codeartifact.html#create_repository"},{"doc":"aws_api/codeartifact","title":"delete_domain","content":"pub fn delete_domain(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeartifact.delete_domain\naws_api/codeartifact delete_domain","url":"aws_api/codeartifact.html#delete_domain"},{"doc":"aws_api/codeartifact","title":"delete_domain_permissions_policy","content":"pub fn delete_domain_permissions_policy(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeartifact.delete_domain_permissions_policy\naws_api/codeartifact delete_domain_permissions_policy","url":"aws_api/codeartifact.html#delete_domain_permissions_policy"},{"doc":"aws_api/codeartifact","title":"delete_package","content":"pub fn delete_package(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeartifact.delete_package\naws_api/codeartifact delete_package","url":"aws_api/codeartifact.html#delete_package"},{"doc":"aws_api/codeartifact","title":"delete_package_group","content":"pub fn delete_package_group(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeartifact.delete_package_group\naws_api/codeartifact delete_package_group","url":"aws_api/codeartifact.html#delete_package_group"},{"doc":"aws_api/codeartifact","title":"delete_package_versions","content":"pub fn delete_package_versions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeartifact.delete_package_versions\naws_api/codeartifact delete_package_versions","url":"aws_api/codeartifact.html#delete_package_versions"},{"doc":"aws_api/codeartifact","title":"delete_repository","content":"pub fn delete_repository(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeartifact.delete_repository\naws_api/codeartifact delete_repository","url":"aws_api/codeartifact.html#delete_repository"},{"doc":"aws_api/codeartifact","title":"delete_repository_permissions_policy","content":"pub fn delete_repository_permissions_policy(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeartifact.delete_repository_permissions_policy\naws_api/codeartifact delete_repository_permissions_policy","url":"aws_api/codeartifact.html#delete_repository_permissions_policy"},{"doc":"aws_api/codeartifact","title":"describe_domain","content":"pub fn describe_domain(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeartifact.describe_domain\naws_api/codeartifact describe_domain","url":"aws_api/codeartifact.html#describe_domain"},{"doc":"aws_api/codeartifact","title":"describe_package","content":"pub fn describe_package(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeartifact.describe_package\naws_api/codeartifact describe_package","url":"aws_api/codeartifact.html#describe_package"},{"doc":"aws_api/codeartifact","title":"describe_package_group","content":"pub fn describe_package_group(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeartifact.describe_package_group\naws_api/codeartifact describe_package_group","url":"aws_api/codeartifact.html#describe_package_group"},{"doc":"aws_api/codeartifact","title":"describe_package_version","content":"pub fn describe_package_version(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeartifact.describe_package_version\naws_api/codeartifact describe_package_version","url":"aws_api/codeartifact.html#describe_package_version"},{"doc":"aws_api/codeartifact","title":"describe_repository","content":"pub fn describe_repository(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeartifact.describe_repository\naws_api/codeartifact describe_repository","url":"aws_api/codeartifact.html#describe_repository"},{"doc":"aws_api/codeartifact","title":"disassociate_external_connection","content":"pub fn disassociate_external_connection(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeartifact.disassociate_external_connection\naws_api/codeartifact disassociate_external_connection","url":"aws_api/codeartifact.html#disassociate_external_connection"},{"doc":"aws_api/codeartifact","title":"dispose_package_versions","content":"pub fn dispose_package_versions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeartifact.dispose_package_versions\naws_api/codeartifact dispose_package_versions","url":"aws_api/codeartifact.html#dispose_package_versions"},{"doc":"aws_api/codeartifact","title":"get_associated_package_group","content":"pub fn get_associated_package_group(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeartifact.get_associated_package_group\naws_api/codeartifact get_associated_package_group","url":"aws_api/codeartifact.html#get_associated_package_group"},{"doc":"aws_api/codeartifact","title":"get_authorization_token","content":"pub fn get_authorization_token(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeartifact.get_authorization_token\naws_api/codeartifact get_authorization_token","url":"aws_api/codeartifact.html#get_authorization_token"},{"doc":"aws_api/codeartifact","title":"get_domain_permissions_policy","content":"pub fn get_domain_permissions_policy(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeartifact.get_domain_permissions_policy\naws_api/codeartifact get_domain_permissions_policy","url":"aws_api/codeartifact.html#get_domain_permissions_policy"},{"doc":"aws_api/codeartifact","title":"get_package_version_asset","content":"pub fn get_package_version_asset(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeartifact.get_package_version_asset\naws_api/codeartifact get_package_version_asset","url":"aws_api/codeartifact.html#get_package_version_asset"},{"doc":"aws_api/codeartifact","title":"get_package_version_readme","content":"pub fn get_package_version_readme(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeartifact.get_package_version_readme\naws_api/codeartifact get_package_version_readme","url":"aws_api/codeartifact.html#get_package_version_readme"},{"doc":"aws_api/codeartifact","title":"get_repository_endpoint","content":"pub fn get_repository_endpoint(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeartifact.get_repository_endpoint\naws_api/codeartifact get_repository_endpoint","url":"aws_api/codeartifact.html#get_repository_endpoint"},{"doc":"aws_api/codeartifact","title":"get_repository_permissions_policy","content":"pub fn get_repository_permissions_policy(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeartifact.get_repository_permissions_policy\naws_api/codeartifact get_repository_permissions_policy","url":"aws_api/codeartifact.html#get_repository_permissions_policy"},{"doc":"aws_api/codeartifact","title":"list_allowed_repositories_for_group","content":"pub fn list_allowed_repositories_for_group(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeartifact.list_allowed_repositories_for_group\naws_api/codeartifact list_allowed_repositories_for_group","url":"aws_api/codeartifact.html#list_allowed_repositories_for_group"},{"doc":"aws_api/codeartifact","title":"list_associated_packages","content":"pub fn list_associated_packages(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeartifact.list_associated_packages\naws_api/codeartifact list_associated_packages","url":"aws_api/codeartifact.html#list_associated_packages"},{"doc":"aws_api/codeartifact","title":"list_domains","content":"pub fn list_domains(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeartifact.list_domains\naws_api/codeartifact list_domains","url":"aws_api/codeartifact.html#list_domains"},{"doc":"aws_api/codeartifact","title":"list_package_groups","content":"pub fn list_package_groups(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeartifact.list_package_groups\naws_api/codeartifact list_package_groups","url":"aws_api/codeartifact.html#list_package_groups"},{"doc":"aws_api/codeartifact","title":"list_package_version_assets","content":"pub fn list_package_version_assets(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeartifact.list_package_version_assets\naws_api/codeartifact list_package_version_assets","url":"aws_api/codeartifact.html#list_package_version_assets"},{"doc":"aws_api/codeartifact","title":"list_package_version_dependencies","content":"pub fn list_package_version_dependencies(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeartifact.list_package_version_dependencies\naws_api/codeartifact list_package_version_dependencies","url":"aws_api/codeartifact.html#list_package_version_dependencies"},{"doc":"aws_api/codeartifact","title":"list_package_versions","content":"pub fn list_package_versions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeartifact.list_package_versions\naws_api/codeartifact list_package_versions","url":"aws_api/codeartifact.html#list_package_versions"},{"doc":"aws_api/codeartifact","title":"list_packages","content":"pub fn list_packages(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeartifact.list_packages\naws_api/codeartifact list_packages","url":"aws_api/codeartifact.html#list_packages"},{"doc":"aws_api/codeartifact","title":"list_repositories","content":"pub fn list_repositories(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeartifact.list_repositories\naws_api/codeartifact list_repositories","url":"aws_api/codeartifact.html#list_repositories"},{"doc":"aws_api/codeartifact","title":"list_repositories_in_domain","content":"pub fn list_repositories_in_domain(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeartifact.list_repositories_in_domain\naws_api/codeartifact list_repositories_in_domain","url":"aws_api/codeartifact.html#list_repositories_in_domain"},{"doc":"aws_api/codeartifact","title":"list_sub_package_groups","content":"pub fn list_sub_package_groups(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeartifact.list_sub_package_groups\naws_api/codeartifact list_sub_package_groups","url":"aws_api/codeartifact.html#list_sub_package_groups"},{"doc":"aws_api/codeartifact","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeartifact.list_tags_for_resource\naws_api/codeartifact list_tags_for_resource","url":"aws_api/codeartifact.html#list_tags_for_resource"},{"doc":"aws_api/codeartifact","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/codeartifact.new\naws_api/codeartifact new","url":"aws_api/codeartifact.html#new"},{"doc":"aws_api/codeartifact","title":"publish_package_version","content":"pub fn publish_package_version(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeartifact.publish_package_version\naws_api/codeartifact publish_package_version","url":"aws_api/codeartifact.html#publish_package_version"},{"doc":"aws_api/codeartifact","title":"put_domain_permissions_policy","content":"pub fn put_domain_permissions_policy(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeartifact.put_domain_permissions_policy\naws_api/codeartifact put_domain_permissions_policy","url":"aws_api/codeartifact.html#put_domain_permissions_policy"},{"doc":"aws_api/codeartifact","title":"put_package_origin_configuration","content":"pub fn put_package_origin_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeartifact.put_package_origin_configuration\naws_api/codeartifact put_package_origin_configuration","url":"aws_api/codeartifact.html#put_package_origin_configuration"},{"doc":"aws_api/codeartifact","title":"put_repository_permissions_policy","content":"pub fn put_repository_permissions_policy(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeartifact.put_repository_permissions_policy\naws_api/codeartifact put_repository_permissions_policy","url":"aws_api/codeartifact.html#put_repository_permissions_policy"},{"doc":"aws_api/codeartifact","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeartifact.tag_resource\naws_api/codeartifact tag_resource","url":"aws_api/codeartifact.html#tag_resource"},{"doc":"aws_api/codeartifact","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeartifact.untag_resource\naws_api/codeartifact untag_resource","url":"aws_api/codeartifact.html#untag_resource"},{"doc":"aws_api/codeartifact","title":"update_package_group","content":"pub fn update_package_group(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeartifact.update_package_group\naws_api/codeartifact update_package_group","url":"aws_api/codeartifact.html#update_package_group"},{"doc":"aws_api/codeartifact","title":"update_package_group_origin_configuration","content":"pub fn update_package_group_origin_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeartifact.update_package_group_origin_configuration\naws_api/codeartifact update_package_group_origin_configuration","url":"aws_api/codeartifact.html#update_package_group_origin_configuration"},{"doc":"aws_api/codeartifact","title":"update_package_versions_status","content":"pub fn update_package_versions_status(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeartifact.update_package_versions_status\naws_api/codeartifact update_package_versions_status","url":"aws_api/codeartifact.html#update_package_versions_status"},{"doc":"aws_api/codeartifact","title":"update_repository","content":"pub fn update_repository(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeartifact.update_repository\naws_api/codeartifact update_repository","url":"aws_api/codeartifact.html#update_repository"},{"doc":"aws_api/codeartifact","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/codeartifact.with_custom_endpoint\naws_api/codeartifact with_custom_endpoint","url":"aws_api/codeartifact.html#with_custom_endpoint"},{"doc":"aws_api/codeartifact","title":"aws_api/codeartifact","content":"","url":"aws_api/codeartifact.html"},{"doc":"aws_api/codebuild","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/codebuild.Client\naws_api/codebuild Client","url":"aws_api/codebuild.html#Client"},{"doc":"aws_api/codebuild","title":"batch_delete_builds","content":"pub fn batch_delete_builds(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codebuild.batch_delete_builds\naws_api/codebuild batch_delete_builds","url":"aws_api/codebuild.html#batch_delete_builds"},{"doc":"aws_api/codebuild","title":"batch_get_build_batches","content":"pub fn batch_get_build_batches(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codebuild.batch_get_build_batches\naws_api/codebuild batch_get_build_batches","url":"aws_api/codebuild.html#batch_get_build_batches"},{"doc":"aws_api/codebuild","title":"batch_get_builds","content":"pub fn batch_get_builds(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codebuild.batch_get_builds\naws_api/codebuild batch_get_builds","url":"aws_api/codebuild.html#batch_get_builds"},{"doc":"aws_api/codebuild","title":"batch_get_fleets","content":"pub fn batch_get_fleets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codebuild.batch_get_fleets\naws_api/codebuild batch_get_fleets","url":"aws_api/codebuild.html#batch_get_fleets"},{"doc":"aws_api/codebuild","title":"batch_get_projects","content":"pub fn batch_get_projects(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codebuild.batch_get_projects\naws_api/codebuild batch_get_projects","url":"aws_api/codebuild.html#batch_get_projects"},{"doc":"aws_api/codebuild","title":"batch_get_report_groups","content":"pub fn batch_get_report_groups(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codebuild.batch_get_report_groups\naws_api/codebuild batch_get_report_groups","url":"aws_api/codebuild.html#batch_get_report_groups"},{"doc":"aws_api/codebuild","title":"batch_get_reports","content":"pub fn batch_get_reports(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codebuild.batch_get_reports\naws_api/codebuild batch_get_reports","url":"aws_api/codebuild.html#batch_get_reports"},{"doc":"aws_api/codebuild","title":"create_fleet","content":"pub fn create_fleet(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codebuild.create_fleet\naws_api/codebuild create_fleet","url":"aws_api/codebuild.html#create_fleet"},{"doc":"aws_api/codebuild","title":"create_project","content":"pub fn create_project(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codebuild.create_project\naws_api/codebuild create_project","url":"aws_api/codebuild.html#create_project"},{"doc":"aws_api/codebuild","title":"create_report_group","content":"pub fn create_report_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codebuild.create_report_group\naws_api/codebuild create_report_group","url":"aws_api/codebuild.html#create_report_group"},{"doc":"aws_api/codebuild","title":"create_webhook","content":"pub fn create_webhook(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codebuild.create_webhook\naws_api/codebuild create_webhook","url":"aws_api/codebuild.html#create_webhook"},{"doc":"aws_api/codebuild","title":"delete_build_batch","content":"pub fn delete_build_batch(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codebuild.delete_build_batch\naws_api/codebuild delete_build_batch","url":"aws_api/codebuild.html#delete_build_batch"},{"doc":"aws_api/codebuild","title":"delete_fleet","content":"pub fn delete_fleet(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codebuild.delete_fleet\naws_api/codebuild delete_fleet","url":"aws_api/codebuild.html#delete_fleet"},{"doc":"aws_api/codebuild","title":"delete_project","content":"pub fn delete_project(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codebuild.delete_project\naws_api/codebuild delete_project","url":"aws_api/codebuild.html#delete_project"},{"doc":"aws_api/codebuild","title":"delete_report","content":"pub fn delete_report(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codebuild.delete_report\naws_api/codebuild delete_report","url":"aws_api/codebuild.html#delete_report"},{"doc":"aws_api/codebuild","title":"delete_report_group","content":"pub fn delete_report_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codebuild.delete_report_group\naws_api/codebuild delete_report_group","url":"aws_api/codebuild.html#delete_report_group"},{"doc":"aws_api/codebuild","title":"delete_resource_policy","content":"pub fn delete_resource_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codebuild.delete_resource_policy\naws_api/codebuild delete_resource_policy","url":"aws_api/codebuild.html#delete_resource_policy"},{"doc":"aws_api/codebuild","title":"delete_source_credentials","content":"pub fn delete_source_credentials(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codebuild.delete_source_credentials\naws_api/codebuild delete_source_credentials","url":"aws_api/codebuild.html#delete_source_credentials"},{"doc":"aws_api/codebuild","title":"delete_webhook","content":"pub fn delete_webhook(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codebuild.delete_webhook\naws_api/codebuild delete_webhook","url":"aws_api/codebuild.html#delete_webhook"},{"doc":"aws_api/codebuild","title":"describe_code_coverages","content":"pub fn describe_code_coverages(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codebuild.describe_code_coverages\naws_api/codebuild describe_code_coverages","url":"aws_api/codebuild.html#describe_code_coverages"},{"doc":"aws_api/codebuild","title":"describe_test_cases","content":"pub fn describe_test_cases(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codebuild.describe_test_cases\naws_api/codebuild describe_test_cases","url":"aws_api/codebuild.html#describe_test_cases"},{"doc":"aws_api/codebuild","title":"get_report_group_trend","content":"pub fn get_report_group_trend(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codebuild.get_report_group_trend\naws_api/codebuild get_report_group_trend","url":"aws_api/codebuild.html#get_report_group_trend"},{"doc":"aws_api/codebuild","title":"get_resource_policy","content":"pub fn get_resource_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codebuild.get_resource_policy\naws_api/codebuild get_resource_policy","url":"aws_api/codebuild.html#get_resource_policy"},{"doc":"aws_api/codebuild","title":"import_source_credentials","content":"pub fn import_source_credentials(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codebuild.import_source_credentials\naws_api/codebuild import_source_credentials","url":"aws_api/codebuild.html#import_source_credentials"},{"doc":"aws_api/codebuild","title":"invalidate_project_cache","content":"pub fn invalidate_project_cache(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codebuild.invalidate_project_cache\naws_api/codebuild invalidate_project_cache","url":"aws_api/codebuild.html#invalidate_project_cache"},{"doc":"aws_api/codebuild","title":"list_build_batches","content":"pub fn list_build_batches(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codebuild.list_build_batches\naws_api/codebuild list_build_batches","url":"aws_api/codebuild.html#list_build_batches"},{"doc":"aws_api/codebuild","title":"list_build_batches_for_project","content":"pub fn list_build_batches_for_project(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codebuild.list_build_batches_for_project\naws_api/codebuild list_build_batches_for_project","url":"aws_api/codebuild.html#list_build_batches_for_project"},{"doc":"aws_api/codebuild","title":"list_builds","content":"pub fn list_builds(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codebuild.list_builds\naws_api/codebuild list_builds","url":"aws_api/codebuild.html#list_builds"},{"doc":"aws_api/codebuild","title":"list_builds_for_project","content":"pub fn list_builds_for_project(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codebuild.list_builds_for_project\naws_api/codebuild list_builds_for_project","url":"aws_api/codebuild.html#list_builds_for_project"},{"doc":"aws_api/codebuild","title":"list_curated_environment_images","content":"pub fn list_curated_environment_images(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codebuild.list_curated_environment_images\naws_api/codebuild list_curated_environment_images","url":"aws_api/codebuild.html#list_curated_environment_images"},{"doc":"aws_api/codebuild","title":"list_fleets","content":"pub fn list_fleets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codebuild.list_fleets\naws_api/codebuild list_fleets","url":"aws_api/codebuild.html#list_fleets"},{"doc":"aws_api/codebuild","title":"list_projects","content":"pub fn list_projects(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codebuild.list_projects\naws_api/codebuild list_projects","url":"aws_api/codebuild.html#list_projects"},{"doc":"aws_api/codebuild","title":"list_report_groups","content":"pub fn list_report_groups(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codebuild.list_report_groups\naws_api/codebuild list_report_groups","url":"aws_api/codebuild.html#list_report_groups"},{"doc":"aws_api/codebuild","title":"list_reports","content":"pub fn list_reports(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codebuild.list_reports\naws_api/codebuild list_reports","url":"aws_api/codebuild.html#list_reports"},{"doc":"aws_api/codebuild","title":"list_reports_for_report_group","content":"pub fn list_reports_for_report_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codebuild.list_reports_for_report_group\naws_api/codebuild list_reports_for_report_group","url":"aws_api/codebuild.html#list_reports_for_report_group"},{"doc":"aws_api/codebuild","title":"list_shared_projects","content":"pub fn list_shared_projects(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codebuild.list_shared_projects\naws_api/codebuild list_shared_projects","url":"aws_api/codebuild.html#list_shared_projects"},{"doc":"aws_api/codebuild","title":"list_shared_report_groups","content":"pub fn list_shared_report_groups(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codebuild.list_shared_report_groups\naws_api/codebuild list_shared_report_groups","url":"aws_api/codebuild.html#list_shared_report_groups"},{"doc":"aws_api/codebuild","title":"list_source_credentials","content":"pub fn list_source_credentials(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codebuild.list_source_credentials\naws_api/codebuild list_source_credentials","url":"aws_api/codebuild.html#list_source_credentials"},{"doc":"aws_api/codebuild","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/codebuild.new\naws_api/codebuild new","url":"aws_api/codebuild.html#new"},{"doc":"aws_api/codebuild","title":"put_resource_policy","content":"pub fn put_resource_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codebuild.put_resource_policy\naws_api/codebuild put_resource_policy","url":"aws_api/codebuild.html#put_resource_policy"},{"doc":"aws_api/codebuild","title":"retry_build","content":"pub fn retry_build(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codebuild.retry_build\naws_api/codebuild retry_build","url":"aws_api/codebuild.html#retry_build"},{"doc":"aws_api/codebuild","title":"retry_build_batch","content":"pub fn retry_build_batch(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codebuild.retry_build_batch\naws_api/codebuild retry_build_batch","url":"aws_api/codebuild.html#retry_build_batch"},{"doc":"aws_api/codebuild","title":"start_build","content":"pub fn start_build(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codebuild.start_build\naws_api/codebuild start_build","url":"aws_api/codebuild.html#start_build"},{"doc":"aws_api/codebuild","title":"start_build_batch","content":"pub fn start_build_batch(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codebuild.start_build_batch\naws_api/codebuild start_build_batch","url":"aws_api/codebuild.html#start_build_batch"},{"doc":"aws_api/codebuild","title":"stop_build","content":"pub fn stop_build(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codebuild.stop_build\naws_api/codebuild stop_build","url":"aws_api/codebuild.html#stop_build"},{"doc":"aws_api/codebuild","title":"stop_build_batch","content":"pub fn stop_build_batch(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codebuild.stop_build_batch\naws_api/codebuild stop_build_batch","url":"aws_api/codebuild.html#stop_build_batch"},{"doc":"aws_api/codebuild","title":"update_fleet","content":"pub fn update_fleet(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codebuild.update_fleet\naws_api/codebuild update_fleet","url":"aws_api/codebuild.html#update_fleet"},{"doc":"aws_api/codebuild","title":"update_project","content":"pub fn update_project(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codebuild.update_project\naws_api/codebuild update_project","url":"aws_api/codebuild.html#update_project"},{"doc":"aws_api/codebuild","title":"update_project_visibility","content":"pub fn update_project_visibility(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codebuild.update_project_visibility\naws_api/codebuild update_project_visibility","url":"aws_api/codebuild.html#update_project_visibility"},{"doc":"aws_api/codebuild","title":"update_report_group","content":"pub fn update_report_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codebuild.update_report_group\naws_api/codebuild update_report_group","url":"aws_api/codebuild.html#update_report_group"},{"doc":"aws_api/codebuild","title":"update_webhook","content":"pub fn update_webhook(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codebuild.update_webhook\naws_api/codebuild update_webhook","url":"aws_api/codebuild.html#update_webhook"},{"doc":"aws_api/codebuild","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/codebuild.with_custom_endpoint\naws_api/codebuild with_custom_endpoint","url":"aws_api/codebuild.html#with_custom_endpoint"},{"doc":"aws_api/codebuild","title":"aws_api/codebuild","content":"","url":"aws_api/codebuild.html"},{"doc":"aws_api/codecommit","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/codecommit.Client\naws_api/codecommit Client","url":"aws_api/codecommit.html#Client"},{"doc":"aws_api/codecommit","title":"associate_approval_rule_template_with_repository","content":"pub fn associate_approval_rule_template_with_repository(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.associate_approval_rule_template_with_repository\naws_api/codecommit associate_approval_rule_template_with_repository","url":"aws_api/codecommit.html#associate_approval_rule_template_with_repository"},{"doc":"aws_api/codecommit","title":"batch_associate_approval_rule_template_with_repositories","content":"pub fn batch_associate_approval_rule_template_with_repositories(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.batch_associate_approval_rule_template_with_repositories\naws_api/codecommit batch_associate_approval_rule_template_with_repositories","url":"aws_api/codecommit.html#batch_associate_approval_rule_template_with_repositories"},{"doc":"aws_api/codecommit","title":"batch_describe_merge_conflicts","content":"pub fn batch_describe_merge_conflicts(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.batch_describe_merge_conflicts\naws_api/codecommit batch_describe_merge_conflicts","url":"aws_api/codecommit.html#batch_describe_merge_conflicts"},{"doc":"aws_api/codecommit","title":"batch_disassociate_approval_rule_template_from_repositories","content":"pub fn batch_disassociate_approval_rule_template_from_repositories(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.batch_disassociate_approval_rule_template_from_repositories\naws_api/codecommit batch_disassociate_approval_rule_template_from_repositories","url":"aws_api/codecommit.html#batch_disassociate_approval_rule_template_from_repositories"},{"doc":"aws_api/codecommit","title":"batch_get_commits","content":"pub fn batch_get_commits(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.batch_get_commits\naws_api/codecommit batch_get_commits","url":"aws_api/codecommit.html#batch_get_commits"},{"doc":"aws_api/codecommit","title":"batch_get_repositories","content":"pub fn batch_get_repositories(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.batch_get_repositories\naws_api/codecommit batch_get_repositories","url":"aws_api/codecommit.html#batch_get_repositories"},{"doc":"aws_api/codecommit","title":"create_approval_rule_template","content":"pub fn create_approval_rule_template(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.create_approval_rule_template\naws_api/codecommit create_approval_rule_template","url":"aws_api/codecommit.html#create_approval_rule_template"},{"doc":"aws_api/codecommit","title":"create_branch","content":"pub fn create_branch(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.create_branch\naws_api/codecommit create_branch","url":"aws_api/codecommit.html#create_branch"},{"doc":"aws_api/codecommit","title":"create_commit","content":"pub fn create_commit(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.create_commit\naws_api/codecommit create_commit","url":"aws_api/codecommit.html#create_commit"},{"doc":"aws_api/codecommit","title":"create_pull_request","content":"pub fn create_pull_request(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.create_pull_request\naws_api/codecommit create_pull_request","url":"aws_api/codecommit.html#create_pull_request"},{"doc":"aws_api/codecommit","title":"create_pull_request_approval_rule","content":"pub fn create_pull_request_approval_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.create_pull_request_approval_rule\naws_api/codecommit create_pull_request_approval_rule","url":"aws_api/codecommit.html#create_pull_request_approval_rule"},{"doc":"aws_api/codecommit","title":"create_repository","content":"pub fn create_repository(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.create_repository\naws_api/codecommit create_repository","url":"aws_api/codecommit.html#create_repository"},{"doc":"aws_api/codecommit","title":"create_unreferenced_merge_commit","content":"pub fn create_unreferenced_merge_commit(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.create_unreferenced_merge_commit\naws_api/codecommit create_unreferenced_merge_commit","url":"aws_api/codecommit.html#create_unreferenced_merge_commit"},{"doc":"aws_api/codecommit","title":"delete_approval_rule_template","content":"pub fn delete_approval_rule_template(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.delete_approval_rule_template\naws_api/codecommit delete_approval_rule_template","url":"aws_api/codecommit.html#delete_approval_rule_template"},{"doc":"aws_api/codecommit","title":"delete_branch","content":"pub fn delete_branch(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.delete_branch\naws_api/codecommit delete_branch","url":"aws_api/codecommit.html#delete_branch"},{"doc":"aws_api/codecommit","title":"delete_comment_content","content":"pub fn delete_comment_content(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.delete_comment_content\naws_api/codecommit delete_comment_content","url":"aws_api/codecommit.html#delete_comment_content"},{"doc":"aws_api/codecommit","title":"delete_file","content":"pub fn delete_file(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.delete_file\naws_api/codecommit delete_file","url":"aws_api/codecommit.html#delete_file"},{"doc":"aws_api/codecommit","title":"delete_pull_request_approval_rule","content":"pub fn delete_pull_request_approval_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.delete_pull_request_approval_rule\naws_api/codecommit delete_pull_request_approval_rule","url":"aws_api/codecommit.html#delete_pull_request_approval_rule"},{"doc":"aws_api/codecommit","title":"delete_repository","content":"pub fn delete_repository(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.delete_repository\naws_api/codecommit delete_repository","url":"aws_api/codecommit.html#delete_repository"},{"doc":"aws_api/codecommit","title":"describe_merge_conflicts","content":"pub fn describe_merge_conflicts(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.describe_merge_conflicts\naws_api/codecommit describe_merge_conflicts","url":"aws_api/codecommit.html#describe_merge_conflicts"},{"doc":"aws_api/codecommit","title":"describe_pull_request_events","content":"pub fn describe_pull_request_events(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.describe_pull_request_events\naws_api/codecommit describe_pull_request_events","url":"aws_api/codecommit.html#describe_pull_request_events"},{"doc":"aws_api/codecommit","title":"disassociate_approval_rule_template_from_repository","content":"pub fn disassociate_approval_rule_template_from_repository(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.disassociate_approval_rule_template_from_repository\naws_api/codecommit disassociate_approval_rule_template_from_repository","url":"aws_api/codecommit.html#disassociate_approval_rule_template_from_repository"},{"doc":"aws_api/codecommit","title":"evaluate_pull_request_approval_rules","content":"pub fn evaluate_pull_request_approval_rules(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.evaluate_pull_request_approval_rules\naws_api/codecommit evaluate_pull_request_approval_rules","url":"aws_api/codecommit.html#evaluate_pull_request_approval_rules"},{"doc":"aws_api/codecommit","title":"get_approval_rule_template","content":"pub fn get_approval_rule_template(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.get_approval_rule_template\naws_api/codecommit get_approval_rule_template","url":"aws_api/codecommit.html#get_approval_rule_template"},{"doc":"aws_api/codecommit","title":"get_blob","content":"pub fn get_blob(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.get_blob\naws_api/codecommit get_blob","url":"aws_api/codecommit.html#get_blob"},{"doc":"aws_api/codecommit","title":"get_branch","content":"pub fn get_branch(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.get_branch\naws_api/codecommit get_branch","url":"aws_api/codecommit.html#get_branch"},{"doc":"aws_api/codecommit","title":"get_comment","content":"pub fn get_comment(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.get_comment\naws_api/codecommit get_comment","url":"aws_api/codecommit.html#get_comment"},{"doc":"aws_api/codecommit","title":"get_comment_reactions","content":"pub fn get_comment_reactions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.get_comment_reactions\naws_api/codecommit get_comment_reactions","url":"aws_api/codecommit.html#get_comment_reactions"},{"doc":"aws_api/codecommit","title":"get_comments_for_compared_commit","content":"pub fn get_comments_for_compared_commit(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.get_comments_for_compared_commit\naws_api/codecommit get_comments_for_compared_commit","url":"aws_api/codecommit.html#get_comments_for_compared_commit"},{"doc":"aws_api/codecommit","title":"get_comments_for_pull_request","content":"pub fn get_comments_for_pull_request(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.get_comments_for_pull_request\naws_api/codecommit get_comments_for_pull_request","url":"aws_api/codecommit.html#get_comments_for_pull_request"},{"doc":"aws_api/codecommit","title":"get_commit","content":"pub fn get_commit(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.get_commit\naws_api/codecommit get_commit","url":"aws_api/codecommit.html#get_commit"},{"doc":"aws_api/codecommit","title":"get_differences","content":"pub fn get_differences(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.get_differences\naws_api/codecommit get_differences","url":"aws_api/codecommit.html#get_differences"},{"doc":"aws_api/codecommit","title":"get_file","content":"pub fn get_file(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.get_file\naws_api/codecommit get_file","url":"aws_api/codecommit.html#get_file"},{"doc":"aws_api/codecommit","title":"get_folder","content":"pub fn get_folder(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.get_folder\naws_api/codecommit get_folder","url":"aws_api/codecommit.html#get_folder"},{"doc":"aws_api/codecommit","title":"get_merge_commit","content":"pub fn get_merge_commit(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.get_merge_commit\naws_api/codecommit get_merge_commit","url":"aws_api/codecommit.html#get_merge_commit"},{"doc":"aws_api/codecommit","title":"get_merge_conflicts","content":"pub fn get_merge_conflicts(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.get_merge_conflicts\naws_api/codecommit get_merge_conflicts","url":"aws_api/codecommit.html#get_merge_conflicts"},{"doc":"aws_api/codecommit","title":"get_merge_options","content":"pub fn get_merge_options(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.get_merge_options\naws_api/codecommit get_merge_options","url":"aws_api/codecommit.html#get_merge_options"},{"doc":"aws_api/codecommit","title":"get_pull_request","content":"pub fn get_pull_request(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.get_pull_request\naws_api/codecommit get_pull_request","url":"aws_api/codecommit.html#get_pull_request"},{"doc":"aws_api/codecommit","title":"get_pull_request_approval_states","content":"pub fn get_pull_request_approval_states(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.get_pull_request_approval_states\naws_api/codecommit get_pull_request_approval_states","url":"aws_api/codecommit.html#get_pull_request_approval_states"},{"doc":"aws_api/codecommit","title":"get_pull_request_override_state","content":"pub fn get_pull_request_override_state(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.get_pull_request_override_state\naws_api/codecommit get_pull_request_override_state","url":"aws_api/codecommit.html#get_pull_request_override_state"},{"doc":"aws_api/codecommit","title":"get_repository","content":"pub fn get_repository(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.get_repository\naws_api/codecommit get_repository","url":"aws_api/codecommit.html#get_repository"},{"doc":"aws_api/codecommit","title":"get_repository_triggers","content":"pub fn get_repository_triggers(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.get_repository_triggers\naws_api/codecommit get_repository_triggers","url":"aws_api/codecommit.html#get_repository_triggers"},{"doc":"aws_api/codecommit","title":"list_approval_rule_templates","content":"pub fn list_approval_rule_templates(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.list_approval_rule_templates\naws_api/codecommit list_approval_rule_templates","url":"aws_api/codecommit.html#list_approval_rule_templates"},{"doc":"aws_api/codecommit","title":"list_associated_approval_rule_templates_for_repository","content":"pub fn list_associated_approval_rule_templates_for_repository(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.list_associated_approval_rule_templates_for_repository\naws_api/codecommit list_associated_approval_rule_templates_for_repository","url":"aws_api/codecommit.html#list_associated_approval_rule_templates_for_repository"},{"doc":"aws_api/codecommit","title":"list_branches","content":"pub fn list_branches(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.list_branches\naws_api/codecommit list_branches","url":"aws_api/codecommit.html#list_branches"},{"doc":"aws_api/codecommit","title":"list_file_commit_history","content":"pub fn list_file_commit_history(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.list_file_commit_history\naws_api/codecommit list_file_commit_history","url":"aws_api/codecommit.html#list_file_commit_history"},{"doc":"aws_api/codecommit","title":"list_pull_requests","content":"pub fn list_pull_requests(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.list_pull_requests\naws_api/codecommit list_pull_requests","url":"aws_api/codecommit.html#list_pull_requests"},{"doc":"aws_api/codecommit","title":"list_repositories","content":"pub fn list_repositories(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.list_repositories\naws_api/codecommit list_repositories","url":"aws_api/codecommit.html#list_repositories"},{"doc":"aws_api/codecommit","title":"list_repositories_for_approval_rule_template","content":"pub fn list_repositories_for_approval_rule_template(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.list_repositories_for_approval_rule_template\naws_api/codecommit list_repositories_for_approval_rule_template","url":"aws_api/codecommit.html#list_repositories_for_approval_rule_template"},{"doc":"aws_api/codecommit","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.list_tags_for_resource\naws_api/codecommit list_tags_for_resource","url":"aws_api/codecommit.html#list_tags_for_resource"},{"doc":"aws_api/codecommit","title":"merge_branches_by_fast_forward","content":"pub fn merge_branches_by_fast_forward(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.merge_branches_by_fast_forward\naws_api/codecommit merge_branches_by_fast_forward","url":"aws_api/codecommit.html#merge_branches_by_fast_forward"},{"doc":"aws_api/codecommit","title":"merge_branches_by_squash","content":"pub fn merge_branches_by_squash(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.merge_branches_by_squash\naws_api/codecommit merge_branches_by_squash","url":"aws_api/codecommit.html#merge_branches_by_squash"},{"doc":"aws_api/codecommit","title":"merge_branches_by_three_way","content":"pub fn merge_branches_by_three_way(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.merge_branches_by_three_way\naws_api/codecommit merge_branches_by_three_way","url":"aws_api/codecommit.html#merge_branches_by_three_way"},{"doc":"aws_api/codecommit","title":"merge_pull_request_by_fast_forward","content":"pub fn merge_pull_request_by_fast_forward(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.merge_pull_request_by_fast_forward\naws_api/codecommit merge_pull_request_by_fast_forward","url":"aws_api/codecommit.html#merge_pull_request_by_fast_forward"},{"doc":"aws_api/codecommit","title":"merge_pull_request_by_squash","content":"pub fn merge_pull_request_by_squash(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.merge_pull_request_by_squash\naws_api/codecommit merge_pull_request_by_squash","url":"aws_api/codecommit.html#merge_pull_request_by_squash"},{"doc":"aws_api/codecommit","title":"merge_pull_request_by_three_way","content":"pub fn merge_pull_request_by_three_way(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.merge_pull_request_by_three_way\naws_api/codecommit merge_pull_request_by_three_way","url":"aws_api/codecommit.html#merge_pull_request_by_three_way"},{"doc":"aws_api/codecommit","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/codecommit.new\naws_api/codecommit new","url":"aws_api/codecommit.html#new"},{"doc":"aws_api/codecommit","title":"override_pull_request_approval_rules","content":"pub fn override_pull_request_approval_rules(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.override_pull_request_approval_rules\naws_api/codecommit override_pull_request_approval_rules","url":"aws_api/codecommit.html#override_pull_request_approval_rules"},{"doc":"aws_api/codecommit","title":"post_comment_for_compared_commit","content":"pub fn post_comment_for_compared_commit(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.post_comment_for_compared_commit\naws_api/codecommit post_comment_for_compared_commit","url":"aws_api/codecommit.html#post_comment_for_compared_commit"},{"doc":"aws_api/codecommit","title":"post_comment_for_pull_request","content":"pub fn post_comment_for_pull_request(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.post_comment_for_pull_request\naws_api/codecommit post_comment_for_pull_request","url":"aws_api/codecommit.html#post_comment_for_pull_request"},{"doc":"aws_api/codecommit","title":"post_comment_reply","content":"pub fn post_comment_reply(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.post_comment_reply\naws_api/codecommit post_comment_reply","url":"aws_api/codecommit.html#post_comment_reply"},{"doc":"aws_api/codecommit","title":"put_comment_reaction","content":"pub fn put_comment_reaction(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.put_comment_reaction\naws_api/codecommit put_comment_reaction","url":"aws_api/codecommit.html#put_comment_reaction"},{"doc":"aws_api/codecommit","title":"put_file","content":"pub fn put_file(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.put_file\naws_api/codecommit put_file","url":"aws_api/codecommit.html#put_file"},{"doc":"aws_api/codecommit","title":"put_repository_triggers","content":"pub fn put_repository_triggers(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.put_repository_triggers\naws_api/codecommit put_repository_triggers","url":"aws_api/codecommit.html#put_repository_triggers"},{"doc":"aws_api/codecommit","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.tag_resource\naws_api/codecommit tag_resource","url":"aws_api/codecommit.html#tag_resource"},{"doc":"aws_api/codecommit","title":"test_repository_triggers","content":"pub fn test_repository_triggers(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.test_repository_triggers\naws_api/codecommit test_repository_triggers","url":"aws_api/codecommit.html#test_repository_triggers"},{"doc":"aws_api/codecommit","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.untag_resource\naws_api/codecommit untag_resource","url":"aws_api/codecommit.html#untag_resource"},{"doc":"aws_api/codecommit","title":"update_approval_rule_template_content","content":"pub fn update_approval_rule_template_content(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.update_approval_rule_template_content\naws_api/codecommit update_approval_rule_template_content","url":"aws_api/codecommit.html#update_approval_rule_template_content"},{"doc":"aws_api/codecommit","title":"update_approval_rule_template_description","content":"pub fn update_approval_rule_template_description(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.update_approval_rule_template_description\naws_api/codecommit update_approval_rule_template_description","url":"aws_api/codecommit.html#update_approval_rule_template_description"},{"doc":"aws_api/codecommit","title":"update_approval_rule_template_name","content":"pub fn update_approval_rule_template_name(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.update_approval_rule_template_name\naws_api/codecommit update_approval_rule_template_name","url":"aws_api/codecommit.html#update_approval_rule_template_name"},{"doc":"aws_api/codecommit","title":"update_comment","content":"pub fn update_comment(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.update_comment\naws_api/codecommit update_comment","url":"aws_api/codecommit.html#update_comment"},{"doc":"aws_api/codecommit","title":"update_default_branch","content":"pub fn update_default_branch(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.update_default_branch\naws_api/codecommit update_default_branch","url":"aws_api/codecommit.html#update_default_branch"},{"doc":"aws_api/codecommit","title":"update_pull_request_approval_rule_content","content":"pub fn update_pull_request_approval_rule_content(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.update_pull_request_approval_rule_content\naws_api/codecommit update_pull_request_approval_rule_content","url":"aws_api/codecommit.html#update_pull_request_approval_rule_content"},{"doc":"aws_api/codecommit","title":"update_pull_request_approval_state","content":"pub fn update_pull_request_approval_state(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.update_pull_request_approval_state\naws_api/codecommit update_pull_request_approval_state","url":"aws_api/codecommit.html#update_pull_request_approval_state"},{"doc":"aws_api/codecommit","title":"update_pull_request_description","content":"pub fn update_pull_request_description(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.update_pull_request_description\naws_api/codecommit update_pull_request_description","url":"aws_api/codecommit.html#update_pull_request_description"},{"doc":"aws_api/codecommit","title":"update_pull_request_status","content":"pub fn update_pull_request_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.update_pull_request_status\naws_api/codecommit update_pull_request_status","url":"aws_api/codecommit.html#update_pull_request_status"},{"doc":"aws_api/codecommit","title":"update_pull_request_title","content":"pub fn update_pull_request_title(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.update_pull_request_title\naws_api/codecommit update_pull_request_title","url":"aws_api/codecommit.html#update_pull_request_title"},{"doc":"aws_api/codecommit","title":"update_repository_description","content":"pub fn update_repository_description(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.update_repository_description\naws_api/codecommit update_repository_description","url":"aws_api/codecommit.html#update_repository_description"},{"doc":"aws_api/codecommit","title":"update_repository_encryption_key","content":"pub fn update_repository_encryption_key(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.update_repository_encryption_key\naws_api/codecommit update_repository_encryption_key","url":"aws_api/codecommit.html#update_repository_encryption_key"},{"doc":"aws_api/codecommit","title":"update_repository_name","content":"pub fn update_repository_name(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codecommit.update_repository_name\naws_api/codecommit update_repository_name","url":"aws_api/codecommit.html#update_repository_name"},{"doc":"aws_api/codecommit","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/codecommit.with_custom_endpoint\naws_api/codecommit with_custom_endpoint","url":"aws_api/codecommit.html#with_custom_endpoint"},{"doc":"aws_api/codecommit","title":"aws_api/codecommit","content":"","url":"aws_api/codecommit.html"},{"doc":"aws_api/codedeploy","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/codedeploy.Client\naws_api/codedeploy Client","url":"aws_api/codedeploy.html#Client"},{"doc":"aws_api/codedeploy","title":"add_tags_to_on_premises_instances","content":"pub fn add_tags_to_on_premises_instances(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codedeploy.add_tags_to_on_premises_instances\naws_api/codedeploy add_tags_to_on_premises_instances","url":"aws_api/codedeploy.html#add_tags_to_on_premises_instances"},{"doc":"aws_api/codedeploy","title":"batch_get_application_revisions","content":"pub fn batch_get_application_revisions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codedeploy.batch_get_application_revisions\naws_api/codedeploy batch_get_application_revisions","url":"aws_api/codedeploy.html#batch_get_application_revisions"},{"doc":"aws_api/codedeploy","title":"batch_get_applications","content":"pub fn batch_get_applications(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codedeploy.batch_get_applications\naws_api/codedeploy batch_get_applications","url":"aws_api/codedeploy.html#batch_get_applications"},{"doc":"aws_api/codedeploy","title":"batch_get_deployment_groups","content":"pub fn batch_get_deployment_groups(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codedeploy.batch_get_deployment_groups\naws_api/codedeploy batch_get_deployment_groups","url":"aws_api/codedeploy.html#batch_get_deployment_groups"},{"doc":"aws_api/codedeploy","title":"batch_get_deployment_instances","content":"pub fn batch_get_deployment_instances(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codedeploy.batch_get_deployment_instances\naws_api/codedeploy batch_get_deployment_instances","url":"aws_api/codedeploy.html#batch_get_deployment_instances"},{"doc":"aws_api/codedeploy","title":"batch_get_deployment_targets","content":"pub fn batch_get_deployment_targets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codedeploy.batch_get_deployment_targets\naws_api/codedeploy batch_get_deployment_targets","url":"aws_api/codedeploy.html#batch_get_deployment_targets"},{"doc":"aws_api/codedeploy","title":"batch_get_deployments","content":"pub fn batch_get_deployments(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codedeploy.batch_get_deployments\naws_api/codedeploy batch_get_deployments","url":"aws_api/codedeploy.html#batch_get_deployments"},{"doc":"aws_api/codedeploy","title":"batch_get_on_premises_instances","content":"pub fn batch_get_on_premises_instances(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codedeploy.batch_get_on_premises_instances\naws_api/codedeploy batch_get_on_premises_instances","url":"aws_api/codedeploy.html#batch_get_on_premises_instances"},{"doc":"aws_api/codedeploy","title":"continue_deployment","content":"pub fn continue_deployment(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codedeploy.continue_deployment\naws_api/codedeploy continue_deployment","url":"aws_api/codedeploy.html#continue_deployment"},{"doc":"aws_api/codedeploy","title":"create_application","content":"pub fn create_application(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codedeploy.create_application\naws_api/codedeploy create_application","url":"aws_api/codedeploy.html#create_application"},{"doc":"aws_api/codedeploy","title":"create_deployment","content":"pub fn create_deployment(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codedeploy.create_deployment\naws_api/codedeploy create_deployment","url":"aws_api/codedeploy.html#create_deployment"},{"doc":"aws_api/codedeploy","title":"create_deployment_config","content":"pub fn create_deployment_config(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codedeploy.create_deployment_config\naws_api/codedeploy create_deployment_config","url":"aws_api/codedeploy.html#create_deployment_config"},{"doc":"aws_api/codedeploy","title":"create_deployment_group","content":"pub fn create_deployment_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codedeploy.create_deployment_group\naws_api/codedeploy create_deployment_group","url":"aws_api/codedeploy.html#create_deployment_group"},{"doc":"aws_api/codedeploy","title":"delete_application","content":"pub fn delete_application(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codedeploy.delete_application\naws_api/codedeploy delete_application","url":"aws_api/codedeploy.html#delete_application"},{"doc":"aws_api/codedeploy","title":"delete_deployment_config","content":"pub fn delete_deployment_config(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codedeploy.delete_deployment_config\naws_api/codedeploy delete_deployment_config","url":"aws_api/codedeploy.html#delete_deployment_config"},{"doc":"aws_api/codedeploy","title":"delete_deployment_group","content":"pub fn delete_deployment_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codedeploy.delete_deployment_group\naws_api/codedeploy delete_deployment_group","url":"aws_api/codedeploy.html#delete_deployment_group"},{"doc":"aws_api/codedeploy","title":"delete_git_hub_account_token","content":"pub fn delete_git_hub_account_token(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codedeploy.delete_git_hub_account_token\naws_api/codedeploy delete_git_hub_account_token","url":"aws_api/codedeploy.html#delete_git_hub_account_token"},{"doc":"aws_api/codedeploy","title":"delete_resources_by_external_id","content":"pub fn delete_resources_by_external_id(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codedeploy.delete_resources_by_external_id\naws_api/codedeploy delete_resources_by_external_id","url":"aws_api/codedeploy.html#delete_resources_by_external_id"},{"doc":"aws_api/codedeploy","title":"deregister_on_premises_instance","content":"pub fn deregister_on_premises_instance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codedeploy.deregister_on_premises_instance\naws_api/codedeploy deregister_on_premises_instance","url":"aws_api/codedeploy.html#deregister_on_premises_instance"},{"doc":"aws_api/codedeploy","title":"get_application","content":"pub fn get_application(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codedeploy.get_application\naws_api/codedeploy get_application","url":"aws_api/codedeploy.html#get_application"},{"doc":"aws_api/codedeploy","title":"get_application_revision","content":"pub fn get_application_revision(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codedeploy.get_application_revision\naws_api/codedeploy get_application_revision","url":"aws_api/codedeploy.html#get_application_revision"},{"doc":"aws_api/codedeploy","title":"get_deployment","content":"pub fn get_deployment(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codedeploy.get_deployment\naws_api/codedeploy get_deployment","url":"aws_api/codedeploy.html#get_deployment"},{"doc":"aws_api/codedeploy","title":"get_deployment_config","content":"pub fn get_deployment_config(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codedeploy.get_deployment_config\naws_api/codedeploy get_deployment_config","url":"aws_api/codedeploy.html#get_deployment_config"},{"doc":"aws_api/codedeploy","title":"get_deployment_group","content":"pub fn get_deployment_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codedeploy.get_deployment_group\naws_api/codedeploy get_deployment_group","url":"aws_api/codedeploy.html#get_deployment_group"},{"doc":"aws_api/codedeploy","title":"get_deployment_instance","content":"pub fn get_deployment_instance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codedeploy.get_deployment_instance\naws_api/codedeploy get_deployment_instance","url":"aws_api/codedeploy.html#get_deployment_instance"},{"doc":"aws_api/codedeploy","title":"get_deployment_target","content":"pub fn get_deployment_target(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codedeploy.get_deployment_target\naws_api/codedeploy get_deployment_target","url":"aws_api/codedeploy.html#get_deployment_target"},{"doc":"aws_api/codedeploy","title":"get_on_premises_instance","content":"pub fn get_on_premises_instance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codedeploy.get_on_premises_instance\naws_api/codedeploy get_on_premises_instance","url":"aws_api/codedeploy.html#get_on_premises_instance"},{"doc":"aws_api/codedeploy","title":"list_application_revisions","content":"pub fn list_application_revisions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codedeploy.list_application_revisions\naws_api/codedeploy list_application_revisions","url":"aws_api/codedeploy.html#list_application_revisions"},{"doc":"aws_api/codedeploy","title":"list_applications","content":"pub fn list_applications(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codedeploy.list_applications\naws_api/codedeploy list_applications","url":"aws_api/codedeploy.html#list_applications"},{"doc":"aws_api/codedeploy","title":"list_deployment_configs","content":"pub fn list_deployment_configs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codedeploy.list_deployment_configs\naws_api/codedeploy list_deployment_configs","url":"aws_api/codedeploy.html#list_deployment_configs"},{"doc":"aws_api/codedeploy","title":"list_deployment_groups","content":"pub fn list_deployment_groups(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codedeploy.list_deployment_groups\naws_api/codedeploy list_deployment_groups","url":"aws_api/codedeploy.html#list_deployment_groups"},{"doc":"aws_api/codedeploy","title":"list_deployment_instances","content":"pub fn list_deployment_instances(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codedeploy.list_deployment_instances\naws_api/codedeploy list_deployment_instances","url":"aws_api/codedeploy.html#list_deployment_instances"},{"doc":"aws_api/codedeploy","title":"list_deployment_targets","content":"pub fn list_deployment_targets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codedeploy.list_deployment_targets\naws_api/codedeploy list_deployment_targets","url":"aws_api/codedeploy.html#list_deployment_targets"},{"doc":"aws_api/codedeploy","title":"list_deployments","content":"pub fn list_deployments(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codedeploy.list_deployments\naws_api/codedeploy list_deployments","url":"aws_api/codedeploy.html#list_deployments"},{"doc":"aws_api/codedeploy","title":"list_git_hub_account_token_names","content":"pub fn list_git_hub_account_token_names(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codedeploy.list_git_hub_account_token_names\naws_api/codedeploy list_git_hub_account_token_names","url":"aws_api/codedeploy.html#list_git_hub_account_token_names"},{"doc":"aws_api/codedeploy","title":"list_on_premises_instances","content":"pub fn list_on_premises_instances(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codedeploy.list_on_premises_instances\naws_api/codedeploy list_on_premises_instances","url":"aws_api/codedeploy.html#list_on_premises_instances"},{"doc":"aws_api/codedeploy","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codedeploy.list_tags_for_resource\naws_api/codedeploy list_tags_for_resource","url":"aws_api/codedeploy.html#list_tags_for_resource"},{"doc":"aws_api/codedeploy","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/codedeploy.new\naws_api/codedeploy new","url":"aws_api/codedeploy.html#new"},{"doc":"aws_api/codedeploy","title":"put_lifecycle_event_hook_execution_status","content":"pub fn put_lifecycle_event_hook_execution_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codedeploy.put_lifecycle_event_hook_execution_status\naws_api/codedeploy put_lifecycle_event_hook_execution_status","url":"aws_api/codedeploy.html#put_lifecycle_event_hook_execution_status"},{"doc":"aws_api/codedeploy","title":"register_application_revision","content":"pub fn register_application_revision(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codedeploy.register_application_revision\naws_api/codedeploy register_application_revision","url":"aws_api/codedeploy.html#register_application_revision"},{"doc":"aws_api/codedeploy","title":"register_on_premises_instance","content":"pub fn register_on_premises_instance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codedeploy.register_on_premises_instance\naws_api/codedeploy register_on_premises_instance","url":"aws_api/codedeploy.html#register_on_premises_instance"},{"doc":"aws_api/codedeploy","title":"remove_tags_from_on_premises_instances","content":"pub fn remove_tags_from_on_premises_instances(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codedeploy.remove_tags_from_on_premises_instances\naws_api/codedeploy remove_tags_from_on_premises_instances","url":"aws_api/codedeploy.html#remove_tags_from_on_premises_instances"},{"doc":"aws_api/codedeploy","title":"skip_wait_time_for_instance_termination","content":"pub fn skip_wait_time_for_instance_termination(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codedeploy.skip_wait_time_for_instance_termination\naws_api/codedeploy skip_wait_time_for_instance_termination","url":"aws_api/codedeploy.html#skip_wait_time_for_instance_termination"},{"doc":"aws_api/codedeploy","title":"stop_deployment","content":"pub fn stop_deployment(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codedeploy.stop_deployment\naws_api/codedeploy stop_deployment","url":"aws_api/codedeploy.html#stop_deployment"},{"doc":"aws_api/codedeploy","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codedeploy.tag_resource\naws_api/codedeploy tag_resource","url":"aws_api/codedeploy.html#tag_resource"},{"doc":"aws_api/codedeploy","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codedeploy.untag_resource\naws_api/codedeploy untag_resource","url":"aws_api/codedeploy.html#untag_resource"},{"doc":"aws_api/codedeploy","title":"update_application","content":"pub fn update_application(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codedeploy.update_application\naws_api/codedeploy update_application","url":"aws_api/codedeploy.html#update_application"},{"doc":"aws_api/codedeploy","title":"update_deployment_group","content":"pub fn update_deployment_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codedeploy.update_deployment_group\naws_api/codedeploy update_deployment_group","url":"aws_api/codedeploy.html#update_deployment_group"},{"doc":"aws_api/codedeploy","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/codedeploy.with_custom_endpoint\naws_api/codedeploy with_custom_endpoint","url":"aws_api/codedeploy.html#with_custom_endpoint"},{"doc":"aws_api/codedeploy","title":"aws_api/codedeploy","content":"","url":"aws_api/codedeploy.html"},{"doc":"aws_api/codeguru_reviewer","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/codeguru_reviewer.Client\naws_api/codeguru_reviewer Client","url":"aws_api/codeguru_reviewer.html#Client"},{"doc":"aws_api/codeguru_reviewer","title":"associate_repository","content":"pub fn associate_repository(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeguru_reviewer.associate_repository\naws_api/codeguru_reviewer associate_repository","url":"aws_api/codeguru_reviewer.html#associate_repository"},{"doc":"aws_api/codeguru_reviewer","title":"create_code_review","content":"pub fn create_code_review(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeguru_reviewer.create_code_review\naws_api/codeguru_reviewer create_code_review","url":"aws_api/codeguru_reviewer.html#create_code_review"},{"doc":"aws_api/codeguru_reviewer","title":"describe_code_review","content":"pub fn describe_code_review(\n  client: Client,\n  code_review_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeguru_reviewer.describe_code_review\naws_api/codeguru_reviewer describe_code_review","url":"aws_api/codeguru_reviewer.html#describe_code_review"},{"doc":"aws_api/codeguru_reviewer","title":"describe_recommendation_feedback","content":"pub fn describe_recommendation_feedback(\n  client: Client,\n  code_review_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeguru_reviewer.describe_recommendation_feedback\naws_api/codeguru_reviewer describe_recommendation_feedback","url":"aws_api/codeguru_reviewer.html#describe_recommendation_feedback"},{"doc":"aws_api/codeguru_reviewer","title":"describe_repository_association","content":"pub fn describe_repository_association(\n  client: Client,\n  association_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeguru_reviewer.describe_repository_association\naws_api/codeguru_reviewer describe_repository_association","url":"aws_api/codeguru_reviewer.html#describe_repository_association"},{"doc":"aws_api/codeguru_reviewer","title":"disassociate_repository","content":"pub fn disassociate_repository(\n  client: Client,\n  association_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeguru_reviewer.disassociate_repository\naws_api/codeguru_reviewer disassociate_repository","url":"aws_api/codeguru_reviewer.html#disassociate_repository"},{"doc":"aws_api/codeguru_reviewer","title":"list_code_reviews","content":"pub fn list_code_reviews(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeguru_reviewer.list_code_reviews\naws_api/codeguru_reviewer list_code_reviews","url":"aws_api/codeguru_reviewer.html#list_code_reviews"},{"doc":"aws_api/codeguru_reviewer","title":"list_recommendation_feedback","content":"pub fn list_recommendation_feedback(\n  client: Client,\n  code_review_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeguru_reviewer.list_recommendation_feedback\naws_api/codeguru_reviewer list_recommendation_feedback","url":"aws_api/codeguru_reviewer.html#list_recommendation_feedback"},{"doc":"aws_api/codeguru_reviewer","title":"list_recommendations","content":"pub fn list_recommendations(\n  client: Client,\n  code_review_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeguru_reviewer.list_recommendations\naws_api/codeguru_reviewer list_recommendations","url":"aws_api/codeguru_reviewer.html#list_recommendations"},{"doc":"aws_api/codeguru_reviewer","title":"list_repository_associations","content":"pub fn list_repository_associations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeguru_reviewer.list_repository_associations\naws_api/codeguru_reviewer list_repository_associations","url":"aws_api/codeguru_reviewer.html#list_repository_associations"},{"doc":"aws_api/codeguru_reviewer","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeguru_reviewer.list_tags_for_resource\naws_api/codeguru_reviewer list_tags_for_resource","url":"aws_api/codeguru_reviewer.html#list_tags_for_resource"},{"doc":"aws_api/codeguru_reviewer","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/codeguru_reviewer.new\naws_api/codeguru_reviewer new","url":"aws_api/codeguru_reviewer.html#new"},{"doc":"aws_api/codeguru_reviewer","title":"put_recommendation_feedback","content":"pub fn put_recommendation_feedback(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeguru_reviewer.put_recommendation_feedback\naws_api/codeguru_reviewer put_recommendation_feedback","url":"aws_api/codeguru_reviewer.html#put_recommendation_feedback"},{"doc":"aws_api/codeguru_reviewer","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeguru_reviewer.tag_resource\naws_api/codeguru_reviewer tag_resource","url":"aws_api/codeguru_reviewer.html#tag_resource"},{"doc":"aws_api/codeguru_reviewer","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codeguru_reviewer.untag_resource\naws_api/codeguru_reviewer untag_resource","url":"aws_api/codeguru_reviewer.html#untag_resource"},{"doc":"aws_api/codeguru_reviewer","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/codeguru_reviewer.with_custom_endpoint\naws_api/codeguru_reviewer with_custom_endpoint","url":"aws_api/codeguru_reviewer.html#with_custom_endpoint"},{"doc":"aws_api/codeguru_reviewer","title":"aws_api/codeguru_reviewer","content":"","url":"aws_api/codeguru_reviewer.html"},{"doc":"aws_api/codepipeline","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/codepipeline.Client\naws_api/codepipeline Client","url":"aws_api/codepipeline.html#Client"},{"doc":"aws_api/codepipeline","title":"acknowledge_job","content":"pub fn acknowledge_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codepipeline.acknowledge_job\naws_api/codepipeline acknowledge_job","url":"aws_api/codepipeline.html#acknowledge_job"},{"doc":"aws_api/codepipeline","title":"acknowledge_third_party_job","content":"pub fn acknowledge_third_party_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codepipeline.acknowledge_third_party_job\naws_api/codepipeline acknowledge_third_party_job","url":"aws_api/codepipeline.html#acknowledge_third_party_job"},{"doc":"aws_api/codepipeline","title":"create_custom_action_type","content":"pub fn create_custom_action_type(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codepipeline.create_custom_action_type\naws_api/codepipeline create_custom_action_type","url":"aws_api/codepipeline.html#create_custom_action_type"},{"doc":"aws_api/codepipeline","title":"create_pipeline","content":"pub fn create_pipeline(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codepipeline.create_pipeline\naws_api/codepipeline create_pipeline","url":"aws_api/codepipeline.html#create_pipeline"},{"doc":"aws_api/codepipeline","title":"delete_custom_action_type","content":"pub fn delete_custom_action_type(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codepipeline.delete_custom_action_type\naws_api/codepipeline delete_custom_action_type","url":"aws_api/codepipeline.html#delete_custom_action_type"},{"doc":"aws_api/codepipeline","title":"delete_pipeline","content":"pub fn delete_pipeline(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codepipeline.delete_pipeline\naws_api/codepipeline delete_pipeline","url":"aws_api/codepipeline.html#delete_pipeline"},{"doc":"aws_api/codepipeline","title":"delete_webhook","content":"pub fn delete_webhook(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codepipeline.delete_webhook\naws_api/codepipeline delete_webhook","url":"aws_api/codepipeline.html#delete_webhook"},{"doc":"aws_api/codepipeline","title":"deregister_webhook_with_third_party","content":"pub fn deregister_webhook_with_third_party(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codepipeline.deregister_webhook_with_third_party\naws_api/codepipeline deregister_webhook_with_third_party","url":"aws_api/codepipeline.html#deregister_webhook_with_third_party"},{"doc":"aws_api/codepipeline","title":"disable_stage_transition","content":"pub fn disable_stage_transition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codepipeline.disable_stage_transition\naws_api/codepipeline disable_stage_transition","url":"aws_api/codepipeline.html#disable_stage_transition"},{"doc":"aws_api/codepipeline","title":"enable_stage_transition","content":"pub fn enable_stage_transition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codepipeline.enable_stage_transition\naws_api/codepipeline enable_stage_transition","url":"aws_api/codepipeline.html#enable_stage_transition"},{"doc":"aws_api/codepipeline","title":"get_action_type","content":"pub fn get_action_type(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codepipeline.get_action_type\naws_api/codepipeline get_action_type","url":"aws_api/codepipeline.html#get_action_type"},{"doc":"aws_api/codepipeline","title":"get_job_details","content":"pub fn get_job_details(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codepipeline.get_job_details\naws_api/codepipeline get_job_details","url":"aws_api/codepipeline.html#get_job_details"},{"doc":"aws_api/codepipeline","title":"get_pipeline","content":"pub fn get_pipeline(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codepipeline.get_pipeline\naws_api/codepipeline get_pipeline","url":"aws_api/codepipeline.html#get_pipeline"},{"doc":"aws_api/codepipeline","title":"get_pipeline_execution","content":"pub fn get_pipeline_execution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codepipeline.get_pipeline_execution\naws_api/codepipeline get_pipeline_execution","url":"aws_api/codepipeline.html#get_pipeline_execution"},{"doc":"aws_api/codepipeline","title":"get_pipeline_state","content":"pub fn get_pipeline_state(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codepipeline.get_pipeline_state\naws_api/codepipeline get_pipeline_state","url":"aws_api/codepipeline.html#get_pipeline_state"},{"doc":"aws_api/codepipeline","title":"get_third_party_job_details","content":"pub fn get_third_party_job_details(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codepipeline.get_third_party_job_details\naws_api/codepipeline get_third_party_job_details","url":"aws_api/codepipeline.html#get_third_party_job_details"},{"doc":"aws_api/codepipeline","title":"list_action_executions","content":"pub fn list_action_executions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codepipeline.list_action_executions\naws_api/codepipeline list_action_executions","url":"aws_api/codepipeline.html#list_action_executions"},{"doc":"aws_api/codepipeline","title":"list_action_types","content":"pub fn list_action_types(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codepipeline.list_action_types\naws_api/codepipeline list_action_types","url":"aws_api/codepipeline.html#list_action_types"},{"doc":"aws_api/codepipeline","title":"list_pipeline_executions","content":"pub fn list_pipeline_executions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codepipeline.list_pipeline_executions\naws_api/codepipeline list_pipeline_executions","url":"aws_api/codepipeline.html#list_pipeline_executions"},{"doc":"aws_api/codepipeline","title":"list_pipelines","content":"pub fn list_pipelines(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codepipeline.list_pipelines\naws_api/codepipeline list_pipelines","url":"aws_api/codepipeline.html#list_pipelines"},{"doc":"aws_api/codepipeline","title":"list_rule_executions","content":"pub fn list_rule_executions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codepipeline.list_rule_executions\naws_api/codepipeline list_rule_executions","url":"aws_api/codepipeline.html#list_rule_executions"},{"doc":"aws_api/codepipeline","title":"list_rule_types","content":"pub fn list_rule_types(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codepipeline.list_rule_types\naws_api/codepipeline list_rule_types","url":"aws_api/codepipeline.html#list_rule_types"},{"doc":"aws_api/codepipeline","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codepipeline.list_tags_for_resource\naws_api/codepipeline list_tags_for_resource","url":"aws_api/codepipeline.html#list_tags_for_resource"},{"doc":"aws_api/codepipeline","title":"list_webhooks","content":"pub fn list_webhooks(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codepipeline.list_webhooks\naws_api/codepipeline list_webhooks","url":"aws_api/codepipeline.html#list_webhooks"},{"doc":"aws_api/codepipeline","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/codepipeline.new\naws_api/codepipeline new","url":"aws_api/codepipeline.html#new"},{"doc":"aws_api/codepipeline","title":"override_stage_condition","content":"pub fn override_stage_condition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codepipeline.override_stage_condition\naws_api/codepipeline override_stage_condition","url":"aws_api/codepipeline.html#override_stage_condition"},{"doc":"aws_api/codepipeline","title":"poll_for_jobs","content":"pub fn poll_for_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codepipeline.poll_for_jobs\naws_api/codepipeline poll_for_jobs","url":"aws_api/codepipeline.html#poll_for_jobs"},{"doc":"aws_api/codepipeline","title":"poll_for_third_party_jobs","content":"pub fn poll_for_third_party_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codepipeline.poll_for_third_party_jobs\naws_api/codepipeline poll_for_third_party_jobs","url":"aws_api/codepipeline.html#poll_for_third_party_jobs"},{"doc":"aws_api/codepipeline","title":"put_action_revision","content":"pub fn put_action_revision(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codepipeline.put_action_revision\naws_api/codepipeline put_action_revision","url":"aws_api/codepipeline.html#put_action_revision"},{"doc":"aws_api/codepipeline","title":"put_approval_result","content":"pub fn put_approval_result(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codepipeline.put_approval_result\naws_api/codepipeline put_approval_result","url":"aws_api/codepipeline.html#put_approval_result"},{"doc":"aws_api/codepipeline","title":"put_job_failure_result","content":"pub fn put_job_failure_result(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codepipeline.put_job_failure_result\naws_api/codepipeline put_job_failure_result","url":"aws_api/codepipeline.html#put_job_failure_result"},{"doc":"aws_api/codepipeline","title":"put_job_success_result","content":"pub fn put_job_success_result(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codepipeline.put_job_success_result\naws_api/codepipeline put_job_success_result","url":"aws_api/codepipeline.html#put_job_success_result"},{"doc":"aws_api/codepipeline","title":"put_third_party_job_failure_result","content":"pub fn put_third_party_job_failure_result(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codepipeline.put_third_party_job_failure_result\naws_api/codepipeline put_third_party_job_failure_result","url":"aws_api/codepipeline.html#put_third_party_job_failure_result"},{"doc":"aws_api/codepipeline","title":"put_third_party_job_success_result","content":"pub fn put_third_party_job_success_result(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codepipeline.put_third_party_job_success_result\naws_api/codepipeline put_third_party_job_success_result","url":"aws_api/codepipeline.html#put_third_party_job_success_result"},{"doc":"aws_api/codepipeline","title":"put_webhook","content":"pub fn put_webhook(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codepipeline.put_webhook\naws_api/codepipeline put_webhook","url":"aws_api/codepipeline.html#put_webhook"},{"doc":"aws_api/codepipeline","title":"register_webhook_with_third_party","content":"pub fn register_webhook_with_third_party(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codepipeline.register_webhook_with_third_party\naws_api/codepipeline register_webhook_with_third_party","url":"aws_api/codepipeline.html#register_webhook_with_third_party"},{"doc":"aws_api/codepipeline","title":"retry_stage_execution","content":"pub fn retry_stage_execution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codepipeline.retry_stage_execution\naws_api/codepipeline retry_stage_execution","url":"aws_api/codepipeline.html#retry_stage_execution"},{"doc":"aws_api/codepipeline","title":"rollback_stage","content":"pub fn rollback_stage(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codepipeline.rollback_stage\naws_api/codepipeline rollback_stage","url":"aws_api/codepipeline.html#rollback_stage"},{"doc":"aws_api/codepipeline","title":"start_pipeline_execution","content":"pub fn start_pipeline_execution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codepipeline.start_pipeline_execution\naws_api/codepipeline start_pipeline_execution","url":"aws_api/codepipeline.html#start_pipeline_execution"},{"doc":"aws_api/codepipeline","title":"stop_pipeline_execution","content":"pub fn stop_pipeline_execution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codepipeline.stop_pipeline_execution\naws_api/codepipeline stop_pipeline_execution","url":"aws_api/codepipeline.html#stop_pipeline_execution"},{"doc":"aws_api/codepipeline","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codepipeline.tag_resource\naws_api/codepipeline tag_resource","url":"aws_api/codepipeline.html#tag_resource"},{"doc":"aws_api/codepipeline","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codepipeline.untag_resource\naws_api/codepipeline untag_resource","url":"aws_api/codepipeline.html#untag_resource"},{"doc":"aws_api/codepipeline","title":"update_action_type","content":"pub fn update_action_type(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codepipeline.update_action_type\naws_api/codepipeline update_action_type","url":"aws_api/codepipeline.html#update_action_type"},{"doc":"aws_api/codepipeline","title":"update_pipeline","content":"pub fn update_pipeline(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codepipeline.update_pipeline\naws_api/codepipeline update_pipeline","url":"aws_api/codepipeline.html#update_pipeline"},{"doc":"aws_api/codepipeline","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/codepipeline.with_custom_endpoint\naws_api/codepipeline with_custom_endpoint","url":"aws_api/codepipeline.html#with_custom_endpoint"},{"doc":"aws_api/codepipeline","title":"aws_api/codepipeline","content":"","url":"aws_api/codepipeline.html"},{"doc":"aws_api/codestar","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/codestar.Client\naws_api/codestar Client","url":"aws_api/codestar.html#Client"},{"doc":"aws_api/codestar","title":"associate_team_member","content":"pub fn associate_team_member(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar.associate_team_member\naws_api/codestar associate_team_member","url":"aws_api/codestar.html#associate_team_member"},{"doc":"aws_api/codestar","title":"create_project","content":"pub fn create_project(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar.create_project\naws_api/codestar create_project","url":"aws_api/codestar.html#create_project"},{"doc":"aws_api/codestar","title":"create_user_profile","content":"pub fn create_user_profile(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar.create_user_profile\naws_api/codestar create_user_profile","url":"aws_api/codestar.html#create_user_profile"},{"doc":"aws_api/codestar","title":"delete_project","content":"pub fn delete_project(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar.delete_project\naws_api/codestar delete_project","url":"aws_api/codestar.html#delete_project"},{"doc":"aws_api/codestar","title":"delete_user_profile","content":"pub fn delete_user_profile(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar.delete_user_profile\naws_api/codestar delete_user_profile","url":"aws_api/codestar.html#delete_user_profile"},{"doc":"aws_api/codestar","title":"describe_project","content":"pub fn describe_project(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar.describe_project\naws_api/codestar describe_project","url":"aws_api/codestar.html#describe_project"},{"doc":"aws_api/codestar","title":"describe_user_profile","content":"pub fn describe_user_profile(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar.describe_user_profile\naws_api/codestar describe_user_profile","url":"aws_api/codestar.html#describe_user_profile"},{"doc":"aws_api/codestar","title":"disassociate_team_member","content":"pub fn disassociate_team_member(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar.disassociate_team_member\naws_api/codestar disassociate_team_member","url":"aws_api/codestar.html#disassociate_team_member"},{"doc":"aws_api/codestar","title":"list_projects","content":"pub fn list_projects(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar.list_projects\naws_api/codestar list_projects","url":"aws_api/codestar.html#list_projects"},{"doc":"aws_api/codestar","title":"list_resources","content":"pub fn list_resources(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar.list_resources\naws_api/codestar list_resources","url":"aws_api/codestar.html#list_resources"},{"doc":"aws_api/codestar","title":"list_tags_for_project","content":"pub fn list_tags_for_project(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar.list_tags_for_project\naws_api/codestar list_tags_for_project","url":"aws_api/codestar.html#list_tags_for_project"},{"doc":"aws_api/codestar","title":"list_team_members","content":"pub fn list_team_members(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar.list_team_members\naws_api/codestar list_team_members","url":"aws_api/codestar.html#list_team_members"},{"doc":"aws_api/codestar","title":"list_user_profiles","content":"pub fn list_user_profiles(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar.list_user_profiles\naws_api/codestar list_user_profiles","url":"aws_api/codestar.html#list_user_profiles"},{"doc":"aws_api/codestar","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/codestar.new\naws_api/codestar new","url":"aws_api/codestar.html#new"},{"doc":"aws_api/codestar","title":"tag_project","content":"pub fn tag_project(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar.tag_project\naws_api/codestar tag_project","url":"aws_api/codestar.html#tag_project"},{"doc":"aws_api/codestar","title":"untag_project","content":"pub fn untag_project(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar.untag_project\naws_api/codestar untag_project","url":"aws_api/codestar.html#untag_project"},{"doc":"aws_api/codestar","title":"update_project","content":"pub fn update_project(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar.update_project\naws_api/codestar update_project","url":"aws_api/codestar.html#update_project"},{"doc":"aws_api/codestar","title":"update_team_member","content":"pub fn update_team_member(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar.update_team_member\naws_api/codestar update_team_member","url":"aws_api/codestar.html#update_team_member"},{"doc":"aws_api/codestar","title":"update_user_profile","content":"pub fn update_user_profile(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar.update_user_profile\naws_api/codestar update_user_profile","url":"aws_api/codestar.html#update_user_profile"},{"doc":"aws_api/codestar","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/codestar.with_custom_endpoint\naws_api/codestar with_custom_endpoint","url":"aws_api/codestar.html#with_custom_endpoint"},{"doc":"aws_api/codestar","title":"aws_api/codestar","content":"","url":"aws_api/codestar.html"},{"doc":"aws_api/codestar_connections","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/codestar_connections.Client\naws_api/codestar_connections Client","url":"aws_api/codestar_connections.html#Client"},{"doc":"aws_api/codestar_connections","title":"create_connection","content":"pub fn create_connection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar_connections.create_connection\naws_api/codestar_connections create_connection","url":"aws_api/codestar_connections.html#create_connection"},{"doc":"aws_api/codestar_connections","title":"create_host","content":"pub fn create_host(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar_connections.create_host\naws_api/codestar_connections create_host","url":"aws_api/codestar_connections.html#create_host"},{"doc":"aws_api/codestar_connections","title":"create_repository_link","content":"pub fn create_repository_link(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar_connections.create_repository_link\naws_api/codestar_connections create_repository_link","url":"aws_api/codestar_connections.html#create_repository_link"},{"doc":"aws_api/codestar_connections","title":"create_sync_configuration","content":"pub fn create_sync_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar_connections.create_sync_configuration\naws_api/codestar_connections create_sync_configuration","url":"aws_api/codestar_connections.html#create_sync_configuration"},{"doc":"aws_api/codestar_connections","title":"delete_connection","content":"pub fn delete_connection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar_connections.delete_connection\naws_api/codestar_connections delete_connection","url":"aws_api/codestar_connections.html#delete_connection"},{"doc":"aws_api/codestar_connections","title":"delete_host","content":"pub fn delete_host(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar_connections.delete_host\naws_api/codestar_connections delete_host","url":"aws_api/codestar_connections.html#delete_host"},{"doc":"aws_api/codestar_connections","title":"delete_repository_link","content":"pub fn delete_repository_link(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar_connections.delete_repository_link\naws_api/codestar_connections delete_repository_link","url":"aws_api/codestar_connections.html#delete_repository_link"},{"doc":"aws_api/codestar_connections","title":"delete_sync_configuration","content":"pub fn delete_sync_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar_connections.delete_sync_configuration\naws_api/codestar_connections delete_sync_configuration","url":"aws_api/codestar_connections.html#delete_sync_configuration"},{"doc":"aws_api/codestar_connections","title":"get_connection","content":"pub fn get_connection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar_connections.get_connection\naws_api/codestar_connections get_connection","url":"aws_api/codestar_connections.html#get_connection"},{"doc":"aws_api/codestar_connections","title":"get_host","content":"pub fn get_host(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar_connections.get_host\naws_api/codestar_connections get_host","url":"aws_api/codestar_connections.html#get_host"},{"doc":"aws_api/codestar_connections","title":"get_repository_link","content":"pub fn get_repository_link(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar_connections.get_repository_link\naws_api/codestar_connections get_repository_link","url":"aws_api/codestar_connections.html#get_repository_link"},{"doc":"aws_api/codestar_connections","title":"get_repository_sync_status","content":"pub fn get_repository_sync_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar_connections.get_repository_sync_status\naws_api/codestar_connections get_repository_sync_status","url":"aws_api/codestar_connections.html#get_repository_sync_status"},{"doc":"aws_api/codestar_connections","title":"get_resource_sync_status","content":"pub fn get_resource_sync_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar_connections.get_resource_sync_status\naws_api/codestar_connections get_resource_sync_status","url":"aws_api/codestar_connections.html#get_resource_sync_status"},{"doc":"aws_api/codestar_connections","title":"get_sync_blocker_summary","content":"pub fn get_sync_blocker_summary(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar_connections.get_sync_blocker_summary\naws_api/codestar_connections get_sync_blocker_summary","url":"aws_api/codestar_connections.html#get_sync_blocker_summary"},{"doc":"aws_api/codestar_connections","title":"get_sync_configuration","content":"pub fn get_sync_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar_connections.get_sync_configuration\naws_api/codestar_connections get_sync_configuration","url":"aws_api/codestar_connections.html#get_sync_configuration"},{"doc":"aws_api/codestar_connections","title":"list_connections","content":"pub fn list_connections(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar_connections.list_connections\naws_api/codestar_connections list_connections","url":"aws_api/codestar_connections.html#list_connections"},{"doc":"aws_api/codestar_connections","title":"list_hosts","content":"pub fn list_hosts(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar_connections.list_hosts\naws_api/codestar_connections list_hosts","url":"aws_api/codestar_connections.html#list_hosts"},{"doc":"aws_api/codestar_connections","title":"list_repository_links","content":"pub fn list_repository_links(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar_connections.list_repository_links\naws_api/codestar_connections list_repository_links","url":"aws_api/codestar_connections.html#list_repository_links"},{"doc":"aws_api/codestar_connections","title":"list_repository_sync_definitions","content":"pub fn list_repository_sync_definitions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar_connections.list_repository_sync_definitions\naws_api/codestar_connections list_repository_sync_definitions","url":"aws_api/codestar_connections.html#list_repository_sync_definitions"},{"doc":"aws_api/codestar_connections","title":"list_sync_configurations","content":"pub fn list_sync_configurations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar_connections.list_sync_configurations\naws_api/codestar_connections list_sync_configurations","url":"aws_api/codestar_connections.html#list_sync_configurations"},{"doc":"aws_api/codestar_connections","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar_connections.list_tags_for_resource\naws_api/codestar_connections list_tags_for_resource","url":"aws_api/codestar_connections.html#list_tags_for_resource"},{"doc":"aws_api/codestar_connections","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/codestar_connections.new\naws_api/codestar_connections new","url":"aws_api/codestar_connections.html#new"},{"doc":"aws_api/codestar_connections","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar_connections.tag_resource\naws_api/codestar_connections tag_resource","url":"aws_api/codestar_connections.html#tag_resource"},{"doc":"aws_api/codestar_connections","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar_connections.untag_resource\naws_api/codestar_connections untag_resource","url":"aws_api/codestar_connections.html#untag_resource"},{"doc":"aws_api/codestar_connections","title":"update_host","content":"pub fn update_host(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar_connections.update_host\naws_api/codestar_connections update_host","url":"aws_api/codestar_connections.html#update_host"},{"doc":"aws_api/codestar_connections","title":"update_repository_link","content":"pub fn update_repository_link(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar_connections.update_repository_link\naws_api/codestar_connections update_repository_link","url":"aws_api/codestar_connections.html#update_repository_link"},{"doc":"aws_api/codestar_connections","title":"update_sync_blocker","content":"pub fn update_sync_blocker(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar_connections.update_sync_blocker\naws_api/codestar_connections update_sync_blocker","url":"aws_api/codestar_connections.html#update_sync_blocker"},{"doc":"aws_api/codestar_connections","title":"update_sync_configuration","content":"pub fn update_sync_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar_connections.update_sync_configuration\naws_api/codestar_connections update_sync_configuration","url":"aws_api/codestar_connections.html#update_sync_configuration"},{"doc":"aws_api/codestar_connections","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/codestar_connections.with_custom_endpoint\naws_api/codestar_connections with_custom_endpoint","url":"aws_api/codestar_connections.html#with_custom_endpoint"},{"doc":"aws_api/codestar_connections","title":"aws_api/codestar_connections","content":"","url":"aws_api/codestar_connections.html"},{"doc":"aws_api/codestar_notifications","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/codestar_notifications.Client\naws_api/codestar_notifications Client","url":"aws_api/codestar_notifications.html#Client"},{"doc":"aws_api/codestar_notifications","title":"create_notification_rule","content":"pub fn create_notification_rule(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar_notifications.create_notification_rule\naws_api/codestar_notifications create_notification_rule","url":"aws_api/codestar_notifications.html#create_notification_rule"},{"doc":"aws_api/codestar_notifications","title":"delete_notification_rule","content":"pub fn delete_notification_rule(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar_notifications.delete_notification_rule\naws_api/codestar_notifications delete_notification_rule","url":"aws_api/codestar_notifications.html#delete_notification_rule"},{"doc":"aws_api/codestar_notifications","title":"delete_target","content":"pub fn delete_target(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar_notifications.delete_target\naws_api/codestar_notifications delete_target","url":"aws_api/codestar_notifications.html#delete_target"},{"doc":"aws_api/codestar_notifications","title":"describe_notification_rule","content":"pub fn describe_notification_rule(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar_notifications.describe_notification_rule\naws_api/codestar_notifications describe_notification_rule","url":"aws_api/codestar_notifications.html#describe_notification_rule"},{"doc":"aws_api/codestar_notifications","title":"list_event_types","content":"pub fn list_event_types(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar_notifications.list_event_types\naws_api/codestar_notifications list_event_types","url":"aws_api/codestar_notifications.html#list_event_types"},{"doc":"aws_api/codestar_notifications","title":"list_notification_rules","content":"pub fn list_notification_rules(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar_notifications.list_notification_rules\naws_api/codestar_notifications list_notification_rules","url":"aws_api/codestar_notifications.html#list_notification_rules"},{"doc":"aws_api/codestar_notifications","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar_notifications.list_tags_for_resource\naws_api/codestar_notifications list_tags_for_resource","url":"aws_api/codestar_notifications.html#list_tags_for_resource"},{"doc":"aws_api/codestar_notifications","title":"list_targets","content":"pub fn list_targets(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar_notifications.list_targets\naws_api/codestar_notifications list_targets","url":"aws_api/codestar_notifications.html#list_targets"},{"doc":"aws_api/codestar_notifications","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/codestar_notifications.new\naws_api/codestar_notifications new","url":"aws_api/codestar_notifications.html#new"},{"doc":"aws_api/codestar_notifications","title":"subscribe","content":"pub fn subscribe(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar_notifications.subscribe\naws_api/codestar_notifications subscribe","url":"aws_api/codestar_notifications.html#subscribe"},{"doc":"aws_api/codestar_notifications","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar_notifications.tag_resource\naws_api/codestar_notifications tag_resource","url":"aws_api/codestar_notifications.html#tag_resource"},{"doc":"aws_api/codestar_notifications","title":"unsubscribe","content":"pub fn unsubscribe(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar_notifications.unsubscribe\naws_api/codestar_notifications unsubscribe","url":"aws_api/codestar_notifications.html#unsubscribe"},{"doc":"aws_api/codestar_notifications","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar_notifications.untag_resource\naws_api/codestar_notifications untag_resource","url":"aws_api/codestar_notifications.html#untag_resource"},{"doc":"aws_api/codestar_notifications","title":"update_notification_rule","content":"pub fn update_notification_rule(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/codestar_notifications.update_notification_rule\naws_api/codestar_notifications update_notification_rule","url":"aws_api/codestar_notifications.html#update_notification_rule"},{"doc":"aws_api/codestar_notifications","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/codestar_notifications.with_custom_endpoint\naws_api/codestar_notifications with_custom_endpoint","url":"aws_api/codestar_notifications.html#with_custom_endpoint"},{"doc":"aws_api/codestar_notifications","title":"aws_api/codestar_notifications","content":"","url":"aws_api/codestar_notifications.html"},{"doc":"aws_api/cognito_identity","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/cognito_identity.Client\naws_api/cognito_identity Client","url":"aws_api/cognito_identity.html#Client"},{"doc":"aws_api/cognito_identity","title":"create_identity_pool","content":"pub fn create_identity_pool(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity.create_identity_pool\naws_api/cognito_identity create_identity_pool","url":"aws_api/cognito_identity.html#create_identity_pool"},{"doc":"aws_api/cognito_identity","title":"delete_identities","content":"pub fn delete_identities(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity.delete_identities\naws_api/cognito_identity delete_identities","url":"aws_api/cognito_identity.html#delete_identities"},{"doc":"aws_api/cognito_identity","title":"delete_identity_pool","content":"pub fn delete_identity_pool(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity.delete_identity_pool\naws_api/cognito_identity delete_identity_pool","url":"aws_api/cognito_identity.html#delete_identity_pool"},{"doc":"aws_api/cognito_identity","title":"describe_identity","content":"pub fn describe_identity(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity.describe_identity\naws_api/cognito_identity describe_identity","url":"aws_api/cognito_identity.html#describe_identity"},{"doc":"aws_api/cognito_identity","title":"describe_identity_pool","content":"pub fn describe_identity_pool(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity.describe_identity_pool\naws_api/cognito_identity describe_identity_pool","url":"aws_api/cognito_identity.html#describe_identity_pool"},{"doc":"aws_api/cognito_identity","title":"get_credentials_for_identity","content":"pub fn get_credentials_for_identity(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity.get_credentials_for_identity\naws_api/cognito_identity get_credentials_for_identity","url":"aws_api/cognito_identity.html#get_credentials_for_identity"},{"doc":"aws_api/cognito_identity","title":"get_id","content":"pub fn get_id(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity.get_id\naws_api/cognito_identity get_id","url":"aws_api/cognito_identity.html#get_id"},{"doc":"aws_api/cognito_identity","title":"get_identity_pool_roles","content":"pub fn get_identity_pool_roles(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity.get_identity_pool_roles\naws_api/cognito_identity get_identity_pool_roles","url":"aws_api/cognito_identity.html#get_identity_pool_roles"},{"doc":"aws_api/cognito_identity","title":"get_open_id_token","content":"pub fn get_open_id_token(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity.get_open_id_token\naws_api/cognito_identity get_open_id_token","url":"aws_api/cognito_identity.html#get_open_id_token"},{"doc":"aws_api/cognito_identity","title":"get_open_id_token_for_developer_identity","content":"pub fn get_open_id_token_for_developer_identity(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity.get_open_id_token_for_developer_identity\naws_api/cognito_identity get_open_id_token_for_developer_identity","url":"aws_api/cognito_identity.html#get_open_id_token_for_developer_identity"},{"doc":"aws_api/cognito_identity","title":"get_principal_tag_attribute_map","content":"pub fn get_principal_tag_attribute_map(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity.get_principal_tag_attribute_map\naws_api/cognito_identity get_principal_tag_attribute_map","url":"aws_api/cognito_identity.html#get_principal_tag_attribute_map"},{"doc":"aws_api/cognito_identity","title":"list_identities","content":"pub fn list_identities(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity.list_identities\naws_api/cognito_identity list_identities","url":"aws_api/cognito_identity.html#list_identities"},{"doc":"aws_api/cognito_identity","title":"list_identity_pools","content":"pub fn list_identity_pools(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity.list_identity_pools\naws_api/cognito_identity list_identity_pools","url":"aws_api/cognito_identity.html#list_identity_pools"},{"doc":"aws_api/cognito_identity","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity.list_tags_for_resource\naws_api/cognito_identity list_tags_for_resource","url":"aws_api/cognito_identity.html#list_tags_for_resource"},{"doc":"aws_api/cognito_identity","title":"lookup_developer_identity","content":"pub fn lookup_developer_identity(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity.lookup_developer_identity\naws_api/cognito_identity lookup_developer_identity","url":"aws_api/cognito_identity.html#lookup_developer_identity"},{"doc":"aws_api/cognito_identity","title":"merge_developer_identities","content":"pub fn merge_developer_identities(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity.merge_developer_identities\naws_api/cognito_identity merge_developer_identities","url":"aws_api/cognito_identity.html#merge_developer_identities"},{"doc":"aws_api/cognito_identity","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/cognito_identity.new\naws_api/cognito_identity new","url":"aws_api/cognito_identity.html#new"},{"doc":"aws_api/cognito_identity","title":"set_identity_pool_roles","content":"pub fn set_identity_pool_roles(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity.set_identity_pool_roles\naws_api/cognito_identity set_identity_pool_roles","url":"aws_api/cognito_identity.html#set_identity_pool_roles"},{"doc":"aws_api/cognito_identity","title":"set_principal_tag_attribute_map","content":"pub fn set_principal_tag_attribute_map(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity.set_principal_tag_attribute_map\naws_api/cognito_identity set_principal_tag_attribute_map","url":"aws_api/cognito_identity.html#set_principal_tag_attribute_map"},{"doc":"aws_api/cognito_identity","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity.tag_resource\naws_api/cognito_identity tag_resource","url":"aws_api/cognito_identity.html#tag_resource"},{"doc":"aws_api/cognito_identity","title":"unlink_developer_identity","content":"pub fn unlink_developer_identity(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity.unlink_developer_identity\naws_api/cognito_identity unlink_developer_identity","url":"aws_api/cognito_identity.html#unlink_developer_identity"},{"doc":"aws_api/cognito_identity","title":"unlink_identity","content":"pub fn unlink_identity(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity.unlink_identity\naws_api/cognito_identity unlink_identity","url":"aws_api/cognito_identity.html#unlink_identity"},{"doc":"aws_api/cognito_identity","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity.untag_resource\naws_api/cognito_identity untag_resource","url":"aws_api/cognito_identity.html#untag_resource"},{"doc":"aws_api/cognito_identity","title":"update_identity_pool","content":"pub fn update_identity_pool(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity.update_identity_pool\naws_api/cognito_identity update_identity_pool","url":"aws_api/cognito_identity.html#update_identity_pool"},{"doc":"aws_api/cognito_identity","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/cognito_identity.with_custom_endpoint\naws_api/cognito_identity with_custom_endpoint","url":"aws_api/cognito_identity.html#with_custom_endpoint"},{"doc":"aws_api/cognito_identity","title":"aws_api/cognito_identity","content":"","url":"aws_api/cognito_identity.html"},{"doc":"aws_api/cognito_identity_provider","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/cognito_identity_provider.Client\naws_api/cognito_identity_provider Client","url":"aws_api/cognito_identity_provider.html#Client"},{"doc":"aws_api/cognito_identity_provider","title":"add_custom_attributes","content":"pub fn add_custom_attributes(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.add_custom_attributes\naws_api/cognito_identity_provider add_custom_attributes","url":"aws_api/cognito_identity_provider.html#add_custom_attributes"},{"doc":"aws_api/cognito_identity_provider","title":"admin_add_user_to_group","content":"pub fn admin_add_user_to_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.admin_add_user_to_group\naws_api/cognito_identity_provider admin_add_user_to_group","url":"aws_api/cognito_identity_provider.html#admin_add_user_to_group"},{"doc":"aws_api/cognito_identity_provider","title":"admin_confirm_sign_up","content":"pub fn admin_confirm_sign_up(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.admin_confirm_sign_up\naws_api/cognito_identity_provider admin_confirm_sign_up","url":"aws_api/cognito_identity_provider.html#admin_confirm_sign_up"},{"doc":"aws_api/cognito_identity_provider","title":"admin_create_user","content":"pub fn admin_create_user(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.admin_create_user\naws_api/cognito_identity_provider admin_create_user","url":"aws_api/cognito_identity_provider.html#admin_create_user"},{"doc":"aws_api/cognito_identity_provider","title":"admin_delete_user","content":"pub fn admin_delete_user(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.admin_delete_user\naws_api/cognito_identity_provider admin_delete_user","url":"aws_api/cognito_identity_provider.html#admin_delete_user"},{"doc":"aws_api/cognito_identity_provider","title":"admin_delete_user_attributes","content":"pub fn admin_delete_user_attributes(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.admin_delete_user_attributes\naws_api/cognito_identity_provider admin_delete_user_attributes","url":"aws_api/cognito_identity_provider.html#admin_delete_user_attributes"},{"doc":"aws_api/cognito_identity_provider","title":"admin_disable_provider_for_user","content":"pub fn admin_disable_provider_for_user(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.admin_disable_provider_for_user\naws_api/cognito_identity_provider admin_disable_provider_for_user","url":"aws_api/cognito_identity_provider.html#admin_disable_provider_for_user"},{"doc":"aws_api/cognito_identity_provider","title":"admin_disable_user","content":"pub fn admin_disable_user(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.admin_disable_user\naws_api/cognito_identity_provider admin_disable_user","url":"aws_api/cognito_identity_provider.html#admin_disable_user"},{"doc":"aws_api/cognito_identity_provider","title":"admin_enable_user","content":"pub fn admin_enable_user(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.admin_enable_user\naws_api/cognito_identity_provider admin_enable_user","url":"aws_api/cognito_identity_provider.html#admin_enable_user"},{"doc":"aws_api/cognito_identity_provider","title":"admin_forget_device","content":"pub fn admin_forget_device(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.admin_forget_device\naws_api/cognito_identity_provider admin_forget_device","url":"aws_api/cognito_identity_provider.html#admin_forget_device"},{"doc":"aws_api/cognito_identity_provider","title":"admin_get_device","content":"pub fn admin_get_device(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.admin_get_device\naws_api/cognito_identity_provider admin_get_device","url":"aws_api/cognito_identity_provider.html#admin_get_device"},{"doc":"aws_api/cognito_identity_provider","title":"admin_get_user","content":"pub fn admin_get_user(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.admin_get_user\naws_api/cognito_identity_provider admin_get_user","url":"aws_api/cognito_identity_provider.html#admin_get_user"},{"doc":"aws_api/cognito_identity_provider","title":"admin_initiate_auth","content":"pub fn admin_initiate_auth(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.admin_initiate_auth\naws_api/cognito_identity_provider admin_initiate_auth","url":"aws_api/cognito_identity_provider.html#admin_initiate_auth"},{"doc":"aws_api/cognito_identity_provider","title":"admin_link_provider_for_user","content":"pub fn admin_link_provider_for_user(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.admin_link_provider_for_user\naws_api/cognito_identity_provider admin_link_provider_for_user","url":"aws_api/cognito_identity_provider.html#admin_link_provider_for_user"},{"doc":"aws_api/cognito_identity_provider","title":"admin_list_devices","content":"pub fn admin_list_devices(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.admin_list_devices\naws_api/cognito_identity_provider admin_list_devices","url":"aws_api/cognito_identity_provider.html#admin_list_devices"},{"doc":"aws_api/cognito_identity_provider","title":"admin_list_groups_for_user","content":"pub fn admin_list_groups_for_user(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.admin_list_groups_for_user\naws_api/cognito_identity_provider admin_list_groups_for_user","url":"aws_api/cognito_identity_provider.html#admin_list_groups_for_user"},{"doc":"aws_api/cognito_identity_provider","title":"admin_list_user_auth_events","content":"pub fn admin_list_user_auth_events(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.admin_list_user_auth_events\naws_api/cognito_identity_provider admin_list_user_auth_events","url":"aws_api/cognito_identity_provider.html#admin_list_user_auth_events"},{"doc":"aws_api/cognito_identity_provider","title":"admin_remove_user_from_group","content":"pub fn admin_remove_user_from_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.admin_remove_user_from_group\naws_api/cognito_identity_provider admin_remove_user_from_group","url":"aws_api/cognito_identity_provider.html#admin_remove_user_from_group"},{"doc":"aws_api/cognito_identity_provider","title":"admin_reset_user_password","content":"pub fn admin_reset_user_password(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.admin_reset_user_password\naws_api/cognito_identity_provider admin_reset_user_password","url":"aws_api/cognito_identity_provider.html#admin_reset_user_password"},{"doc":"aws_api/cognito_identity_provider","title":"admin_respond_to_auth_challenge","content":"pub fn admin_respond_to_auth_challenge(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.admin_respond_to_auth_challenge\naws_api/cognito_identity_provider admin_respond_to_auth_challenge","url":"aws_api/cognito_identity_provider.html#admin_respond_to_auth_challenge"},{"doc":"aws_api/cognito_identity_provider","title":"admin_set_user_mfa_preference","content":"pub fn admin_set_user_mfa_preference(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.admin_set_user_mfa_preference\naws_api/cognito_identity_provider admin_set_user_mfa_preference","url":"aws_api/cognito_identity_provider.html#admin_set_user_mfa_preference"},{"doc":"aws_api/cognito_identity_provider","title":"admin_set_user_password","content":"pub fn admin_set_user_password(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.admin_set_user_password\naws_api/cognito_identity_provider admin_set_user_password","url":"aws_api/cognito_identity_provider.html#admin_set_user_password"},{"doc":"aws_api/cognito_identity_provider","title":"admin_set_user_settings","content":"pub fn admin_set_user_settings(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.admin_set_user_settings\naws_api/cognito_identity_provider admin_set_user_settings","url":"aws_api/cognito_identity_provider.html#admin_set_user_settings"},{"doc":"aws_api/cognito_identity_provider","title":"admin_update_auth_event_feedback","content":"pub fn admin_update_auth_event_feedback(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.admin_update_auth_event_feedback\naws_api/cognito_identity_provider admin_update_auth_event_feedback","url":"aws_api/cognito_identity_provider.html#admin_update_auth_event_feedback"},{"doc":"aws_api/cognito_identity_provider","title":"admin_update_device_status","content":"pub fn admin_update_device_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.admin_update_device_status\naws_api/cognito_identity_provider admin_update_device_status","url":"aws_api/cognito_identity_provider.html#admin_update_device_status"},{"doc":"aws_api/cognito_identity_provider","title":"admin_update_user_attributes","content":"pub fn admin_update_user_attributes(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.admin_update_user_attributes\naws_api/cognito_identity_provider admin_update_user_attributes","url":"aws_api/cognito_identity_provider.html#admin_update_user_attributes"},{"doc":"aws_api/cognito_identity_provider","title":"admin_user_global_sign_out","content":"pub fn admin_user_global_sign_out(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.admin_user_global_sign_out\naws_api/cognito_identity_provider admin_user_global_sign_out","url":"aws_api/cognito_identity_provider.html#admin_user_global_sign_out"},{"doc":"aws_api/cognito_identity_provider","title":"associate_software_token","content":"pub fn associate_software_token(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.associate_software_token\naws_api/cognito_identity_provider associate_software_token","url":"aws_api/cognito_identity_provider.html#associate_software_token"},{"doc":"aws_api/cognito_identity_provider","title":"change_password","content":"pub fn change_password(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.change_password\naws_api/cognito_identity_provider change_password","url":"aws_api/cognito_identity_provider.html#change_password"},{"doc":"aws_api/cognito_identity_provider","title":"confirm_device","content":"pub fn confirm_device(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.confirm_device\naws_api/cognito_identity_provider confirm_device","url":"aws_api/cognito_identity_provider.html#confirm_device"},{"doc":"aws_api/cognito_identity_provider","title":"confirm_forgot_password","content":"pub fn confirm_forgot_password(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.confirm_forgot_password\naws_api/cognito_identity_provider confirm_forgot_password","url":"aws_api/cognito_identity_provider.html#confirm_forgot_password"},{"doc":"aws_api/cognito_identity_provider","title":"confirm_sign_up","content":"pub fn confirm_sign_up(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.confirm_sign_up\naws_api/cognito_identity_provider confirm_sign_up","url":"aws_api/cognito_identity_provider.html#confirm_sign_up"},{"doc":"aws_api/cognito_identity_provider","title":"create_group","content":"pub fn create_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.create_group\naws_api/cognito_identity_provider create_group","url":"aws_api/cognito_identity_provider.html#create_group"},{"doc":"aws_api/cognito_identity_provider","title":"create_identity_provider","content":"pub fn create_identity_provider(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.create_identity_provider\naws_api/cognito_identity_provider create_identity_provider","url":"aws_api/cognito_identity_provider.html#create_identity_provider"},{"doc":"aws_api/cognito_identity_provider","title":"create_resource_server","content":"pub fn create_resource_server(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.create_resource_server\naws_api/cognito_identity_provider create_resource_server","url":"aws_api/cognito_identity_provider.html#create_resource_server"},{"doc":"aws_api/cognito_identity_provider","title":"create_user_import_job","content":"pub fn create_user_import_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.create_user_import_job\naws_api/cognito_identity_provider create_user_import_job","url":"aws_api/cognito_identity_provider.html#create_user_import_job"},{"doc":"aws_api/cognito_identity_provider","title":"create_user_pool","content":"pub fn create_user_pool(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.create_user_pool\naws_api/cognito_identity_provider create_user_pool","url":"aws_api/cognito_identity_provider.html#create_user_pool"},{"doc":"aws_api/cognito_identity_provider","title":"create_user_pool_client","content":"pub fn create_user_pool_client(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.create_user_pool_client\naws_api/cognito_identity_provider create_user_pool_client","url":"aws_api/cognito_identity_provider.html#create_user_pool_client"},{"doc":"aws_api/cognito_identity_provider","title":"create_user_pool_domain","content":"pub fn create_user_pool_domain(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.create_user_pool_domain\naws_api/cognito_identity_provider create_user_pool_domain","url":"aws_api/cognito_identity_provider.html#create_user_pool_domain"},{"doc":"aws_api/cognito_identity_provider","title":"delete_group","content":"pub fn delete_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.delete_group\naws_api/cognito_identity_provider delete_group","url":"aws_api/cognito_identity_provider.html#delete_group"},{"doc":"aws_api/cognito_identity_provider","title":"delete_identity_provider","content":"pub fn delete_identity_provider(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.delete_identity_provider\naws_api/cognito_identity_provider delete_identity_provider","url":"aws_api/cognito_identity_provider.html#delete_identity_provider"},{"doc":"aws_api/cognito_identity_provider","title":"delete_resource_server","content":"pub fn delete_resource_server(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.delete_resource_server\naws_api/cognito_identity_provider delete_resource_server","url":"aws_api/cognito_identity_provider.html#delete_resource_server"},{"doc":"aws_api/cognito_identity_provider","title":"delete_user","content":"pub fn delete_user(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.delete_user\naws_api/cognito_identity_provider delete_user","url":"aws_api/cognito_identity_provider.html#delete_user"},{"doc":"aws_api/cognito_identity_provider","title":"delete_user_attributes","content":"pub fn delete_user_attributes(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.delete_user_attributes\naws_api/cognito_identity_provider delete_user_attributes","url":"aws_api/cognito_identity_provider.html#delete_user_attributes"},{"doc":"aws_api/cognito_identity_provider","title":"delete_user_pool","content":"pub fn delete_user_pool(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.delete_user_pool\naws_api/cognito_identity_provider delete_user_pool","url":"aws_api/cognito_identity_provider.html#delete_user_pool"},{"doc":"aws_api/cognito_identity_provider","title":"delete_user_pool_client","content":"pub fn delete_user_pool_client(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.delete_user_pool_client\naws_api/cognito_identity_provider delete_user_pool_client","url":"aws_api/cognito_identity_provider.html#delete_user_pool_client"},{"doc":"aws_api/cognito_identity_provider","title":"delete_user_pool_domain","content":"pub fn delete_user_pool_domain(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.delete_user_pool_domain\naws_api/cognito_identity_provider delete_user_pool_domain","url":"aws_api/cognito_identity_provider.html#delete_user_pool_domain"},{"doc":"aws_api/cognito_identity_provider","title":"describe_identity_provider","content":"pub fn describe_identity_provider(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.describe_identity_provider\naws_api/cognito_identity_provider describe_identity_provider","url":"aws_api/cognito_identity_provider.html#describe_identity_provider"},{"doc":"aws_api/cognito_identity_provider","title":"describe_resource_server","content":"pub fn describe_resource_server(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.describe_resource_server\naws_api/cognito_identity_provider describe_resource_server","url":"aws_api/cognito_identity_provider.html#describe_resource_server"},{"doc":"aws_api/cognito_identity_provider","title":"describe_risk_configuration","content":"pub fn describe_risk_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.describe_risk_configuration\naws_api/cognito_identity_provider describe_risk_configuration","url":"aws_api/cognito_identity_provider.html#describe_risk_configuration"},{"doc":"aws_api/cognito_identity_provider","title":"describe_user_import_job","content":"pub fn describe_user_import_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.describe_user_import_job\naws_api/cognito_identity_provider describe_user_import_job","url":"aws_api/cognito_identity_provider.html#describe_user_import_job"},{"doc":"aws_api/cognito_identity_provider","title":"describe_user_pool","content":"pub fn describe_user_pool(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.describe_user_pool\naws_api/cognito_identity_provider describe_user_pool","url":"aws_api/cognito_identity_provider.html#describe_user_pool"},{"doc":"aws_api/cognito_identity_provider","title":"describe_user_pool_client","content":"pub fn describe_user_pool_client(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.describe_user_pool_client\naws_api/cognito_identity_provider describe_user_pool_client","url":"aws_api/cognito_identity_provider.html#describe_user_pool_client"},{"doc":"aws_api/cognito_identity_provider","title":"describe_user_pool_domain","content":"pub fn describe_user_pool_domain(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.describe_user_pool_domain\naws_api/cognito_identity_provider describe_user_pool_domain","url":"aws_api/cognito_identity_provider.html#describe_user_pool_domain"},{"doc":"aws_api/cognito_identity_provider","title":"forget_device","content":"pub fn forget_device(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.forget_device\naws_api/cognito_identity_provider forget_device","url":"aws_api/cognito_identity_provider.html#forget_device"},{"doc":"aws_api/cognito_identity_provider","title":"forgot_password","content":"pub fn forgot_password(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.forgot_password\naws_api/cognito_identity_provider forgot_password","url":"aws_api/cognito_identity_provider.html#forgot_password"},{"doc":"aws_api/cognito_identity_provider","title":"get_csv_header","content":"pub fn get_csv_header(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.get_csv_header\naws_api/cognito_identity_provider get_csv_header","url":"aws_api/cognito_identity_provider.html#get_csv_header"},{"doc":"aws_api/cognito_identity_provider","title":"get_device","content":"pub fn get_device(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.get_device\naws_api/cognito_identity_provider get_device","url":"aws_api/cognito_identity_provider.html#get_device"},{"doc":"aws_api/cognito_identity_provider","title":"get_group","content":"pub fn get_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.get_group\naws_api/cognito_identity_provider get_group","url":"aws_api/cognito_identity_provider.html#get_group"},{"doc":"aws_api/cognito_identity_provider","title":"get_identity_provider_by_identifier","content":"pub fn get_identity_provider_by_identifier(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.get_identity_provider_by_identifier\naws_api/cognito_identity_provider get_identity_provider_by_identifier","url":"aws_api/cognito_identity_provider.html#get_identity_provider_by_identifier"},{"doc":"aws_api/cognito_identity_provider","title":"get_log_delivery_configuration","content":"pub fn get_log_delivery_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.get_log_delivery_configuration\naws_api/cognito_identity_provider get_log_delivery_configuration","url":"aws_api/cognito_identity_provider.html#get_log_delivery_configuration"},{"doc":"aws_api/cognito_identity_provider","title":"get_signing_certificate","content":"pub fn get_signing_certificate(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.get_signing_certificate\naws_api/cognito_identity_provider get_signing_certificate","url":"aws_api/cognito_identity_provider.html#get_signing_certificate"},{"doc":"aws_api/cognito_identity_provider","title":"get_ui_customization","content":"pub fn get_ui_customization(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.get_ui_customization\naws_api/cognito_identity_provider get_ui_customization","url":"aws_api/cognito_identity_provider.html#get_ui_customization"},{"doc":"aws_api/cognito_identity_provider","title":"get_user","content":"pub fn get_user(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.get_user\naws_api/cognito_identity_provider get_user","url":"aws_api/cognito_identity_provider.html#get_user"},{"doc":"aws_api/cognito_identity_provider","title":"get_user_attribute_verification_code","content":"pub fn get_user_attribute_verification_code(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.get_user_attribute_verification_code\naws_api/cognito_identity_provider get_user_attribute_verification_code","url":"aws_api/cognito_identity_provider.html#get_user_attribute_verification_code"},{"doc":"aws_api/cognito_identity_provider","title":"get_user_pool_mfa_config","content":"pub fn get_user_pool_mfa_config(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.get_user_pool_mfa_config\naws_api/cognito_identity_provider get_user_pool_mfa_config","url":"aws_api/cognito_identity_provider.html#get_user_pool_mfa_config"},{"doc":"aws_api/cognito_identity_provider","title":"global_sign_out","content":"pub fn global_sign_out(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.global_sign_out\naws_api/cognito_identity_provider global_sign_out","url":"aws_api/cognito_identity_provider.html#global_sign_out"},{"doc":"aws_api/cognito_identity_provider","title":"initiate_auth","content":"pub fn initiate_auth(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.initiate_auth\naws_api/cognito_identity_provider initiate_auth","url":"aws_api/cognito_identity_provider.html#initiate_auth"},{"doc":"aws_api/cognito_identity_provider","title":"list_devices","content":"pub fn list_devices(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.list_devices\naws_api/cognito_identity_provider list_devices","url":"aws_api/cognito_identity_provider.html#list_devices"},{"doc":"aws_api/cognito_identity_provider","title":"list_groups","content":"pub fn list_groups(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.list_groups\naws_api/cognito_identity_provider list_groups","url":"aws_api/cognito_identity_provider.html#list_groups"},{"doc":"aws_api/cognito_identity_provider","title":"list_identity_providers","content":"pub fn list_identity_providers(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.list_identity_providers\naws_api/cognito_identity_provider list_identity_providers","url":"aws_api/cognito_identity_provider.html#list_identity_providers"},{"doc":"aws_api/cognito_identity_provider","title":"list_resource_servers","content":"pub fn list_resource_servers(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.list_resource_servers\naws_api/cognito_identity_provider list_resource_servers","url":"aws_api/cognito_identity_provider.html#list_resource_servers"},{"doc":"aws_api/cognito_identity_provider","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.list_tags_for_resource\naws_api/cognito_identity_provider list_tags_for_resource","url":"aws_api/cognito_identity_provider.html#list_tags_for_resource"},{"doc":"aws_api/cognito_identity_provider","title":"list_user_import_jobs","content":"pub fn list_user_import_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.list_user_import_jobs\naws_api/cognito_identity_provider list_user_import_jobs","url":"aws_api/cognito_identity_provider.html#list_user_import_jobs"},{"doc":"aws_api/cognito_identity_provider","title":"list_user_pool_clients","content":"pub fn list_user_pool_clients(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.list_user_pool_clients\naws_api/cognito_identity_provider list_user_pool_clients","url":"aws_api/cognito_identity_provider.html#list_user_pool_clients"},{"doc":"aws_api/cognito_identity_provider","title":"list_user_pools","content":"pub fn list_user_pools(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.list_user_pools\naws_api/cognito_identity_provider list_user_pools","url":"aws_api/cognito_identity_provider.html#list_user_pools"},{"doc":"aws_api/cognito_identity_provider","title":"list_users","content":"pub fn list_users(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.list_users\naws_api/cognito_identity_provider list_users","url":"aws_api/cognito_identity_provider.html#list_users"},{"doc":"aws_api/cognito_identity_provider","title":"list_users_in_group","content":"pub fn list_users_in_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.list_users_in_group\naws_api/cognito_identity_provider list_users_in_group","url":"aws_api/cognito_identity_provider.html#list_users_in_group"},{"doc":"aws_api/cognito_identity_provider","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/cognito_identity_provider.new\naws_api/cognito_identity_provider new","url":"aws_api/cognito_identity_provider.html#new"},{"doc":"aws_api/cognito_identity_provider","title":"resend_confirmation_code","content":"pub fn resend_confirmation_code(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.resend_confirmation_code\naws_api/cognito_identity_provider resend_confirmation_code","url":"aws_api/cognito_identity_provider.html#resend_confirmation_code"},{"doc":"aws_api/cognito_identity_provider","title":"respond_to_auth_challenge","content":"pub fn respond_to_auth_challenge(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.respond_to_auth_challenge\naws_api/cognito_identity_provider respond_to_auth_challenge","url":"aws_api/cognito_identity_provider.html#respond_to_auth_challenge"},{"doc":"aws_api/cognito_identity_provider","title":"revoke_token","content":"pub fn revoke_token(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.revoke_token\naws_api/cognito_identity_provider revoke_token","url":"aws_api/cognito_identity_provider.html#revoke_token"},{"doc":"aws_api/cognito_identity_provider","title":"set_log_delivery_configuration","content":"pub fn set_log_delivery_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.set_log_delivery_configuration\naws_api/cognito_identity_provider set_log_delivery_configuration","url":"aws_api/cognito_identity_provider.html#set_log_delivery_configuration"},{"doc":"aws_api/cognito_identity_provider","title":"set_risk_configuration","content":"pub fn set_risk_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.set_risk_configuration\naws_api/cognito_identity_provider set_risk_configuration","url":"aws_api/cognito_identity_provider.html#set_risk_configuration"},{"doc":"aws_api/cognito_identity_provider","title":"set_ui_customization","content":"pub fn set_ui_customization(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.set_ui_customization\naws_api/cognito_identity_provider set_ui_customization","url":"aws_api/cognito_identity_provider.html#set_ui_customization"},{"doc":"aws_api/cognito_identity_provider","title":"set_user_mfa_preference","content":"pub fn set_user_mfa_preference(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.set_user_mfa_preference\naws_api/cognito_identity_provider set_user_mfa_preference","url":"aws_api/cognito_identity_provider.html#set_user_mfa_preference"},{"doc":"aws_api/cognito_identity_provider","title":"set_user_pool_mfa_config","content":"pub fn set_user_pool_mfa_config(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.set_user_pool_mfa_config\naws_api/cognito_identity_provider set_user_pool_mfa_config","url":"aws_api/cognito_identity_provider.html#set_user_pool_mfa_config"},{"doc":"aws_api/cognito_identity_provider","title":"set_user_settings","content":"pub fn set_user_settings(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.set_user_settings\naws_api/cognito_identity_provider set_user_settings","url":"aws_api/cognito_identity_provider.html#set_user_settings"},{"doc":"aws_api/cognito_identity_provider","title":"sign_up","content":"pub fn sign_up(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.sign_up\naws_api/cognito_identity_provider sign_up","url":"aws_api/cognito_identity_provider.html#sign_up"},{"doc":"aws_api/cognito_identity_provider","title":"start_user_import_job","content":"pub fn start_user_import_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.start_user_import_job\naws_api/cognito_identity_provider start_user_import_job","url":"aws_api/cognito_identity_provider.html#start_user_import_job"},{"doc":"aws_api/cognito_identity_provider","title":"stop_user_import_job","content":"pub fn stop_user_import_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.stop_user_import_job\naws_api/cognito_identity_provider stop_user_import_job","url":"aws_api/cognito_identity_provider.html#stop_user_import_job"},{"doc":"aws_api/cognito_identity_provider","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.tag_resource\naws_api/cognito_identity_provider tag_resource","url":"aws_api/cognito_identity_provider.html#tag_resource"},{"doc":"aws_api/cognito_identity_provider","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.untag_resource\naws_api/cognito_identity_provider untag_resource","url":"aws_api/cognito_identity_provider.html#untag_resource"},{"doc":"aws_api/cognito_identity_provider","title":"update_auth_event_feedback","content":"pub fn update_auth_event_feedback(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.update_auth_event_feedback\naws_api/cognito_identity_provider update_auth_event_feedback","url":"aws_api/cognito_identity_provider.html#update_auth_event_feedback"},{"doc":"aws_api/cognito_identity_provider","title":"update_device_status","content":"pub fn update_device_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.update_device_status\naws_api/cognito_identity_provider update_device_status","url":"aws_api/cognito_identity_provider.html#update_device_status"},{"doc":"aws_api/cognito_identity_provider","title":"update_group","content":"pub fn update_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.update_group\naws_api/cognito_identity_provider update_group","url":"aws_api/cognito_identity_provider.html#update_group"},{"doc":"aws_api/cognito_identity_provider","title":"update_identity_provider","content":"pub fn update_identity_provider(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.update_identity_provider\naws_api/cognito_identity_provider update_identity_provider","url":"aws_api/cognito_identity_provider.html#update_identity_provider"},{"doc":"aws_api/cognito_identity_provider","title":"update_resource_server","content":"pub fn update_resource_server(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.update_resource_server\naws_api/cognito_identity_provider update_resource_server","url":"aws_api/cognito_identity_provider.html#update_resource_server"},{"doc":"aws_api/cognito_identity_provider","title":"update_user_attributes","content":"pub fn update_user_attributes(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.update_user_attributes\naws_api/cognito_identity_provider update_user_attributes","url":"aws_api/cognito_identity_provider.html#update_user_attributes"},{"doc":"aws_api/cognito_identity_provider","title":"update_user_pool","content":"pub fn update_user_pool(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.update_user_pool\naws_api/cognito_identity_provider update_user_pool","url":"aws_api/cognito_identity_provider.html#update_user_pool"},{"doc":"aws_api/cognito_identity_provider","title":"update_user_pool_client","content":"pub fn update_user_pool_client(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.update_user_pool_client\naws_api/cognito_identity_provider update_user_pool_client","url":"aws_api/cognito_identity_provider.html#update_user_pool_client"},{"doc":"aws_api/cognito_identity_provider","title":"update_user_pool_domain","content":"pub fn update_user_pool_domain(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.update_user_pool_domain\naws_api/cognito_identity_provider update_user_pool_domain","url":"aws_api/cognito_identity_provider.html#update_user_pool_domain"},{"doc":"aws_api/cognito_identity_provider","title":"verify_software_token","content":"pub fn verify_software_token(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.verify_software_token\naws_api/cognito_identity_provider verify_software_token","url":"aws_api/cognito_identity_provider.html#verify_software_token"},{"doc":"aws_api/cognito_identity_provider","title":"verify_user_attribute","content":"pub fn verify_user_attribute(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_identity_provider.verify_user_attribute\naws_api/cognito_identity_provider verify_user_attribute","url":"aws_api/cognito_identity_provider.html#verify_user_attribute"},{"doc":"aws_api/cognito_identity_provider","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/cognito_identity_provider.with_custom_endpoint\naws_api/cognito_identity_provider with_custom_endpoint","url":"aws_api/cognito_identity_provider.html#with_custom_endpoint"},{"doc":"aws_api/cognito_identity_provider","title":"aws_api/cognito_identity_provider","content":"","url":"aws_api/cognito_identity_provider.html"},{"doc":"aws_api/cognito_sync","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/cognito_sync.Client\naws_api/cognito_sync Client","url":"aws_api/cognito_sync.html#Client"},{"doc":"aws_api/cognito_sync","title":"bulk_publish","content":"pub fn bulk_publish(\n  client: Client,\n  identity_pool_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_sync.bulk_publish\naws_api/cognito_sync bulk_publish","url":"aws_api/cognito_sync.html#bulk_publish"},{"doc":"aws_api/cognito_sync","title":"delete_dataset","content":"pub fn delete_dataset(\n  client: Client,\n  identity_pool_id: String,\n  identity_id: String,\n  dataset_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_sync.delete_dataset\naws_api/cognito_sync delete_dataset","url":"aws_api/cognito_sync.html#delete_dataset"},{"doc":"aws_api/cognito_sync","title":"describe_dataset","content":"pub fn describe_dataset(\n  client: Client,\n  identity_pool_id: String,\n  identity_id: String,\n  dataset_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_sync.describe_dataset\naws_api/cognito_sync describe_dataset","url":"aws_api/cognito_sync.html#describe_dataset"},{"doc":"aws_api/cognito_sync","title":"describe_identity_pool_usage","content":"pub fn describe_identity_pool_usage(\n  client: Client,\n  identity_pool_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_sync.describe_identity_pool_usage\naws_api/cognito_sync describe_identity_pool_usage","url":"aws_api/cognito_sync.html#describe_identity_pool_usage"},{"doc":"aws_api/cognito_sync","title":"describe_identity_usage","content":"pub fn describe_identity_usage(\n  client: Client,\n  identity_pool_id: String,\n  identity_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_sync.describe_identity_usage\naws_api/cognito_sync describe_identity_usage","url":"aws_api/cognito_sync.html#describe_identity_usage"},{"doc":"aws_api/cognito_sync","title":"get_bulk_publish_details","content":"pub fn get_bulk_publish_details(\n  client: Client,\n  identity_pool_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_sync.get_bulk_publish_details\naws_api/cognito_sync get_bulk_publish_details","url":"aws_api/cognito_sync.html#get_bulk_publish_details"},{"doc":"aws_api/cognito_sync","title":"get_cognito_events","content":"pub fn get_cognito_events(\n  client: Client,\n  identity_pool_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_sync.get_cognito_events\naws_api/cognito_sync get_cognito_events","url":"aws_api/cognito_sync.html#get_cognito_events"},{"doc":"aws_api/cognito_sync","title":"get_identity_pool_configuration","content":"pub fn get_identity_pool_configuration(\n  client: Client,\n  identity_pool_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_sync.get_identity_pool_configuration\naws_api/cognito_sync get_identity_pool_configuration","url":"aws_api/cognito_sync.html#get_identity_pool_configuration"},{"doc":"aws_api/cognito_sync","title":"list_datasets","content":"pub fn list_datasets(\n  client: Client,\n  identity_pool_id: String,\n  identity_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_sync.list_datasets\naws_api/cognito_sync list_datasets","url":"aws_api/cognito_sync.html#list_datasets"},{"doc":"aws_api/cognito_sync","title":"list_identity_pool_usage","content":"pub fn list_identity_pool_usage(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_sync.list_identity_pool_usage\naws_api/cognito_sync list_identity_pool_usage","url":"aws_api/cognito_sync.html#list_identity_pool_usage"},{"doc":"aws_api/cognito_sync","title":"list_records","content":"pub fn list_records(\n  client: Client,\n  identity_pool_id: String,\n  identity_id: String,\n  dataset_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_sync.list_records\naws_api/cognito_sync list_records","url":"aws_api/cognito_sync.html#list_records"},{"doc":"aws_api/cognito_sync","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/cognito_sync.new\naws_api/cognito_sync new","url":"aws_api/cognito_sync.html#new"},{"doc":"aws_api/cognito_sync","title":"register_device","content":"pub fn register_device(\n  client: Client,\n  identity_pool_id: String,\n  identity_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_sync.register_device\naws_api/cognito_sync register_device","url":"aws_api/cognito_sync.html#register_device"},{"doc":"aws_api/cognito_sync","title":"set_cognito_events","content":"pub fn set_cognito_events(\n  client: Client,\n  identity_pool_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_sync.set_cognito_events\naws_api/cognito_sync set_cognito_events","url":"aws_api/cognito_sync.html#set_cognito_events"},{"doc":"aws_api/cognito_sync","title":"set_identity_pool_configuration","content":"pub fn set_identity_pool_configuration(\n  client: Client,\n  identity_pool_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_sync.set_identity_pool_configuration\naws_api/cognito_sync set_identity_pool_configuration","url":"aws_api/cognito_sync.html#set_identity_pool_configuration"},{"doc":"aws_api/cognito_sync","title":"subscribe_to_dataset","content":"pub fn subscribe_to_dataset(\n  client: Client,\n  identity_pool_id: String,\n  identity_id: String,\n  dataset_name: String,\n  device_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_sync.subscribe_to_dataset\naws_api/cognito_sync subscribe_to_dataset","url":"aws_api/cognito_sync.html#subscribe_to_dataset"},{"doc":"aws_api/cognito_sync","title":"unsubscribe_from_dataset","content":"pub fn unsubscribe_from_dataset(\n  client: Client,\n  identity_pool_id: String,\n  identity_id: String,\n  dataset_name: String,\n  device_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_sync.unsubscribe_from_dataset\naws_api/cognito_sync unsubscribe_from_dataset","url":"aws_api/cognito_sync.html#unsubscribe_from_dataset"},{"doc":"aws_api/cognito_sync","title":"update_records","content":"pub fn update_records(\n  client: Client,\n  identity_pool_id: String,\n  identity_id: String,\n  dataset_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cognito_sync.update_records\naws_api/cognito_sync update_records","url":"aws_api/cognito_sync.html#update_records"},{"doc":"aws_api/cognito_sync","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/cognito_sync.with_custom_endpoint\naws_api/cognito_sync with_custom_endpoint","url":"aws_api/cognito_sync.html#with_custom_endpoint"},{"doc":"aws_api/cognito_sync","title":"aws_api/cognito_sync","content":"","url":"aws_api/cognito_sync.html"},{"doc":"aws_api/comprehend","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/comprehend.Client\naws_api/comprehend Client","url":"aws_api/comprehend.html#Client"},{"doc":"aws_api/comprehend","title":"batch_detect_dominant_language","content":"pub fn batch_detect_dominant_language(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.batch_detect_dominant_language\naws_api/comprehend batch_detect_dominant_language","url":"aws_api/comprehend.html#batch_detect_dominant_language"},{"doc":"aws_api/comprehend","title":"batch_detect_entities","content":"pub fn batch_detect_entities(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.batch_detect_entities\naws_api/comprehend batch_detect_entities","url":"aws_api/comprehend.html#batch_detect_entities"},{"doc":"aws_api/comprehend","title":"batch_detect_key_phrases","content":"pub fn batch_detect_key_phrases(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.batch_detect_key_phrases\naws_api/comprehend batch_detect_key_phrases","url":"aws_api/comprehend.html#batch_detect_key_phrases"},{"doc":"aws_api/comprehend","title":"batch_detect_sentiment","content":"pub fn batch_detect_sentiment(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.batch_detect_sentiment\naws_api/comprehend batch_detect_sentiment","url":"aws_api/comprehend.html#batch_detect_sentiment"},{"doc":"aws_api/comprehend","title":"batch_detect_syntax","content":"pub fn batch_detect_syntax(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.batch_detect_syntax\naws_api/comprehend batch_detect_syntax","url":"aws_api/comprehend.html#batch_detect_syntax"},{"doc":"aws_api/comprehend","title":"batch_detect_targeted_sentiment","content":"pub fn batch_detect_targeted_sentiment(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.batch_detect_targeted_sentiment\naws_api/comprehend batch_detect_targeted_sentiment","url":"aws_api/comprehend.html#batch_detect_targeted_sentiment"},{"doc":"aws_api/comprehend","title":"classify_document","content":"pub fn classify_document(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.classify_document\naws_api/comprehend classify_document","url":"aws_api/comprehend.html#classify_document"},{"doc":"aws_api/comprehend","title":"contains_pii_entities","content":"pub fn contains_pii_entities(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.contains_pii_entities\naws_api/comprehend contains_pii_entities","url":"aws_api/comprehend.html#contains_pii_entities"},{"doc":"aws_api/comprehend","title":"create_dataset","content":"pub fn create_dataset(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.create_dataset\naws_api/comprehend create_dataset","url":"aws_api/comprehend.html#create_dataset"},{"doc":"aws_api/comprehend","title":"create_document_classifier","content":"pub fn create_document_classifier(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.create_document_classifier\naws_api/comprehend create_document_classifier","url":"aws_api/comprehend.html#create_document_classifier"},{"doc":"aws_api/comprehend","title":"create_endpoint","content":"pub fn create_endpoint(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.create_endpoint\naws_api/comprehend create_endpoint","url":"aws_api/comprehend.html#create_endpoint"},{"doc":"aws_api/comprehend","title":"create_entity_recognizer","content":"pub fn create_entity_recognizer(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.create_entity_recognizer\naws_api/comprehend create_entity_recognizer","url":"aws_api/comprehend.html#create_entity_recognizer"},{"doc":"aws_api/comprehend","title":"create_flywheel","content":"pub fn create_flywheel(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.create_flywheel\naws_api/comprehend create_flywheel","url":"aws_api/comprehend.html#create_flywheel"},{"doc":"aws_api/comprehend","title":"delete_document_classifier","content":"pub fn delete_document_classifier(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.delete_document_classifier\naws_api/comprehend delete_document_classifier","url":"aws_api/comprehend.html#delete_document_classifier"},{"doc":"aws_api/comprehend","title":"delete_endpoint","content":"pub fn delete_endpoint(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.delete_endpoint\naws_api/comprehend delete_endpoint","url":"aws_api/comprehend.html#delete_endpoint"},{"doc":"aws_api/comprehend","title":"delete_entity_recognizer","content":"pub fn delete_entity_recognizer(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.delete_entity_recognizer\naws_api/comprehend delete_entity_recognizer","url":"aws_api/comprehend.html#delete_entity_recognizer"},{"doc":"aws_api/comprehend","title":"delete_flywheel","content":"pub fn delete_flywheel(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.delete_flywheel\naws_api/comprehend delete_flywheel","url":"aws_api/comprehend.html#delete_flywheel"},{"doc":"aws_api/comprehend","title":"delete_resource_policy","content":"pub fn delete_resource_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.delete_resource_policy\naws_api/comprehend delete_resource_policy","url":"aws_api/comprehend.html#delete_resource_policy"},{"doc":"aws_api/comprehend","title":"describe_dataset","content":"pub fn describe_dataset(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.describe_dataset\naws_api/comprehend describe_dataset","url":"aws_api/comprehend.html#describe_dataset"},{"doc":"aws_api/comprehend","title":"describe_document_classification_job","content":"pub fn describe_document_classification_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.describe_document_classification_job\naws_api/comprehend describe_document_classification_job","url":"aws_api/comprehend.html#describe_document_classification_job"},{"doc":"aws_api/comprehend","title":"describe_document_classifier","content":"pub fn describe_document_classifier(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.describe_document_classifier\naws_api/comprehend describe_document_classifier","url":"aws_api/comprehend.html#describe_document_classifier"},{"doc":"aws_api/comprehend","title":"describe_dominant_language_detection_job","content":"pub fn describe_dominant_language_detection_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.describe_dominant_language_detection_job\naws_api/comprehend describe_dominant_language_detection_job","url":"aws_api/comprehend.html#describe_dominant_language_detection_job"},{"doc":"aws_api/comprehend","title":"describe_endpoint","content":"pub fn describe_endpoint(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.describe_endpoint\naws_api/comprehend describe_endpoint","url":"aws_api/comprehend.html#describe_endpoint"},{"doc":"aws_api/comprehend","title":"describe_entities_detection_job","content":"pub fn describe_entities_detection_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.describe_entities_detection_job\naws_api/comprehend describe_entities_detection_job","url":"aws_api/comprehend.html#describe_entities_detection_job"},{"doc":"aws_api/comprehend","title":"describe_entity_recognizer","content":"pub fn describe_entity_recognizer(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.describe_entity_recognizer\naws_api/comprehend describe_entity_recognizer","url":"aws_api/comprehend.html#describe_entity_recognizer"},{"doc":"aws_api/comprehend","title":"describe_events_detection_job","content":"pub fn describe_events_detection_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.describe_events_detection_job\naws_api/comprehend describe_events_detection_job","url":"aws_api/comprehend.html#describe_events_detection_job"},{"doc":"aws_api/comprehend","title":"describe_flywheel","content":"pub fn describe_flywheel(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.describe_flywheel\naws_api/comprehend describe_flywheel","url":"aws_api/comprehend.html#describe_flywheel"},{"doc":"aws_api/comprehend","title":"describe_flywheel_iteration","content":"pub fn describe_flywheel_iteration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.describe_flywheel_iteration\naws_api/comprehend describe_flywheel_iteration","url":"aws_api/comprehend.html#describe_flywheel_iteration"},{"doc":"aws_api/comprehend","title":"describe_key_phrases_detection_job","content":"pub fn describe_key_phrases_detection_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.describe_key_phrases_detection_job\naws_api/comprehend describe_key_phrases_detection_job","url":"aws_api/comprehend.html#describe_key_phrases_detection_job"},{"doc":"aws_api/comprehend","title":"describe_pii_entities_detection_job","content":"pub fn describe_pii_entities_detection_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.describe_pii_entities_detection_job\naws_api/comprehend describe_pii_entities_detection_job","url":"aws_api/comprehend.html#describe_pii_entities_detection_job"},{"doc":"aws_api/comprehend","title":"describe_resource_policy","content":"pub fn describe_resource_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.describe_resource_policy\naws_api/comprehend describe_resource_policy","url":"aws_api/comprehend.html#describe_resource_policy"},{"doc":"aws_api/comprehend","title":"describe_sentiment_detection_job","content":"pub fn describe_sentiment_detection_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.describe_sentiment_detection_job\naws_api/comprehend describe_sentiment_detection_job","url":"aws_api/comprehend.html#describe_sentiment_detection_job"},{"doc":"aws_api/comprehend","title":"describe_targeted_sentiment_detection_job","content":"pub fn describe_targeted_sentiment_detection_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.describe_targeted_sentiment_detection_job\naws_api/comprehend describe_targeted_sentiment_detection_job","url":"aws_api/comprehend.html#describe_targeted_sentiment_detection_job"},{"doc":"aws_api/comprehend","title":"describe_topics_detection_job","content":"pub fn describe_topics_detection_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.describe_topics_detection_job\naws_api/comprehend describe_topics_detection_job","url":"aws_api/comprehend.html#describe_topics_detection_job"},{"doc":"aws_api/comprehend","title":"detect_dominant_language","content":"pub fn detect_dominant_language(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.detect_dominant_language\naws_api/comprehend detect_dominant_language","url":"aws_api/comprehend.html#detect_dominant_language"},{"doc":"aws_api/comprehend","title":"detect_entities","content":"pub fn detect_entities(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.detect_entities\naws_api/comprehend detect_entities","url":"aws_api/comprehend.html#detect_entities"},{"doc":"aws_api/comprehend","title":"detect_key_phrases","content":"pub fn detect_key_phrases(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.detect_key_phrases\naws_api/comprehend detect_key_phrases","url":"aws_api/comprehend.html#detect_key_phrases"},{"doc":"aws_api/comprehend","title":"detect_pii_entities","content":"pub fn detect_pii_entities(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.detect_pii_entities\naws_api/comprehend detect_pii_entities","url":"aws_api/comprehend.html#detect_pii_entities"},{"doc":"aws_api/comprehend","title":"detect_sentiment","content":"pub fn detect_sentiment(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.detect_sentiment\naws_api/comprehend detect_sentiment","url":"aws_api/comprehend.html#detect_sentiment"},{"doc":"aws_api/comprehend","title":"detect_syntax","content":"pub fn detect_syntax(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.detect_syntax\naws_api/comprehend detect_syntax","url":"aws_api/comprehend.html#detect_syntax"},{"doc":"aws_api/comprehend","title":"detect_targeted_sentiment","content":"pub fn detect_targeted_sentiment(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.detect_targeted_sentiment\naws_api/comprehend detect_targeted_sentiment","url":"aws_api/comprehend.html#detect_targeted_sentiment"},{"doc":"aws_api/comprehend","title":"detect_toxic_content","content":"pub fn detect_toxic_content(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.detect_toxic_content\naws_api/comprehend detect_toxic_content","url":"aws_api/comprehend.html#detect_toxic_content"},{"doc":"aws_api/comprehend","title":"import_model","content":"pub fn import_model(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.import_model\naws_api/comprehend import_model","url":"aws_api/comprehend.html#import_model"},{"doc":"aws_api/comprehend","title":"list_datasets","content":"pub fn list_datasets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.list_datasets\naws_api/comprehend list_datasets","url":"aws_api/comprehend.html#list_datasets"},{"doc":"aws_api/comprehend","title":"list_document_classification_jobs","content":"pub fn list_document_classification_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.list_document_classification_jobs\naws_api/comprehend list_document_classification_jobs","url":"aws_api/comprehend.html#list_document_classification_jobs"},{"doc":"aws_api/comprehend","title":"list_document_classifier_summaries","content":"pub fn list_document_classifier_summaries(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.list_document_classifier_summaries\naws_api/comprehend list_document_classifier_summaries","url":"aws_api/comprehend.html#list_document_classifier_summaries"},{"doc":"aws_api/comprehend","title":"list_document_classifiers","content":"pub fn list_document_classifiers(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.list_document_classifiers\naws_api/comprehend list_document_classifiers","url":"aws_api/comprehend.html#list_document_classifiers"},{"doc":"aws_api/comprehend","title":"list_dominant_language_detection_jobs","content":"pub fn list_dominant_language_detection_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.list_dominant_language_detection_jobs\naws_api/comprehend list_dominant_language_detection_jobs","url":"aws_api/comprehend.html#list_dominant_language_detection_jobs"},{"doc":"aws_api/comprehend","title":"list_endpoints","content":"pub fn list_endpoints(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.list_endpoints\naws_api/comprehend list_endpoints","url":"aws_api/comprehend.html#list_endpoints"},{"doc":"aws_api/comprehend","title":"list_entities_detection_jobs","content":"pub fn list_entities_detection_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.list_entities_detection_jobs\naws_api/comprehend list_entities_detection_jobs","url":"aws_api/comprehend.html#list_entities_detection_jobs"},{"doc":"aws_api/comprehend","title":"list_entity_recognizer_summaries","content":"pub fn list_entity_recognizer_summaries(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.list_entity_recognizer_summaries\naws_api/comprehend list_entity_recognizer_summaries","url":"aws_api/comprehend.html#list_entity_recognizer_summaries"},{"doc":"aws_api/comprehend","title":"list_entity_recognizers","content":"pub fn list_entity_recognizers(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.list_entity_recognizers\naws_api/comprehend list_entity_recognizers","url":"aws_api/comprehend.html#list_entity_recognizers"},{"doc":"aws_api/comprehend","title":"list_events_detection_jobs","content":"pub fn list_events_detection_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.list_events_detection_jobs\naws_api/comprehend list_events_detection_jobs","url":"aws_api/comprehend.html#list_events_detection_jobs"},{"doc":"aws_api/comprehend","title":"list_flywheel_iteration_history","content":"pub fn list_flywheel_iteration_history(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.list_flywheel_iteration_history\naws_api/comprehend list_flywheel_iteration_history","url":"aws_api/comprehend.html#list_flywheel_iteration_history"},{"doc":"aws_api/comprehend","title":"list_flywheels","content":"pub fn list_flywheels(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.list_flywheels\naws_api/comprehend list_flywheels","url":"aws_api/comprehend.html#list_flywheels"},{"doc":"aws_api/comprehend","title":"list_key_phrases_detection_jobs","content":"pub fn list_key_phrases_detection_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.list_key_phrases_detection_jobs\naws_api/comprehend list_key_phrases_detection_jobs","url":"aws_api/comprehend.html#list_key_phrases_detection_jobs"},{"doc":"aws_api/comprehend","title":"list_pii_entities_detection_jobs","content":"pub fn list_pii_entities_detection_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.list_pii_entities_detection_jobs\naws_api/comprehend list_pii_entities_detection_jobs","url":"aws_api/comprehend.html#list_pii_entities_detection_jobs"},{"doc":"aws_api/comprehend","title":"list_sentiment_detection_jobs","content":"pub fn list_sentiment_detection_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.list_sentiment_detection_jobs\naws_api/comprehend list_sentiment_detection_jobs","url":"aws_api/comprehend.html#list_sentiment_detection_jobs"},{"doc":"aws_api/comprehend","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.list_tags_for_resource\naws_api/comprehend list_tags_for_resource","url":"aws_api/comprehend.html#list_tags_for_resource"},{"doc":"aws_api/comprehend","title":"list_targeted_sentiment_detection_jobs","content":"pub fn list_targeted_sentiment_detection_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.list_targeted_sentiment_detection_jobs\naws_api/comprehend list_targeted_sentiment_detection_jobs","url":"aws_api/comprehend.html#list_targeted_sentiment_detection_jobs"},{"doc":"aws_api/comprehend","title":"list_topics_detection_jobs","content":"pub fn list_topics_detection_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.list_topics_detection_jobs\naws_api/comprehend list_topics_detection_jobs","url":"aws_api/comprehend.html#list_topics_detection_jobs"},{"doc":"aws_api/comprehend","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/comprehend.new\naws_api/comprehend new","url":"aws_api/comprehend.html#new"},{"doc":"aws_api/comprehend","title":"put_resource_policy","content":"pub fn put_resource_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.put_resource_policy\naws_api/comprehend put_resource_policy","url":"aws_api/comprehend.html#put_resource_policy"},{"doc":"aws_api/comprehend","title":"start_document_classification_job","content":"pub fn start_document_classification_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.start_document_classification_job\naws_api/comprehend start_document_classification_job","url":"aws_api/comprehend.html#start_document_classification_job"},{"doc":"aws_api/comprehend","title":"start_dominant_language_detection_job","content":"pub fn start_dominant_language_detection_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.start_dominant_language_detection_job\naws_api/comprehend start_dominant_language_detection_job","url":"aws_api/comprehend.html#start_dominant_language_detection_job"},{"doc":"aws_api/comprehend","title":"start_entities_detection_job","content":"pub fn start_entities_detection_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.start_entities_detection_job\naws_api/comprehend start_entities_detection_job","url":"aws_api/comprehend.html#start_entities_detection_job"},{"doc":"aws_api/comprehend","title":"start_events_detection_job","content":"pub fn start_events_detection_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.start_events_detection_job\naws_api/comprehend start_events_detection_job","url":"aws_api/comprehend.html#start_events_detection_job"},{"doc":"aws_api/comprehend","title":"start_flywheel_iteration","content":"pub fn start_flywheel_iteration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.start_flywheel_iteration\naws_api/comprehend start_flywheel_iteration","url":"aws_api/comprehend.html#start_flywheel_iteration"},{"doc":"aws_api/comprehend","title":"start_key_phrases_detection_job","content":"pub fn start_key_phrases_detection_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.start_key_phrases_detection_job\naws_api/comprehend start_key_phrases_detection_job","url":"aws_api/comprehend.html#start_key_phrases_detection_job"},{"doc":"aws_api/comprehend","title":"start_pii_entities_detection_job","content":"pub fn start_pii_entities_detection_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.start_pii_entities_detection_job\naws_api/comprehend start_pii_entities_detection_job","url":"aws_api/comprehend.html#start_pii_entities_detection_job"},{"doc":"aws_api/comprehend","title":"start_sentiment_detection_job","content":"pub fn start_sentiment_detection_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.start_sentiment_detection_job\naws_api/comprehend start_sentiment_detection_job","url":"aws_api/comprehend.html#start_sentiment_detection_job"},{"doc":"aws_api/comprehend","title":"start_targeted_sentiment_detection_job","content":"pub fn start_targeted_sentiment_detection_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.start_targeted_sentiment_detection_job\naws_api/comprehend start_targeted_sentiment_detection_job","url":"aws_api/comprehend.html#start_targeted_sentiment_detection_job"},{"doc":"aws_api/comprehend","title":"start_topics_detection_job","content":"pub fn start_topics_detection_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.start_topics_detection_job\naws_api/comprehend start_topics_detection_job","url":"aws_api/comprehend.html#start_topics_detection_job"},{"doc":"aws_api/comprehend","title":"stop_dominant_language_detection_job","content":"pub fn stop_dominant_language_detection_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.stop_dominant_language_detection_job\naws_api/comprehend stop_dominant_language_detection_job","url":"aws_api/comprehend.html#stop_dominant_language_detection_job"},{"doc":"aws_api/comprehend","title":"stop_entities_detection_job","content":"pub fn stop_entities_detection_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.stop_entities_detection_job\naws_api/comprehend stop_entities_detection_job","url":"aws_api/comprehend.html#stop_entities_detection_job"},{"doc":"aws_api/comprehend","title":"stop_events_detection_job","content":"pub fn stop_events_detection_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.stop_events_detection_job\naws_api/comprehend stop_events_detection_job","url":"aws_api/comprehend.html#stop_events_detection_job"},{"doc":"aws_api/comprehend","title":"stop_key_phrases_detection_job","content":"pub fn stop_key_phrases_detection_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.stop_key_phrases_detection_job\naws_api/comprehend stop_key_phrases_detection_job","url":"aws_api/comprehend.html#stop_key_phrases_detection_job"},{"doc":"aws_api/comprehend","title":"stop_pii_entities_detection_job","content":"pub fn stop_pii_entities_detection_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.stop_pii_entities_detection_job\naws_api/comprehend stop_pii_entities_detection_job","url":"aws_api/comprehend.html#stop_pii_entities_detection_job"},{"doc":"aws_api/comprehend","title":"stop_sentiment_detection_job","content":"pub fn stop_sentiment_detection_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.stop_sentiment_detection_job\naws_api/comprehend stop_sentiment_detection_job","url":"aws_api/comprehend.html#stop_sentiment_detection_job"},{"doc":"aws_api/comprehend","title":"stop_targeted_sentiment_detection_job","content":"pub fn stop_targeted_sentiment_detection_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.stop_targeted_sentiment_detection_job\naws_api/comprehend stop_targeted_sentiment_detection_job","url":"aws_api/comprehend.html#stop_targeted_sentiment_detection_job"},{"doc":"aws_api/comprehend","title":"stop_training_document_classifier","content":"pub fn stop_training_document_classifier(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.stop_training_document_classifier\naws_api/comprehend stop_training_document_classifier","url":"aws_api/comprehend.html#stop_training_document_classifier"},{"doc":"aws_api/comprehend","title":"stop_training_entity_recognizer","content":"pub fn stop_training_entity_recognizer(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.stop_training_entity_recognizer\naws_api/comprehend stop_training_entity_recognizer","url":"aws_api/comprehend.html#stop_training_entity_recognizer"},{"doc":"aws_api/comprehend","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.tag_resource\naws_api/comprehend tag_resource","url":"aws_api/comprehend.html#tag_resource"},{"doc":"aws_api/comprehend","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.untag_resource\naws_api/comprehend untag_resource","url":"aws_api/comprehend.html#untag_resource"},{"doc":"aws_api/comprehend","title":"update_endpoint","content":"pub fn update_endpoint(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.update_endpoint\naws_api/comprehend update_endpoint","url":"aws_api/comprehend.html#update_endpoint"},{"doc":"aws_api/comprehend","title":"update_flywheel","content":"pub fn update_flywheel(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehend.update_flywheel\naws_api/comprehend update_flywheel","url":"aws_api/comprehend.html#update_flywheel"},{"doc":"aws_api/comprehend","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/comprehend.with_custom_endpoint\naws_api/comprehend with_custom_endpoint","url":"aws_api/comprehend.html#with_custom_endpoint"},{"doc":"aws_api/comprehend","title":"aws_api/comprehend","content":"","url":"aws_api/comprehend.html"},{"doc":"aws_api/comprehendmedical","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/comprehendmedical.Client\naws_api/comprehendmedical Client","url":"aws_api/comprehendmedical.html#Client"},{"doc":"aws_api/comprehendmedical","title":"describe_entities_detection_v2_job","content":"pub fn describe_entities_detection_v2_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehendmedical.describe_entities_detection_v2_job\naws_api/comprehendmedical describe_entities_detection_v2_job","url":"aws_api/comprehendmedical.html#describe_entities_detection_v2_job"},{"doc":"aws_api/comprehendmedical","title":"describe_icd10_cm_inference_job","content":"pub fn describe_icd10_cm_inference_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehendmedical.describe_icd10_cm_inference_job\naws_api/comprehendmedical describe_icd10_cm_inference_job","url":"aws_api/comprehendmedical.html#describe_icd10_cm_inference_job"},{"doc":"aws_api/comprehendmedical","title":"describe_phi_detection_job","content":"pub fn describe_phi_detection_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehendmedical.describe_phi_detection_job\naws_api/comprehendmedical describe_phi_detection_job","url":"aws_api/comprehendmedical.html#describe_phi_detection_job"},{"doc":"aws_api/comprehendmedical","title":"describe_rx_norm_inference_job","content":"pub fn describe_rx_norm_inference_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehendmedical.describe_rx_norm_inference_job\naws_api/comprehendmedical describe_rx_norm_inference_job","url":"aws_api/comprehendmedical.html#describe_rx_norm_inference_job"},{"doc":"aws_api/comprehendmedical","title":"describe_snomedct_inference_job","content":"pub fn describe_snomedct_inference_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehendmedical.describe_snomedct_inference_job\naws_api/comprehendmedical describe_snomedct_inference_job","url":"aws_api/comprehendmedical.html#describe_snomedct_inference_job"},{"doc":"aws_api/comprehendmedical","title":"detect_entities","content":"pub fn detect_entities(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehendmedical.detect_entities\naws_api/comprehendmedical detect_entities","url":"aws_api/comprehendmedical.html#detect_entities"},{"doc":"aws_api/comprehendmedical","title":"detect_entities_v2","content":"pub fn detect_entities_v2(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehendmedical.detect_entities_v2\naws_api/comprehendmedical detect_entities_v2","url":"aws_api/comprehendmedical.html#detect_entities_v2"},{"doc":"aws_api/comprehendmedical","title":"detect_phi","content":"pub fn detect_phi(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehendmedical.detect_phi\naws_api/comprehendmedical detect_phi","url":"aws_api/comprehendmedical.html#detect_phi"},{"doc":"aws_api/comprehendmedical","title":"infer_icd10_cm","content":"pub fn infer_icd10_cm(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehendmedical.infer_icd10_cm\naws_api/comprehendmedical infer_icd10_cm","url":"aws_api/comprehendmedical.html#infer_icd10_cm"},{"doc":"aws_api/comprehendmedical","title":"infer_rx_norm","content":"pub fn infer_rx_norm(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehendmedical.infer_rx_norm\naws_api/comprehendmedical infer_rx_norm","url":"aws_api/comprehendmedical.html#infer_rx_norm"},{"doc":"aws_api/comprehendmedical","title":"infer_snomedct","content":"pub fn infer_snomedct(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehendmedical.infer_snomedct\naws_api/comprehendmedical infer_snomedct","url":"aws_api/comprehendmedical.html#infer_snomedct"},{"doc":"aws_api/comprehendmedical","title":"list_entities_detection_v2_jobs","content":"pub fn list_entities_detection_v2_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehendmedical.list_entities_detection_v2_jobs\naws_api/comprehendmedical list_entities_detection_v2_jobs","url":"aws_api/comprehendmedical.html#list_entities_detection_v2_jobs"},{"doc":"aws_api/comprehendmedical","title":"list_icd10_cm_inference_jobs","content":"pub fn list_icd10_cm_inference_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehendmedical.list_icd10_cm_inference_jobs\naws_api/comprehendmedical list_icd10_cm_inference_jobs","url":"aws_api/comprehendmedical.html#list_icd10_cm_inference_jobs"},{"doc":"aws_api/comprehendmedical","title":"list_phi_detection_jobs","content":"pub fn list_phi_detection_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehendmedical.list_phi_detection_jobs\naws_api/comprehendmedical list_phi_detection_jobs","url":"aws_api/comprehendmedical.html#list_phi_detection_jobs"},{"doc":"aws_api/comprehendmedical","title":"list_rx_norm_inference_jobs","content":"pub fn list_rx_norm_inference_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehendmedical.list_rx_norm_inference_jobs\naws_api/comprehendmedical list_rx_norm_inference_jobs","url":"aws_api/comprehendmedical.html#list_rx_norm_inference_jobs"},{"doc":"aws_api/comprehendmedical","title":"list_snomedct_inference_jobs","content":"pub fn list_snomedct_inference_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehendmedical.list_snomedct_inference_jobs\naws_api/comprehendmedical list_snomedct_inference_jobs","url":"aws_api/comprehendmedical.html#list_snomedct_inference_jobs"},{"doc":"aws_api/comprehendmedical","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/comprehendmedical.new\naws_api/comprehendmedical new","url":"aws_api/comprehendmedical.html#new"},{"doc":"aws_api/comprehendmedical","title":"start_entities_detection_v2_job","content":"pub fn start_entities_detection_v2_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehendmedical.start_entities_detection_v2_job\naws_api/comprehendmedical start_entities_detection_v2_job","url":"aws_api/comprehendmedical.html#start_entities_detection_v2_job"},{"doc":"aws_api/comprehendmedical","title":"start_icd10_cm_inference_job","content":"pub fn start_icd10_cm_inference_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehendmedical.start_icd10_cm_inference_job\naws_api/comprehendmedical start_icd10_cm_inference_job","url":"aws_api/comprehendmedical.html#start_icd10_cm_inference_job"},{"doc":"aws_api/comprehendmedical","title":"start_phi_detection_job","content":"pub fn start_phi_detection_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehendmedical.start_phi_detection_job\naws_api/comprehendmedical start_phi_detection_job","url":"aws_api/comprehendmedical.html#start_phi_detection_job"},{"doc":"aws_api/comprehendmedical","title":"start_rx_norm_inference_job","content":"pub fn start_rx_norm_inference_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehendmedical.start_rx_norm_inference_job\naws_api/comprehendmedical start_rx_norm_inference_job","url":"aws_api/comprehendmedical.html#start_rx_norm_inference_job"},{"doc":"aws_api/comprehendmedical","title":"start_snomedct_inference_job","content":"pub fn start_snomedct_inference_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehendmedical.start_snomedct_inference_job\naws_api/comprehendmedical start_snomedct_inference_job","url":"aws_api/comprehendmedical.html#start_snomedct_inference_job"},{"doc":"aws_api/comprehendmedical","title":"stop_entities_detection_v2_job","content":"pub fn stop_entities_detection_v2_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehendmedical.stop_entities_detection_v2_job\naws_api/comprehendmedical stop_entities_detection_v2_job","url":"aws_api/comprehendmedical.html#stop_entities_detection_v2_job"},{"doc":"aws_api/comprehendmedical","title":"stop_icd10_cm_inference_job","content":"pub fn stop_icd10_cm_inference_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehendmedical.stop_icd10_cm_inference_job\naws_api/comprehendmedical stop_icd10_cm_inference_job","url":"aws_api/comprehendmedical.html#stop_icd10_cm_inference_job"},{"doc":"aws_api/comprehendmedical","title":"stop_phi_detection_job","content":"pub fn stop_phi_detection_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehendmedical.stop_phi_detection_job\naws_api/comprehendmedical stop_phi_detection_job","url":"aws_api/comprehendmedical.html#stop_phi_detection_job"},{"doc":"aws_api/comprehendmedical","title":"stop_rx_norm_inference_job","content":"pub fn stop_rx_norm_inference_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehendmedical.stop_rx_norm_inference_job\naws_api/comprehendmedical stop_rx_norm_inference_job","url":"aws_api/comprehendmedical.html#stop_rx_norm_inference_job"},{"doc":"aws_api/comprehendmedical","title":"stop_snomedct_inference_job","content":"pub fn stop_snomedct_inference_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/comprehendmedical.stop_snomedct_inference_job\naws_api/comprehendmedical stop_snomedct_inference_job","url":"aws_api/comprehendmedical.html#stop_snomedct_inference_job"},{"doc":"aws_api/comprehendmedical","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/comprehendmedical.with_custom_endpoint\naws_api/comprehendmedical with_custom_endpoint","url":"aws_api/comprehendmedical.html#with_custom_endpoint"},{"doc":"aws_api/comprehendmedical","title":"aws_api/comprehendmedical","content":"","url":"aws_api/comprehendmedical.html"},{"doc":"aws_api/compute_optimizer","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/compute_optimizer.Client\naws_api/compute_optimizer Client","url":"aws_api/compute_optimizer.html#Client"},{"doc":"aws_api/compute_optimizer","title":"delete_recommendation_preferences","content":"pub fn delete_recommendation_preferences(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/compute_optimizer.delete_recommendation_preferences\naws_api/compute_optimizer delete_recommendation_preferences","url":"aws_api/compute_optimizer.html#delete_recommendation_preferences"},{"doc":"aws_api/compute_optimizer","title":"describe_recommendation_export_jobs","content":"pub fn describe_recommendation_export_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/compute_optimizer.describe_recommendation_export_jobs\naws_api/compute_optimizer describe_recommendation_export_jobs","url":"aws_api/compute_optimizer.html#describe_recommendation_export_jobs"},{"doc":"aws_api/compute_optimizer","title":"export_auto_scaling_group_recommendations","content":"pub fn export_auto_scaling_group_recommendations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/compute_optimizer.export_auto_scaling_group_recommendations\naws_api/compute_optimizer export_auto_scaling_group_recommendations","url":"aws_api/compute_optimizer.html#export_auto_scaling_group_recommendations"},{"doc":"aws_api/compute_optimizer","title":"export_ebs_volume_recommendations","content":"pub fn export_ebs_volume_recommendations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/compute_optimizer.export_ebs_volume_recommendations\naws_api/compute_optimizer export_ebs_volume_recommendations","url":"aws_api/compute_optimizer.html#export_ebs_volume_recommendations"},{"doc":"aws_api/compute_optimizer","title":"export_ec2_instance_recommendations","content":"pub fn export_ec2_instance_recommendations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/compute_optimizer.export_ec2_instance_recommendations\naws_api/compute_optimizer export_ec2_instance_recommendations","url":"aws_api/compute_optimizer.html#export_ec2_instance_recommendations"},{"doc":"aws_api/compute_optimizer","title":"export_ecs_service_recommendations","content":"pub fn export_ecs_service_recommendations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/compute_optimizer.export_ecs_service_recommendations\naws_api/compute_optimizer export_ecs_service_recommendations","url":"aws_api/compute_optimizer.html#export_ecs_service_recommendations"},{"doc":"aws_api/compute_optimizer","title":"export_lambda_function_recommendations","content":"pub fn export_lambda_function_recommendations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/compute_optimizer.export_lambda_function_recommendations\naws_api/compute_optimizer export_lambda_function_recommendations","url":"aws_api/compute_optimizer.html#export_lambda_function_recommendations"},{"doc":"aws_api/compute_optimizer","title":"export_license_recommendations","content":"pub fn export_license_recommendations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/compute_optimizer.export_license_recommendations\naws_api/compute_optimizer export_license_recommendations","url":"aws_api/compute_optimizer.html#export_license_recommendations"},{"doc":"aws_api/compute_optimizer","title":"export_rds_database_recommendations","content":"pub fn export_rds_database_recommendations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/compute_optimizer.export_rds_database_recommendations\naws_api/compute_optimizer export_rds_database_recommendations","url":"aws_api/compute_optimizer.html#export_rds_database_recommendations"},{"doc":"aws_api/compute_optimizer","title":"get_auto_scaling_group_recommendations","content":"pub fn get_auto_scaling_group_recommendations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/compute_optimizer.get_auto_scaling_group_recommendations\naws_api/compute_optimizer get_auto_scaling_group_recommendations","url":"aws_api/compute_optimizer.html#get_auto_scaling_group_recommendations"},{"doc":"aws_api/compute_optimizer","title":"get_ebs_volume_recommendations","content":"pub fn get_ebs_volume_recommendations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/compute_optimizer.get_ebs_volume_recommendations\naws_api/compute_optimizer get_ebs_volume_recommendations","url":"aws_api/compute_optimizer.html#get_ebs_volume_recommendations"},{"doc":"aws_api/compute_optimizer","title":"get_ec2_instance_recommendations","content":"pub fn get_ec2_instance_recommendations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/compute_optimizer.get_ec2_instance_recommendations\naws_api/compute_optimizer get_ec2_instance_recommendations","url":"aws_api/compute_optimizer.html#get_ec2_instance_recommendations"},{"doc":"aws_api/compute_optimizer","title":"get_ec2_recommendation_projected_metrics","content":"pub fn get_ec2_recommendation_projected_metrics(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/compute_optimizer.get_ec2_recommendation_projected_metrics\naws_api/compute_optimizer get_ec2_recommendation_projected_metrics","url":"aws_api/compute_optimizer.html#get_ec2_recommendation_projected_metrics"},{"doc":"aws_api/compute_optimizer","title":"get_ecs_service_recommendation_projected_metrics","content":"pub fn get_ecs_service_recommendation_projected_metrics(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/compute_optimizer.get_ecs_service_recommendation_projected_metrics\naws_api/compute_optimizer get_ecs_service_recommendation_projected_metrics","url":"aws_api/compute_optimizer.html#get_ecs_service_recommendation_projected_metrics"},{"doc":"aws_api/compute_optimizer","title":"get_ecs_service_recommendations","content":"pub fn get_ecs_service_recommendations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/compute_optimizer.get_ecs_service_recommendations\naws_api/compute_optimizer get_ecs_service_recommendations","url":"aws_api/compute_optimizer.html#get_ecs_service_recommendations"},{"doc":"aws_api/compute_optimizer","title":"get_effective_recommendation_preferences","content":"pub fn get_effective_recommendation_preferences(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/compute_optimizer.get_effective_recommendation_preferences\naws_api/compute_optimizer get_effective_recommendation_preferences","url":"aws_api/compute_optimizer.html#get_effective_recommendation_preferences"},{"doc":"aws_api/compute_optimizer","title":"get_enrollment_status","content":"pub fn get_enrollment_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/compute_optimizer.get_enrollment_status\naws_api/compute_optimizer get_enrollment_status","url":"aws_api/compute_optimizer.html#get_enrollment_status"},{"doc":"aws_api/compute_optimizer","title":"get_enrollment_statuses_for_organization","content":"pub fn get_enrollment_statuses_for_organization(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/compute_optimizer.get_enrollment_statuses_for_organization\naws_api/compute_optimizer get_enrollment_statuses_for_organization","url":"aws_api/compute_optimizer.html#get_enrollment_statuses_for_organization"},{"doc":"aws_api/compute_optimizer","title":"get_lambda_function_recommendations","content":"pub fn get_lambda_function_recommendations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/compute_optimizer.get_lambda_function_recommendations\naws_api/compute_optimizer get_lambda_function_recommendations","url":"aws_api/compute_optimizer.html#get_lambda_function_recommendations"},{"doc":"aws_api/compute_optimizer","title":"get_license_recommendations","content":"pub fn get_license_recommendations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/compute_optimizer.get_license_recommendations\naws_api/compute_optimizer get_license_recommendations","url":"aws_api/compute_optimizer.html#get_license_recommendations"},{"doc":"aws_api/compute_optimizer","title":"get_rds_database_recommendation_projected_metrics","content":"pub fn get_rds_database_recommendation_projected_metrics(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/compute_optimizer.get_rds_database_recommendation_projected_metrics\naws_api/compute_optimizer get_rds_database_recommendation_projected_metrics","url":"aws_api/compute_optimizer.html#get_rds_database_recommendation_projected_metrics"},{"doc":"aws_api/compute_optimizer","title":"get_rds_database_recommendations","content":"pub fn get_rds_database_recommendations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/compute_optimizer.get_rds_database_recommendations\naws_api/compute_optimizer get_rds_database_recommendations","url":"aws_api/compute_optimizer.html#get_rds_database_recommendations"},{"doc":"aws_api/compute_optimizer","title":"get_recommendation_preferences","content":"pub fn get_recommendation_preferences(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/compute_optimizer.get_recommendation_preferences\naws_api/compute_optimizer get_recommendation_preferences","url":"aws_api/compute_optimizer.html#get_recommendation_preferences"},{"doc":"aws_api/compute_optimizer","title":"get_recommendation_summaries","content":"pub fn get_recommendation_summaries(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/compute_optimizer.get_recommendation_summaries\naws_api/compute_optimizer get_recommendation_summaries","url":"aws_api/compute_optimizer.html#get_recommendation_summaries"},{"doc":"aws_api/compute_optimizer","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/compute_optimizer.new\naws_api/compute_optimizer new","url":"aws_api/compute_optimizer.html#new"},{"doc":"aws_api/compute_optimizer","title":"put_recommendation_preferences","content":"pub fn put_recommendation_preferences(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/compute_optimizer.put_recommendation_preferences\naws_api/compute_optimizer put_recommendation_preferences","url":"aws_api/compute_optimizer.html#put_recommendation_preferences"},{"doc":"aws_api/compute_optimizer","title":"update_enrollment_status","content":"pub fn update_enrollment_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/compute_optimizer.update_enrollment_status\naws_api/compute_optimizer update_enrollment_status","url":"aws_api/compute_optimizer.html#update_enrollment_status"},{"doc":"aws_api/compute_optimizer","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/compute_optimizer.with_custom_endpoint\naws_api/compute_optimizer with_custom_endpoint","url":"aws_api/compute_optimizer.html#with_custom_endpoint"},{"doc":"aws_api/compute_optimizer","title":"aws_api/compute_optimizer","content":"","url":"aws_api/compute_optimizer.html"},{"doc":"aws_api/config_service","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/config_service.Client\naws_api/config_service Client","url":"aws_api/config_service.html#Client"},{"doc":"aws_api/config_service","title":"batch_get_aggregate_resource_config","content":"pub fn batch_get_aggregate_resource_config(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.batch_get_aggregate_resource_config\naws_api/config_service batch_get_aggregate_resource_config","url":"aws_api/config_service.html#batch_get_aggregate_resource_config"},{"doc":"aws_api/config_service","title":"batch_get_resource_config","content":"pub fn batch_get_resource_config(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.batch_get_resource_config\naws_api/config_service batch_get_resource_config","url":"aws_api/config_service.html#batch_get_resource_config"},{"doc":"aws_api/config_service","title":"delete_aggregation_authorization","content":"pub fn delete_aggregation_authorization(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.delete_aggregation_authorization\naws_api/config_service delete_aggregation_authorization","url":"aws_api/config_service.html#delete_aggregation_authorization"},{"doc":"aws_api/config_service","title":"delete_config_rule","content":"pub fn delete_config_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.delete_config_rule\naws_api/config_service delete_config_rule","url":"aws_api/config_service.html#delete_config_rule"},{"doc":"aws_api/config_service","title":"delete_configuration_aggregator","content":"pub fn delete_configuration_aggregator(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.delete_configuration_aggregator\naws_api/config_service delete_configuration_aggregator","url":"aws_api/config_service.html#delete_configuration_aggregator"},{"doc":"aws_api/config_service","title":"delete_configuration_recorder","content":"pub fn delete_configuration_recorder(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.delete_configuration_recorder\naws_api/config_service delete_configuration_recorder","url":"aws_api/config_service.html#delete_configuration_recorder"},{"doc":"aws_api/config_service","title":"delete_conformance_pack","content":"pub fn delete_conformance_pack(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.delete_conformance_pack\naws_api/config_service delete_conformance_pack","url":"aws_api/config_service.html#delete_conformance_pack"},{"doc":"aws_api/config_service","title":"delete_delivery_channel","content":"pub fn delete_delivery_channel(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.delete_delivery_channel\naws_api/config_service delete_delivery_channel","url":"aws_api/config_service.html#delete_delivery_channel"},{"doc":"aws_api/config_service","title":"delete_evaluation_results","content":"pub fn delete_evaluation_results(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.delete_evaluation_results\naws_api/config_service delete_evaluation_results","url":"aws_api/config_service.html#delete_evaluation_results"},{"doc":"aws_api/config_service","title":"delete_organization_config_rule","content":"pub fn delete_organization_config_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.delete_organization_config_rule\naws_api/config_service delete_organization_config_rule","url":"aws_api/config_service.html#delete_organization_config_rule"},{"doc":"aws_api/config_service","title":"delete_organization_conformance_pack","content":"pub fn delete_organization_conformance_pack(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.delete_organization_conformance_pack\naws_api/config_service delete_organization_conformance_pack","url":"aws_api/config_service.html#delete_organization_conformance_pack"},{"doc":"aws_api/config_service","title":"delete_pending_aggregation_request","content":"pub fn delete_pending_aggregation_request(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.delete_pending_aggregation_request\naws_api/config_service delete_pending_aggregation_request","url":"aws_api/config_service.html#delete_pending_aggregation_request"},{"doc":"aws_api/config_service","title":"delete_remediation_configuration","content":"pub fn delete_remediation_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.delete_remediation_configuration\naws_api/config_service delete_remediation_configuration","url":"aws_api/config_service.html#delete_remediation_configuration"},{"doc":"aws_api/config_service","title":"delete_remediation_exceptions","content":"pub fn delete_remediation_exceptions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.delete_remediation_exceptions\naws_api/config_service delete_remediation_exceptions","url":"aws_api/config_service.html#delete_remediation_exceptions"},{"doc":"aws_api/config_service","title":"delete_resource_config","content":"pub fn delete_resource_config(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.delete_resource_config\naws_api/config_service delete_resource_config","url":"aws_api/config_service.html#delete_resource_config"},{"doc":"aws_api/config_service","title":"delete_retention_configuration","content":"pub fn delete_retention_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.delete_retention_configuration\naws_api/config_service delete_retention_configuration","url":"aws_api/config_service.html#delete_retention_configuration"},{"doc":"aws_api/config_service","title":"delete_stored_query","content":"pub fn delete_stored_query(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.delete_stored_query\naws_api/config_service delete_stored_query","url":"aws_api/config_service.html#delete_stored_query"},{"doc":"aws_api/config_service","title":"deliver_config_snapshot","content":"pub fn deliver_config_snapshot(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.deliver_config_snapshot\naws_api/config_service deliver_config_snapshot","url":"aws_api/config_service.html#deliver_config_snapshot"},{"doc":"aws_api/config_service","title":"describe_aggregate_compliance_by_config_rules","content":"pub fn describe_aggregate_compliance_by_config_rules(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.describe_aggregate_compliance_by_config_rules\naws_api/config_service describe_aggregate_compliance_by_config_rules","url":"aws_api/config_service.html#describe_aggregate_compliance_by_config_rules"},{"doc":"aws_api/config_service","title":"describe_aggregate_compliance_by_conformance_packs","content":"pub fn describe_aggregate_compliance_by_conformance_packs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.describe_aggregate_compliance_by_conformance_packs\naws_api/config_service describe_aggregate_compliance_by_conformance_packs","url":"aws_api/config_service.html#describe_aggregate_compliance_by_conformance_packs"},{"doc":"aws_api/config_service","title":"describe_aggregation_authorizations","content":"pub fn describe_aggregation_authorizations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.describe_aggregation_authorizations\naws_api/config_service describe_aggregation_authorizations","url":"aws_api/config_service.html#describe_aggregation_authorizations"},{"doc":"aws_api/config_service","title":"describe_compliance_by_config_rule","content":"pub fn describe_compliance_by_config_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.describe_compliance_by_config_rule\naws_api/config_service describe_compliance_by_config_rule","url":"aws_api/config_service.html#describe_compliance_by_config_rule"},{"doc":"aws_api/config_service","title":"describe_compliance_by_resource","content":"pub fn describe_compliance_by_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.describe_compliance_by_resource\naws_api/config_service describe_compliance_by_resource","url":"aws_api/config_service.html#describe_compliance_by_resource"},{"doc":"aws_api/config_service","title":"describe_config_rule_evaluation_status","content":"pub fn describe_config_rule_evaluation_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.describe_config_rule_evaluation_status\naws_api/config_service describe_config_rule_evaluation_status","url":"aws_api/config_service.html#describe_config_rule_evaluation_status"},{"doc":"aws_api/config_service","title":"describe_config_rules","content":"pub fn describe_config_rules(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.describe_config_rules\naws_api/config_service describe_config_rules","url":"aws_api/config_service.html#describe_config_rules"},{"doc":"aws_api/config_service","title":"describe_configuration_aggregator_sources_status","content":"pub fn describe_configuration_aggregator_sources_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.describe_configuration_aggregator_sources_status\naws_api/config_service describe_configuration_aggregator_sources_status","url":"aws_api/config_service.html#describe_configuration_aggregator_sources_status"},{"doc":"aws_api/config_service","title":"describe_configuration_aggregators","content":"pub fn describe_configuration_aggregators(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.describe_configuration_aggregators\naws_api/config_service describe_configuration_aggregators","url":"aws_api/config_service.html#describe_configuration_aggregators"},{"doc":"aws_api/config_service","title":"describe_configuration_recorder_status","content":"pub fn describe_configuration_recorder_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.describe_configuration_recorder_status\naws_api/config_service describe_configuration_recorder_status","url":"aws_api/config_service.html#describe_configuration_recorder_status"},{"doc":"aws_api/config_service","title":"describe_configuration_recorders","content":"pub fn describe_configuration_recorders(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.describe_configuration_recorders\naws_api/config_service describe_configuration_recorders","url":"aws_api/config_service.html#describe_configuration_recorders"},{"doc":"aws_api/config_service","title":"describe_conformance_pack_compliance","content":"pub fn describe_conformance_pack_compliance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.describe_conformance_pack_compliance\naws_api/config_service describe_conformance_pack_compliance","url":"aws_api/config_service.html#describe_conformance_pack_compliance"},{"doc":"aws_api/config_service","title":"describe_conformance_pack_status","content":"pub fn describe_conformance_pack_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.describe_conformance_pack_status\naws_api/config_service describe_conformance_pack_status","url":"aws_api/config_service.html#describe_conformance_pack_status"},{"doc":"aws_api/config_service","title":"describe_conformance_packs","content":"pub fn describe_conformance_packs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.describe_conformance_packs\naws_api/config_service describe_conformance_packs","url":"aws_api/config_service.html#describe_conformance_packs"},{"doc":"aws_api/config_service","title":"describe_delivery_channel_status","content":"pub fn describe_delivery_channel_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.describe_delivery_channel_status\naws_api/config_service describe_delivery_channel_status","url":"aws_api/config_service.html#describe_delivery_channel_status"},{"doc":"aws_api/config_service","title":"describe_delivery_channels","content":"pub fn describe_delivery_channels(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.describe_delivery_channels\naws_api/config_service describe_delivery_channels","url":"aws_api/config_service.html#describe_delivery_channels"},{"doc":"aws_api/config_service","title":"describe_organization_config_rule_statuses","content":"pub fn describe_organization_config_rule_statuses(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.describe_organization_config_rule_statuses\naws_api/config_service describe_organization_config_rule_statuses","url":"aws_api/config_service.html#describe_organization_config_rule_statuses"},{"doc":"aws_api/config_service","title":"describe_organization_config_rules","content":"pub fn describe_organization_config_rules(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.describe_organization_config_rules\naws_api/config_service describe_organization_config_rules","url":"aws_api/config_service.html#describe_organization_config_rules"},{"doc":"aws_api/config_service","title":"describe_organization_conformance_pack_statuses","content":"pub fn describe_organization_conformance_pack_statuses(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.describe_organization_conformance_pack_statuses\naws_api/config_service describe_organization_conformance_pack_statuses","url":"aws_api/config_service.html#describe_organization_conformance_pack_statuses"},{"doc":"aws_api/config_service","title":"describe_organization_conformance_packs","content":"pub fn describe_organization_conformance_packs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.describe_organization_conformance_packs\naws_api/config_service describe_organization_conformance_packs","url":"aws_api/config_service.html#describe_organization_conformance_packs"},{"doc":"aws_api/config_service","title":"describe_pending_aggregation_requests","content":"pub fn describe_pending_aggregation_requests(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.describe_pending_aggregation_requests\naws_api/config_service describe_pending_aggregation_requests","url":"aws_api/config_service.html#describe_pending_aggregation_requests"},{"doc":"aws_api/config_service","title":"describe_remediation_configurations","content":"pub fn describe_remediation_configurations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.describe_remediation_configurations\naws_api/config_service describe_remediation_configurations","url":"aws_api/config_service.html#describe_remediation_configurations"},{"doc":"aws_api/config_service","title":"describe_remediation_exceptions","content":"pub fn describe_remediation_exceptions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.describe_remediation_exceptions\naws_api/config_service describe_remediation_exceptions","url":"aws_api/config_service.html#describe_remediation_exceptions"},{"doc":"aws_api/config_service","title":"describe_remediation_execution_status","content":"pub fn describe_remediation_execution_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.describe_remediation_execution_status\naws_api/config_service describe_remediation_execution_status","url":"aws_api/config_service.html#describe_remediation_execution_status"},{"doc":"aws_api/config_service","title":"describe_retention_configurations","content":"pub fn describe_retention_configurations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.describe_retention_configurations\naws_api/config_service describe_retention_configurations","url":"aws_api/config_service.html#describe_retention_configurations"},{"doc":"aws_api/config_service","title":"get_aggregate_compliance_details_by_config_rule","content":"pub fn get_aggregate_compliance_details_by_config_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.get_aggregate_compliance_details_by_config_rule\naws_api/config_service get_aggregate_compliance_details_by_config_rule","url":"aws_api/config_service.html#get_aggregate_compliance_details_by_config_rule"},{"doc":"aws_api/config_service","title":"get_aggregate_config_rule_compliance_summary","content":"pub fn get_aggregate_config_rule_compliance_summary(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.get_aggregate_config_rule_compliance_summary\naws_api/config_service get_aggregate_config_rule_compliance_summary","url":"aws_api/config_service.html#get_aggregate_config_rule_compliance_summary"},{"doc":"aws_api/config_service","title":"get_aggregate_conformance_pack_compliance_summary","content":"pub fn get_aggregate_conformance_pack_compliance_summary(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.get_aggregate_conformance_pack_compliance_summary\naws_api/config_service get_aggregate_conformance_pack_compliance_summary","url":"aws_api/config_service.html#get_aggregate_conformance_pack_compliance_summary"},{"doc":"aws_api/config_service","title":"get_aggregate_discovered_resource_counts","content":"pub fn get_aggregate_discovered_resource_counts(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.get_aggregate_discovered_resource_counts\naws_api/config_service get_aggregate_discovered_resource_counts","url":"aws_api/config_service.html#get_aggregate_discovered_resource_counts"},{"doc":"aws_api/config_service","title":"get_aggregate_resource_config","content":"pub fn get_aggregate_resource_config(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.get_aggregate_resource_config\naws_api/config_service get_aggregate_resource_config","url":"aws_api/config_service.html#get_aggregate_resource_config"},{"doc":"aws_api/config_service","title":"get_compliance_details_by_config_rule","content":"pub fn get_compliance_details_by_config_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.get_compliance_details_by_config_rule\naws_api/config_service get_compliance_details_by_config_rule","url":"aws_api/config_service.html#get_compliance_details_by_config_rule"},{"doc":"aws_api/config_service","title":"get_compliance_details_by_resource","content":"pub fn get_compliance_details_by_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.get_compliance_details_by_resource\naws_api/config_service get_compliance_details_by_resource","url":"aws_api/config_service.html#get_compliance_details_by_resource"},{"doc":"aws_api/config_service","title":"get_compliance_summary_by_config_rule","content":"pub fn get_compliance_summary_by_config_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.get_compliance_summary_by_config_rule\naws_api/config_service get_compliance_summary_by_config_rule","url":"aws_api/config_service.html#get_compliance_summary_by_config_rule"},{"doc":"aws_api/config_service","title":"get_compliance_summary_by_resource_type","content":"pub fn get_compliance_summary_by_resource_type(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.get_compliance_summary_by_resource_type\naws_api/config_service get_compliance_summary_by_resource_type","url":"aws_api/config_service.html#get_compliance_summary_by_resource_type"},{"doc":"aws_api/config_service","title":"get_conformance_pack_compliance_details","content":"pub fn get_conformance_pack_compliance_details(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.get_conformance_pack_compliance_details\naws_api/config_service get_conformance_pack_compliance_details","url":"aws_api/config_service.html#get_conformance_pack_compliance_details"},{"doc":"aws_api/config_service","title":"get_conformance_pack_compliance_summary","content":"pub fn get_conformance_pack_compliance_summary(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.get_conformance_pack_compliance_summary\naws_api/config_service get_conformance_pack_compliance_summary","url":"aws_api/config_service.html#get_conformance_pack_compliance_summary"},{"doc":"aws_api/config_service","title":"get_custom_rule_policy","content":"pub fn get_custom_rule_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.get_custom_rule_policy\naws_api/config_service get_custom_rule_policy","url":"aws_api/config_service.html#get_custom_rule_policy"},{"doc":"aws_api/config_service","title":"get_discovered_resource_counts","content":"pub fn get_discovered_resource_counts(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.get_discovered_resource_counts\naws_api/config_service get_discovered_resource_counts","url":"aws_api/config_service.html#get_discovered_resource_counts"},{"doc":"aws_api/config_service","title":"get_organization_config_rule_detailed_status","content":"pub fn get_organization_config_rule_detailed_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.get_organization_config_rule_detailed_status\naws_api/config_service get_organization_config_rule_detailed_status","url":"aws_api/config_service.html#get_organization_config_rule_detailed_status"},{"doc":"aws_api/config_service","title":"get_organization_conformance_pack_detailed_status","content":"pub fn get_organization_conformance_pack_detailed_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.get_organization_conformance_pack_detailed_status\naws_api/config_service get_organization_conformance_pack_detailed_status","url":"aws_api/config_service.html#get_organization_conformance_pack_detailed_status"},{"doc":"aws_api/config_service","title":"get_organization_custom_rule_policy","content":"pub fn get_organization_custom_rule_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.get_organization_custom_rule_policy\naws_api/config_service get_organization_custom_rule_policy","url":"aws_api/config_service.html#get_organization_custom_rule_policy"},{"doc":"aws_api/config_service","title":"get_resource_config_history","content":"pub fn get_resource_config_history(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.get_resource_config_history\naws_api/config_service get_resource_config_history","url":"aws_api/config_service.html#get_resource_config_history"},{"doc":"aws_api/config_service","title":"get_resource_evaluation_summary","content":"pub fn get_resource_evaluation_summary(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.get_resource_evaluation_summary\naws_api/config_service get_resource_evaluation_summary","url":"aws_api/config_service.html#get_resource_evaluation_summary"},{"doc":"aws_api/config_service","title":"get_stored_query","content":"pub fn get_stored_query(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.get_stored_query\naws_api/config_service get_stored_query","url":"aws_api/config_service.html#get_stored_query"},{"doc":"aws_api/config_service","title":"list_aggregate_discovered_resources","content":"pub fn list_aggregate_discovered_resources(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.list_aggregate_discovered_resources\naws_api/config_service list_aggregate_discovered_resources","url":"aws_api/config_service.html#list_aggregate_discovered_resources"},{"doc":"aws_api/config_service","title":"list_conformance_pack_compliance_scores","content":"pub fn list_conformance_pack_compliance_scores(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.list_conformance_pack_compliance_scores\naws_api/config_service list_conformance_pack_compliance_scores","url":"aws_api/config_service.html#list_conformance_pack_compliance_scores"},{"doc":"aws_api/config_service","title":"list_discovered_resources","content":"pub fn list_discovered_resources(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.list_discovered_resources\naws_api/config_service list_discovered_resources","url":"aws_api/config_service.html#list_discovered_resources"},{"doc":"aws_api/config_service","title":"list_resource_evaluations","content":"pub fn list_resource_evaluations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.list_resource_evaluations\naws_api/config_service list_resource_evaluations","url":"aws_api/config_service.html#list_resource_evaluations"},{"doc":"aws_api/config_service","title":"list_stored_queries","content":"pub fn list_stored_queries(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.list_stored_queries\naws_api/config_service list_stored_queries","url":"aws_api/config_service.html#list_stored_queries"},{"doc":"aws_api/config_service","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.list_tags_for_resource\naws_api/config_service list_tags_for_resource","url":"aws_api/config_service.html#list_tags_for_resource"},{"doc":"aws_api/config_service","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/config_service.new\naws_api/config_service new","url":"aws_api/config_service.html#new"},{"doc":"aws_api/config_service","title":"put_aggregation_authorization","content":"pub fn put_aggregation_authorization(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.put_aggregation_authorization\naws_api/config_service put_aggregation_authorization","url":"aws_api/config_service.html#put_aggregation_authorization"},{"doc":"aws_api/config_service","title":"put_config_rule","content":"pub fn put_config_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.put_config_rule\naws_api/config_service put_config_rule","url":"aws_api/config_service.html#put_config_rule"},{"doc":"aws_api/config_service","title":"put_configuration_aggregator","content":"pub fn put_configuration_aggregator(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.put_configuration_aggregator\naws_api/config_service put_configuration_aggregator","url":"aws_api/config_service.html#put_configuration_aggregator"},{"doc":"aws_api/config_service","title":"put_configuration_recorder","content":"pub fn put_configuration_recorder(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.put_configuration_recorder\naws_api/config_service put_configuration_recorder","url":"aws_api/config_service.html#put_configuration_recorder"},{"doc":"aws_api/config_service","title":"put_conformance_pack","content":"pub fn put_conformance_pack(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.put_conformance_pack\naws_api/config_service put_conformance_pack","url":"aws_api/config_service.html#put_conformance_pack"},{"doc":"aws_api/config_service","title":"put_delivery_channel","content":"pub fn put_delivery_channel(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.put_delivery_channel\naws_api/config_service put_delivery_channel","url":"aws_api/config_service.html#put_delivery_channel"},{"doc":"aws_api/config_service","title":"put_evaluations","content":"pub fn put_evaluations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.put_evaluations\naws_api/config_service put_evaluations","url":"aws_api/config_service.html#put_evaluations"},{"doc":"aws_api/config_service","title":"put_external_evaluation","content":"pub fn put_external_evaluation(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.put_external_evaluation\naws_api/config_service put_external_evaluation","url":"aws_api/config_service.html#put_external_evaluation"},{"doc":"aws_api/config_service","title":"put_organization_config_rule","content":"pub fn put_organization_config_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.put_organization_config_rule\naws_api/config_service put_organization_config_rule","url":"aws_api/config_service.html#put_organization_config_rule"},{"doc":"aws_api/config_service","title":"put_organization_conformance_pack","content":"pub fn put_organization_conformance_pack(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.put_organization_conformance_pack\naws_api/config_service put_organization_conformance_pack","url":"aws_api/config_service.html#put_organization_conformance_pack"},{"doc":"aws_api/config_service","title":"put_remediation_configurations","content":"pub fn put_remediation_configurations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.put_remediation_configurations\naws_api/config_service put_remediation_configurations","url":"aws_api/config_service.html#put_remediation_configurations"},{"doc":"aws_api/config_service","title":"put_remediation_exceptions","content":"pub fn put_remediation_exceptions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.put_remediation_exceptions\naws_api/config_service put_remediation_exceptions","url":"aws_api/config_service.html#put_remediation_exceptions"},{"doc":"aws_api/config_service","title":"put_resource_config","content":"pub fn put_resource_config(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.put_resource_config\naws_api/config_service put_resource_config","url":"aws_api/config_service.html#put_resource_config"},{"doc":"aws_api/config_service","title":"put_retention_configuration","content":"pub fn put_retention_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.put_retention_configuration\naws_api/config_service put_retention_configuration","url":"aws_api/config_service.html#put_retention_configuration"},{"doc":"aws_api/config_service","title":"put_stored_query","content":"pub fn put_stored_query(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.put_stored_query\naws_api/config_service put_stored_query","url":"aws_api/config_service.html#put_stored_query"},{"doc":"aws_api/config_service","title":"select_aggregate_resource_config","content":"pub fn select_aggregate_resource_config(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.select_aggregate_resource_config\naws_api/config_service select_aggregate_resource_config","url":"aws_api/config_service.html#select_aggregate_resource_config"},{"doc":"aws_api/config_service","title":"select_resource_config","content":"pub fn select_resource_config(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.select_resource_config\naws_api/config_service select_resource_config","url":"aws_api/config_service.html#select_resource_config"},{"doc":"aws_api/config_service","title":"start_config_rules_evaluation","content":"pub fn start_config_rules_evaluation(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.start_config_rules_evaluation\naws_api/config_service start_config_rules_evaluation","url":"aws_api/config_service.html#start_config_rules_evaluation"},{"doc":"aws_api/config_service","title":"start_configuration_recorder","content":"pub fn start_configuration_recorder(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.start_configuration_recorder\naws_api/config_service start_configuration_recorder","url":"aws_api/config_service.html#start_configuration_recorder"},{"doc":"aws_api/config_service","title":"start_remediation_execution","content":"pub fn start_remediation_execution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.start_remediation_execution\naws_api/config_service start_remediation_execution","url":"aws_api/config_service.html#start_remediation_execution"},{"doc":"aws_api/config_service","title":"start_resource_evaluation","content":"pub fn start_resource_evaluation(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.start_resource_evaluation\naws_api/config_service start_resource_evaluation","url":"aws_api/config_service.html#start_resource_evaluation"},{"doc":"aws_api/config_service","title":"stop_configuration_recorder","content":"pub fn stop_configuration_recorder(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.stop_configuration_recorder\naws_api/config_service stop_configuration_recorder","url":"aws_api/config_service.html#stop_configuration_recorder"},{"doc":"aws_api/config_service","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.tag_resource\naws_api/config_service tag_resource","url":"aws_api/config_service.html#tag_resource"},{"doc":"aws_api/config_service","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/config_service.untag_resource\naws_api/config_service untag_resource","url":"aws_api/config_service.html#untag_resource"},{"doc":"aws_api/config_service","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/config_service.with_custom_endpoint\naws_api/config_service with_custom_endpoint","url":"aws_api/config_service.html#with_custom_endpoint"},{"doc":"aws_api/config_service","title":"aws_api/config_service","content":"","url":"aws_api/config_service.html"},{"doc":"aws_api/connect","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/connect.Client\naws_api/connect Client","url":"aws_api/connect.html#Client"},{"doc":"aws_api/connect","title":"activate_evaluation_form","content":"pub fn activate_evaluation_form(\n  client: Client,\n  instance_id: String,\n  evaluation_form_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.activate_evaluation_form\naws_api/connect activate_evaluation_form","url":"aws_api/connect.html#activate_evaluation_form"},{"doc":"aws_api/connect","title":"associate_analytics_data_set","content":"pub fn associate_analytics_data_set(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.associate_analytics_data_set\naws_api/connect associate_analytics_data_set","url":"aws_api/connect.html#associate_analytics_data_set"},{"doc":"aws_api/connect","title":"associate_approved_origin","content":"pub fn associate_approved_origin(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.associate_approved_origin\naws_api/connect associate_approved_origin","url":"aws_api/connect.html#associate_approved_origin"},{"doc":"aws_api/connect","title":"associate_bot","content":"pub fn associate_bot(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.associate_bot\naws_api/connect associate_bot","url":"aws_api/connect.html#associate_bot"},{"doc":"aws_api/connect","title":"associate_default_vocabulary","content":"pub fn associate_default_vocabulary(\n  client: Client,\n  instance_id: String,\n  language_code: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.associate_default_vocabulary\naws_api/connect associate_default_vocabulary","url":"aws_api/connect.html#associate_default_vocabulary"},{"doc":"aws_api/connect","title":"associate_flow","content":"pub fn associate_flow(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.associate_flow\naws_api/connect associate_flow","url":"aws_api/connect.html#associate_flow"},{"doc":"aws_api/connect","title":"associate_instance_storage_config","content":"pub fn associate_instance_storage_config(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.associate_instance_storage_config\naws_api/connect associate_instance_storage_config","url":"aws_api/connect.html#associate_instance_storage_config"},{"doc":"aws_api/connect","title":"associate_lambda_function","content":"pub fn associate_lambda_function(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.associate_lambda_function\naws_api/connect associate_lambda_function","url":"aws_api/connect.html#associate_lambda_function"},{"doc":"aws_api/connect","title":"associate_lex_bot","content":"pub fn associate_lex_bot(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.associate_lex_bot\naws_api/connect associate_lex_bot","url":"aws_api/connect.html#associate_lex_bot"},{"doc":"aws_api/connect","title":"associate_phone_number_contact_flow","content":"pub fn associate_phone_number_contact_flow(\n  client: Client,\n  phone_number_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.associate_phone_number_contact_flow\naws_api/connect associate_phone_number_contact_flow","url":"aws_api/connect.html#associate_phone_number_contact_flow"},{"doc":"aws_api/connect","title":"associate_queue_quick_connects","content":"pub fn associate_queue_quick_connects(\n  client: Client,\n  instance_id: String,\n  queue_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.associate_queue_quick_connects\naws_api/connect associate_queue_quick_connects","url":"aws_api/connect.html#associate_queue_quick_connects"},{"doc":"aws_api/connect","title":"associate_routing_profile_queues","content":"pub fn associate_routing_profile_queues(\n  client: Client,\n  instance_id: String,\n  routing_profile_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.associate_routing_profile_queues\naws_api/connect associate_routing_profile_queues","url":"aws_api/connect.html#associate_routing_profile_queues"},{"doc":"aws_api/connect","title":"associate_security_key","content":"pub fn associate_security_key(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.associate_security_key\naws_api/connect associate_security_key","url":"aws_api/connect.html#associate_security_key"},{"doc":"aws_api/connect","title":"associate_traffic_distribution_group_user","content":"pub fn associate_traffic_distribution_group_user(\n  client: Client,\n  traffic_distribution_group_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.associate_traffic_distribution_group_user\naws_api/connect associate_traffic_distribution_group_user","url":"aws_api/connect.html#associate_traffic_distribution_group_user"},{"doc":"aws_api/connect","title":"associate_user_proficiencies","content":"pub fn associate_user_proficiencies(\n  client: Client,\n  instance_id: String,\n  user_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.associate_user_proficiencies\naws_api/connect associate_user_proficiencies","url":"aws_api/connect.html#associate_user_proficiencies"},{"doc":"aws_api/connect","title":"batch_associate_analytics_data_set","content":"pub fn batch_associate_analytics_data_set(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.batch_associate_analytics_data_set\naws_api/connect batch_associate_analytics_data_set","url":"aws_api/connect.html#batch_associate_analytics_data_set"},{"doc":"aws_api/connect","title":"batch_disassociate_analytics_data_set","content":"pub fn batch_disassociate_analytics_data_set(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.batch_disassociate_analytics_data_set\naws_api/connect batch_disassociate_analytics_data_set","url":"aws_api/connect.html#batch_disassociate_analytics_data_set"},{"doc":"aws_api/connect","title":"batch_get_attached_file_metadata","content":"pub fn batch_get_attached_file_metadata(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.batch_get_attached_file_metadata\naws_api/connect batch_get_attached_file_metadata","url":"aws_api/connect.html#batch_get_attached_file_metadata"},{"doc":"aws_api/connect","title":"batch_get_flow_association","content":"pub fn batch_get_flow_association(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.batch_get_flow_association\naws_api/connect batch_get_flow_association","url":"aws_api/connect.html#batch_get_flow_association"},{"doc":"aws_api/connect","title":"batch_put_contact","content":"pub fn batch_put_contact(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.batch_put_contact\naws_api/connect batch_put_contact","url":"aws_api/connect.html#batch_put_contact"},{"doc":"aws_api/connect","title":"claim_phone_number","content":"pub fn claim_phone_number(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.claim_phone_number\naws_api/connect claim_phone_number","url":"aws_api/connect.html#claim_phone_number"},{"doc":"aws_api/connect","title":"complete_attached_file_upload","content":"pub fn complete_attached_file_upload(\n  client: Client,\n  instance_id: String,\n  file_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.complete_attached_file_upload\naws_api/connect complete_attached_file_upload","url":"aws_api/connect.html#complete_attached_file_upload"},{"doc":"aws_api/connect","title":"create_agent_status","content":"pub fn create_agent_status(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.create_agent_status\naws_api/connect create_agent_status","url":"aws_api/connect.html#create_agent_status"},{"doc":"aws_api/connect","title":"create_contact_flow","content":"pub fn create_contact_flow(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.create_contact_flow\naws_api/connect create_contact_flow","url":"aws_api/connect.html#create_contact_flow"},{"doc":"aws_api/connect","title":"create_contact_flow_module","content":"pub fn create_contact_flow_module(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.create_contact_flow_module\naws_api/connect create_contact_flow_module","url":"aws_api/connect.html#create_contact_flow_module"},{"doc":"aws_api/connect","title":"create_evaluation_form","content":"pub fn create_evaluation_form(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.create_evaluation_form\naws_api/connect create_evaluation_form","url":"aws_api/connect.html#create_evaluation_form"},{"doc":"aws_api/connect","title":"create_hours_of_operation","content":"pub fn create_hours_of_operation(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.create_hours_of_operation\naws_api/connect create_hours_of_operation","url":"aws_api/connect.html#create_hours_of_operation"},{"doc":"aws_api/connect","title":"create_instance","content":"pub fn create_instance(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.create_instance\naws_api/connect create_instance","url":"aws_api/connect.html#create_instance"},{"doc":"aws_api/connect","title":"create_integration_association","content":"pub fn create_integration_association(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.create_integration_association\naws_api/connect create_integration_association","url":"aws_api/connect.html#create_integration_association"},{"doc":"aws_api/connect","title":"create_participant","content":"pub fn create_participant(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.create_participant\naws_api/connect create_participant","url":"aws_api/connect.html#create_participant"},{"doc":"aws_api/connect","title":"create_persistent_contact_association","content":"pub fn create_persistent_contact_association(\n  client: Client,\n  instance_id: String,\n  initial_contact_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.create_persistent_contact_association\naws_api/connect create_persistent_contact_association","url":"aws_api/connect.html#create_persistent_contact_association"},{"doc":"aws_api/connect","title":"create_predefined_attribute","content":"pub fn create_predefined_attribute(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.create_predefined_attribute\naws_api/connect create_predefined_attribute","url":"aws_api/connect.html#create_predefined_attribute"},{"doc":"aws_api/connect","title":"create_prompt","content":"pub fn create_prompt(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.create_prompt\naws_api/connect create_prompt","url":"aws_api/connect.html#create_prompt"},{"doc":"aws_api/connect","title":"create_queue","content":"pub fn create_queue(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.create_queue\naws_api/connect create_queue","url":"aws_api/connect.html#create_queue"},{"doc":"aws_api/connect","title":"create_quick_connect","content":"pub fn create_quick_connect(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.create_quick_connect\naws_api/connect create_quick_connect","url":"aws_api/connect.html#create_quick_connect"},{"doc":"aws_api/connect","title":"create_routing_profile","content":"pub fn create_routing_profile(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.create_routing_profile\naws_api/connect create_routing_profile","url":"aws_api/connect.html#create_routing_profile"},{"doc":"aws_api/connect","title":"create_rule","content":"pub fn create_rule(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.create_rule\naws_api/connect create_rule","url":"aws_api/connect.html#create_rule"},{"doc":"aws_api/connect","title":"create_security_profile","content":"pub fn create_security_profile(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.create_security_profile\naws_api/connect create_security_profile","url":"aws_api/connect.html#create_security_profile"},{"doc":"aws_api/connect","title":"create_task_template","content":"pub fn create_task_template(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.create_task_template\naws_api/connect create_task_template","url":"aws_api/connect.html#create_task_template"},{"doc":"aws_api/connect","title":"create_traffic_distribution_group","content":"pub fn create_traffic_distribution_group(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.create_traffic_distribution_group\naws_api/connect create_traffic_distribution_group","url":"aws_api/connect.html#create_traffic_distribution_group"},{"doc":"aws_api/connect","title":"create_use_case","content":"pub fn create_use_case(\n  client: Client,\n  instance_id: String,\n  integration_association_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.create_use_case\naws_api/connect create_use_case","url":"aws_api/connect.html#create_use_case"},{"doc":"aws_api/connect","title":"create_user","content":"pub fn create_user(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.create_user\naws_api/connect create_user","url":"aws_api/connect.html#create_user"},{"doc":"aws_api/connect","title":"create_user_hierarchy_group","content":"pub fn create_user_hierarchy_group(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.create_user_hierarchy_group\naws_api/connect create_user_hierarchy_group","url":"aws_api/connect.html#create_user_hierarchy_group"},{"doc":"aws_api/connect","title":"create_view","content":"pub fn create_view(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.create_view\naws_api/connect create_view","url":"aws_api/connect.html#create_view"},{"doc":"aws_api/connect","title":"create_view_version","content":"pub fn create_view_version(\n  client: Client,\n  instance_id: String,\n  view_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.create_view_version\naws_api/connect create_view_version","url":"aws_api/connect.html#create_view_version"},{"doc":"aws_api/connect","title":"create_vocabulary","content":"pub fn create_vocabulary(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.create_vocabulary\naws_api/connect create_vocabulary","url":"aws_api/connect.html#create_vocabulary"},{"doc":"aws_api/connect","title":"deactivate_evaluation_form","content":"pub fn deactivate_evaluation_form(\n  client: Client,\n  instance_id: String,\n  evaluation_form_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.deactivate_evaluation_form\naws_api/connect deactivate_evaluation_form","url":"aws_api/connect.html#deactivate_evaluation_form"},{"doc":"aws_api/connect","title":"delete_attached_file","content":"pub fn delete_attached_file(\n  client: Client,\n  instance_id: String,\n  file_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.delete_attached_file\naws_api/connect delete_attached_file","url":"aws_api/connect.html#delete_attached_file"},{"doc":"aws_api/connect","title":"delete_contact_evaluation","content":"pub fn delete_contact_evaluation(\n  client: Client,\n  instance_id: String,\n  evaluation_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.delete_contact_evaluation\naws_api/connect delete_contact_evaluation","url":"aws_api/connect.html#delete_contact_evaluation"},{"doc":"aws_api/connect","title":"delete_contact_flow","content":"pub fn delete_contact_flow(\n  client: Client,\n  instance_id: String,\n  contact_flow_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.delete_contact_flow\naws_api/connect delete_contact_flow","url":"aws_api/connect.html#delete_contact_flow"},{"doc":"aws_api/connect","title":"delete_contact_flow_module","content":"pub fn delete_contact_flow_module(\n  client: Client,\n  instance_id: String,\n  contact_flow_module_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.delete_contact_flow_module\naws_api/connect delete_contact_flow_module","url":"aws_api/connect.html#delete_contact_flow_module"},{"doc":"aws_api/connect","title":"delete_evaluation_form","content":"pub fn delete_evaluation_form(\n  client: Client,\n  instance_id: String,\n  evaluation_form_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.delete_evaluation_form\naws_api/connect delete_evaluation_form","url":"aws_api/connect.html#delete_evaluation_form"},{"doc":"aws_api/connect","title":"delete_hours_of_operation","content":"pub fn delete_hours_of_operation(\n  client: Client,\n  instance_id: String,\n  hours_of_operation_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.delete_hours_of_operation\naws_api/connect delete_hours_of_operation","url":"aws_api/connect.html#delete_hours_of_operation"},{"doc":"aws_api/connect","title":"delete_instance","content":"pub fn delete_instance(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.delete_instance\naws_api/connect delete_instance","url":"aws_api/connect.html#delete_instance"},{"doc":"aws_api/connect","title":"delete_integration_association","content":"pub fn delete_integration_association(\n  client: Client,\n  instance_id: String,\n  integration_association_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.delete_integration_association\naws_api/connect delete_integration_association","url":"aws_api/connect.html#delete_integration_association"},{"doc":"aws_api/connect","title":"delete_predefined_attribute","content":"pub fn delete_predefined_attribute(\n  client: Client,\n  instance_id: String,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.delete_predefined_attribute\naws_api/connect delete_predefined_attribute","url":"aws_api/connect.html#delete_predefined_attribute"},{"doc":"aws_api/connect","title":"delete_prompt","content":"pub fn delete_prompt(\n  client: Client,\n  instance_id: String,\n  prompt_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.delete_prompt\naws_api/connect delete_prompt","url":"aws_api/connect.html#delete_prompt"},{"doc":"aws_api/connect","title":"delete_queue","content":"pub fn delete_queue(\n  client: Client,\n  instance_id: String,\n  queue_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.delete_queue\naws_api/connect delete_queue","url":"aws_api/connect.html#delete_queue"},{"doc":"aws_api/connect","title":"delete_quick_connect","content":"pub fn delete_quick_connect(\n  client: Client,\n  instance_id: String,\n  quick_connect_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.delete_quick_connect\naws_api/connect delete_quick_connect","url":"aws_api/connect.html#delete_quick_connect"},{"doc":"aws_api/connect","title":"delete_routing_profile","content":"pub fn delete_routing_profile(\n  client: Client,\n  instance_id: String,\n  routing_profile_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.delete_routing_profile\naws_api/connect delete_routing_profile","url":"aws_api/connect.html#delete_routing_profile"},{"doc":"aws_api/connect","title":"delete_rule","content":"pub fn delete_rule(\n  client: Client,\n  instance_id: String,\n  rule_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.delete_rule\naws_api/connect delete_rule","url":"aws_api/connect.html#delete_rule"},{"doc":"aws_api/connect","title":"delete_security_profile","content":"pub fn delete_security_profile(\n  client: Client,\n  instance_id: String,\n  security_profile_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.delete_security_profile\naws_api/connect delete_security_profile","url":"aws_api/connect.html#delete_security_profile"},{"doc":"aws_api/connect","title":"delete_task_template","content":"pub fn delete_task_template(\n  client: Client,\n  instance_id: String,\n  task_template_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.delete_task_template\naws_api/connect delete_task_template","url":"aws_api/connect.html#delete_task_template"},{"doc":"aws_api/connect","title":"delete_traffic_distribution_group","content":"pub fn delete_traffic_distribution_group(\n  client: Client,\n  traffic_distribution_group_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.delete_traffic_distribution_group\naws_api/connect delete_traffic_distribution_group","url":"aws_api/connect.html#delete_traffic_distribution_group"},{"doc":"aws_api/connect","title":"delete_use_case","content":"pub fn delete_use_case(\n  client: Client,\n  instance_id: String,\n  integration_association_id: String,\n  use_case_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.delete_use_case\naws_api/connect delete_use_case","url":"aws_api/connect.html#delete_use_case"},{"doc":"aws_api/connect","title":"delete_user","content":"pub fn delete_user(\n  client: Client,\n  instance_id: String,\n  user_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.delete_user\naws_api/connect delete_user","url":"aws_api/connect.html#delete_user"},{"doc":"aws_api/connect","title":"delete_user_hierarchy_group","content":"pub fn delete_user_hierarchy_group(\n  client: Client,\n  instance_id: String,\n  hierarchy_group_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.delete_user_hierarchy_group\naws_api/connect delete_user_hierarchy_group","url":"aws_api/connect.html#delete_user_hierarchy_group"},{"doc":"aws_api/connect","title":"delete_view","content":"pub fn delete_view(\n  client: Client,\n  instance_id: String,\n  view_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.delete_view\naws_api/connect delete_view","url":"aws_api/connect.html#delete_view"},{"doc":"aws_api/connect","title":"delete_view_version","content":"pub fn delete_view_version(\n  client: Client,\n  instance_id: String,\n  view_id: String,\n  view_version: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.delete_view_version\naws_api/connect delete_view_version","url":"aws_api/connect.html#delete_view_version"},{"doc":"aws_api/connect","title":"delete_vocabulary","content":"pub fn delete_vocabulary(\n  client: Client,\n  instance_id: String,\n  vocabulary_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.delete_vocabulary\naws_api/connect delete_vocabulary","url":"aws_api/connect.html#delete_vocabulary"},{"doc":"aws_api/connect","title":"describe_agent_status","content":"pub fn describe_agent_status(\n  client: Client,\n  instance_id: String,\n  agent_status_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.describe_agent_status\naws_api/connect describe_agent_status","url":"aws_api/connect.html#describe_agent_status"},{"doc":"aws_api/connect","title":"describe_authentication_profile","content":"pub fn describe_authentication_profile(\n  client: Client,\n  instance_id: String,\n  authentication_profile_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.describe_authentication_profile\naws_api/connect describe_authentication_profile","url":"aws_api/connect.html#describe_authentication_profile"},{"doc":"aws_api/connect","title":"describe_contact","content":"pub fn describe_contact(\n  client: Client,\n  instance_id: String,\n  contact_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.describe_contact\naws_api/connect describe_contact","url":"aws_api/connect.html#describe_contact"},{"doc":"aws_api/connect","title":"describe_contact_evaluation","content":"pub fn describe_contact_evaluation(\n  client: Client,\n  instance_id: String,\n  evaluation_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.describe_contact_evaluation\naws_api/connect describe_contact_evaluation","url":"aws_api/connect.html#describe_contact_evaluation"},{"doc":"aws_api/connect","title":"describe_contact_flow","content":"pub fn describe_contact_flow(\n  client: Client,\n  instance_id: String,\n  contact_flow_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.describe_contact_flow\naws_api/connect describe_contact_flow","url":"aws_api/connect.html#describe_contact_flow"},{"doc":"aws_api/connect","title":"describe_contact_flow_module","content":"pub fn describe_contact_flow_module(\n  client: Client,\n  instance_id: String,\n  contact_flow_module_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.describe_contact_flow_module\naws_api/connect describe_contact_flow_module","url":"aws_api/connect.html#describe_contact_flow_module"},{"doc":"aws_api/connect","title":"describe_evaluation_form","content":"pub fn describe_evaluation_form(\n  client: Client,\n  instance_id: String,\n  evaluation_form_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.describe_evaluation_form\naws_api/connect describe_evaluation_form","url":"aws_api/connect.html#describe_evaluation_form"},{"doc":"aws_api/connect","title":"describe_hours_of_operation","content":"pub fn describe_hours_of_operation(\n  client: Client,\n  instance_id: String,\n  hours_of_operation_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.describe_hours_of_operation\naws_api/connect describe_hours_of_operation","url":"aws_api/connect.html#describe_hours_of_operation"},{"doc":"aws_api/connect","title":"describe_instance","content":"pub fn describe_instance(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.describe_instance\naws_api/connect describe_instance","url":"aws_api/connect.html#describe_instance"},{"doc":"aws_api/connect","title":"describe_instance_attribute","content":"pub fn describe_instance_attribute(\n  client: Client,\n  instance_id: String,\n  attribute_type: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.describe_instance_attribute\naws_api/connect describe_instance_attribute","url":"aws_api/connect.html#describe_instance_attribute"},{"doc":"aws_api/connect","title":"describe_instance_storage_config","content":"pub fn describe_instance_storage_config(\n  client: Client,\n  instance_id: String,\n  association_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.describe_instance_storage_config\naws_api/connect describe_instance_storage_config","url":"aws_api/connect.html#describe_instance_storage_config"},{"doc":"aws_api/connect","title":"describe_phone_number","content":"pub fn describe_phone_number(\n  client: Client,\n  phone_number_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.describe_phone_number\naws_api/connect describe_phone_number","url":"aws_api/connect.html#describe_phone_number"},{"doc":"aws_api/connect","title":"describe_predefined_attribute","content":"pub fn describe_predefined_attribute(\n  client: Client,\n  instance_id: String,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.describe_predefined_attribute\naws_api/connect describe_predefined_attribute","url":"aws_api/connect.html#describe_predefined_attribute"},{"doc":"aws_api/connect","title":"describe_prompt","content":"pub fn describe_prompt(\n  client: Client,\n  instance_id: String,\n  prompt_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.describe_prompt\naws_api/connect describe_prompt","url":"aws_api/connect.html#describe_prompt"},{"doc":"aws_api/connect","title":"describe_queue","content":"pub fn describe_queue(\n  client: Client,\n  instance_id: String,\n  queue_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.describe_queue\naws_api/connect describe_queue","url":"aws_api/connect.html#describe_queue"},{"doc":"aws_api/connect","title":"describe_quick_connect","content":"pub fn describe_quick_connect(\n  client: Client,\n  instance_id: String,\n  quick_connect_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.describe_quick_connect\naws_api/connect describe_quick_connect","url":"aws_api/connect.html#describe_quick_connect"},{"doc":"aws_api/connect","title":"describe_routing_profile","content":"pub fn describe_routing_profile(\n  client: Client,\n  instance_id: String,\n  routing_profile_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.describe_routing_profile\naws_api/connect describe_routing_profile","url":"aws_api/connect.html#describe_routing_profile"},{"doc":"aws_api/connect","title":"describe_rule","content":"pub fn describe_rule(\n  client: Client,\n  instance_id: String,\n  rule_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.describe_rule\naws_api/connect describe_rule","url":"aws_api/connect.html#describe_rule"},{"doc":"aws_api/connect","title":"describe_security_profile","content":"pub fn describe_security_profile(\n  client: Client,\n  instance_id: String,\n  security_profile_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.describe_security_profile\naws_api/connect describe_security_profile","url":"aws_api/connect.html#describe_security_profile"},{"doc":"aws_api/connect","title":"describe_traffic_distribution_group","content":"pub fn describe_traffic_distribution_group(\n  client: Client,\n  traffic_distribution_group_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.describe_traffic_distribution_group\naws_api/connect describe_traffic_distribution_group","url":"aws_api/connect.html#describe_traffic_distribution_group"},{"doc":"aws_api/connect","title":"describe_user","content":"pub fn describe_user(\n  client: Client,\n  instance_id: String,\n  user_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.describe_user\naws_api/connect describe_user","url":"aws_api/connect.html#describe_user"},{"doc":"aws_api/connect","title":"describe_user_hierarchy_group","content":"pub fn describe_user_hierarchy_group(\n  client: Client,\n  instance_id: String,\n  hierarchy_group_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.describe_user_hierarchy_group\naws_api/connect describe_user_hierarchy_group","url":"aws_api/connect.html#describe_user_hierarchy_group"},{"doc":"aws_api/connect","title":"describe_user_hierarchy_structure","content":"pub fn describe_user_hierarchy_structure(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.describe_user_hierarchy_structure\naws_api/connect describe_user_hierarchy_structure","url":"aws_api/connect.html#describe_user_hierarchy_structure"},{"doc":"aws_api/connect","title":"describe_view","content":"pub fn describe_view(\n  client: Client,\n  instance_id: String,\n  view_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.describe_view\naws_api/connect describe_view","url":"aws_api/connect.html#describe_view"},{"doc":"aws_api/connect","title":"describe_vocabulary","content":"pub fn describe_vocabulary(\n  client: Client,\n  instance_id: String,\n  vocabulary_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.describe_vocabulary\naws_api/connect describe_vocabulary","url":"aws_api/connect.html#describe_vocabulary"},{"doc":"aws_api/connect","title":"disassociate_analytics_data_set","content":"pub fn disassociate_analytics_data_set(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.disassociate_analytics_data_set\naws_api/connect disassociate_analytics_data_set","url":"aws_api/connect.html#disassociate_analytics_data_set"},{"doc":"aws_api/connect","title":"disassociate_approved_origin","content":"pub fn disassociate_approved_origin(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.disassociate_approved_origin\naws_api/connect disassociate_approved_origin","url":"aws_api/connect.html#disassociate_approved_origin"},{"doc":"aws_api/connect","title":"disassociate_bot","content":"pub fn disassociate_bot(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.disassociate_bot\naws_api/connect disassociate_bot","url":"aws_api/connect.html#disassociate_bot"},{"doc":"aws_api/connect","title":"disassociate_flow","content":"pub fn disassociate_flow(\n  client: Client,\n  instance_id: String,\n  resource_id: String,\n  resource_type: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.disassociate_flow\naws_api/connect disassociate_flow","url":"aws_api/connect.html#disassociate_flow"},{"doc":"aws_api/connect","title":"disassociate_instance_storage_config","content":"pub fn disassociate_instance_storage_config(\n  client: Client,\n  instance_id: String,\n  association_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.disassociate_instance_storage_config\naws_api/connect disassociate_instance_storage_config","url":"aws_api/connect.html#disassociate_instance_storage_config"},{"doc":"aws_api/connect","title":"disassociate_lambda_function","content":"pub fn disassociate_lambda_function(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.disassociate_lambda_function\naws_api/connect disassociate_lambda_function","url":"aws_api/connect.html#disassociate_lambda_function"},{"doc":"aws_api/connect","title":"disassociate_lex_bot","content":"pub fn disassociate_lex_bot(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.disassociate_lex_bot\naws_api/connect disassociate_lex_bot","url":"aws_api/connect.html#disassociate_lex_bot"},{"doc":"aws_api/connect","title":"disassociate_phone_number_contact_flow","content":"pub fn disassociate_phone_number_contact_flow(\n  client: Client,\n  phone_number_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.disassociate_phone_number_contact_flow\naws_api/connect disassociate_phone_number_contact_flow","url":"aws_api/connect.html#disassociate_phone_number_contact_flow"},{"doc":"aws_api/connect","title":"disassociate_queue_quick_connects","content":"pub fn disassociate_queue_quick_connects(\n  client: Client,\n  instance_id: String,\n  queue_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.disassociate_queue_quick_connects\naws_api/connect disassociate_queue_quick_connects","url":"aws_api/connect.html#disassociate_queue_quick_connects"},{"doc":"aws_api/connect","title":"disassociate_routing_profile_queues","content":"pub fn disassociate_routing_profile_queues(\n  client: Client,\n  instance_id: String,\n  routing_profile_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.disassociate_routing_profile_queues\naws_api/connect disassociate_routing_profile_queues","url":"aws_api/connect.html#disassociate_routing_profile_queues"},{"doc":"aws_api/connect","title":"disassociate_security_key","content":"pub fn disassociate_security_key(\n  client: Client,\n  instance_id: String,\n  association_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.disassociate_security_key\naws_api/connect disassociate_security_key","url":"aws_api/connect.html#disassociate_security_key"},{"doc":"aws_api/connect","title":"disassociate_traffic_distribution_group_user","content":"pub fn disassociate_traffic_distribution_group_user(\n  client: Client,\n  traffic_distribution_group_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.disassociate_traffic_distribution_group_user\naws_api/connect disassociate_traffic_distribution_group_user","url":"aws_api/connect.html#disassociate_traffic_distribution_group_user"},{"doc":"aws_api/connect","title":"disassociate_user_proficiencies","content":"pub fn disassociate_user_proficiencies(\n  client: Client,\n  instance_id: String,\n  user_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.disassociate_user_proficiencies\naws_api/connect disassociate_user_proficiencies","url":"aws_api/connect.html#disassociate_user_proficiencies"},{"doc":"aws_api/connect","title":"dismiss_user_contact","content":"pub fn dismiss_user_contact(\n  client: Client,\n  instance_id: String,\n  user_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.dismiss_user_contact\naws_api/connect dismiss_user_contact","url":"aws_api/connect.html#dismiss_user_contact"},{"doc":"aws_api/connect","title":"get_attached_file","content":"pub fn get_attached_file(\n  client: Client,\n  instance_id: String,\n  file_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.get_attached_file\naws_api/connect get_attached_file","url":"aws_api/connect.html#get_attached_file"},{"doc":"aws_api/connect","title":"get_contact_attributes","content":"pub fn get_contact_attributes(\n  client: Client,\n  instance_id: String,\n  initial_contact_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.get_contact_attributes\naws_api/connect get_contact_attributes","url":"aws_api/connect.html#get_contact_attributes"},{"doc":"aws_api/connect","title":"get_current_metric_data","content":"pub fn get_current_metric_data(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.get_current_metric_data\naws_api/connect get_current_metric_data","url":"aws_api/connect.html#get_current_metric_data"},{"doc":"aws_api/connect","title":"get_current_user_data","content":"pub fn get_current_user_data(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.get_current_user_data\naws_api/connect get_current_user_data","url":"aws_api/connect.html#get_current_user_data"},{"doc":"aws_api/connect","title":"get_federation_token","content":"pub fn get_federation_token(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.get_federation_token\naws_api/connect get_federation_token","url":"aws_api/connect.html#get_federation_token"},{"doc":"aws_api/connect","title":"get_flow_association","content":"pub fn get_flow_association(\n  client: Client,\n  instance_id: String,\n  resource_id: String,\n  resource_type: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.get_flow_association\naws_api/connect get_flow_association","url":"aws_api/connect.html#get_flow_association"},{"doc":"aws_api/connect","title":"get_metric_data","content":"pub fn get_metric_data(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.get_metric_data\naws_api/connect get_metric_data","url":"aws_api/connect.html#get_metric_data"},{"doc":"aws_api/connect","title":"get_metric_data_v2","content":"pub fn get_metric_data_v2(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.get_metric_data_v2\naws_api/connect get_metric_data_v2","url":"aws_api/connect.html#get_metric_data_v2"},{"doc":"aws_api/connect","title":"get_prompt_file","content":"pub fn get_prompt_file(\n  client: Client,\n  instance_id: String,\n  prompt_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.get_prompt_file\naws_api/connect get_prompt_file","url":"aws_api/connect.html#get_prompt_file"},{"doc":"aws_api/connect","title":"get_task_template","content":"pub fn get_task_template(\n  client: Client,\n  instance_id: String,\n  task_template_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.get_task_template\naws_api/connect get_task_template","url":"aws_api/connect.html#get_task_template"},{"doc":"aws_api/connect","title":"get_traffic_distribution","content":"pub fn get_traffic_distribution(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.get_traffic_distribution\naws_api/connect get_traffic_distribution","url":"aws_api/connect.html#get_traffic_distribution"},{"doc":"aws_api/connect","title":"import_phone_number","content":"pub fn import_phone_number(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.import_phone_number\naws_api/connect import_phone_number","url":"aws_api/connect.html#import_phone_number"},{"doc":"aws_api/connect","title":"list_agent_statuses","content":"pub fn list_agent_statuses(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.list_agent_statuses\naws_api/connect list_agent_statuses","url":"aws_api/connect.html#list_agent_statuses"},{"doc":"aws_api/connect","title":"list_analytics_data_associations","content":"pub fn list_analytics_data_associations(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.list_analytics_data_associations\naws_api/connect list_analytics_data_associations","url":"aws_api/connect.html#list_analytics_data_associations"},{"doc":"aws_api/connect","title":"list_approved_origins","content":"pub fn list_approved_origins(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.list_approved_origins\naws_api/connect list_approved_origins","url":"aws_api/connect.html#list_approved_origins"},{"doc":"aws_api/connect","title":"list_authentication_profiles","content":"pub fn list_authentication_profiles(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.list_authentication_profiles\naws_api/connect list_authentication_profiles","url":"aws_api/connect.html#list_authentication_profiles"},{"doc":"aws_api/connect","title":"list_bots","content":"pub fn list_bots(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.list_bots\naws_api/connect list_bots","url":"aws_api/connect.html#list_bots"},{"doc":"aws_api/connect","title":"list_contact_evaluations","content":"pub fn list_contact_evaluations(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.list_contact_evaluations\naws_api/connect list_contact_evaluations","url":"aws_api/connect.html#list_contact_evaluations"},{"doc":"aws_api/connect","title":"list_contact_flow_modules","content":"pub fn list_contact_flow_modules(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.list_contact_flow_modules\naws_api/connect list_contact_flow_modules","url":"aws_api/connect.html#list_contact_flow_modules"},{"doc":"aws_api/connect","title":"list_contact_flows","content":"pub fn list_contact_flows(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.list_contact_flows\naws_api/connect list_contact_flows","url":"aws_api/connect.html#list_contact_flows"},{"doc":"aws_api/connect","title":"list_contact_references","content":"pub fn list_contact_references(\n  client: Client,\n  instance_id: String,\n  contact_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.list_contact_references\naws_api/connect list_contact_references","url":"aws_api/connect.html#list_contact_references"},{"doc":"aws_api/connect","title":"list_default_vocabularies","content":"pub fn list_default_vocabularies(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.list_default_vocabularies\naws_api/connect list_default_vocabularies","url":"aws_api/connect.html#list_default_vocabularies"},{"doc":"aws_api/connect","title":"list_evaluation_form_versions","content":"pub fn list_evaluation_form_versions(\n  client: Client,\n  instance_id: String,\n  evaluation_form_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.list_evaluation_form_versions\naws_api/connect list_evaluation_form_versions","url":"aws_api/connect.html#list_evaluation_form_versions"},{"doc":"aws_api/connect","title":"list_evaluation_forms","content":"pub fn list_evaluation_forms(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.list_evaluation_forms\naws_api/connect list_evaluation_forms","url":"aws_api/connect.html#list_evaluation_forms"},{"doc":"aws_api/connect","title":"list_flow_associations","content":"pub fn list_flow_associations(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.list_flow_associations\naws_api/connect list_flow_associations","url":"aws_api/connect.html#list_flow_associations"},{"doc":"aws_api/connect","title":"list_hours_of_operations","content":"pub fn list_hours_of_operations(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.list_hours_of_operations\naws_api/connect list_hours_of_operations","url":"aws_api/connect.html#list_hours_of_operations"},{"doc":"aws_api/connect","title":"list_instance_attributes","content":"pub fn list_instance_attributes(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.list_instance_attributes\naws_api/connect list_instance_attributes","url":"aws_api/connect.html#list_instance_attributes"},{"doc":"aws_api/connect","title":"list_instance_storage_configs","content":"pub fn list_instance_storage_configs(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.list_instance_storage_configs\naws_api/connect list_instance_storage_configs","url":"aws_api/connect.html#list_instance_storage_configs"},{"doc":"aws_api/connect","title":"list_instances","content":"pub fn list_instances(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.list_instances\naws_api/connect list_instances","url":"aws_api/connect.html#list_instances"},{"doc":"aws_api/connect","title":"list_integration_associations","content":"pub fn list_integration_associations(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.list_integration_associations\naws_api/connect list_integration_associations","url":"aws_api/connect.html#list_integration_associations"},{"doc":"aws_api/connect","title":"list_lambda_functions","content":"pub fn list_lambda_functions(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.list_lambda_functions\naws_api/connect list_lambda_functions","url":"aws_api/connect.html#list_lambda_functions"},{"doc":"aws_api/connect","title":"list_lex_bots","content":"pub fn list_lex_bots(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.list_lex_bots\naws_api/connect list_lex_bots","url":"aws_api/connect.html#list_lex_bots"},{"doc":"aws_api/connect","title":"list_phone_numbers","content":"pub fn list_phone_numbers(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.list_phone_numbers\naws_api/connect list_phone_numbers","url":"aws_api/connect.html#list_phone_numbers"},{"doc":"aws_api/connect","title":"list_phone_numbers_v2","content":"pub fn list_phone_numbers_v2(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.list_phone_numbers_v2\naws_api/connect list_phone_numbers_v2","url":"aws_api/connect.html#list_phone_numbers_v2"},{"doc":"aws_api/connect","title":"list_predefined_attributes","content":"pub fn list_predefined_attributes(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.list_predefined_attributes\naws_api/connect list_predefined_attributes","url":"aws_api/connect.html#list_predefined_attributes"},{"doc":"aws_api/connect","title":"list_prompts","content":"pub fn list_prompts(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.list_prompts\naws_api/connect list_prompts","url":"aws_api/connect.html#list_prompts"},{"doc":"aws_api/connect","title":"list_queue_quick_connects","content":"pub fn list_queue_quick_connects(\n  client: Client,\n  instance_id: String,\n  queue_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.list_queue_quick_connects\naws_api/connect list_queue_quick_connects","url":"aws_api/connect.html#list_queue_quick_connects"},{"doc":"aws_api/connect","title":"list_queues","content":"pub fn list_queues(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.list_queues\naws_api/connect list_queues","url":"aws_api/connect.html#list_queues"},{"doc":"aws_api/connect","title":"list_quick_connects","content":"pub fn list_quick_connects(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.list_quick_connects\naws_api/connect list_quick_connects","url":"aws_api/connect.html#list_quick_connects"},{"doc":"aws_api/connect","title":"list_realtime_contact_analysis_segments_v2","content":"pub fn list_realtime_contact_analysis_segments_v2(\n  client: Client,\n  instance_id: String,\n  contact_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.list_realtime_contact_analysis_segments_v2\naws_api/connect list_realtime_contact_analysis_segments_v2","url":"aws_api/connect.html#list_realtime_contact_analysis_segments_v2"},{"doc":"aws_api/connect","title":"list_routing_profile_queues","content":"pub fn list_routing_profile_queues(\n  client: Client,\n  instance_id: String,\n  routing_profile_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.list_routing_profile_queues\naws_api/connect list_routing_profile_queues","url":"aws_api/connect.html#list_routing_profile_queues"},{"doc":"aws_api/connect","title":"list_routing_profiles","content":"pub fn list_routing_profiles(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.list_routing_profiles\naws_api/connect list_routing_profiles","url":"aws_api/connect.html#list_routing_profiles"},{"doc":"aws_api/connect","title":"list_rules","content":"pub fn list_rules(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.list_rules\naws_api/connect list_rules","url":"aws_api/connect.html#list_rules"},{"doc":"aws_api/connect","title":"list_security_keys","content":"pub fn list_security_keys(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.list_security_keys\naws_api/connect list_security_keys","url":"aws_api/connect.html#list_security_keys"},{"doc":"aws_api/connect","title":"list_security_profile_applications","content":"pub fn list_security_profile_applications(\n  client: Client,\n  instance_id: String,\n  security_profile_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.list_security_profile_applications\naws_api/connect list_security_profile_applications","url":"aws_api/connect.html#list_security_profile_applications"},{"doc":"aws_api/connect","title":"list_security_profile_permissions","content":"pub fn list_security_profile_permissions(\n  client: Client,\n  instance_id: String,\n  security_profile_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.list_security_profile_permissions\naws_api/connect list_security_profile_permissions","url":"aws_api/connect.html#list_security_profile_permissions"},{"doc":"aws_api/connect","title":"list_security_profiles","content":"pub fn list_security_profiles(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.list_security_profiles\naws_api/connect list_security_profiles","url":"aws_api/connect.html#list_security_profiles"},{"doc":"aws_api/connect","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.list_tags_for_resource\naws_api/connect list_tags_for_resource","url":"aws_api/connect.html#list_tags_for_resource"},{"doc":"aws_api/connect","title":"list_task_templates","content":"pub fn list_task_templates(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.list_task_templates\naws_api/connect list_task_templates","url":"aws_api/connect.html#list_task_templates"},{"doc":"aws_api/connect","title":"list_traffic_distribution_group_users","content":"pub fn list_traffic_distribution_group_users(\n  client: Client,\n  traffic_distribution_group_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.list_traffic_distribution_group_users\naws_api/connect list_traffic_distribution_group_users","url":"aws_api/connect.html#list_traffic_distribution_group_users"},{"doc":"aws_api/connect","title":"list_traffic_distribution_groups","content":"pub fn list_traffic_distribution_groups(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.list_traffic_distribution_groups\naws_api/connect list_traffic_distribution_groups","url":"aws_api/connect.html#list_traffic_distribution_groups"},{"doc":"aws_api/connect","title":"list_use_cases","content":"pub fn list_use_cases(\n  client: Client,\n  instance_id: String,\n  integration_association_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.list_use_cases\naws_api/connect list_use_cases","url":"aws_api/connect.html#list_use_cases"},{"doc":"aws_api/connect","title":"list_user_hierarchy_groups","content":"pub fn list_user_hierarchy_groups(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.list_user_hierarchy_groups\naws_api/connect list_user_hierarchy_groups","url":"aws_api/connect.html#list_user_hierarchy_groups"},{"doc":"aws_api/connect","title":"list_user_proficiencies","content":"pub fn list_user_proficiencies(\n  client: Client,\n  instance_id: String,\n  user_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.list_user_proficiencies\naws_api/connect list_user_proficiencies","url":"aws_api/connect.html#list_user_proficiencies"},{"doc":"aws_api/connect","title":"list_users","content":"pub fn list_users(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.list_users\naws_api/connect list_users","url":"aws_api/connect.html#list_users"},{"doc":"aws_api/connect","title":"list_view_versions","content":"pub fn list_view_versions(\n  client: Client,\n  instance_id: String,\n  view_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.list_view_versions\naws_api/connect list_view_versions","url":"aws_api/connect.html#list_view_versions"},{"doc":"aws_api/connect","title":"list_views","content":"pub fn list_views(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.list_views\naws_api/connect list_views","url":"aws_api/connect.html#list_views"},{"doc":"aws_api/connect","title":"monitor_contact","content":"pub fn monitor_contact(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.monitor_contact\naws_api/connect monitor_contact","url":"aws_api/connect.html#monitor_contact"},{"doc":"aws_api/connect","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/connect.new\naws_api/connect new","url":"aws_api/connect.html#new"},{"doc":"aws_api/connect","title":"pause_contact","content":"pub fn pause_contact(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.pause_contact\naws_api/connect pause_contact","url":"aws_api/connect.html#pause_contact"},{"doc":"aws_api/connect","title":"put_user_status","content":"pub fn put_user_status(\n  client: Client,\n  instance_id: String,\n  user_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.put_user_status\naws_api/connect put_user_status","url":"aws_api/connect.html#put_user_status"},{"doc":"aws_api/connect","title":"release_phone_number","content":"pub fn release_phone_number(\n  client: Client,\n  phone_number_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.release_phone_number\naws_api/connect release_phone_number","url":"aws_api/connect.html#release_phone_number"},{"doc":"aws_api/connect","title":"replicate_instance","content":"pub fn replicate_instance(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.replicate_instance\naws_api/connect replicate_instance","url":"aws_api/connect.html#replicate_instance"},{"doc":"aws_api/connect","title":"resume_contact","content":"pub fn resume_contact(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.resume_contact\naws_api/connect resume_contact","url":"aws_api/connect.html#resume_contact"},{"doc":"aws_api/connect","title":"resume_contact_recording","content":"pub fn resume_contact_recording(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.resume_contact_recording\naws_api/connect resume_contact_recording","url":"aws_api/connect.html#resume_contact_recording"},{"doc":"aws_api/connect","title":"search_agent_statuses","content":"pub fn search_agent_statuses(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.search_agent_statuses\naws_api/connect search_agent_statuses","url":"aws_api/connect.html#search_agent_statuses"},{"doc":"aws_api/connect","title":"search_available_phone_numbers","content":"pub fn search_available_phone_numbers(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.search_available_phone_numbers\naws_api/connect search_available_phone_numbers","url":"aws_api/connect.html#search_available_phone_numbers"},{"doc":"aws_api/connect","title":"search_contact_flow_modules","content":"pub fn search_contact_flow_modules(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.search_contact_flow_modules\naws_api/connect search_contact_flow_modules","url":"aws_api/connect.html#search_contact_flow_modules"},{"doc":"aws_api/connect","title":"search_contact_flows","content":"pub fn search_contact_flows(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.search_contact_flows\naws_api/connect search_contact_flows","url":"aws_api/connect.html#search_contact_flows"},{"doc":"aws_api/connect","title":"search_contacts","content":"pub fn search_contacts(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.search_contacts\naws_api/connect search_contacts","url":"aws_api/connect.html#search_contacts"},{"doc":"aws_api/connect","title":"search_hours_of_operations","content":"pub fn search_hours_of_operations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.search_hours_of_operations\naws_api/connect search_hours_of_operations","url":"aws_api/connect.html#search_hours_of_operations"},{"doc":"aws_api/connect","title":"search_predefined_attributes","content":"pub fn search_predefined_attributes(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.search_predefined_attributes\naws_api/connect search_predefined_attributes","url":"aws_api/connect.html#search_predefined_attributes"},{"doc":"aws_api/connect","title":"search_prompts","content":"pub fn search_prompts(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.search_prompts\naws_api/connect search_prompts","url":"aws_api/connect.html#search_prompts"},{"doc":"aws_api/connect","title":"search_queues","content":"pub fn search_queues(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.search_queues\naws_api/connect search_queues","url":"aws_api/connect.html#search_queues"},{"doc":"aws_api/connect","title":"search_quick_connects","content":"pub fn search_quick_connects(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.search_quick_connects\naws_api/connect search_quick_connects","url":"aws_api/connect.html#search_quick_connects"},{"doc":"aws_api/connect","title":"search_resource_tags","content":"pub fn search_resource_tags(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.search_resource_tags\naws_api/connect search_resource_tags","url":"aws_api/connect.html#search_resource_tags"},{"doc":"aws_api/connect","title":"search_routing_profiles","content":"pub fn search_routing_profiles(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.search_routing_profiles\naws_api/connect search_routing_profiles","url":"aws_api/connect.html#search_routing_profiles"},{"doc":"aws_api/connect","title":"search_security_profiles","content":"pub fn search_security_profiles(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.search_security_profiles\naws_api/connect search_security_profiles","url":"aws_api/connect.html#search_security_profiles"},{"doc":"aws_api/connect","title":"search_user_hierarchy_groups","content":"pub fn search_user_hierarchy_groups(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.search_user_hierarchy_groups\naws_api/connect search_user_hierarchy_groups","url":"aws_api/connect.html#search_user_hierarchy_groups"},{"doc":"aws_api/connect","title":"search_users","content":"pub fn search_users(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.search_users\naws_api/connect search_users","url":"aws_api/connect.html#search_users"},{"doc":"aws_api/connect","title":"search_vocabularies","content":"pub fn search_vocabularies(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.search_vocabularies\naws_api/connect search_vocabularies","url":"aws_api/connect.html#search_vocabularies"},{"doc":"aws_api/connect","title":"send_chat_integration_event","content":"pub fn send_chat_integration_event(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.send_chat_integration_event\naws_api/connect send_chat_integration_event","url":"aws_api/connect.html#send_chat_integration_event"},{"doc":"aws_api/connect","title":"start_attached_file_upload","content":"pub fn start_attached_file_upload(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.start_attached_file_upload\naws_api/connect start_attached_file_upload","url":"aws_api/connect.html#start_attached_file_upload"},{"doc":"aws_api/connect","title":"start_chat_contact","content":"pub fn start_chat_contact(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.start_chat_contact\naws_api/connect start_chat_contact","url":"aws_api/connect.html#start_chat_contact"},{"doc":"aws_api/connect","title":"start_contact_evaluation","content":"pub fn start_contact_evaluation(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.start_contact_evaluation\naws_api/connect start_contact_evaluation","url":"aws_api/connect.html#start_contact_evaluation"},{"doc":"aws_api/connect","title":"start_contact_recording","content":"pub fn start_contact_recording(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.start_contact_recording\naws_api/connect start_contact_recording","url":"aws_api/connect.html#start_contact_recording"},{"doc":"aws_api/connect","title":"start_contact_streaming","content":"pub fn start_contact_streaming(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.start_contact_streaming\naws_api/connect start_contact_streaming","url":"aws_api/connect.html#start_contact_streaming"},{"doc":"aws_api/connect","title":"start_outbound_voice_contact","content":"pub fn start_outbound_voice_contact(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.start_outbound_voice_contact\naws_api/connect start_outbound_voice_contact","url":"aws_api/connect.html#start_outbound_voice_contact"},{"doc":"aws_api/connect","title":"start_task_contact","content":"pub fn start_task_contact(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.start_task_contact\naws_api/connect start_task_contact","url":"aws_api/connect.html#start_task_contact"},{"doc":"aws_api/connect","title":"start_web_rtc_contact","content":"pub fn start_web_rtc_contact(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.start_web_rtc_contact\naws_api/connect start_web_rtc_contact","url":"aws_api/connect.html#start_web_rtc_contact"},{"doc":"aws_api/connect","title":"stop_contact","content":"pub fn stop_contact(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.stop_contact\naws_api/connect stop_contact","url":"aws_api/connect.html#stop_contact"},{"doc":"aws_api/connect","title":"stop_contact_recording","content":"pub fn stop_contact_recording(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.stop_contact_recording\naws_api/connect stop_contact_recording","url":"aws_api/connect.html#stop_contact_recording"},{"doc":"aws_api/connect","title":"stop_contact_streaming","content":"pub fn stop_contact_streaming(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.stop_contact_streaming\naws_api/connect stop_contact_streaming","url":"aws_api/connect.html#stop_contact_streaming"},{"doc":"aws_api/connect","title":"submit_contact_evaluation","content":"pub fn submit_contact_evaluation(\n  client: Client,\n  instance_id: String,\n  evaluation_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.submit_contact_evaluation\naws_api/connect submit_contact_evaluation","url":"aws_api/connect.html#submit_contact_evaluation"},{"doc":"aws_api/connect","title":"suspend_contact_recording","content":"pub fn suspend_contact_recording(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.suspend_contact_recording\naws_api/connect suspend_contact_recording","url":"aws_api/connect.html#suspend_contact_recording"},{"doc":"aws_api/connect","title":"tag_contact","content":"pub fn tag_contact(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.tag_contact\naws_api/connect tag_contact","url":"aws_api/connect.html#tag_contact"},{"doc":"aws_api/connect","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.tag_resource\naws_api/connect tag_resource","url":"aws_api/connect.html#tag_resource"},{"doc":"aws_api/connect","title":"transfer_contact","content":"pub fn transfer_contact(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.transfer_contact\naws_api/connect transfer_contact","url":"aws_api/connect.html#transfer_contact"},{"doc":"aws_api/connect","title":"untag_contact","content":"pub fn untag_contact(\n  client: Client,\n  instance_id: String,\n  contact_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.untag_contact\naws_api/connect untag_contact","url":"aws_api/connect.html#untag_contact"},{"doc":"aws_api/connect","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.untag_resource\naws_api/connect untag_resource","url":"aws_api/connect.html#untag_resource"},{"doc":"aws_api/connect","title":"update_agent_status","content":"pub fn update_agent_status(\n  client: Client,\n  instance_id: String,\n  agent_status_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.update_agent_status\naws_api/connect update_agent_status","url":"aws_api/connect.html#update_agent_status"},{"doc":"aws_api/connect","title":"update_authentication_profile","content":"pub fn update_authentication_profile(\n  client: Client,\n  instance_id: String,\n  authentication_profile_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.update_authentication_profile\naws_api/connect update_authentication_profile","url":"aws_api/connect.html#update_authentication_profile"},{"doc":"aws_api/connect","title":"update_contact","content":"pub fn update_contact(\n  client: Client,\n  instance_id: String,\n  contact_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.update_contact\naws_api/connect update_contact","url":"aws_api/connect.html#update_contact"},{"doc":"aws_api/connect","title":"update_contact_attributes","content":"pub fn update_contact_attributes(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.update_contact_attributes\naws_api/connect update_contact_attributes","url":"aws_api/connect.html#update_contact_attributes"},{"doc":"aws_api/connect","title":"update_contact_evaluation","content":"pub fn update_contact_evaluation(\n  client: Client,\n  instance_id: String,\n  evaluation_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.update_contact_evaluation\naws_api/connect update_contact_evaluation","url":"aws_api/connect.html#update_contact_evaluation"},{"doc":"aws_api/connect","title":"update_contact_flow_content","content":"pub fn update_contact_flow_content(\n  client: Client,\n  instance_id: String,\n  contact_flow_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.update_contact_flow_content\naws_api/connect update_contact_flow_content","url":"aws_api/connect.html#update_contact_flow_content"},{"doc":"aws_api/connect","title":"update_contact_flow_metadata","content":"pub fn update_contact_flow_metadata(\n  client: Client,\n  instance_id: String,\n  contact_flow_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.update_contact_flow_metadata\naws_api/connect update_contact_flow_metadata","url":"aws_api/connect.html#update_contact_flow_metadata"},{"doc":"aws_api/connect","title":"update_contact_flow_module_content","content":"pub fn update_contact_flow_module_content(\n  client: Client,\n  instance_id: String,\n  contact_flow_module_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.update_contact_flow_module_content\naws_api/connect update_contact_flow_module_content","url":"aws_api/connect.html#update_contact_flow_module_content"},{"doc":"aws_api/connect","title":"update_contact_flow_module_metadata","content":"pub fn update_contact_flow_module_metadata(\n  client: Client,\n  instance_id: String,\n  contact_flow_module_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.update_contact_flow_module_metadata\naws_api/connect update_contact_flow_module_metadata","url":"aws_api/connect.html#update_contact_flow_module_metadata"},{"doc":"aws_api/connect","title":"update_contact_flow_name","content":"pub fn update_contact_flow_name(\n  client: Client,\n  instance_id: String,\n  contact_flow_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.update_contact_flow_name\naws_api/connect update_contact_flow_name","url":"aws_api/connect.html#update_contact_flow_name"},{"doc":"aws_api/connect","title":"update_contact_routing_data","content":"pub fn update_contact_routing_data(\n  client: Client,\n  instance_id: String,\n  contact_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.update_contact_routing_data\naws_api/connect update_contact_routing_data","url":"aws_api/connect.html#update_contact_routing_data"},{"doc":"aws_api/connect","title":"update_contact_schedule","content":"pub fn update_contact_schedule(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.update_contact_schedule\naws_api/connect update_contact_schedule","url":"aws_api/connect.html#update_contact_schedule"},{"doc":"aws_api/connect","title":"update_evaluation_form","content":"pub fn update_evaluation_form(\n  client: Client,\n  instance_id: String,\n  evaluation_form_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.update_evaluation_form\naws_api/connect update_evaluation_form","url":"aws_api/connect.html#update_evaluation_form"},{"doc":"aws_api/connect","title":"update_hours_of_operation","content":"pub fn update_hours_of_operation(\n  client: Client,\n  instance_id: String,\n  hours_of_operation_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.update_hours_of_operation\naws_api/connect update_hours_of_operation","url":"aws_api/connect.html#update_hours_of_operation"},{"doc":"aws_api/connect","title":"update_instance_attribute","content":"pub fn update_instance_attribute(\n  client: Client,\n  instance_id: String,\n  attribute_type: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.update_instance_attribute\naws_api/connect update_instance_attribute","url":"aws_api/connect.html#update_instance_attribute"},{"doc":"aws_api/connect","title":"update_instance_storage_config","content":"pub fn update_instance_storage_config(\n  client: Client,\n  instance_id: String,\n  association_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.update_instance_storage_config\naws_api/connect update_instance_storage_config","url":"aws_api/connect.html#update_instance_storage_config"},{"doc":"aws_api/connect","title":"update_participant_role_config","content":"pub fn update_participant_role_config(\n  client: Client,\n  instance_id: String,\n  contact_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.update_participant_role_config\naws_api/connect update_participant_role_config","url":"aws_api/connect.html#update_participant_role_config"},{"doc":"aws_api/connect","title":"update_phone_number","content":"pub fn update_phone_number(\n  client: Client,\n  phone_number_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.update_phone_number\naws_api/connect update_phone_number","url":"aws_api/connect.html#update_phone_number"},{"doc":"aws_api/connect","title":"update_phone_number_metadata","content":"pub fn update_phone_number_metadata(\n  client: Client,\n  phone_number_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.update_phone_number_metadata\naws_api/connect update_phone_number_metadata","url":"aws_api/connect.html#update_phone_number_metadata"},{"doc":"aws_api/connect","title":"update_predefined_attribute","content":"pub fn update_predefined_attribute(\n  client: Client,\n  instance_id: String,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.update_predefined_attribute\naws_api/connect update_predefined_attribute","url":"aws_api/connect.html#update_predefined_attribute"},{"doc":"aws_api/connect","title":"update_prompt","content":"pub fn update_prompt(\n  client: Client,\n  instance_id: String,\n  prompt_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.update_prompt\naws_api/connect update_prompt","url":"aws_api/connect.html#update_prompt"},{"doc":"aws_api/connect","title":"update_queue_hours_of_operation","content":"pub fn update_queue_hours_of_operation(\n  client: Client,\n  instance_id: String,\n  queue_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.update_queue_hours_of_operation\naws_api/connect update_queue_hours_of_operation","url":"aws_api/connect.html#update_queue_hours_of_operation"},{"doc":"aws_api/connect","title":"update_queue_max_contacts","content":"pub fn update_queue_max_contacts(\n  client: Client,\n  instance_id: String,\n  queue_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.update_queue_max_contacts\naws_api/connect update_queue_max_contacts","url":"aws_api/connect.html#update_queue_max_contacts"},{"doc":"aws_api/connect","title":"update_queue_name","content":"pub fn update_queue_name(\n  client: Client,\n  instance_id: String,\n  queue_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.update_queue_name\naws_api/connect update_queue_name","url":"aws_api/connect.html#update_queue_name"},{"doc":"aws_api/connect","title":"update_queue_outbound_caller_config","content":"pub fn update_queue_outbound_caller_config(\n  client: Client,\n  instance_id: String,\n  queue_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.update_queue_outbound_caller_config\naws_api/connect update_queue_outbound_caller_config","url":"aws_api/connect.html#update_queue_outbound_caller_config"},{"doc":"aws_api/connect","title":"update_queue_status","content":"pub fn update_queue_status(\n  client: Client,\n  instance_id: String,\n  queue_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.update_queue_status\naws_api/connect update_queue_status","url":"aws_api/connect.html#update_queue_status"},{"doc":"aws_api/connect","title":"update_quick_connect_config","content":"pub fn update_quick_connect_config(\n  client: Client,\n  instance_id: String,\n  quick_connect_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.update_quick_connect_config\naws_api/connect update_quick_connect_config","url":"aws_api/connect.html#update_quick_connect_config"},{"doc":"aws_api/connect","title":"update_quick_connect_name","content":"pub fn update_quick_connect_name(\n  client: Client,\n  instance_id: String,\n  quick_connect_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.update_quick_connect_name\naws_api/connect update_quick_connect_name","url":"aws_api/connect.html#update_quick_connect_name"},{"doc":"aws_api/connect","title":"update_routing_profile_agent_availability_timer","content":"pub fn update_routing_profile_agent_availability_timer(\n  client: Client,\n  instance_id: String,\n  routing_profile_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.update_routing_profile_agent_availability_timer\naws_api/connect update_routing_profile_agent_availability_timer","url":"aws_api/connect.html#update_routing_profile_agent_availability_timer"},{"doc":"aws_api/connect","title":"update_routing_profile_concurrency","content":"pub fn update_routing_profile_concurrency(\n  client: Client,\n  instance_id: String,\n  routing_profile_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.update_routing_profile_concurrency\naws_api/connect update_routing_profile_concurrency","url":"aws_api/connect.html#update_routing_profile_concurrency"},{"doc":"aws_api/connect","title":"update_routing_profile_default_outbound_queue","content":"pub fn update_routing_profile_default_outbound_queue(\n  client: Client,\n  instance_id: String,\n  routing_profile_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.update_routing_profile_default_outbound_queue\naws_api/connect update_routing_profile_default_outbound_queue","url":"aws_api/connect.html#update_routing_profile_default_outbound_queue"},{"doc":"aws_api/connect","title":"update_routing_profile_name","content":"pub fn update_routing_profile_name(\n  client: Client,\n  instance_id: String,\n  routing_profile_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.update_routing_profile_name\naws_api/connect update_routing_profile_name","url":"aws_api/connect.html#update_routing_profile_name"},{"doc":"aws_api/connect","title":"update_routing_profile_queues","content":"pub fn update_routing_profile_queues(\n  client: Client,\n  instance_id: String,\n  routing_profile_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.update_routing_profile_queues\naws_api/connect update_routing_profile_queues","url":"aws_api/connect.html#update_routing_profile_queues"},{"doc":"aws_api/connect","title":"update_rule","content":"pub fn update_rule(\n  client: Client,\n  instance_id: String,\n  rule_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.update_rule\naws_api/connect update_rule","url":"aws_api/connect.html#update_rule"},{"doc":"aws_api/connect","title":"update_security_profile","content":"pub fn update_security_profile(\n  client: Client,\n  instance_id: String,\n  security_profile_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.update_security_profile\naws_api/connect update_security_profile","url":"aws_api/connect.html#update_security_profile"},{"doc":"aws_api/connect","title":"update_task_template","content":"pub fn update_task_template(\n  client: Client,\n  instance_id: String,\n  task_template_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.update_task_template\naws_api/connect update_task_template","url":"aws_api/connect.html#update_task_template"},{"doc":"aws_api/connect","title":"update_traffic_distribution","content":"pub fn update_traffic_distribution(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.update_traffic_distribution\naws_api/connect update_traffic_distribution","url":"aws_api/connect.html#update_traffic_distribution"},{"doc":"aws_api/connect","title":"update_user_hierarchy","content":"pub fn update_user_hierarchy(\n  client: Client,\n  instance_id: String,\n  user_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.update_user_hierarchy\naws_api/connect update_user_hierarchy","url":"aws_api/connect.html#update_user_hierarchy"},{"doc":"aws_api/connect","title":"update_user_hierarchy_group_name","content":"pub fn update_user_hierarchy_group_name(\n  client: Client,\n  instance_id: String,\n  hierarchy_group_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.update_user_hierarchy_group_name\naws_api/connect update_user_hierarchy_group_name","url":"aws_api/connect.html#update_user_hierarchy_group_name"},{"doc":"aws_api/connect","title":"update_user_hierarchy_structure","content":"pub fn update_user_hierarchy_structure(\n  client: Client,\n  instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.update_user_hierarchy_structure\naws_api/connect update_user_hierarchy_structure","url":"aws_api/connect.html#update_user_hierarchy_structure"},{"doc":"aws_api/connect","title":"update_user_identity_info","content":"pub fn update_user_identity_info(\n  client: Client,\n  instance_id: String,\n  user_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.update_user_identity_info\naws_api/connect update_user_identity_info","url":"aws_api/connect.html#update_user_identity_info"},{"doc":"aws_api/connect","title":"update_user_phone_config","content":"pub fn update_user_phone_config(\n  client: Client,\n  instance_id: String,\n  user_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.update_user_phone_config\naws_api/connect update_user_phone_config","url":"aws_api/connect.html#update_user_phone_config"},{"doc":"aws_api/connect","title":"update_user_proficiencies","content":"pub fn update_user_proficiencies(\n  client: Client,\n  instance_id: String,\n  user_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.update_user_proficiencies\naws_api/connect update_user_proficiencies","url":"aws_api/connect.html#update_user_proficiencies"},{"doc":"aws_api/connect","title":"update_user_routing_profile","content":"pub fn update_user_routing_profile(\n  client: Client,\n  instance_id: String,\n  user_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.update_user_routing_profile\naws_api/connect update_user_routing_profile","url":"aws_api/connect.html#update_user_routing_profile"},{"doc":"aws_api/connect","title":"update_user_security_profiles","content":"pub fn update_user_security_profiles(\n  client: Client,\n  instance_id: String,\n  user_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.update_user_security_profiles\naws_api/connect update_user_security_profiles","url":"aws_api/connect.html#update_user_security_profiles"},{"doc":"aws_api/connect","title":"update_view_content","content":"pub fn update_view_content(\n  client: Client,\n  instance_id: String,\n  view_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.update_view_content\naws_api/connect update_view_content","url":"aws_api/connect.html#update_view_content"},{"doc":"aws_api/connect","title":"update_view_metadata","content":"pub fn update_view_metadata(\n  client: Client,\n  instance_id: String,\n  view_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect.update_view_metadata\naws_api/connect update_view_metadata","url":"aws_api/connect.html#update_view_metadata"},{"doc":"aws_api/connect","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/connect.with_custom_endpoint\naws_api/connect with_custom_endpoint","url":"aws_api/connect.html#with_custom_endpoint"},{"doc":"aws_api/connect","title":"aws_api/connect","content":"","url":"aws_api/connect.html"},{"doc":"aws_api/connect_contact_lens","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/connect_contact_lens.Client\naws_api/connect_contact_lens Client","url":"aws_api/connect_contact_lens.html#Client"},{"doc":"aws_api/connect_contact_lens","title":"list_realtime_contact_analysis_segments","content":"pub fn list_realtime_contact_analysis_segments(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connect_contact_lens.list_realtime_contact_analysis_segments\naws_api/connect_contact_lens list_realtime_contact_analysis_segments","url":"aws_api/connect_contact_lens.html#list_realtime_contact_analysis_segments"},{"doc":"aws_api/connect_contact_lens","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/connect_contact_lens.new\naws_api/connect_contact_lens new","url":"aws_api/connect_contact_lens.html#new"},{"doc":"aws_api/connect_contact_lens","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/connect_contact_lens.with_custom_endpoint\naws_api/connect_contact_lens with_custom_endpoint","url":"aws_api/connect_contact_lens.html#with_custom_endpoint"},{"doc":"aws_api/connect_contact_lens","title":"aws_api/connect_contact_lens","content":"","url":"aws_api/connect_contact_lens.html"},{"doc":"aws_api/connectcampaigns","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/connectcampaigns.Client\naws_api/connectcampaigns Client","url":"aws_api/connectcampaigns.html#Client"},{"doc":"aws_api/connectcampaigns","title":"create_campaign","content":"pub fn create_campaign(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connectcampaigns.create_campaign\naws_api/connectcampaigns create_campaign","url":"aws_api/connectcampaigns.html#create_campaign"},{"doc":"aws_api/connectcampaigns","title":"delete_campaign","content":"pub fn delete_campaign(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connectcampaigns.delete_campaign\naws_api/connectcampaigns delete_campaign","url":"aws_api/connectcampaigns.html#delete_campaign"},{"doc":"aws_api/connectcampaigns","title":"delete_connect_instance_config","content":"pub fn delete_connect_instance_config(\n  client: Client,\n  connect_instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connectcampaigns.delete_connect_instance_config\naws_api/connectcampaigns delete_connect_instance_config","url":"aws_api/connectcampaigns.html#delete_connect_instance_config"},{"doc":"aws_api/connectcampaigns","title":"delete_instance_onboarding_job","content":"pub fn delete_instance_onboarding_job(\n  client: Client,\n  connect_instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connectcampaigns.delete_instance_onboarding_job\naws_api/connectcampaigns delete_instance_onboarding_job","url":"aws_api/connectcampaigns.html#delete_instance_onboarding_job"},{"doc":"aws_api/connectcampaigns","title":"describe_campaign","content":"pub fn describe_campaign(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connectcampaigns.describe_campaign\naws_api/connectcampaigns describe_campaign","url":"aws_api/connectcampaigns.html#describe_campaign"},{"doc":"aws_api/connectcampaigns","title":"get_campaign_state","content":"pub fn get_campaign_state(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connectcampaigns.get_campaign_state\naws_api/connectcampaigns get_campaign_state","url":"aws_api/connectcampaigns.html#get_campaign_state"},{"doc":"aws_api/connectcampaigns","title":"get_campaign_state_batch","content":"pub fn get_campaign_state_batch(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connectcampaigns.get_campaign_state_batch\naws_api/connectcampaigns get_campaign_state_batch","url":"aws_api/connectcampaigns.html#get_campaign_state_batch"},{"doc":"aws_api/connectcampaigns","title":"get_connect_instance_config","content":"pub fn get_connect_instance_config(\n  client: Client,\n  connect_instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connectcampaigns.get_connect_instance_config\naws_api/connectcampaigns get_connect_instance_config","url":"aws_api/connectcampaigns.html#get_connect_instance_config"},{"doc":"aws_api/connectcampaigns","title":"get_instance_onboarding_job_status","content":"pub fn get_instance_onboarding_job_status(\n  client: Client,\n  connect_instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connectcampaigns.get_instance_onboarding_job_status\naws_api/connectcampaigns get_instance_onboarding_job_status","url":"aws_api/connectcampaigns.html#get_instance_onboarding_job_status"},{"doc":"aws_api/connectcampaigns","title":"list_campaigns","content":"pub fn list_campaigns(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connectcampaigns.list_campaigns\naws_api/connectcampaigns list_campaigns","url":"aws_api/connectcampaigns.html#list_campaigns"},{"doc":"aws_api/connectcampaigns","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connectcampaigns.list_tags_for_resource\naws_api/connectcampaigns list_tags_for_resource","url":"aws_api/connectcampaigns.html#list_tags_for_resource"},{"doc":"aws_api/connectcampaigns","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/connectcampaigns.new\naws_api/connectcampaigns new","url":"aws_api/connectcampaigns.html#new"},{"doc":"aws_api/connectcampaigns","title":"pause_campaign","content":"pub fn pause_campaign(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connectcampaigns.pause_campaign\naws_api/connectcampaigns pause_campaign","url":"aws_api/connectcampaigns.html#pause_campaign"},{"doc":"aws_api/connectcampaigns","title":"put_dial_request_batch","content":"pub fn put_dial_request_batch(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connectcampaigns.put_dial_request_batch\naws_api/connectcampaigns put_dial_request_batch","url":"aws_api/connectcampaigns.html#put_dial_request_batch"},{"doc":"aws_api/connectcampaigns","title":"resume_campaign","content":"pub fn resume_campaign(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connectcampaigns.resume_campaign\naws_api/connectcampaigns resume_campaign","url":"aws_api/connectcampaigns.html#resume_campaign"},{"doc":"aws_api/connectcampaigns","title":"start_campaign","content":"pub fn start_campaign(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connectcampaigns.start_campaign\naws_api/connectcampaigns start_campaign","url":"aws_api/connectcampaigns.html#start_campaign"},{"doc":"aws_api/connectcampaigns","title":"start_instance_onboarding_job","content":"pub fn start_instance_onboarding_job(\n  client: Client,\n  connect_instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connectcampaigns.start_instance_onboarding_job\naws_api/connectcampaigns start_instance_onboarding_job","url":"aws_api/connectcampaigns.html#start_instance_onboarding_job"},{"doc":"aws_api/connectcampaigns","title":"stop_campaign","content":"pub fn stop_campaign(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connectcampaigns.stop_campaign\naws_api/connectcampaigns stop_campaign","url":"aws_api/connectcampaigns.html#stop_campaign"},{"doc":"aws_api/connectcampaigns","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connectcampaigns.tag_resource\naws_api/connectcampaigns tag_resource","url":"aws_api/connectcampaigns.html#tag_resource"},{"doc":"aws_api/connectcampaigns","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connectcampaigns.untag_resource\naws_api/connectcampaigns untag_resource","url":"aws_api/connectcampaigns.html#untag_resource"},{"doc":"aws_api/connectcampaigns","title":"update_campaign_dialer_config","content":"pub fn update_campaign_dialer_config(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connectcampaigns.update_campaign_dialer_config\naws_api/connectcampaigns update_campaign_dialer_config","url":"aws_api/connectcampaigns.html#update_campaign_dialer_config"},{"doc":"aws_api/connectcampaigns","title":"update_campaign_name","content":"pub fn update_campaign_name(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connectcampaigns.update_campaign_name\naws_api/connectcampaigns update_campaign_name","url":"aws_api/connectcampaigns.html#update_campaign_name"},{"doc":"aws_api/connectcampaigns","title":"update_campaign_outbound_call_config","content":"pub fn update_campaign_outbound_call_config(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connectcampaigns.update_campaign_outbound_call_config\naws_api/connectcampaigns update_campaign_outbound_call_config","url":"aws_api/connectcampaigns.html#update_campaign_outbound_call_config"},{"doc":"aws_api/connectcampaigns","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/connectcampaigns.with_custom_endpoint\naws_api/connectcampaigns with_custom_endpoint","url":"aws_api/connectcampaigns.html#with_custom_endpoint"},{"doc":"aws_api/connectcampaigns","title":"aws_api/connectcampaigns","content":"","url":"aws_api/connectcampaigns.html"},{"doc":"aws_api/connectcases","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/connectcases.Client\naws_api/connectcases Client","url":"aws_api/connectcases.html#Client"},{"doc":"aws_api/connectcases","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connectcases.list_tags_for_resource\naws_api/connectcases list_tags_for_resource","url":"aws_api/connectcases.html#list_tags_for_resource"},{"doc":"aws_api/connectcases","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/connectcases.new\naws_api/connectcases new","url":"aws_api/connectcases.html#new"},{"doc":"aws_api/connectcases","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connectcases.tag_resource\naws_api/connectcases tag_resource","url":"aws_api/connectcases.html#tag_resource"},{"doc":"aws_api/connectcases","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connectcases.untag_resource\naws_api/connectcases untag_resource","url":"aws_api/connectcases.html#untag_resource"},{"doc":"aws_api/connectcases","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/connectcases.with_custom_endpoint\naws_api/connectcases with_custom_endpoint","url":"aws_api/connectcases.html#with_custom_endpoint"},{"doc":"aws_api/connectcases","title":"aws_api/connectcases","content":"","url":"aws_api/connectcases.html"},{"doc":"aws_api/connectparticipant","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/connectparticipant.Client\naws_api/connectparticipant Client","url":"aws_api/connectparticipant.html#Client"},{"doc":"aws_api/connectparticipant","title":"complete_attachment_upload","content":"pub fn complete_attachment_upload(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connectparticipant.complete_attachment_upload\naws_api/connectparticipant complete_attachment_upload","url":"aws_api/connectparticipant.html#complete_attachment_upload"},{"doc":"aws_api/connectparticipant","title":"create_participant_connection","content":"pub fn create_participant_connection(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connectparticipant.create_participant_connection\naws_api/connectparticipant create_participant_connection","url":"aws_api/connectparticipant.html#create_participant_connection"},{"doc":"aws_api/connectparticipant","title":"describe_view","content":"pub fn describe_view(\n  client: Client,\n  view_token: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connectparticipant.describe_view\naws_api/connectparticipant describe_view","url":"aws_api/connectparticipant.html#describe_view"},{"doc":"aws_api/connectparticipant","title":"disconnect_participant","content":"pub fn disconnect_participant(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connectparticipant.disconnect_participant\naws_api/connectparticipant disconnect_participant","url":"aws_api/connectparticipant.html#disconnect_participant"},{"doc":"aws_api/connectparticipant","title":"get_attachment","content":"pub fn get_attachment(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connectparticipant.get_attachment\naws_api/connectparticipant get_attachment","url":"aws_api/connectparticipant.html#get_attachment"},{"doc":"aws_api/connectparticipant","title":"get_transcript","content":"pub fn get_transcript(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connectparticipant.get_transcript\naws_api/connectparticipant get_transcript","url":"aws_api/connectparticipant.html#get_transcript"},{"doc":"aws_api/connectparticipant","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/connectparticipant.new\naws_api/connectparticipant new","url":"aws_api/connectparticipant.html#new"},{"doc":"aws_api/connectparticipant","title":"send_event","content":"pub fn send_event(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connectparticipant.send_event\naws_api/connectparticipant send_event","url":"aws_api/connectparticipant.html#send_event"},{"doc":"aws_api/connectparticipant","title":"send_message","content":"pub fn send_message(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connectparticipant.send_message\naws_api/connectparticipant send_message","url":"aws_api/connectparticipant.html#send_message"},{"doc":"aws_api/connectparticipant","title":"start_attachment_upload","content":"pub fn start_attachment_upload(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/connectparticipant.start_attachment_upload\naws_api/connectparticipant start_attachment_upload","url":"aws_api/connectparticipant.html#start_attachment_upload"},{"doc":"aws_api/connectparticipant","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/connectparticipant.with_custom_endpoint\naws_api/connectparticipant with_custom_endpoint","url":"aws_api/connectparticipant.html#with_custom_endpoint"},{"doc":"aws_api/connectparticipant","title":"aws_api/connectparticipant","content":"","url":"aws_api/connectparticipant.html"},{"doc":"aws_api/controltower","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/controltower.Client\naws_api/controltower Client","url":"aws_api/controltower.html#Client"},{"doc":"aws_api/controltower","title":"disable_control","content":"pub fn disable_control(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/controltower.disable_control\naws_api/controltower disable_control","url":"aws_api/controltower.html#disable_control"},{"doc":"aws_api/controltower","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/controltower.new\naws_api/controltower new","url":"aws_api/controltower.html#new"},{"doc":"aws_api/controltower","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/controltower.with_custom_endpoint\naws_api/controltower with_custom_endpoint","url":"aws_api/controltower.html#with_custom_endpoint"},{"doc":"aws_api/controltower","title":"aws_api/controltower","content":"","url":"aws_api/controltower.html"},{"doc":"aws_api/cost_and_usage_report_service","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/cost_and_usage_report_service.Client\naws_api/cost_and_usage_report_service Client","url":"aws_api/cost_and_usage_report_service.html#Client"},{"doc":"aws_api/cost_and_usage_report_service","title":"delete_report_definition","content":"pub fn delete_report_definition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_and_usage_report_service.delete_report_definition\naws_api/cost_and_usage_report_service delete_report_definition","url":"aws_api/cost_and_usage_report_service.html#delete_report_definition"},{"doc":"aws_api/cost_and_usage_report_service","title":"describe_report_definitions","content":"pub fn describe_report_definitions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_and_usage_report_service.describe_report_definitions\naws_api/cost_and_usage_report_service describe_report_definitions","url":"aws_api/cost_and_usage_report_service.html#describe_report_definitions"},{"doc":"aws_api/cost_and_usage_report_service","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_and_usage_report_service.list_tags_for_resource\naws_api/cost_and_usage_report_service list_tags_for_resource","url":"aws_api/cost_and_usage_report_service.html#list_tags_for_resource"},{"doc":"aws_api/cost_and_usage_report_service","title":"modify_report_definition","content":"pub fn modify_report_definition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_and_usage_report_service.modify_report_definition\naws_api/cost_and_usage_report_service modify_report_definition","url":"aws_api/cost_and_usage_report_service.html#modify_report_definition"},{"doc":"aws_api/cost_and_usage_report_service","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/cost_and_usage_report_service.new\naws_api/cost_and_usage_report_service new","url":"aws_api/cost_and_usage_report_service.html#new"},{"doc":"aws_api/cost_and_usage_report_service","title":"put_report_definition","content":"pub fn put_report_definition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_and_usage_report_service.put_report_definition\naws_api/cost_and_usage_report_service put_report_definition","url":"aws_api/cost_and_usage_report_service.html#put_report_definition"},{"doc":"aws_api/cost_and_usage_report_service","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_and_usage_report_service.tag_resource\naws_api/cost_and_usage_report_service tag_resource","url":"aws_api/cost_and_usage_report_service.html#tag_resource"},{"doc":"aws_api/cost_and_usage_report_service","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_and_usage_report_service.untag_resource\naws_api/cost_and_usage_report_service untag_resource","url":"aws_api/cost_and_usage_report_service.html#untag_resource"},{"doc":"aws_api/cost_and_usage_report_service","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/cost_and_usage_report_service.with_custom_endpoint\naws_api/cost_and_usage_report_service with_custom_endpoint","url":"aws_api/cost_and_usage_report_service.html#with_custom_endpoint"},{"doc":"aws_api/cost_and_usage_report_service","title":"aws_api/cost_and_usage_report_service","content":"","url":"aws_api/cost_and_usage_report_service.html"},{"doc":"aws_api/cost_explorer","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/cost_explorer.Client\naws_api/cost_explorer Client","url":"aws_api/cost_explorer.html#Client"},{"doc":"aws_api/cost_explorer","title":"create_anomaly_monitor","content":"pub fn create_anomaly_monitor(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_explorer.create_anomaly_monitor\naws_api/cost_explorer create_anomaly_monitor","url":"aws_api/cost_explorer.html#create_anomaly_monitor"},{"doc":"aws_api/cost_explorer","title":"create_anomaly_subscription","content":"pub fn create_anomaly_subscription(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_explorer.create_anomaly_subscription\naws_api/cost_explorer create_anomaly_subscription","url":"aws_api/cost_explorer.html#create_anomaly_subscription"},{"doc":"aws_api/cost_explorer","title":"create_cost_category_definition","content":"pub fn create_cost_category_definition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_explorer.create_cost_category_definition\naws_api/cost_explorer create_cost_category_definition","url":"aws_api/cost_explorer.html#create_cost_category_definition"},{"doc":"aws_api/cost_explorer","title":"delete_anomaly_monitor","content":"pub fn delete_anomaly_monitor(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_explorer.delete_anomaly_monitor\naws_api/cost_explorer delete_anomaly_monitor","url":"aws_api/cost_explorer.html#delete_anomaly_monitor"},{"doc":"aws_api/cost_explorer","title":"delete_anomaly_subscription","content":"pub fn delete_anomaly_subscription(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_explorer.delete_anomaly_subscription\naws_api/cost_explorer delete_anomaly_subscription","url":"aws_api/cost_explorer.html#delete_anomaly_subscription"},{"doc":"aws_api/cost_explorer","title":"delete_cost_category_definition","content":"pub fn delete_cost_category_definition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_explorer.delete_cost_category_definition\naws_api/cost_explorer delete_cost_category_definition","url":"aws_api/cost_explorer.html#delete_cost_category_definition"},{"doc":"aws_api/cost_explorer","title":"describe_cost_category_definition","content":"pub fn describe_cost_category_definition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_explorer.describe_cost_category_definition\naws_api/cost_explorer describe_cost_category_definition","url":"aws_api/cost_explorer.html#describe_cost_category_definition"},{"doc":"aws_api/cost_explorer","title":"get_anomalies","content":"pub fn get_anomalies(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_explorer.get_anomalies\naws_api/cost_explorer get_anomalies","url":"aws_api/cost_explorer.html#get_anomalies"},{"doc":"aws_api/cost_explorer","title":"get_anomaly_monitors","content":"pub fn get_anomaly_monitors(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_explorer.get_anomaly_monitors\naws_api/cost_explorer get_anomaly_monitors","url":"aws_api/cost_explorer.html#get_anomaly_monitors"},{"doc":"aws_api/cost_explorer","title":"get_anomaly_subscriptions","content":"pub fn get_anomaly_subscriptions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_explorer.get_anomaly_subscriptions\naws_api/cost_explorer get_anomaly_subscriptions","url":"aws_api/cost_explorer.html#get_anomaly_subscriptions"},{"doc":"aws_api/cost_explorer","title":"get_approximate_usage_records","content":"pub fn get_approximate_usage_records(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_explorer.get_approximate_usage_records\naws_api/cost_explorer get_approximate_usage_records","url":"aws_api/cost_explorer.html#get_approximate_usage_records"},{"doc":"aws_api/cost_explorer","title":"get_cost_and_usage","content":"pub fn get_cost_and_usage(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_explorer.get_cost_and_usage\naws_api/cost_explorer get_cost_and_usage","url":"aws_api/cost_explorer.html#get_cost_and_usage"},{"doc":"aws_api/cost_explorer","title":"get_cost_and_usage_with_resources","content":"pub fn get_cost_and_usage_with_resources(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_explorer.get_cost_and_usage_with_resources\naws_api/cost_explorer get_cost_and_usage_with_resources","url":"aws_api/cost_explorer.html#get_cost_and_usage_with_resources"},{"doc":"aws_api/cost_explorer","title":"get_cost_categories","content":"pub fn get_cost_categories(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_explorer.get_cost_categories\naws_api/cost_explorer get_cost_categories","url":"aws_api/cost_explorer.html#get_cost_categories"},{"doc":"aws_api/cost_explorer","title":"get_cost_forecast","content":"pub fn get_cost_forecast(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_explorer.get_cost_forecast\naws_api/cost_explorer get_cost_forecast","url":"aws_api/cost_explorer.html#get_cost_forecast"},{"doc":"aws_api/cost_explorer","title":"get_dimension_values","content":"pub fn get_dimension_values(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_explorer.get_dimension_values\naws_api/cost_explorer get_dimension_values","url":"aws_api/cost_explorer.html#get_dimension_values"},{"doc":"aws_api/cost_explorer","title":"get_reservation_coverage","content":"pub fn get_reservation_coverage(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_explorer.get_reservation_coverage\naws_api/cost_explorer get_reservation_coverage","url":"aws_api/cost_explorer.html#get_reservation_coverage"},{"doc":"aws_api/cost_explorer","title":"get_reservation_purchase_recommendation","content":"pub fn get_reservation_purchase_recommendation(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_explorer.get_reservation_purchase_recommendation\naws_api/cost_explorer get_reservation_purchase_recommendation","url":"aws_api/cost_explorer.html#get_reservation_purchase_recommendation"},{"doc":"aws_api/cost_explorer","title":"get_reservation_utilization","content":"pub fn get_reservation_utilization(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_explorer.get_reservation_utilization\naws_api/cost_explorer get_reservation_utilization","url":"aws_api/cost_explorer.html#get_reservation_utilization"},{"doc":"aws_api/cost_explorer","title":"get_rightsizing_recommendation","content":"pub fn get_rightsizing_recommendation(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_explorer.get_rightsizing_recommendation\naws_api/cost_explorer get_rightsizing_recommendation","url":"aws_api/cost_explorer.html#get_rightsizing_recommendation"},{"doc":"aws_api/cost_explorer","title":"get_savings_plan_purchase_recommendation_details","content":"pub fn get_savings_plan_purchase_recommendation_details(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_explorer.get_savings_plan_purchase_recommendation_details\naws_api/cost_explorer get_savings_plan_purchase_recommendation_details","url":"aws_api/cost_explorer.html#get_savings_plan_purchase_recommendation_details"},{"doc":"aws_api/cost_explorer","title":"get_savings_plans_coverage","content":"pub fn get_savings_plans_coverage(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_explorer.get_savings_plans_coverage\naws_api/cost_explorer get_savings_plans_coverage","url":"aws_api/cost_explorer.html#get_savings_plans_coverage"},{"doc":"aws_api/cost_explorer","title":"get_savings_plans_purchase_recommendation","content":"pub fn get_savings_plans_purchase_recommendation(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_explorer.get_savings_plans_purchase_recommendation\naws_api/cost_explorer get_savings_plans_purchase_recommendation","url":"aws_api/cost_explorer.html#get_savings_plans_purchase_recommendation"},{"doc":"aws_api/cost_explorer","title":"get_savings_plans_utilization","content":"pub fn get_savings_plans_utilization(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_explorer.get_savings_plans_utilization\naws_api/cost_explorer get_savings_plans_utilization","url":"aws_api/cost_explorer.html#get_savings_plans_utilization"},{"doc":"aws_api/cost_explorer","title":"get_savings_plans_utilization_details","content":"pub fn get_savings_plans_utilization_details(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_explorer.get_savings_plans_utilization_details\naws_api/cost_explorer get_savings_plans_utilization_details","url":"aws_api/cost_explorer.html#get_savings_plans_utilization_details"},{"doc":"aws_api/cost_explorer","title":"get_tags","content":"pub fn get_tags(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_explorer.get_tags\naws_api/cost_explorer get_tags","url":"aws_api/cost_explorer.html#get_tags"},{"doc":"aws_api/cost_explorer","title":"get_usage_forecast","content":"pub fn get_usage_forecast(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_explorer.get_usage_forecast\naws_api/cost_explorer get_usage_forecast","url":"aws_api/cost_explorer.html#get_usage_forecast"},{"doc":"aws_api/cost_explorer","title":"list_cost_allocation_tag_backfill_history","content":"pub fn list_cost_allocation_tag_backfill_history(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_explorer.list_cost_allocation_tag_backfill_history\naws_api/cost_explorer list_cost_allocation_tag_backfill_history","url":"aws_api/cost_explorer.html#list_cost_allocation_tag_backfill_history"},{"doc":"aws_api/cost_explorer","title":"list_cost_allocation_tags","content":"pub fn list_cost_allocation_tags(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_explorer.list_cost_allocation_tags\naws_api/cost_explorer list_cost_allocation_tags","url":"aws_api/cost_explorer.html#list_cost_allocation_tags"},{"doc":"aws_api/cost_explorer","title":"list_cost_category_definitions","content":"pub fn list_cost_category_definitions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_explorer.list_cost_category_definitions\naws_api/cost_explorer list_cost_category_definitions","url":"aws_api/cost_explorer.html#list_cost_category_definitions"},{"doc":"aws_api/cost_explorer","title":"list_savings_plans_purchase_recommendation_generation","content":"pub fn list_savings_plans_purchase_recommendation_generation(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_explorer.list_savings_plans_purchase_recommendation_generation\naws_api/cost_explorer list_savings_plans_purchase_recommendation_generation","url":"aws_api/cost_explorer.html#list_savings_plans_purchase_recommendation_generation"},{"doc":"aws_api/cost_explorer","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_explorer.list_tags_for_resource\naws_api/cost_explorer list_tags_for_resource","url":"aws_api/cost_explorer.html#list_tags_for_resource"},{"doc":"aws_api/cost_explorer","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/cost_explorer.new\naws_api/cost_explorer new","url":"aws_api/cost_explorer.html#new"},{"doc":"aws_api/cost_explorer","title":"provide_anomaly_feedback","content":"pub fn provide_anomaly_feedback(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_explorer.provide_anomaly_feedback\naws_api/cost_explorer provide_anomaly_feedback","url":"aws_api/cost_explorer.html#provide_anomaly_feedback"},{"doc":"aws_api/cost_explorer","title":"start_cost_allocation_tag_backfill","content":"pub fn start_cost_allocation_tag_backfill(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_explorer.start_cost_allocation_tag_backfill\naws_api/cost_explorer start_cost_allocation_tag_backfill","url":"aws_api/cost_explorer.html#start_cost_allocation_tag_backfill"},{"doc":"aws_api/cost_explorer","title":"start_savings_plans_purchase_recommendation_generation","content":"pub fn start_savings_plans_purchase_recommendation_generation(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_explorer.start_savings_plans_purchase_recommendation_generation\naws_api/cost_explorer start_savings_plans_purchase_recommendation_generation","url":"aws_api/cost_explorer.html#start_savings_plans_purchase_recommendation_generation"},{"doc":"aws_api/cost_explorer","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_explorer.tag_resource\naws_api/cost_explorer tag_resource","url":"aws_api/cost_explorer.html#tag_resource"},{"doc":"aws_api/cost_explorer","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_explorer.untag_resource\naws_api/cost_explorer untag_resource","url":"aws_api/cost_explorer.html#untag_resource"},{"doc":"aws_api/cost_explorer","title":"update_anomaly_monitor","content":"pub fn update_anomaly_monitor(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_explorer.update_anomaly_monitor\naws_api/cost_explorer update_anomaly_monitor","url":"aws_api/cost_explorer.html#update_anomaly_monitor"},{"doc":"aws_api/cost_explorer","title":"update_anomaly_subscription","content":"pub fn update_anomaly_subscription(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_explorer.update_anomaly_subscription\naws_api/cost_explorer update_anomaly_subscription","url":"aws_api/cost_explorer.html#update_anomaly_subscription"},{"doc":"aws_api/cost_explorer","title":"update_cost_allocation_tags_status","content":"pub fn update_cost_allocation_tags_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_explorer.update_cost_allocation_tags_status\naws_api/cost_explorer update_cost_allocation_tags_status","url":"aws_api/cost_explorer.html#update_cost_allocation_tags_status"},{"doc":"aws_api/cost_explorer","title":"update_cost_category_definition","content":"pub fn update_cost_category_definition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_explorer.update_cost_category_definition\naws_api/cost_explorer update_cost_category_definition","url":"aws_api/cost_explorer.html#update_cost_category_definition"},{"doc":"aws_api/cost_explorer","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/cost_explorer.with_custom_endpoint\naws_api/cost_explorer with_custom_endpoint","url":"aws_api/cost_explorer.html#with_custom_endpoint"},{"doc":"aws_api/cost_explorer","title":"aws_api/cost_explorer","content":"","url":"aws_api/cost_explorer.html"},{"doc":"aws_api/cost_optimization_hub","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/cost_optimization_hub.Client\naws_api/cost_optimization_hub Client","url":"aws_api/cost_optimization_hub.html#Client"},{"doc":"aws_api/cost_optimization_hub","title":"get_preferences","content":"pub fn get_preferences(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_optimization_hub.get_preferences\naws_api/cost_optimization_hub get_preferences","url":"aws_api/cost_optimization_hub.html#get_preferences"},{"doc":"aws_api/cost_optimization_hub","title":"get_recommendation","content":"pub fn get_recommendation(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_optimization_hub.get_recommendation\naws_api/cost_optimization_hub get_recommendation","url":"aws_api/cost_optimization_hub.html#get_recommendation"},{"doc":"aws_api/cost_optimization_hub","title":"list_enrollment_statuses","content":"pub fn list_enrollment_statuses(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_optimization_hub.list_enrollment_statuses\naws_api/cost_optimization_hub list_enrollment_statuses","url":"aws_api/cost_optimization_hub.html#list_enrollment_statuses"},{"doc":"aws_api/cost_optimization_hub","title":"list_recommendation_summaries","content":"pub fn list_recommendation_summaries(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_optimization_hub.list_recommendation_summaries\naws_api/cost_optimization_hub list_recommendation_summaries","url":"aws_api/cost_optimization_hub.html#list_recommendation_summaries"},{"doc":"aws_api/cost_optimization_hub","title":"list_recommendations","content":"pub fn list_recommendations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_optimization_hub.list_recommendations\naws_api/cost_optimization_hub list_recommendations","url":"aws_api/cost_optimization_hub.html#list_recommendations"},{"doc":"aws_api/cost_optimization_hub","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/cost_optimization_hub.new\naws_api/cost_optimization_hub new","url":"aws_api/cost_optimization_hub.html#new"},{"doc":"aws_api/cost_optimization_hub","title":"update_enrollment_status","content":"pub fn update_enrollment_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_optimization_hub.update_enrollment_status\naws_api/cost_optimization_hub update_enrollment_status","url":"aws_api/cost_optimization_hub.html#update_enrollment_status"},{"doc":"aws_api/cost_optimization_hub","title":"update_preferences","content":"pub fn update_preferences(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/cost_optimization_hub.update_preferences\naws_api/cost_optimization_hub update_preferences","url":"aws_api/cost_optimization_hub.html#update_preferences"},{"doc":"aws_api/cost_optimization_hub","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/cost_optimization_hub.with_custom_endpoint\naws_api/cost_optimization_hub with_custom_endpoint","url":"aws_api/cost_optimization_hub.html#with_custom_endpoint"},{"doc":"aws_api/cost_optimization_hub","title":"aws_api/cost_optimization_hub","content":"","url":"aws_api/cost_optimization_hub.html"},{"doc":"aws_api/customer_profiles","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/customer_profiles.Client\naws_api/customer_profiles Client","url":"aws_api/customer_profiles.html#Client"},{"doc":"aws_api/customer_profiles","title":"add_profile_key","content":"pub fn add_profile_key(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.add_profile_key\naws_api/customer_profiles add_profile_key","url":"aws_api/customer_profiles.html#add_profile_key"},{"doc":"aws_api/customer_profiles","title":"create_calculated_attribute_definition","content":"pub fn create_calculated_attribute_definition(\n  client: Client,\n  domain_name: String,\n  calculated_attribute_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.create_calculated_attribute_definition\naws_api/customer_profiles create_calculated_attribute_definition","url":"aws_api/customer_profiles.html#create_calculated_attribute_definition"},{"doc":"aws_api/customer_profiles","title":"create_domain","content":"pub fn create_domain(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.create_domain\naws_api/customer_profiles create_domain","url":"aws_api/customer_profiles.html#create_domain"},{"doc":"aws_api/customer_profiles","title":"create_event_stream","content":"pub fn create_event_stream(\n  client: Client,\n  domain_name: String,\n  event_stream_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.create_event_stream\naws_api/customer_profiles create_event_stream","url":"aws_api/customer_profiles.html#create_event_stream"},{"doc":"aws_api/customer_profiles","title":"create_integration_workflow","content":"pub fn create_integration_workflow(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.create_integration_workflow\naws_api/customer_profiles create_integration_workflow","url":"aws_api/customer_profiles.html#create_integration_workflow"},{"doc":"aws_api/customer_profiles","title":"create_profile","content":"pub fn create_profile(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.create_profile\naws_api/customer_profiles create_profile","url":"aws_api/customer_profiles.html#create_profile"},{"doc":"aws_api/customer_profiles","title":"delete_calculated_attribute_definition","content":"pub fn delete_calculated_attribute_definition(\n  client: Client,\n  domain_name: String,\n  calculated_attribute_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.delete_calculated_attribute_definition\naws_api/customer_profiles delete_calculated_attribute_definition","url":"aws_api/customer_profiles.html#delete_calculated_attribute_definition"},{"doc":"aws_api/customer_profiles","title":"delete_domain","content":"pub fn delete_domain(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.delete_domain\naws_api/customer_profiles delete_domain","url":"aws_api/customer_profiles.html#delete_domain"},{"doc":"aws_api/customer_profiles","title":"delete_event_stream","content":"pub fn delete_event_stream(\n  client: Client,\n  domain_name: String,\n  event_stream_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.delete_event_stream\naws_api/customer_profiles delete_event_stream","url":"aws_api/customer_profiles.html#delete_event_stream"},{"doc":"aws_api/customer_profiles","title":"delete_integration","content":"pub fn delete_integration(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.delete_integration\naws_api/customer_profiles delete_integration","url":"aws_api/customer_profiles.html#delete_integration"},{"doc":"aws_api/customer_profiles","title":"delete_profile","content":"pub fn delete_profile(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.delete_profile\naws_api/customer_profiles delete_profile","url":"aws_api/customer_profiles.html#delete_profile"},{"doc":"aws_api/customer_profiles","title":"delete_profile_key","content":"pub fn delete_profile_key(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.delete_profile_key\naws_api/customer_profiles delete_profile_key","url":"aws_api/customer_profiles.html#delete_profile_key"},{"doc":"aws_api/customer_profiles","title":"delete_profile_object","content":"pub fn delete_profile_object(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.delete_profile_object\naws_api/customer_profiles delete_profile_object","url":"aws_api/customer_profiles.html#delete_profile_object"},{"doc":"aws_api/customer_profiles","title":"delete_profile_object_type","content":"pub fn delete_profile_object_type(\n  client: Client,\n  domain_name: String,\n  object_type_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.delete_profile_object_type\naws_api/customer_profiles delete_profile_object_type","url":"aws_api/customer_profiles.html#delete_profile_object_type"},{"doc":"aws_api/customer_profiles","title":"delete_workflow","content":"pub fn delete_workflow(\n  client: Client,\n  domain_name: String,\n  workflow_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.delete_workflow\naws_api/customer_profiles delete_workflow","url":"aws_api/customer_profiles.html#delete_workflow"},{"doc":"aws_api/customer_profiles","title":"detect_profile_object_type","content":"pub fn detect_profile_object_type(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.detect_profile_object_type\naws_api/customer_profiles detect_profile_object_type","url":"aws_api/customer_profiles.html#detect_profile_object_type"},{"doc":"aws_api/customer_profiles","title":"get_auto_merging_preview","content":"pub fn get_auto_merging_preview(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.get_auto_merging_preview\naws_api/customer_profiles get_auto_merging_preview","url":"aws_api/customer_profiles.html#get_auto_merging_preview"},{"doc":"aws_api/customer_profiles","title":"get_calculated_attribute_definition","content":"pub fn get_calculated_attribute_definition(\n  client: Client,\n  domain_name: String,\n  calculated_attribute_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.get_calculated_attribute_definition\naws_api/customer_profiles get_calculated_attribute_definition","url":"aws_api/customer_profiles.html#get_calculated_attribute_definition"},{"doc":"aws_api/customer_profiles","title":"get_calculated_attribute_for_profile","content":"pub fn get_calculated_attribute_for_profile(\n  client: Client,\n  domain_name: String,\n  profile_id: String,\n  calculated_attribute_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.get_calculated_attribute_for_profile\naws_api/customer_profiles get_calculated_attribute_for_profile","url":"aws_api/customer_profiles.html#get_calculated_attribute_for_profile"},{"doc":"aws_api/customer_profiles","title":"get_domain","content":"pub fn get_domain(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.get_domain\naws_api/customer_profiles get_domain","url":"aws_api/customer_profiles.html#get_domain"},{"doc":"aws_api/customer_profiles","title":"get_event_stream","content":"pub fn get_event_stream(\n  client: Client,\n  domain_name: String,\n  event_stream_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.get_event_stream\naws_api/customer_profiles get_event_stream","url":"aws_api/customer_profiles.html#get_event_stream"},{"doc":"aws_api/customer_profiles","title":"get_identity_resolution_job","content":"pub fn get_identity_resolution_job(\n  client: Client,\n  domain_name: String,\n  job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.get_identity_resolution_job\naws_api/customer_profiles get_identity_resolution_job","url":"aws_api/customer_profiles.html#get_identity_resolution_job"},{"doc":"aws_api/customer_profiles","title":"get_integration","content":"pub fn get_integration(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.get_integration\naws_api/customer_profiles get_integration","url":"aws_api/customer_profiles.html#get_integration"},{"doc":"aws_api/customer_profiles","title":"get_matches","content":"pub fn get_matches(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.get_matches\naws_api/customer_profiles get_matches","url":"aws_api/customer_profiles.html#get_matches"},{"doc":"aws_api/customer_profiles","title":"get_profile_object_type","content":"pub fn get_profile_object_type(\n  client: Client,\n  domain_name: String,\n  object_type_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.get_profile_object_type\naws_api/customer_profiles get_profile_object_type","url":"aws_api/customer_profiles.html#get_profile_object_type"},{"doc":"aws_api/customer_profiles","title":"get_profile_object_type_template","content":"pub fn get_profile_object_type_template(\n  client: Client,\n  template_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.get_profile_object_type_template\naws_api/customer_profiles get_profile_object_type_template","url":"aws_api/customer_profiles.html#get_profile_object_type_template"},{"doc":"aws_api/customer_profiles","title":"get_similar_profiles","content":"pub fn get_similar_profiles(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.get_similar_profiles\naws_api/customer_profiles get_similar_profiles","url":"aws_api/customer_profiles.html#get_similar_profiles"},{"doc":"aws_api/customer_profiles","title":"get_workflow","content":"pub fn get_workflow(\n  client: Client,\n  domain_name: String,\n  workflow_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.get_workflow\naws_api/customer_profiles get_workflow","url":"aws_api/customer_profiles.html#get_workflow"},{"doc":"aws_api/customer_profiles","title":"get_workflow_steps","content":"pub fn get_workflow_steps(\n  client: Client,\n  domain_name: String,\n  workflow_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.get_workflow_steps\naws_api/customer_profiles get_workflow_steps","url":"aws_api/customer_profiles.html#get_workflow_steps"},{"doc":"aws_api/customer_profiles","title":"list_account_integrations","content":"pub fn list_account_integrations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.list_account_integrations\naws_api/customer_profiles list_account_integrations","url":"aws_api/customer_profiles.html#list_account_integrations"},{"doc":"aws_api/customer_profiles","title":"list_calculated_attribute_definitions","content":"pub fn list_calculated_attribute_definitions(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.list_calculated_attribute_definitions\naws_api/customer_profiles list_calculated_attribute_definitions","url":"aws_api/customer_profiles.html#list_calculated_attribute_definitions"},{"doc":"aws_api/customer_profiles","title":"list_calculated_attributes_for_profile","content":"pub fn list_calculated_attributes_for_profile(\n  client: Client,\n  domain_name: String,\n  profile_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.list_calculated_attributes_for_profile\naws_api/customer_profiles list_calculated_attributes_for_profile","url":"aws_api/customer_profiles.html#list_calculated_attributes_for_profile"},{"doc":"aws_api/customer_profiles","title":"list_domains","content":"pub fn list_domains(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.list_domains\naws_api/customer_profiles list_domains","url":"aws_api/customer_profiles.html#list_domains"},{"doc":"aws_api/customer_profiles","title":"list_event_streams","content":"pub fn list_event_streams(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.list_event_streams\naws_api/customer_profiles list_event_streams","url":"aws_api/customer_profiles.html#list_event_streams"},{"doc":"aws_api/customer_profiles","title":"list_identity_resolution_jobs","content":"pub fn list_identity_resolution_jobs(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.list_identity_resolution_jobs\naws_api/customer_profiles list_identity_resolution_jobs","url":"aws_api/customer_profiles.html#list_identity_resolution_jobs"},{"doc":"aws_api/customer_profiles","title":"list_integrations","content":"pub fn list_integrations(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.list_integrations\naws_api/customer_profiles list_integrations","url":"aws_api/customer_profiles.html#list_integrations"},{"doc":"aws_api/customer_profiles","title":"list_profile_object_type_templates","content":"pub fn list_profile_object_type_templates(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.list_profile_object_type_templates\naws_api/customer_profiles list_profile_object_type_templates","url":"aws_api/customer_profiles.html#list_profile_object_type_templates"},{"doc":"aws_api/customer_profiles","title":"list_profile_object_types","content":"pub fn list_profile_object_types(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.list_profile_object_types\naws_api/customer_profiles list_profile_object_types","url":"aws_api/customer_profiles.html#list_profile_object_types"},{"doc":"aws_api/customer_profiles","title":"list_profile_objects","content":"pub fn list_profile_objects(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.list_profile_objects\naws_api/customer_profiles list_profile_objects","url":"aws_api/customer_profiles.html#list_profile_objects"},{"doc":"aws_api/customer_profiles","title":"list_rule_based_matches","content":"pub fn list_rule_based_matches(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.list_rule_based_matches\naws_api/customer_profiles list_rule_based_matches","url":"aws_api/customer_profiles.html#list_rule_based_matches"},{"doc":"aws_api/customer_profiles","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.list_tags_for_resource\naws_api/customer_profiles list_tags_for_resource","url":"aws_api/customer_profiles.html#list_tags_for_resource"},{"doc":"aws_api/customer_profiles","title":"list_workflows","content":"pub fn list_workflows(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.list_workflows\naws_api/customer_profiles list_workflows","url":"aws_api/customer_profiles.html#list_workflows"},{"doc":"aws_api/customer_profiles","title":"merge_profiles","content":"pub fn merge_profiles(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.merge_profiles\naws_api/customer_profiles merge_profiles","url":"aws_api/customer_profiles.html#merge_profiles"},{"doc":"aws_api/customer_profiles","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/customer_profiles.new\naws_api/customer_profiles new","url":"aws_api/customer_profiles.html#new"},{"doc":"aws_api/customer_profiles","title":"put_integration","content":"pub fn put_integration(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.put_integration\naws_api/customer_profiles put_integration","url":"aws_api/customer_profiles.html#put_integration"},{"doc":"aws_api/customer_profiles","title":"put_profile_object","content":"pub fn put_profile_object(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.put_profile_object\naws_api/customer_profiles put_profile_object","url":"aws_api/customer_profiles.html#put_profile_object"},{"doc":"aws_api/customer_profiles","title":"put_profile_object_type","content":"pub fn put_profile_object_type(\n  client: Client,\n  domain_name: String,\n  object_type_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.put_profile_object_type\naws_api/customer_profiles put_profile_object_type","url":"aws_api/customer_profiles.html#put_profile_object_type"},{"doc":"aws_api/customer_profiles","title":"search_profiles","content":"pub fn search_profiles(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.search_profiles\naws_api/customer_profiles search_profiles","url":"aws_api/customer_profiles.html#search_profiles"},{"doc":"aws_api/customer_profiles","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.tag_resource\naws_api/customer_profiles tag_resource","url":"aws_api/customer_profiles.html#tag_resource"},{"doc":"aws_api/customer_profiles","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.untag_resource\naws_api/customer_profiles untag_resource","url":"aws_api/customer_profiles.html#untag_resource"},{"doc":"aws_api/customer_profiles","title":"update_calculated_attribute_definition","content":"pub fn update_calculated_attribute_definition(\n  client: Client,\n  domain_name: String,\n  calculated_attribute_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.update_calculated_attribute_definition\naws_api/customer_profiles update_calculated_attribute_definition","url":"aws_api/customer_profiles.html#update_calculated_attribute_definition"},{"doc":"aws_api/customer_profiles","title":"update_domain","content":"pub fn update_domain(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.update_domain\naws_api/customer_profiles update_domain","url":"aws_api/customer_profiles.html#update_domain"},{"doc":"aws_api/customer_profiles","title":"update_profile","content":"pub fn update_profile(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/customer_profiles.update_profile\naws_api/customer_profiles update_profile","url":"aws_api/customer_profiles.html#update_profile"},{"doc":"aws_api/customer_profiles","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/customer_profiles.with_custom_endpoint\naws_api/customer_profiles with_custom_endpoint","url":"aws_api/customer_profiles.html#with_custom_endpoint"},{"doc":"aws_api/customer_profiles","title":"aws_api/customer_profiles","content":"","url":"aws_api/customer_profiles.html"},{"doc":"aws_api/data_pipeline","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/data_pipeline.Client\naws_api/data_pipeline Client","url":"aws_api/data_pipeline.html#Client"},{"doc":"aws_api/data_pipeline","title":"activate_pipeline","content":"pub fn activate_pipeline(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/data_pipeline.activate_pipeline\naws_api/data_pipeline activate_pipeline","url":"aws_api/data_pipeline.html#activate_pipeline"},{"doc":"aws_api/data_pipeline","title":"add_tags","content":"pub fn add_tags(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/data_pipeline.add_tags\naws_api/data_pipeline add_tags","url":"aws_api/data_pipeline.html#add_tags"},{"doc":"aws_api/data_pipeline","title":"create_pipeline","content":"pub fn create_pipeline(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/data_pipeline.create_pipeline\naws_api/data_pipeline create_pipeline","url":"aws_api/data_pipeline.html#create_pipeline"},{"doc":"aws_api/data_pipeline","title":"deactivate_pipeline","content":"pub fn deactivate_pipeline(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/data_pipeline.deactivate_pipeline\naws_api/data_pipeline deactivate_pipeline","url":"aws_api/data_pipeline.html#deactivate_pipeline"},{"doc":"aws_api/data_pipeline","title":"delete_pipeline","content":"pub fn delete_pipeline(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/data_pipeline.delete_pipeline\naws_api/data_pipeline delete_pipeline","url":"aws_api/data_pipeline.html#delete_pipeline"},{"doc":"aws_api/data_pipeline","title":"describe_objects","content":"pub fn describe_objects(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/data_pipeline.describe_objects\naws_api/data_pipeline describe_objects","url":"aws_api/data_pipeline.html#describe_objects"},{"doc":"aws_api/data_pipeline","title":"describe_pipelines","content":"pub fn describe_pipelines(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/data_pipeline.describe_pipelines\naws_api/data_pipeline describe_pipelines","url":"aws_api/data_pipeline.html#describe_pipelines"},{"doc":"aws_api/data_pipeline","title":"evaluate_expression","content":"pub fn evaluate_expression(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/data_pipeline.evaluate_expression\naws_api/data_pipeline evaluate_expression","url":"aws_api/data_pipeline.html#evaluate_expression"},{"doc":"aws_api/data_pipeline","title":"get_pipeline_definition","content":"pub fn get_pipeline_definition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/data_pipeline.get_pipeline_definition\naws_api/data_pipeline get_pipeline_definition","url":"aws_api/data_pipeline.html#get_pipeline_definition"},{"doc":"aws_api/data_pipeline","title":"list_pipelines","content":"pub fn list_pipelines(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/data_pipeline.list_pipelines\naws_api/data_pipeline list_pipelines","url":"aws_api/data_pipeline.html#list_pipelines"},{"doc":"aws_api/data_pipeline","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/data_pipeline.new\naws_api/data_pipeline new","url":"aws_api/data_pipeline.html#new"},{"doc":"aws_api/data_pipeline","title":"poll_for_task","content":"pub fn poll_for_task(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/data_pipeline.poll_for_task\naws_api/data_pipeline poll_for_task","url":"aws_api/data_pipeline.html#poll_for_task"},{"doc":"aws_api/data_pipeline","title":"put_pipeline_definition","content":"pub fn put_pipeline_definition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/data_pipeline.put_pipeline_definition\naws_api/data_pipeline put_pipeline_definition","url":"aws_api/data_pipeline.html#put_pipeline_definition"},{"doc":"aws_api/data_pipeline","title":"query_objects","content":"pub fn query_objects(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/data_pipeline.query_objects\naws_api/data_pipeline query_objects","url":"aws_api/data_pipeline.html#query_objects"},{"doc":"aws_api/data_pipeline","title":"remove_tags","content":"pub fn remove_tags(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/data_pipeline.remove_tags\naws_api/data_pipeline remove_tags","url":"aws_api/data_pipeline.html#remove_tags"},{"doc":"aws_api/data_pipeline","title":"report_task_progress","content":"pub fn report_task_progress(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/data_pipeline.report_task_progress\naws_api/data_pipeline report_task_progress","url":"aws_api/data_pipeline.html#report_task_progress"},{"doc":"aws_api/data_pipeline","title":"report_task_runner_heartbeat","content":"pub fn report_task_runner_heartbeat(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/data_pipeline.report_task_runner_heartbeat\naws_api/data_pipeline report_task_runner_heartbeat","url":"aws_api/data_pipeline.html#report_task_runner_heartbeat"},{"doc":"aws_api/data_pipeline","title":"set_status","content":"pub fn set_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/data_pipeline.set_status\naws_api/data_pipeline set_status","url":"aws_api/data_pipeline.html#set_status"},{"doc":"aws_api/data_pipeline","title":"set_task_status","content":"pub fn set_task_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/data_pipeline.set_task_status\naws_api/data_pipeline set_task_status","url":"aws_api/data_pipeline.html#set_task_status"},{"doc":"aws_api/data_pipeline","title":"validate_pipeline_definition","content":"pub fn validate_pipeline_definition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/data_pipeline.validate_pipeline_definition\naws_api/data_pipeline validate_pipeline_definition","url":"aws_api/data_pipeline.html#validate_pipeline_definition"},{"doc":"aws_api/data_pipeline","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/data_pipeline.with_custom_endpoint\naws_api/data_pipeline with_custom_endpoint","url":"aws_api/data_pipeline.html#with_custom_endpoint"},{"doc":"aws_api/data_pipeline","title":"aws_api/data_pipeline","content":"","url":"aws_api/data_pipeline.html"},{"doc":"aws_api/database_migration_service","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/database_migration_service.Client\naws_api/database_migration_service Client","url":"aws_api/database_migration_service.html#Client"},{"doc":"aws_api/database_migration_service","title":"add_tags_to_resource","content":"pub fn add_tags_to_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.add_tags_to_resource\naws_api/database_migration_service add_tags_to_resource","url":"aws_api/database_migration_service.html#add_tags_to_resource"},{"doc":"aws_api/database_migration_service","title":"apply_pending_maintenance_action","content":"pub fn apply_pending_maintenance_action(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.apply_pending_maintenance_action\naws_api/database_migration_service apply_pending_maintenance_action","url":"aws_api/database_migration_service.html#apply_pending_maintenance_action"},{"doc":"aws_api/database_migration_service","title":"batch_start_recommendations","content":"pub fn batch_start_recommendations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.batch_start_recommendations\naws_api/database_migration_service batch_start_recommendations","url":"aws_api/database_migration_service.html#batch_start_recommendations"},{"doc":"aws_api/database_migration_service","title":"cancel_replication_task_assessment_run","content":"pub fn cancel_replication_task_assessment_run(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.cancel_replication_task_assessment_run\naws_api/database_migration_service cancel_replication_task_assessment_run","url":"aws_api/database_migration_service.html#cancel_replication_task_assessment_run"},{"doc":"aws_api/database_migration_service","title":"create_data_provider","content":"pub fn create_data_provider(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.create_data_provider\naws_api/database_migration_service create_data_provider","url":"aws_api/database_migration_service.html#create_data_provider"},{"doc":"aws_api/database_migration_service","title":"create_endpoint","content":"pub fn create_endpoint(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.create_endpoint\naws_api/database_migration_service create_endpoint","url":"aws_api/database_migration_service.html#create_endpoint"},{"doc":"aws_api/database_migration_service","title":"create_event_subscription","content":"pub fn create_event_subscription(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.create_event_subscription\naws_api/database_migration_service create_event_subscription","url":"aws_api/database_migration_service.html#create_event_subscription"},{"doc":"aws_api/database_migration_service","title":"create_fleet_advisor_collector","content":"pub fn create_fleet_advisor_collector(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.create_fleet_advisor_collector\naws_api/database_migration_service create_fleet_advisor_collector","url":"aws_api/database_migration_service.html#create_fleet_advisor_collector"},{"doc":"aws_api/database_migration_service","title":"create_instance_profile","content":"pub fn create_instance_profile(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.create_instance_profile\naws_api/database_migration_service create_instance_profile","url":"aws_api/database_migration_service.html#create_instance_profile"},{"doc":"aws_api/database_migration_service","title":"create_migration_project","content":"pub fn create_migration_project(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.create_migration_project\naws_api/database_migration_service create_migration_project","url":"aws_api/database_migration_service.html#create_migration_project"},{"doc":"aws_api/database_migration_service","title":"create_replication_config","content":"pub fn create_replication_config(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.create_replication_config\naws_api/database_migration_service create_replication_config","url":"aws_api/database_migration_service.html#create_replication_config"},{"doc":"aws_api/database_migration_service","title":"create_replication_instance","content":"pub fn create_replication_instance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.create_replication_instance\naws_api/database_migration_service create_replication_instance","url":"aws_api/database_migration_service.html#create_replication_instance"},{"doc":"aws_api/database_migration_service","title":"create_replication_subnet_group","content":"pub fn create_replication_subnet_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.create_replication_subnet_group\naws_api/database_migration_service create_replication_subnet_group","url":"aws_api/database_migration_service.html#create_replication_subnet_group"},{"doc":"aws_api/database_migration_service","title":"create_replication_task","content":"pub fn create_replication_task(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.create_replication_task\naws_api/database_migration_service create_replication_task","url":"aws_api/database_migration_service.html#create_replication_task"},{"doc":"aws_api/database_migration_service","title":"delete_certificate","content":"pub fn delete_certificate(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.delete_certificate\naws_api/database_migration_service delete_certificate","url":"aws_api/database_migration_service.html#delete_certificate"},{"doc":"aws_api/database_migration_service","title":"delete_connection","content":"pub fn delete_connection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.delete_connection\naws_api/database_migration_service delete_connection","url":"aws_api/database_migration_service.html#delete_connection"},{"doc":"aws_api/database_migration_service","title":"delete_data_provider","content":"pub fn delete_data_provider(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.delete_data_provider\naws_api/database_migration_service delete_data_provider","url":"aws_api/database_migration_service.html#delete_data_provider"},{"doc":"aws_api/database_migration_service","title":"delete_endpoint","content":"pub fn delete_endpoint(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.delete_endpoint\naws_api/database_migration_service delete_endpoint","url":"aws_api/database_migration_service.html#delete_endpoint"},{"doc":"aws_api/database_migration_service","title":"delete_event_subscription","content":"pub fn delete_event_subscription(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.delete_event_subscription\naws_api/database_migration_service delete_event_subscription","url":"aws_api/database_migration_service.html#delete_event_subscription"},{"doc":"aws_api/database_migration_service","title":"delete_fleet_advisor_collector","content":"pub fn delete_fleet_advisor_collector(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.delete_fleet_advisor_collector\naws_api/database_migration_service delete_fleet_advisor_collector","url":"aws_api/database_migration_service.html#delete_fleet_advisor_collector"},{"doc":"aws_api/database_migration_service","title":"delete_fleet_advisor_databases","content":"pub fn delete_fleet_advisor_databases(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.delete_fleet_advisor_databases\naws_api/database_migration_service delete_fleet_advisor_databases","url":"aws_api/database_migration_service.html#delete_fleet_advisor_databases"},{"doc":"aws_api/database_migration_service","title":"delete_instance_profile","content":"pub fn delete_instance_profile(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.delete_instance_profile\naws_api/database_migration_service delete_instance_profile","url":"aws_api/database_migration_service.html#delete_instance_profile"},{"doc":"aws_api/database_migration_service","title":"delete_migration_project","content":"pub fn delete_migration_project(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.delete_migration_project\naws_api/database_migration_service delete_migration_project","url":"aws_api/database_migration_service.html#delete_migration_project"},{"doc":"aws_api/database_migration_service","title":"delete_replication_config","content":"pub fn delete_replication_config(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.delete_replication_config\naws_api/database_migration_service delete_replication_config","url":"aws_api/database_migration_service.html#delete_replication_config"},{"doc":"aws_api/database_migration_service","title":"delete_replication_instance","content":"pub fn delete_replication_instance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.delete_replication_instance\naws_api/database_migration_service delete_replication_instance","url":"aws_api/database_migration_service.html#delete_replication_instance"},{"doc":"aws_api/database_migration_service","title":"delete_replication_subnet_group","content":"pub fn delete_replication_subnet_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.delete_replication_subnet_group\naws_api/database_migration_service delete_replication_subnet_group","url":"aws_api/database_migration_service.html#delete_replication_subnet_group"},{"doc":"aws_api/database_migration_service","title":"delete_replication_task","content":"pub fn delete_replication_task(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.delete_replication_task\naws_api/database_migration_service delete_replication_task","url":"aws_api/database_migration_service.html#delete_replication_task"},{"doc":"aws_api/database_migration_service","title":"delete_replication_task_assessment_run","content":"pub fn delete_replication_task_assessment_run(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.delete_replication_task_assessment_run\naws_api/database_migration_service delete_replication_task_assessment_run","url":"aws_api/database_migration_service.html#delete_replication_task_assessment_run"},{"doc":"aws_api/database_migration_service","title":"describe_account_attributes","content":"pub fn describe_account_attributes(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.describe_account_attributes\naws_api/database_migration_service describe_account_attributes","url":"aws_api/database_migration_service.html#describe_account_attributes"},{"doc":"aws_api/database_migration_service","title":"describe_applicable_individual_assessments","content":"pub fn describe_applicable_individual_assessments(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.describe_applicable_individual_assessments\naws_api/database_migration_service describe_applicable_individual_assessments","url":"aws_api/database_migration_service.html#describe_applicable_individual_assessments"},{"doc":"aws_api/database_migration_service","title":"describe_certificates","content":"pub fn describe_certificates(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.describe_certificates\naws_api/database_migration_service describe_certificates","url":"aws_api/database_migration_service.html#describe_certificates"},{"doc":"aws_api/database_migration_service","title":"describe_connections","content":"pub fn describe_connections(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.describe_connections\naws_api/database_migration_service describe_connections","url":"aws_api/database_migration_service.html#describe_connections"},{"doc":"aws_api/database_migration_service","title":"describe_conversion_configuration","content":"pub fn describe_conversion_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.describe_conversion_configuration\naws_api/database_migration_service describe_conversion_configuration","url":"aws_api/database_migration_service.html#describe_conversion_configuration"},{"doc":"aws_api/database_migration_service","title":"describe_data_providers","content":"pub fn describe_data_providers(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.describe_data_providers\naws_api/database_migration_service describe_data_providers","url":"aws_api/database_migration_service.html#describe_data_providers"},{"doc":"aws_api/database_migration_service","title":"describe_endpoint_settings","content":"pub fn describe_endpoint_settings(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.describe_endpoint_settings\naws_api/database_migration_service describe_endpoint_settings","url":"aws_api/database_migration_service.html#describe_endpoint_settings"},{"doc":"aws_api/database_migration_service","title":"describe_endpoint_types","content":"pub fn describe_endpoint_types(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.describe_endpoint_types\naws_api/database_migration_service describe_endpoint_types","url":"aws_api/database_migration_service.html#describe_endpoint_types"},{"doc":"aws_api/database_migration_service","title":"describe_endpoints","content":"pub fn describe_endpoints(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.describe_endpoints\naws_api/database_migration_service describe_endpoints","url":"aws_api/database_migration_service.html#describe_endpoints"},{"doc":"aws_api/database_migration_service","title":"describe_engine_versions","content":"pub fn describe_engine_versions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.describe_engine_versions\naws_api/database_migration_service describe_engine_versions","url":"aws_api/database_migration_service.html#describe_engine_versions"},{"doc":"aws_api/database_migration_service","title":"describe_event_categories","content":"pub fn describe_event_categories(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.describe_event_categories\naws_api/database_migration_service describe_event_categories","url":"aws_api/database_migration_service.html#describe_event_categories"},{"doc":"aws_api/database_migration_service","title":"describe_event_subscriptions","content":"pub fn describe_event_subscriptions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.describe_event_subscriptions\naws_api/database_migration_service describe_event_subscriptions","url":"aws_api/database_migration_service.html#describe_event_subscriptions"},{"doc":"aws_api/database_migration_service","title":"describe_events","content":"pub fn describe_events(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.describe_events\naws_api/database_migration_service describe_events","url":"aws_api/database_migration_service.html#describe_events"},{"doc":"aws_api/database_migration_service","title":"describe_extension_pack_associations","content":"pub fn describe_extension_pack_associations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.describe_extension_pack_associations\naws_api/database_migration_service describe_extension_pack_associations","url":"aws_api/database_migration_service.html#describe_extension_pack_associations"},{"doc":"aws_api/database_migration_service","title":"describe_fleet_advisor_collectors","content":"pub fn describe_fleet_advisor_collectors(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.describe_fleet_advisor_collectors\naws_api/database_migration_service describe_fleet_advisor_collectors","url":"aws_api/database_migration_service.html#describe_fleet_advisor_collectors"},{"doc":"aws_api/database_migration_service","title":"describe_fleet_advisor_databases","content":"pub fn describe_fleet_advisor_databases(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.describe_fleet_advisor_databases\naws_api/database_migration_service describe_fleet_advisor_databases","url":"aws_api/database_migration_service.html#describe_fleet_advisor_databases"},{"doc":"aws_api/database_migration_service","title":"describe_fleet_advisor_lsa_analysis","content":"pub fn describe_fleet_advisor_lsa_analysis(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.describe_fleet_advisor_lsa_analysis\naws_api/database_migration_service describe_fleet_advisor_lsa_analysis","url":"aws_api/database_migration_service.html#describe_fleet_advisor_lsa_analysis"},{"doc":"aws_api/database_migration_service","title":"describe_fleet_advisor_schema_object_summary","content":"pub fn describe_fleet_advisor_schema_object_summary(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.describe_fleet_advisor_schema_object_summary\naws_api/database_migration_service describe_fleet_advisor_schema_object_summary","url":"aws_api/database_migration_service.html#describe_fleet_advisor_schema_object_summary"},{"doc":"aws_api/database_migration_service","title":"describe_fleet_advisor_schemas","content":"pub fn describe_fleet_advisor_schemas(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.describe_fleet_advisor_schemas\naws_api/database_migration_service describe_fleet_advisor_schemas","url":"aws_api/database_migration_service.html#describe_fleet_advisor_schemas"},{"doc":"aws_api/database_migration_service","title":"describe_instance_profiles","content":"pub fn describe_instance_profiles(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.describe_instance_profiles\naws_api/database_migration_service describe_instance_profiles","url":"aws_api/database_migration_service.html#describe_instance_profiles"},{"doc":"aws_api/database_migration_service","title":"describe_metadata_model_assessments","content":"pub fn describe_metadata_model_assessments(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.describe_metadata_model_assessments\naws_api/database_migration_service describe_metadata_model_assessments","url":"aws_api/database_migration_service.html#describe_metadata_model_assessments"},{"doc":"aws_api/database_migration_service","title":"describe_metadata_model_conversions","content":"pub fn describe_metadata_model_conversions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.describe_metadata_model_conversions\naws_api/database_migration_service describe_metadata_model_conversions","url":"aws_api/database_migration_service.html#describe_metadata_model_conversions"},{"doc":"aws_api/database_migration_service","title":"describe_metadata_model_exports_as_script","content":"pub fn describe_metadata_model_exports_as_script(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.describe_metadata_model_exports_as_script\naws_api/database_migration_service describe_metadata_model_exports_as_script","url":"aws_api/database_migration_service.html#describe_metadata_model_exports_as_script"},{"doc":"aws_api/database_migration_service","title":"describe_metadata_model_exports_to_target","content":"pub fn describe_metadata_model_exports_to_target(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.describe_metadata_model_exports_to_target\naws_api/database_migration_service describe_metadata_model_exports_to_target","url":"aws_api/database_migration_service.html#describe_metadata_model_exports_to_target"},{"doc":"aws_api/database_migration_service","title":"describe_metadata_model_imports","content":"pub fn describe_metadata_model_imports(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.describe_metadata_model_imports\naws_api/database_migration_service describe_metadata_model_imports","url":"aws_api/database_migration_service.html#describe_metadata_model_imports"},{"doc":"aws_api/database_migration_service","title":"describe_migration_projects","content":"pub fn describe_migration_projects(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.describe_migration_projects\naws_api/database_migration_service describe_migration_projects","url":"aws_api/database_migration_service.html#describe_migration_projects"},{"doc":"aws_api/database_migration_service","title":"describe_orderable_replication_instances","content":"pub fn describe_orderable_replication_instances(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.describe_orderable_replication_instances\naws_api/database_migration_service describe_orderable_replication_instances","url":"aws_api/database_migration_service.html#describe_orderable_replication_instances"},{"doc":"aws_api/database_migration_service","title":"describe_pending_maintenance_actions","content":"pub fn describe_pending_maintenance_actions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.describe_pending_maintenance_actions\naws_api/database_migration_service describe_pending_maintenance_actions","url":"aws_api/database_migration_service.html#describe_pending_maintenance_actions"},{"doc":"aws_api/database_migration_service","title":"describe_recommendation_limitations","content":"pub fn describe_recommendation_limitations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.describe_recommendation_limitations\naws_api/database_migration_service describe_recommendation_limitations","url":"aws_api/database_migration_service.html#describe_recommendation_limitations"},{"doc":"aws_api/database_migration_service","title":"describe_recommendations","content":"pub fn describe_recommendations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.describe_recommendations\naws_api/database_migration_service describe_recommendations","url":"aws_api/database_migration_service.html#describe_recommendations"},{"doc":"aws_api/database_migration_service","title":"describe_refresh_schemas_status","content":"pub fn describe_refresh_schemas_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.describe_refresh_schemas_status\naws_api/database_migration_service describe_refresh_schemas_status","url":"aws_api/database_migration_service.html#describe_refresh_schemas_status"},{"doc":"aws_api/database_migration_service","title":"describe_replication_configs","content":"pub fn describe_replication_configs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.describe_replication_configs\naws_api/database_migration_service describe_replication_configs","url":"aws_api/database_migration_service.html#describe_replication_configs"},{"doc":"aws_api/database_migration_service","title":"describe_replication_instance_task_logs","content":"pub fn describe_replication_instance_task_logs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.describe_replication_instance_task_logs\naws_api/database_migration_service describe_replication_instance_task_logs","url":"aws_api/database_migration_service.html#describe_replication_instance_task_logs"},{"doc":"aws_api/database_migration_service","title":"describe_replication_instances","content":"pub fn describe_replication_instances(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.describe_replication_instances\naws_api/database_migration_service describe_replication_instances","url":"aws_api/database_migration_service.html#describe_replication_instances"},{"doc":"aws_api/database_migration_service","title":"describe_replication_subnet_groups","content":"pub fn describe_replication_subnet_groups(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.describe_replication_subnet_groups\naws_api/database_migration_service describe_replication_subnet_groups","url":"aws_api/database_migration_service.html#describe_replication_subnet_groups"},{"doc":"aws_api/database_migration_service","title":"describe_replication_table_statistics","content":"pub fn describe_replication_table_statistics(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.describe_replication_table_statistics\naws_api/database_migration_service describe_replication_table_statistics","url":"aws_api/database_migration_service.html#describe_replication_table_statistics"},{"doc":"aws_api/database_migration_service","title":"describe_replication_task_assessment_results","content":"pub fn describe_replication_task_assessment_results(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.describe_replication_task_assessment_results\naws_api/database_migration_service describe_replication_task_assessment_results","url":"aws_api/database_migration_service.html#describe_replication_task_assessment_results"},{"doc":"aws_api/database_migration_service","title":"describe_replication_task_assessment_runs","content":"pub fn describe_replication_task_assessment_runs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.describe_replication_task_assessment_runs\naws_api/database_migration_service describe_replication_task_assessment_runs","url":"aws_api/database_migration_service.html#describe_replication_task_assessment_runs"},{"doc":"aws_api/database_migration_service","title":"describe_replication_task_individual_assessments","content":"pub fn describe_replication_task_individual_assessments(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.describe_replication_task_individual_assessments\naws_api/database_migration_service describe_replication_task_individual_assessments","url":"aws_api/database_migration_service.html#describe_replication_task_individual_assessments"},{"doc":"aws_api/database_migration_service","title":"describe_replication_tasks","content":"pub fn describe_replication_tasks(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.describe_replication_tasks\naws_api/database_migration_service describe_replication_tasks","url":"aws_api/database_migration_service.html#describe_replication_tasks"},{"doc":"aws_api/database_migration_service","title":"describe_replications","content":"pub fn describe_replications(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.describe_replications\naws_api/database_migration_service describe_replications","url":"aws_api/database_migration_service.html#describe_replications"},{"doc":"aws_api/database_migration_service","title":"describe_schemas","content":"pub fn describe_schemas(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.describe_schemas\naws_api/database_migration_service describe_schemas","url":"aws_api/database_migration_service.html#describe_schemas"},{"doc":"aws_api/database_migration_service","title":"describe_table_statistics","content":"pub fn describe_table_statistics(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.describe_table_statistics\naws_api/database_migration_service describe_table_statistics","url":"aws_api/database_migration_service.html#describe_table_statistics"},{"doc":"aws_api/database_migration_service","title":"export_metadata_model_assessment","content":"pub fn export_metadata_model_assessment(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.export_metadata_model_assessment\naws_api/database_migration_service export_metadata_model_assessment","url":"aws_api/database_migration_service.html#export_metadata_model_assessment"},{"doc":"aws_api/database_migration_service","title":"import_certificate","content":"pub fn import_certificate(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.import_certificate\naws_api/database_migration_service import_certificate","url":"aws_api/database_migration_service.html#import_certificate"},{"doc":"aws_api/database_migration_service","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.list_tags_for_resource\naws_api/database_migration_service list_tags_for_resource","url":"aws_api/database_migration_service.html#list_tags_for_resource"},{"doc":"aws_api/database_migration_service","title":"modify_conversion_configuration","content":"pub fn modify_conversion_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.modify_conversion_configuration\naws_api/database_migration_service modify_conversion_configuration","url":"aws_api/database_migration_service.html#modify_conversion_configuration"},{"doc":"aws_api/database_migration_service","title":"modify_data_provider","content":"pub fn modify_data_provider(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.modify_data_provider\naws_api/database_migration_service modify_data_provider","url":"aws_api/database_migration_service.html#modify_data_provider"},{"doc":"aws_api/database_migration_service","title":"modify_endpoint","content":"pub fn modify_endpoint(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.modify_endpoint\naws_api/database_migration_service modify_endpoint","url":"aws_api/database_migration_service.html#modify_endpoint"},{"doc":"aws_api/database_migration_service","title":"modify_event_subscription","content":"pub fn modify_event_subscription(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.modify_event_subscription\naws_api/database_migration_service modify_event_subscription","url":"aws_api/database_migration_service.html#modify_event_subscription"},{"doc":"aws_api/database_migration_service","title":"modify_instance_profile","content":"pub fn modify_instance_profile(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.modify_instance_profile\naws_api/database_migration_service modify_instance_profile","url":"aws_api/database_migration_service.html#modify_instance_profile"},{"doc":"aws_api/database_migration_service","title":"modify_migration_project","content":"pub fn modify_migration_project(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.modify_migration_project\naws_api/database_migration_service modify_migration_project","url":"aws_api/database_migration_service.html#modify_migration_project"},{"doc":"aws_api/database_migration_service","title":"modify_replication_config","content":"pub fn modify_replication_config(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.modify_replication_config\naws_api/database_migration_service modify_replication_config","url":"aws_api/database_migration_service.html#modify_replication_config"},{"doc":"aws_api/database_migration_service","title":"modify_replication_instance","content":"pub fn modify_replication_instance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.modify_replication_instance\naws_api/database_migration_service modify_replication_instance","url":"aws_api/database_migration_service.html#modify_replication_instance"},{"doc":"aws_api/database_migration_service","title":"modify_replication_subnet_group","content":"pub fn modify_replication_subnet_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.modify_replication_subnet_group\naws_api/database_migration_service modify_replication_subnet_group","url":"aws_api/database_migration_service.html#modify_replication_subnet_group"},{"doc":"aws_api/database_migration_service","title":"modify_replication_task","content":"pub fn modify_replication_task(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.modify_replication_task\naws_api/database_migration_service modify_replication_task","url":"aws_api/database_migration_service.html#modify_replication_task"},{"doc":"aws_api/database_migration_service","title":"move_replication_task","content":"pub fn move_replication_task(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.move_replication_task\naws_api/database_migration_service move_replication_task","url":"aws_api/database_migration_service.html#move_replication_task"},{"doc":"aws_api/database_migration_service","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/database_migration_service.new\naws_api/database_migration_service new","url":"aws_api/database_migration_service.html#new"},{"doc":"aws_api/database_migration_service","title":"reboot_replication_instance","content":"pub fn reboot_replication_instance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.reboot_replication_instance\naws_api/database_migration_service reboot_replication_instance","url":"aws_api/database_migration_service.html#reboot_replication_instance"},{"doc":"aws_api/database_migration_service","title":"refresh_schemas","content":"pub fn refresh_schemas(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.refresh_schemas\naws_api/database_migration_service refresh_schemas","url":"aws_api/database_migration_service.html#refresh_schemas"},{"doc":"aws_api/database_migration_service","title":"reload_replication_tables","content":"pub fn reload_replication_tables(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.reload_replication_tables\naws_api/database_migration_service reload_replication_tables","url":"aws_api/database_migration_service.html#reload_replication_tables"},{"doc":"aws_api/database_migration_service","title":"reload_tables","content":"pub fn reload_tables(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.reload_tables\naws_api/database_migration_service reload_tables","url":"aws_api/database_migration_service.html#reload_tables"},{"doc":"aws_api/database_migration_service","title":"remove_tags_from_resource","content":"pub fn remove_tags_from_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.remove_tags_from_resource\naws_api/database_migration_service remove_tags_from_resource","url":"aws_api/database_migration_service.html#remove_tags_from_resource"},{"doc":"aws_api/database_migration_service","title":"run_fleet_advisor_lsa_analysis","content":"pub fn run_fleet_advisor_lsa_analysis(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.run_fleet_advisor_lsa_analysis\naws_api/database_migration_service run_fleet_advisor_lsa_analysis","url":"aws_api/database_migration_service.html#run_fleet_advisor_lsa_analysis"},{"doc":"aws_api/database_migration_service","title":"start_extension_pack_association","content":"pub fn start_extension_pack_association(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.start_extension_pack_association\naws_api/database_migration_service start_extension_pack_association","url":"aws_api/database_migration_service.html#start_extension_pack_association"},{"doc":"aws_api/database_migration_service","title":"start_metadata_model_assessment","content":"pub fn start_metadata_model_assessment(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.start_metadata_model_assessment\naws_api/database_migration_service start_metadata_model_assessment","url":"aws_api/database_migration_service.html#start_metadata_model_assessment"},{"doc":"aws_api/database_migration_service","title":"start_metadata_model_conversion","content":"pub fn start_metadata_model_conversion(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.start_metadata_model_conversion\naws_api/database_migration_service start_metadata_model_conversion","url":"aws_api/database_migration_service.html#start_metadata_model_conversion"},{"doc":"aws_api/database_migration_service","title":"start_metadata_model_export_as_script","content":"pub fn start_metadata_model_export_as_script(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.start_metadata_model_export_as_script\naws_api/database_migration_service start_metadata_model_export_as_script","url":"aws_api/database_migration_service.html#start_metadata_model_export_as_script"},{"doc":"aws_api/database_migration_service","title":"start_metadata_model_export_to_target","content":"pub fn start_metadata_model_export_to_target(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.start_metadata_model_export_to_target\naws_api/database_migration_service start_metadata_model_export_to_target","url":"aws_api/database_migration_service.html#start_metadata_model_export_to_target"},{"doc":"aws_api/database_migration_service","title":"start_metadata_model_import","content":"pub fn start_metadata_model_import(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.start_metadata_model_import\naws_api/database_migration_service start_metadata_model_import","url":"aws_api/database_migration_service.html#start_metadata_model_import"},{"doc":"aws_api/database_migration_service","title":"start_recommendations","content":"pub fn start_recommendations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.start_recommendations\naws_api/database_migration_service start_recommendations","url":"aws_api/database_migration_service.html#start_recommendations"},{"doc":"aws_api/database_migration_service","title":"start_replication","content":"pub fn start_replication(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.start_replication\naws_api/database_migration_service start_replication","url":"aws_api/database_migration_service.html#start_replication"},{"doc":"aws_api/database_migration_service","title":"start_replication_task","content":"pub fn start_replication_task(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.start_replication_task\naws_api/database_migration_service start_replication_task","url":"aws_api/database_migration_service.html#start_replication_task"},{"doc":"aws_api/database_migration_service","title":"start_replication_task_assessment","content":"pub fn start_replication_task_assessment(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.start_replication_task_assessment\naws_api/database_migration_service start_replication_task_assessment","url":"aws_api/database_migration_service.html#start_replication_task_assessment"},{"doc":"aws_api/database_migration_service","title":"start_replication_task_assessment_run","content":"pub fn start_replication_task_assessment_run(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.start_replication_task_assessment_run\naws_api/database_migration_service start_replication_task_assessment_run","url":"aws_api/database_migration_service.html#start_replication_task_assessment_run"},{"doc":"aws_api/database_migration_service","title":"stop_replication","content":"pub fn stop_replication(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.stop_replication\naws_api/database_migration_service stop_replication","url":"aws_api/database_migration_service.html#stop_replication"},{"doc":"aws_api/database_migration_service","title":"stop_replication_task","content":"pub fn stop_replication_task(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.stop_replication_task\naws_api/database_migration_service stop_replication_task","url":"aws_api/database_migration_service.html#stop_replication_task"},{"doc":"aws_api/database_migration_service","title":"test_connection","content":"pub fn test_connection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.test_connection\naws_api/database_migration_service test_connection","url":"aws_api/database_migration_service.html#test_connection"},{"doc":"aws_api/database_migration_service","title":"update_subscriptions_to_event_bridge","content":"pub fn update_subscriptions_to_event_bridge(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/database_migration_service.update_subscriptions_to_event_bridge\naws_api/database_migration_service update_subscriptions_to_event_bridge","url":"aws_api/database_migration_service.html#update_subscriptions_to_event_bridge"},{"doc":"aws_api/database_migration_service","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/database_migration_service.with_custom_endpoint\naws_api/database_migration_service with_custom_endpoint","url":"aws_api/database_migration_service.html#with_custom_endpoint"},{"doc":"aws_api/database_migration_service","title":"aws_api/database_migration_service","content":"","url":"aws_api/database_migration_service.html"},{"doc":"aws_api/databrew","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/databrew.Client\naws_api/databrew Client","url":"aws_api/databrew.html#Client"},{"doc":"aws_api/databrew","title":"batch_delete_recipe_version","content":"pub fn batch_delete_recipe_version(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/databrew.batch_delete_recipe_version\naws_api/databrew batch_delete_recipe_version","url":"aws_api/databrew.html#batch_delete_recipe_version"},{"doc":"aws_api/databrew","title":"create_dataset","content":"pub fn create_dataset(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/databrew.create_dataset\naws_api/databrew create_dataset","url":"aws_api/databrew.html#create_dataset"},{"doc":"aws_api/databrew","title":"create_profile_job","content":"pub fn create_profile_job(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/databrew.create_profile_job\naws_api/databrew create_profile_job","url":"aws_api/databrew.html#create_profile_job"},{"doc":"aws_api/databrew","title":"create_project","content":"pub fn create_project(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/databrew.create_project\naws_api/databrew create_project","url":"aws_api/databrew.html#create_project"},{"doc":"aws_api/databrew","title":"create_recipe","content":"pub fn create_recipe(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/databrew.create_recipe\naws_api/databrew create_recipe","url":"aws_api/databrew.html#create_recipe"},{"doc":"aws_api/databrew","title":"create_recipe_job","content":"pub fn create_recipe_job(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/databrew.create_recipe_job\naws_api/databrew create_recipe_job","url":"aws_api/databrew.html#create_recipe_job"},{"doc":"aws_api/databrew","title":"create_ruleset","content":"pub fn create_ruleset(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/databrew.create_ruleset\naws_api/databrew create_ruleset","url":"aws_api/databrew.html#create_ruleset"},{"doc":"aws_api/databrew","title":"create_schedule","content":"pub fn create_schedule(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/databrew.create_schedule\naws_api/databrew create_schedule","url":"aws_api/databrew.html#create_schedule"},{"doc":"aws_api/databrew","title":"delete_dataset","content":"pub fn delete_dataset(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/databrew.delete_dataset\naws_api/databrew delete_dataset","url":"aws_api/databrew.html#delete_dataset"},{"doc":"aws_api/databrew","title":"delete_job","content":"pub fn delete_job(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/databrew.delete_job\naws_api/databrew delete_job","url":"aws_api/databrew.html#delete_job"},{"doc":"aws_api/databrew","title":"delete_project","content":"pub fn delete_project(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/databrew.delete_project\naws_api/databrew delete_project","url":"aws_api/databrew.html#delete_project"},{"doc":"aws_api/databrew","title":"delete_recipe_version","content":"pub fn delete_recipe_version(\n  client: Client,\n  name: String,\n  recipe_version: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/databrew.delete_recipe_version\naws_api/databrew delete_recipe_version","url":"aws_api/databrew.html#delete_recipe_version"},{"doc":"aws_api/databrew","title":"delete_ruleset","content":"pub fn delete_ruleset(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/databrew.delete_ruleset\naws_api/databrew delete_ruleset","url":"aws_api/databrew.html#delete_ruleset"},{"doc":"aws_api/databrew","title":"delete_schedule","content":"pub fn delete_schedule(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/databrew.delete_schedule\naws_api/databrew delete_schedule","url":"aws_api/databrew.html#delete_schedule"},{"doc":"aws_api/databrew","title":"describe_dataset","content":"pub fn describe_dataset(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/databrew.describe_dataset\naws_api/databrew describe_dataset","url":"aws_api/databrew.html#describe_dataset"},{"doc":"aws_api/databrew","title":"describe_job","content":"pub fn describe_job(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/databrew.describe_job\naws_api/databrew describe_job","url":"aws_api/databrew.html#describe_job"},{"doc":"aws_api/databrew","title":"describe_job_run","content":"pub fn describe_job_run(\n  client: Client,\n  name: String,\n  run_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/databrew.describe_job_run\naws_api/databrew describe_job_run","url":"aws_api/databrew.html#describe_job_run"},{"doc":"aws_api/databrew","title":"describe_project","content":"pub fn describe_project(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/databrew.describe_project\naws_api/databrew describe_project","url":"aws_api/databrew.html#describe_project"},{"doc":"aws_api/databrew","title":"describe_recipe","content":"pub fn describe_recipe(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/databrew.describe_recipe\naws_api/databrew describe_recipe","url":"aws_api/databrew.html#describe_recipe"},{"doc":"aws_api/databrew","title":"describe_ruleset","content":"pub fn describe_ruleset(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/databrew.describe_ruleset\naws_api/databrew describe_ruleset","url":"aws_api/databrew.html#describe_ruleset"},{"doc":"aws_api/databrew","title":"describe_schedule","content":"pub fn describe_schedule(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/databrew.describe_schedule\naws_api/databrew describe_schedule","url":"aws_api/databrew.html#describe_schedule"},{"doc":"aws_api/databrew","title":"list_datasets","content":"pub fn list_datasets(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/databrew.list_datasets\naws_api/databrew list_datasets","url":"aws_api/databrew.html#list_datasets"},{"doc":"aws_api/databrew","title":"list_job_runs","content":"pub fn list_job_runs(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/databrew.list_job_runs\naws_api/databrew list_job_runs","url":"aws_api/databrew.html#list_job_runs"},{"doc":"aws_api/databrew","title":"list_jobs","content":"pub fn list_jobs(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/databrew.list_jobs\naws_api/databrew list_jobs","url":"aws_api/databrew.html#list_jobs"},{"doc":"aws_api/databrew","title":"list_projects","content":"pub fn list_projects(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/databrew.list_projects\naws_api/databrew list_projects","url":"aws_api/databrew.html#list_projects"},{"doc":"aws_api/databrew","title":"list_recipe_versions","content":"pub fn list_recipe_versions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/databrew.list_recipe_versions\naws_api/databrew list_recipe_versions","url":"aws_api/databrew.html#list_recipe_versions"},{"doc":"aws_api/databrew","title":"list_recipes","content":"pub fn list_recipes(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/databrew.list_recipes\naws_api/databrew list_recipes","url":"aws_api/databrew.html#list_recipes"},{"doc":"aws_api/databrew","title":"list_rulesets","content":"pub fn list_rulesets(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/databrew.list_rulesets\naws_api/databrew list_rulesets","url":"aws_api/databrew.html#list_rulesets"},{"doc":"aws_api/databrew","title":"list_schedules","content":"pub fn list_schedules(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/databrew.list_schedules\naws_api/databrew list_schedules","url":"aws_api/databrew.html#list_schedules"},{"doc":"aws_api/databrew","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/databrew.list_tags_for_resource\naws_api/databrew list_tags_for_resource","url":"aws_api/databrew.html#list_tags_for_resource"},{"doc":"aws_api/databrew","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/databrew.new\naws_api/databrew new","url":"aws_api/databrew.html#new"},{"doc":"aws_api/databrew","title":"publish_recipe","content":"pub fn publish_recipe(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/databrew.publish_recipe\naws_api/databrew publish_recipe","url":"aws_api/databrew.html#publish_recipe"},{"doc":"aws_api/databrew","title":"send_project_session_action","content":"pub fn send_project_session_action(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/databrew.send_project_session_action\naws_api/databrew send_project_session_action","url":"aws_api/databrew.html#send_project_session_action"},{"doc":"aws_api/databrew","title":"start_job_run","content":"pub fn start_job_run(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/databrew.start_job_run\naws_api/databrew start_job_run","url":"aws_api/databrew.html#start_job_run"},{"doc":"aws_api/databrew","title":"start_project_session","content":"pub fn start_project_session(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/databrew.start_project_session\naws_api/databrew start_project_session","url":"aws_api/databrew.html#start_project_session"},{"doc":"aws_api/databrew","title":"stop_job_run","content":"pub fn stop_job_run(\n  client: Client,\n  name: String,\n  run_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/databrew.stop_job_run\naws_api/databrew stop_job_run","url":"aws_api/databrew.html#stop_job_run"},{"doc":"aws_api/databrew","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/databrew.tag_resource\naws_api/databrew tag_resource","url":"aws_api/databrew.html#tag_resource"},{"doc":"aws_api/databrew","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/databrew.untag_resource\naws_api/databrew untag_resource","url":"aws_api/databrew.html#untag_resource"},{"doc":"aws_api/databrew","title":"update_dataset","content":"pub fn update_dataset(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/databrew.update_dataset\naws_api/databrew update_dataset","url":"aws_api/databrew.html#update_dataset"},{"doc":"aws_api/databrew","title":"update_profile_job","content":"pub fn update_profile_job(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/databrew.update_profile_job\naws_api/databrew update_profile_job","url":"aws_api/databrew.html#update_profile_job"},{"doc":"aws_api/databrew","title":"update_project","content":"pub fn update_project(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/databrew.update_project\naws_api/databrew update_project","url":"aws_api/databrew.html#update_project"},{"doc":"aws_api/databrew","title":"update_recipe","content":"pub fn update_recipe(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/databrew.update_recipe\naws_api/databrew update_recipe","url":"aws_api/databrew.html#update_recipe"},{"doc":"aws_api/databrew","title":"update_recipe_job","content":"pub fn update_recipe_job(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/databrew.update_recipe_job\naws_api/databrew update_recipe_job","url":"aws_api/databrew.html#update_recipe_job"},{"doc":"aws_api/databrew","title":"update_ruleset","content":"pub fn update_ruleset(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/databrew.update_ruleset\naws_api/databrew update_ruleset","url":"aws_api/databrew.html#update_ruleset"},{"doc":"aws_api/databrew","title":"update_schedule","content":"pub fn update_schedule(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/databrew.update_schedule\naws_api/databrew update_schedule","url":"aws_api/databrew.html#update_schedule"},{"doc":"aws_api/databrew","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/databrew.with_custom_endpoint\naws_api/databrew with_custom_endpoint","url":"aws_api/databrew.html#with_custom_endpoint"},{"doc":"aws_api/databrew","title":"aws_api/databrew","content":"","url":"aws_api/databrew.html"},{"doc":"aws_api/dataexchange","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/dataexchange.Client\naws_api/dataexchange Client","url":"aws_api/dataexchange.html#Client"},{"doc":"aws_api/dataexchange","title":"cancel_job","content":"pub fn cancel_job(\n  client: Client,\n  job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dataexchange.cancel_job\naws_api/dataexchange cancel_job","url":"aws_api/dataexchange.html#cancel_job"},{"doc":"aws_api/dataexchange","title":"create_data_set","content":"pub fn create_data_set(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dataexchange.create_data_set\naws_api/dataexchange create_data_set","url":"aws_api/dataexchange.html#create_data_set"},{"doc":"aws_api/dataexchange","title":"create_event_action","content":"pub fn create_event_action(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dataexchange.create_event_action\naws_api/dataexchange create_event_action","url":"aws_api/dataexchange.html#create_event_action"},{"doc":"aws_api/dataexchange","title":"create_job","content":"pub fn create_job(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dataexchange.create_job\naws_api/dataexchange create_job","url":"aws_api/dataexchange.html#create_job"},{"doc":"aws_api/dataexchange","title":"create_revision","content":"pub fn create_revision(\n  client: Client,\n  data_set_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dataexchange.create_revision\naws_api/dataexchange create_revision","url":"aws_api/dataexchange.html#create_revision"},{"doc":"aws_api/dataexchange","title":"delete_asset","content":"pub fn delete_asset(\n  client: Client,\n  data_set_id: String,\n  revision_id: String,\n  asset_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dataexchange.delete_asset\naws_api/dataexchange delete_asset","url":"aws_api/dataexchange.html#delete_asset"},{"doc":"aws_api/dataexchange","title":"delete_data_set","content":"pub fn delete_data_set(\n  client: Client,\n  data_set_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dataexchange.delete_data_set\naws_api/dataexchange delete_data_set","url":"aws_api/dataexchange.html#delete_data_set"},{"doc":"aws_api/dataexchange","title":"delete_event_action","content":"pub fn delete_event_action(\n  client: Client,\n  event_action_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dataexchange.delete_event_action\naws_api/dataexchange delete_event_action","url":"aws_api/dataexchange.html#delete_event_action"},{"doc":"aws_api/dataexchange","title":"delete_revision","content":"pub fn delete_revision(\n  client: Client,\n  data_set_id: String,\n  revision_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dataexchange.delete_revision\naws_api/dataexchange delete_revision","url":"aws_api/dataexchange.html#delete_revision"},{"doc":"aws_api/dataexchange","title":"get_asset","content":"pub fn get_asset(\n  client: Client,\n  data_set_id: String,\n  revision_id: String,\n  asset_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dataexchange.get_asset\naws_api/dataexchange get_asset","url":"aws_api/dataexchange.html#get_asset"},{"doc":"aws_api/dataexchange","title":"get_data_set","content":"pub fn get_data_set(\n  client: Client,\n  data_set_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dataexchange.get_data_set\naws_api/dataexchange get_data_set","url":"aws_api/dataexchange.html#get_data_set"},{"doc":"aws_api/dataexchange","title":"get_event_action","content":"pub fn get_event_action(\n  client: Client,\n  event_action_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dataexchange.get_event_action\naws_api/dataexchange get_event_action","url":"aws_api/dataexchange.html#get_event_action"},{"doc":"aws_api/dataexchange","title":"get_job","content":"pub fn get_job(\n  client: Client,\n  job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dataexchange.get_job\naws_api/dataexchange get_job","url":"aws_api/dataexchange.html#get_job"},{"doc":"aws_api/dataexchange","title":"get_revision","content":"pub fn get_revision(\n  client: Client,\n  data_set_id: String,\n  revision_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dataexchange.get_revision\naws_api/dataexchange get_revision","url":"aws_api/dataexchange.html#get_revision"},{"doc":"aws_api/dataexchange","title":"list_data_set_revisions","content":"pub fn list_data_set_revisions(\n  client: Client,\n  data_set_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dataexchange.list_data_set_revisions\naws_api/dataexchange list_data_set_revisions","url":"aws_api/dataexchange.html#list_data_set_revisions"},{"doc":"aws_api/dataexchange","title":"list_data_sets","content":"pub fn list_data_sets(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dataexchange.list_data_sets\naws_api/dataexchange list_data_sets","url":"aws_api/dataexchange.html#list_data_sets"},{"doc":"aws_api/dataexchange","title":"list_event_actions","content":"pub fn list_event_actions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dataexchange.list_event_actions\naws_api/dataexchange list_event_actions","url":"aws_api/dataexchange.html#list_event_actions"},{"doc":"aws_api/dataexchange","title":"list_jobs","content":"pub fn list_jobs(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dataexchange.list_jobs\naws_api/dataexchange list_jobs","url":"aws_api/dataexchange.html#list_jobs"},{"doc":"aws_api/dataexchange","title":"list_revision_assets","content":"pub fn list_revision_assets(\n  client: Client,\n  data_set_id: String,\n  revision_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dataexchange.list_revision_assets\naws_api/dataexchange list_revision_assets","url":"aws_api/dataexchange.html#list_revision_assets"},{"doc":"aws_api/dataexchange","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dataexchange.list_tags_for_resource\naws_api/dataexchange list_tags_for_resource","url":"aws_api/dataexchange.html#list_tags_for_resource"},{"doc":"aws_api/dataexchange","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/dataexchange.new\naws_api/dataexchange new","url":"aws_api/dataexchange.html#new"},{"doc":"aws_api/dataexchange","title":"revoke_revision","content":"pub fn revoke_revision(\n  client: Client,\n  data_set_id: String,\n  revision_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dataexchange.revoke_revision\naws_api/dataexchange revoke_revision","url":"aws_api/dataexchange.html#revoke_revision"},{"doc":"aws_api/dataexchange","title":"send_api_asset","content":"pub fn send_api_asset(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dataexchange.send_api_asset\naws_api/dataexchange send_api_asset","url":"aws_api/dataexchange.html#send_api_asset"},{"doc":"aws_api/dataexchange","title":"send_data_set_notification","content":"pub fn send_data_set_notification(\n  client: Client,\n  data_set_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dataexchange.send_data_set_notification\naws_api/dataexchange send_data_set_notification","url":"aws_api/dataexchange.html#send_data_set_notification"},{"doc":"aws_api/dataexchange","title":"start_job","content":"pub fn start_job(\n  client: Client,\n  job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dataexchange.start_job\naws_api/dataexchange start_job","url":"aws_api/dataexchange.html#start_job"},{"doc":"aws_api/dataexchange","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dataexchange.tag_resource\naws_api/dataexchange tag_resource","url":"aws_api/dataexchange.html#tag_resource"},{"doc":"aws_api/dataexchange","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dataexchange.untag_resource\naws_api/dataexchange untag_resource","url":"aws_api/dataexchange.html#untag_resource"},{"doc":"aws_api/dataexchange","title":"update_asset","content":"pub fn update_asset(\n  client: Client,\n  data_set_id: String,\n  revision_id: String,\n  asset_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dataexchange.update_asset\naws_api/dataexchange update_asset","url":"aws_api/dataexchange.html#update_asset"},{"doc":"aws_api/dataexchange","title":"update_data_set","content":"pub fn update_data_set(\n  client: Client,\n  data_set_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dataexchange.update_data_set\naws_api/dataexchange update_data_set","url":"aws_api/dataexchange.html#update_data_set"},{"doc":"aws_api/dataexchange","title":"update_event_action","content":"pub fn update_event_action(\n  client: Client,\n  event_action_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dataexchange.update_event_action\naws_api/dataexchange update_event_action","url":"aws_api/dataexchange.html#update_event_action"},{"doc":"aws_api/dataexchange","title":"update_revision","content":"pub fn update_revision(\n  client: Client,\n  data_set_id: String,\n  revision_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dataexchange.update_revision\naws_api/dataexchange update_revision","url":"aws_api/dataexchange.html#update_revision"},{"doc":"aws_api/dataexchange","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/dataexchange.with_custom_endpoint\naws_api/dataexchange with_custom_endpoint","url":"aws_api/dataexchange.html#with_custom_endpoint"},{"doc":"aws_api/dataexchange","title":"aws_api/dataexchange","content":"","url":"aws_api/dataexchange.html"},{"doc":"aws_api/datasync","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/datasync.Client\naws_api/datasync Client","url":"aws_api/datasync.html#Client"},{"doc":"aws_api/datasync","title":"add_storage_system","content":"pub fn add_storage_system(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.add_storage_system\naws_api/datasync add_storage_system","url":"aws_api/datasync.html#add_storage_system"},{"doc":"aws_api/datasync","title":"cancel_task_execution","content":"pub fn cancel_task_execution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.cancel_task_execution\naws_api/datasync cancel_task_execution","url":"aws_api/datasync.html#cancel_task_execution"},{"doc":"aws_api/datasync","title":"create_agent","content":"pub fn create_agent(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.create_agent\naws_api/datasync create_agent","url":"aws_api/datasync.html#create_agent"},{"doc":"aws_api/datasync","title":"create_location_azure_blob","content":"pub fn create_location_azure_blob(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.create_location_azure_blob\naws_api/datasync create_location_azure_blob","url":"aws_api/datasync.html#create_location_azure_blob"},{"doc":"aws_api/datasync","title":"create_location_efs","content":"pub fn create_location_efs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.create_location_efs\naws_api/datasync create_location_efs","url":"aws_api/datasync.html#create_location_efs"},{"doc":"aws_api/datasync","title":"create_location_fsx_lustre","content":"pub fn create_location_fsx_lustre(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.create_location_fsx_lustre\naws_api/datasync create_location_fsx_lustre","url":"aws_api/datasync.html#create_location_fsx_lustre"},{"doc":"aws_api/datasync","title":"create_location_fsx_ontap","content":"pub fn create_location_fsx_ontap(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.create_location_fsx_ontap\naws_api/datasync create_location_fsx_ontap","url":"aws_api/datasync.html#create_location_fsx_ontap"},{"doc":"aws_api/datasync","title":"create_location_fsx_open_zfs","content":"pub fn create_location_fsx_open_zfs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.create_location_fsx_open_zfs\naws_api/datasync create_location_fsx_open_zfs","url":"aws_api/datasync.html#create_location_fsx_open_zfs"},{"doc":"aws_api/datasync","title":"create_location_fsx_windows","content":"pub fn create_location_fsx_windows(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.create_location_fsx_windows\naws_api/datasync create_location_fsx_windows","url":"aws_api/datasync.html#create_location_fsx_windows"},{"doc":"aws_api/datasync","title":"create_location_hdfs","content":"pub fn create_location_hdfs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.create_location_hdfs\naws_api/datasync create_location_hdfs","url":"aws_api/datasync.html#create_location_hdfs"},{"doc":"aws_api/datasync","title":"create_location_nfs","content":"pub fn create_location_nfs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.create_location_nfs\naws_api/datasync create_location_nfs","url":"aws_api/datasync.html#create_location_nfs"},{"doc":"aws_api/datasync","title":"create_location_object_storage","content":"pub fn create_location_object_storage(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.create_location_object_storage\naws_api/datasync create_location_object_storage","url":"aws_api/datasync.html#create_location_object_storage"},{"doc":"aws_api/datasync","title":"create_location_s3","content":"pub fn create_location_s3(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.create_location_s3\naws_api/datasync create_location_s3","url":"aws_api/datasync.html#create_location_s3"},{"doc":"aws_api/datasync","title":"create_location_smb","content":"pub fn create_location_smb(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.create_location_smb\naws_api/datasync create_location_smb","url":"aws_api/datasync.html#create_location_smb"},{"doc":"aws_api/datasync","title":"create_task","content":"pub fn create_task(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.create_task\naws_api/datasync create_task","url":"aws_api/datasync.html#create_task"},{"doc":"aws_api/datasync","title":"delete_agent","content":"pub fn delete_agent(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.delete_agent\naws_api/datasync delete_agent","url":"aws_api/datasync.html#delete_agent"},{"doc":"aws_api/datasync","title":"delete_location","content":"pub fn delete_location(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.delete_location\naws_api/datasync delete_location","url":"aws_api/datasync.html#delete_location"},{"doc":"aws_api/datasync","title":"delete_task","content":"pub fn delete_task(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.delete_task\naws_api/datasync delete_task","url":"aws_api/datasync.html#delete_task"},{"doc":"aws_api/datasync","title":"describe_agent","content":"pub fn describe_agent(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.describe_agent\naws_api/datasync describe_agent","url":"aws_api/datasync.html#describe_agent"},{"doc":"aws_api/datasync","title":"describe_discovery_job","content":"pub fn describe_discovery_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.describe_discovery_job\naws_api/datasync describe_discovery_job","url":"aws_api/datasync.html#describe_discovery_job"},{"doc":"aws_api/datasync","title":"describe_location_azure_blob","content":"pub fn describe_location_azure_blob(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.describe_location_azure_blob\naws_api/datasync describe_location_azure_blob","url":"aws_api/datasync.html#describe_location_azure_blob"},{"doc":"aws_api/datasync","title":"describe_location_efs","content":"pub fn describe_location_efs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.describe_location_efs\naws_api/datasync describe_location_efs","url":"aws_api/datasync.html#describe_location_efs"},{"doc":"aws_api/datasync","title":"describe_location_fsx_lustre","content":"pub fn describe_location_fsx_lustre(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.describe_location_fsx_lustre\naws_api/datasync describe_location_fsx_lustre","url":"aws_api/datasync.html#describe_location_fsx_lustre"},{"doc":"aws_api/datasync","title":"describe_location_fsx_ontap","content":"pub fn describe_location_fsx_ontap(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.describe_location_fsx_ontap\naws_api/datasync describe_location_fsx_ontap","url":"aws_api/datasync.html#describe_location_fsx_ontap"},{"doc":"aws_api/datasync","title":"describe_location_fsx_open_zfs","content":"pub fn describe_location_fsx_open_zfs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.describe_location_fsx_open_zfs\naws_api/datasync describe_location_fsx_open_zfs","url":"aws_api/datasync.html#describe_location_fsx_open_zfs"},{"doc":"aws_api/datasync","title":"describe_location_fsx_windows","content":"pub fn describe_location_fsx_windows(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.describe_location_fsx_windows\naws_api/datasync describe_location_fsx_windows","url":"aws_api/datasync.html#describe_location_fsx_windows"},{"doc":"aws_api/datasync","title":"describe_location_hdfs","content":"pub fn describe_location_hdfs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.describe_location_hdfs\naws_api/datasync describe_location_hdfs","url":"aws_api/datasync.html#describe_location_hdfs"},{"doc":"aws_api/datasync","title":"describe_location_nfs","content":"pub fn describe_location_nfs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.describe_location_nfs\naws_api/datasync describe_location_nfs","url":"aws_api/datasync.html#describe_location_nfs"},{"doc":"aws_api/datasync","title":"describe_location_object_storage","content":"pub fn describe_location_object_storage(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.describe_location_object_storage\naws_api/datasync describe_location_object_storage","url":"aws_api/datasync.html#describe_location_object_storage"},{"doc":"aws_api/datasync","title":"describe_location_s3","content":"pub fn describe_location_s3(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.describe_location_s3\naws_api/datasync describe_location_s3","url":"aws_api/datasync.html#describe_location_s3"},{"doc":"aws_api/datasync","title":"describe_location_smb","content":"pub fn describe_location_smb(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.describe_location_smb\naws_api/datasync describe_location_smb","url":"aws_api/datasync.html#describe_location_smb"},{"doc":"aws_api/datasync","title":"describe_storage_system","content":"pub fn describe_storage_system(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.describe_storage_system\naws_api/datasync describe_storage_system","url":"aws_api/datasync.html#describe_storage_system"},{"doc":"aws_api/datasync","title":"describe_storage_system_resource_metrics","content":"pub fn describe_storage_system_resource_metrics(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.describe_storage_system_resource_metrics\naws_api/datasync describe_storage_system_resource_metrics","url":"aws_api/datasync.html#describe_storage_system_resource_metrics"},{"doc":"aws_api/datasync","title":"describe_storage_system_resources","content":"pub fn describe_storage_system_resources(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.describe_storage_system_resources\naws_api/datasync describe_storage_system_resources","url":"aws_api/datasync.html#describe_storage_system_resources"},{"doc":"aws_api/datasync","title":"describe_task","content":"pub fn describe_task(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.describe_task\naws_api/datasync describe_task","url":"aws_api/datasync.html#describe_task"},{"doc":"aws_api/datasync","title":"describe_task_execution","content":"pub fn describe_task_execution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.describe_task_execution\naws_api/datasync describe_task_execution","url":"aws_api/datasync.html#describe_task_execution"},{"doc":"aws_api/datasync","title":"generate_recommendations","content":"pub fn generate_recommendations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.generate_recommendations\naws_api/datasync generate_recommendations","url":"aws_api/datasync.html#generate_recommendations"},{"doc":"aws_api/datasync","title":"list_agents","content":"pub fn list_agents(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.list_agents\naws_api/datasync list_agents","url":"aws_api/datasync.html#list_agents"},{"doc":"aws_api/datasync","title":"list_discovery_jobs","content":"pub fn list_discovery_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.list_discovery_jobs\naws_api/datasync list_discovery_jobs","url":"aws_api/datasync.html#list_discovery_jobs"},{"doc":"aws_api/datasync","title":"list_locations","content":"pub fn list_locations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.list_locations\naws_api/datasync list_locations","url":"aws_api/datasync.html#list_locations"},{"doc":"aws_api/datasync","title":"list_storage_systems","content":"pub fn list_storage_systems(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.list_storage_systems\naws_api/datasync list_storage_systems","url":"aws_api/datasync.html#list_storage_systems"},{"doc":"aws_api/datasync","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.list_tags_for_resource\naws_api/datasync list_tags_for_resource","url":"aws_api/datasync.html#list_tags_for_resource"},{"doc":"aws_api/datasync","title":"list_task_executions","content":"pub fn list_task_executions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.list_task_executions\naws_api/datasync list_task_executions","url":"aws_api/datasync.html#list_task_executions"},{"doc":"aws_api/datasync","title":"list_tasks","content":"pub fn list_tasks(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.list_tasks\naws_api/datasync list_tasks","url":"aws_api/datasync.html#list_tasks"},{"doc":"aws_api/datasync","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/datasync.new\naws_api/datasync new","url":"aws_api/datasync.html#new"},{"doc":"aws_api/datasync","title":"remove_storage_system","content":"pub fn remove_storage_system(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.remove_storage_system\naws_api/datasync remove_storage_system","url":"aws_api/datasync.html#remove_storage_system"},{"doc":"aws_api/datasync","title":"start_discovery_job","content":"pub fn start_discovery_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.start_discovery_job\naws_api/datasync start_discovery_job","url":"aws_api/datasync.html#start_discovery_job"},{"doc":"aws_api/datasync","title":"start_task_execution","content":"pub fn start_task_execution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.start_task_execution\naws_api/datasync start_task_execution","url":"aws_api/datasync.html#start_task_execution"},{"doc":"aws_api/datasync","title":"stop_discovery_job","content":"pub fn stop_discovery_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.stop_discovery_job\naws_api/datasync stop_discovery_job","url":"aws_api/datasync.html#stop_discovery_job"},{"doc":"aws_api/datasync","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.tag_resource\naws_api/datasync tag_resource","url":"aws_api/datasync.html#tag_resource"},{"doc":"aws_api/datasync","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.untag_resource\naws_api/datasync untag_resource","url":"aws_api/datasync.html#untag_resource"},{"doc":"aws_api/datasync","title":"update_agent","content":"pub fn update_agent(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.update_agent\naws_api/datasync update_agent","url":"aws_api/datasync.html#update_agent"},{"doc":"aws_api/datasync","title":"update_discovery_job","content":"pub fn update_discovery_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.update_discovery_job\naws_api/datasync update_discovery_job","url":"aws_api/datasync.html#update_discovery_job"},{"doc":"aws_api/datasync","title":"update_location_azure_blob","content":"pub fn update_location_azure_blob(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.update_location_azure_blob\naws_api/datasync update_location_azure_blob","url":"aws_api/datasync.html#update_location_azure_blob"},{"doc":"aws_api/datasync","title":"update_location_hdfs","content":"pub fn update_location_hdfs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.update_location_hdfs\naws_api/datasync update_location_hdfs","url":"aws_api/datasync.html#update_location_hdfs"},{"doc":"aws_api/datasync","title":"update_location_nfs","content":"pub fn update_location_nfs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.update_location_nfs\naws_api/datasync update_location_nfs","url":"aws_api/datasync.html#update_location_nfs"},{"doc":"aws_api/datasync","title":"update_location_object_storage","content":"pub fn update_location_object_storage(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.update_location_object_storage\naws_api/datasync update_location_object_storage","url":"aws_api/datasync.html#update_location_object_storage"},{"doc":"aws_api/datasync","title":"update_location_smb","content":"pub fn update_location_smb(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.update_location_smb\naws_api/datasync update_location_smb","url":"aws_api/datasync.html#update_location_smb"},{"doc":"aws_api/datasync","title":"update_storage_system","content":"pub fn update_storage_system(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.update_storage_system\naws_api/datasync update_storage_system","url":"aws_api/datasync.html#update_storage_system"},{"doc":"aws_api/datasync","title":"update_task","content":"pub fn update_task(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.update_task\naws_api/datasync update_task","url":"aws_api/datasync.html#update_task"},{"doc":"aws_api/datasync","title":"update_task_execution","content":"pub fn update_task_execution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datasync.update_task_execution\naws_api/datasync update_task_execution","url":"aws_api/datasync.html#update_task_execution"},{"doc":"aws_api/datasync","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/datasync.with_custom_endpoint\naws_api/datasync with_custom_endpoint","url":"aws_api/datasync.html#with_custom_endpoint"},{"doc":"aws_api/datasync","title":"aws_api/datasync","content":"","url":"aws_api/datasync.html"},{"doc":"aws_api/datazone","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/datazone.Client\naws_api/datazone Client","url":"aws_api/datazone.html#Client"},{"doc":"aws_api/datazone","title":"accept_predictions","content":"pub fn accept_predictions(\n  client: Client,\n  domain_identifier: String,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.accept_predictions\naws_api/datazone accept_predictions","url":"aws_api/datazone.html#accept_predictions"},{"doc":"aws_api/datazone","title":"accept_subscription_request","content":"pub fn accept_subscription_request(\n  client: Client,\n  domain_identifier: String,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.accept_subscription_request\naws_api/datazone accept_subscription_request","url":"aws_api/datazone.html#accept_subscription_request"},{"doc":"aws_api/datazone","title":"associate_environment_role","content":"pub fn associate_environment_role(\n  client: Client,\n  domain_identifier: String,\n  environment_identifier: String,\n  environment_role_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.associate_environment_role\naws_api/datazone associate_environment_role","url":"aws_api/datazone.html#associate_environment_role"},{"doc":"aws_api/datazone","title":"cancel_subscription","content":"pub fn cancel_subscription(\n  client: Client,\n  domain_identifier: String,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.cancel_subscription\naws_api/datazone cancel_subscription","url":"aws_api/datazone.html#cancel_subscription"},{"doc":"aws_api/datazone","title":"create_asset_filter","content":"pub fn create_asset_filter(\n  client: Client,\n  domain_identifier: String,\n  asset_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.create_asset_filter\naws_api/datazone create_asset_filter","url":"aws_api/datazone.html#create_asset_filter"},{"doc":"aws_api/datazone","title":"create_environment","content":"pub fn create_environment(\n  client: Client,\n  domain_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.create_environment\naws_api/datazone create_environment","url":"aws_api/datazone.html#create_environment"},{"doc":"aws_api/datazone","title":"create_environment_action","content":"pub fn create_environment_action(\n  client: Client,\n  domain_identifier: String,\n  environment_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.create_environment_action\naws_api/datazone create_environment_action","url":"aws_api/datazone.html#create_environment_action"},{"doc":"aws_api/datazone","title":"create_environment_profile","content":"pub fn create_environment_profile(\n  client: Client,\n  domain_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.create_environment_profile\naws_api/datazone create_environment_profile","url":"aws_api/datazone.html#create_environment_profile"},{"doc":"aws_api/datazone","title":"create_group_profile","content":"pub fn create_group_profile(\n  client: Client,\n  domain_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.create_group_profile\naws_api/datazone create_group_profile","url":"aws_api/datazone.html#create_group_profile"},{"doc":"aws_api/datazone","title":"create_listing_change_set","content":"pub fn create_listing_change_set(\n  client: Client,\n  domain_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.create_listing_change_set\naws_api/datazone create_listing_change_set","url":"aws_api/datazone.html#create_listing_change_set"},{"doc":"aws_api/datazone","title":"create_project","content":"pub fn create_project(\n  client: Client,\n  domain_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.create_project\naws_api/datazone create_project","url":"aws_api/datazone.html#create_project"},{"doc":"aws_api/datazone","title":"create_project_membership","content":"pub fn create_project_membership(\n  client: Client,\n  domain_identifier: String,\n  project_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.create_project_membership\naws_api/datazone create_project_membership","url":"aws_api/datazone.html#create_project_membership"},{"doc":"aws_api/datazone","title":"create_subscription_grant","content":"pub fn create_subscription_grant(\n  client: Client,\n  domain_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.create_subscription_grant\naws_api/datazone create_subscription_grant","url":"aws_api/datazone.html#create_subscription_grant"},{"doc":"aws_api/datazone","title":"create_subscription_request","content":"pub fn create_subscription_request(\n  client: Client,\n  domain_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.create_subscription_request\naws_api/datazone create_subscription_request","url":"aws_api/datazone.html#create_subscription_request"},{"doc":"aws_api/datazone","title":"create_subscription_target","content":"pub fn create_subscription_target(\n  client: Client,\n  domain_identifier: String,\n  environment_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.create_subscription_target\naws_api/datazone create_subscription_target","url":"aws_api/datazone.html#create_subscription_target"},{"doc":"aws_api/datazone","title":"create_user_profile","content":"pub fn create_user_profile(\n  client: Client,\n  domain_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.create_user_profile\naws_api/datazone create_user_profile","url":"aws_api/datazone.html#create_user_profile"},{"doc":"aws_api/datazone","title":"delete_asset_filter","content":"pub fn delete_asset_filter(\n  client: Client,\n  domain_identifier: String,\n  asset_identifier: String,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.delete_asset_filter\naws_api/datazone delete_asset_filter","url":"aws_api/datazone.html#delete_asset_filter"},{"doc":"aws_api/datazone","title":"delete_environment","content":"pub fn delete_environment(\n  client: Client,\n  domain_identifier: String,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.delete_environment\naws_api/datazone delete_environment","url":"aws_api/datazone.html#delete_environment"},{"doc":"aws_api/datazone","title":"delete_environment_action","content":"pub fn delete_environment_action(\n  client: Client,\n  domain_identifier: String,\n  environment_identifier: String,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.delete_environment_action\naws_api/datazone delete_environment_action","url":"aws_api/datazone.html#delete_environment_action"},{"doc":"aws_api/datazone","title":"delete_environment_profile","content":"pub fn delete_environment_profile(\n  client: Client,\n  domain_identifier: String,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.delete_environment_profile\naws_api/datazone delete_environment_profile","url":"aws_api/datazone.html#delete_environment_profile"},{"doc":"aws_api/datazone","title":"delete_project","content":"pub fn delete_project(\n  client: Client,\n  domain_identifier: String,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.delete_project\naws_api/datazone delete_project","url":"aws_api/datazone.html#delete_project"},{"doc":"aws_api/datazone","title":"delete_project_membership","content":"pub fn delete_project_membership(\n  client: Client,\n  domain_identifier: String,\n  project_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.delete_project_membership\naws_api/datazone delete_project_membership","url":"aws_api/datazone.html#delete_project_membership"},{"doc":"aws_api/datazone","title":"delete_subscription_grant","content":"pub fn delete_subscription_grant(\n  client: Client,\n  domain_identifier: String,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.delete_subscription_grant\naws_api/datazone delete_subscription_grant","url":"aws_api/datazone.html#delete_subscription_grant"},{"doc":"aws_api/datazone","title":"delete_subscription_request","content":"pub fn delete_subscription_request(\n  client: Client,\n  domain_identifier: String,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.delete_subscription_request\naws_api/datazone delete_subscription_request","url":"aws_api/datazone.html#delete_subscription_request"},{"doc":"aws_api/datazone","title":"delete_subscription_target","content":"pub fn delete_subscription_target(\n  client: Client,\n  domain_identifier: String,\n  environment_identifier: String,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.delete_subscription_target\naws_api/datazone delete_subscription_target","url":"aws_api/datazone.html#delete_subscription_target"},{"doc":"aws_api/datazone","title":"delete_time_series_data_points","content":"pub fn delete_time_series_data_points(\n  client: Client,\n  domain_identifier: String,\n  entity_type: String,\n  entity_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.delete_time_series_data_points\naws_api/datazone delete_time_series_data_points","url":"aws_api/datazone.html#delete_time_series_data_points"},{"doc":"aws_api/datazone","title":"disassociate_environment_role","content":"pub fn disassociate_environment_role(\n  client: Client,\n  domain_identifier: String,\n  environment_identifier: String,\n  environment_role_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.disassociate_environment_role\naws_api/datazone disassociate_environment_role","url":"aws_api/datazone.html#disassociate_environment_role"},{"doc":"aws_api/datazone","title":"get_asset_filter","content":"pub fn get_asset_filter(\n  client: Client,\n  domain_identifier: String,\n  asset_identifier: String,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.get_asset_filter\naws_api/datazone get_asset_filter","url":"aws_api/datazone.html#get_asset_filter"},{"doc":"aws_api/datazone","title":"get_environment","content":"pub fn get_environment(\n  client: Client,\n  domain_identifier: String,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.get_environment\naws_api/datazone get_environment","url":"aws_api/datazone.html#get_environment"},{"doc":"aws_api/datazone","title":"get_environment_action","content":"pub fn get_environment_action(\n  client: Client,\n  domain_identifier: String,\n  environment_identifier: String,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.get_environment_action\naws_api/datazone get_environment_action","url":"aws_api/datazone.html#get_environment_action"},{"doc":"aws_api/datazone","title":"get_environment_blueprint","content":"pub fn get_environment_blueprint(\n  client: Client,\n  domain_identifier: String,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.get_environment_blueprint\naws_api/datazone get_environment_blueprint","url":"aws_api/datazone.html#get_environment_blueprint"},{"doc":"aws_api/datazone","title":"get_environment_credentials","content":"pub fn get_environment_credentials(\n  client: Client,\n  domain_identifier: String,\n  environment_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.get_environment_credentials\naws_api/datazone get_environment_credentials","url":"aws_api/datazone.html#get_environment_credentials"},{"doc":"aws_api/datazone","title":"get_environment_profile","content":"pub fn get_environment_profile(\n  client: Client,\n  domain_identifier: String,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.get_environment_profile\naws_api/datazone get_environment_profile","url":"aws_api/datazone.html#get_environment_profile"},{"doc":"aws_api/datazone","title":"get_group_profile","content":"pub fn get_group_profile(\n  client: Client,\n  domain_identifier: String,\n  group_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.get_group_profile\naws_api/datazone get_group_profile","url":"aws_api/datazone.html#get_group_profile"},{"doc":"aws_api/datazone","title":"get_iam_portal_login_url","content":"pub fn get_iam_portal_login_url(\n  client: Client,\n  domain_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.get_iam_portal_login_url\naws_api/datazone get_iam_portal_login_url","url":"aws_api/datazone.html#get_iam_portal_login_url"},{"doc":"aws_api/datazone","title":"get_lineage_node","content":"pub fn get_lineage_node(\n  client: Client,\n  domain_identifier: String,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.get_lineage_node\naws_api/datazone get_lineage_node","url":"aws_api/datazone.html#get_lineage_node"},{"doc":"aws_api/datazone","title":"get_project","content":"pub fn get_project(\n  client: Client,\n  domain_identifier: String,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.get_project\naws_api/datazone get_project","url":"aws_api/datazone.html#get_project"},{"doc":"aws_api/datazone","title":"get_subscription","content":"pub fn get_subscription(\n  client: Client,\n  domain_identifier: String,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.get_subscription\naws_api/datazone get_subscription","url":"aws_api/datazone.html#get_subscription"},{"doc":"aws_api/datazone","title":"get_subscription_grant","content":"pub fn get_subscription_grant(\n  client: Client,\n  domain_identifier: String,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.get_subscription_grant\naws_api/datazone get_subscription_grant","url":"aws_api/datazone.html#get_subscription_grant"},{"doc":"aws_api/datazone","title":"get_subscription_request_details","content":"pub fn get_subscription_request_details(\n  client: Client,\n  domain_identifier: String,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.get_subscription_request_details\naws_api/datazone get_subscription_request_details","url":"aws_api/datazone.html#get_subscription_request_details"},{"doc":"aws_api/datazone","title":"get_subscription_target","content":"pub fn get_subscription_target(\n  client: Client,\n  domain_identifier: String,\n  environment_identifier: String,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.get_subscription_target\naws_api/datazone get_subscription_target","url":"aws_api/datazone.html#get_subscription_target"},{"doc":"aws_api/datazone","title":"get_time_series_data_point","content":"pub fn get_time_series_data_point(\n  client: Client,\n  domain_identifier: String,\n  entity_type: String,\n  entity_identifier: String,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.get_time_series_data_point\naws_api/datazone get_time_series_data_point","url":"aws_api/datazone.html#get_time_series_data_point"},{"doc":"aws_api/datazone","title":"get_user_profile","content":"pub fn get_user_profile(\n  client: Client,\n  domain_identifier: String,\n  user_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.get_user_profile\naws_api/datazone get_user_profile","url":"aws_api/datazone.html#get_user_profile"},{"doc":"aws_api/datazone","title":"list_asset_filters","content":"pub fn list_asset_filters(\n  client: Client,\n  domain_identifier: String,\n  asset_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.list_asset_filters\naws_api/datazone list_asset_filters","url":"aws_api/datazone.html#list_asset_filters"},{"doc":"aws_api/datazone","title":"list_asset_revisions","content":"pub fn list_asset_revisions(\n  client: Client,\n  domain_identifier: String,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.list_asset_revisions\naws_api/datazone list_asset_revisions","url":"aws_api/datazone.html#list_asset_revisions"},{"doc":"aws_api/datazone","title":"list_data_product_revisions","content":"pub fn list_data_product_revisions(\n  client: Client,\n  domain_identifier: String,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.list_data_product_revisions\naws_api/datazone list_data_product_revisions","url":"aws_api/datazone.html#list_data_product_revisions"},{"doc":"aws_api/datazone","title":"list_data_source_run_activities","content":"pub fn list_data_source_run_activities(\n  client: Client,\n  domain_identifier: String,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.list_data_source_run_activities\naws_api/datazone list_data_source_run_activities","url":"aws_api/datazone.html#list_data_source_run_activities"},{"doc":"aws_api/datazone","title":"list_environment_actions","content":"pub fn list_environment_actions(\n  client: Client,\n  domain_identifier: String,\n  environment_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.list_environment_actions\naws_api/datazone list_environment_actions","url":"aws_api/datazone.html#list_environment_actions"},{"doc":"aws_api/datazone","title":"list_environment_blueprints","content":"pub fn list_environment_blueprints(\n  client: Client,\n  domain_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.list_environment_blueprints\naws_api/datazone list_environment_blueprints","url":"aws_api/datazone.html#list_environment_blueprints"},{"doc":"aws_api/datazone","title":"list_environment_profiles","content":"pub fn list_environment_profiles(\n  client: Client,\n  domain_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.list_environment_profiles\naws_api/datazone list_environment_profiles","url":"aws_api/datazone.html#list_environment_profiles"},{"doc":"aws_api/datazone","title":"list_environments","content":"pub fn list_environments(\n  client: Client,\n  domain_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.list_environments\naws_api/datazone list_environments","url":"aws_api/datazone.html#list_environments"},{"doc":"aws_api/datazone","title":"list_lineage_node_history","content":"pub fn list_lineage_node_history(\n  client: Client,\n  domain_identifier: String,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.list_lineage_node_history\naws_api/datazone list_lineage_node_history","url":"aws_api/datazone.html#list_lineage_node_history"},{"doc":"aws_api/datazone","title":"list_notifications","content":"pub fn list_notifications(\n  client: Client,\n  domain_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.list_notifications\naws_api/datazone list_notifications","url":"aws_api/datazone.html#list_notifications"},{"doc":"aws_api/datazone","title":"list_project_memberships","content":"pub fn list_project_memberships(\n  client: Client,\n  domain_identifier: String,\n  project_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.list_project_memberships\naws_api/datazone list_project_memberships","url":"aws_api/datazone.html#list_project_memberships"},{"doc":"aws_api/datazone","title":"list_projects","content":"pub fn list_projects(\n  client: Client,\n  domain_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.list_projects\naws_api/datazone list_projects","url":"aws_api/datazone.html#list_projects"},{"doc":"aws_api/datazone","title":"list_subscription_grants","content":"pub fn list_subscription_grants(\n  client: Client,\n  domain_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.list_subscription_grants\naws_api/datazone list_subscription_grants","url":"aws_api/datazone.html#list_subscription_grants"},{"doc":"aws_api/datazone","title":"list_subscription_requests","content":"pub fn list_subscription_requests(\n  client: Client,\n  domain_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.list_subscription_requests\naws_api/datazone list_subscription_requests","url":"aws_api/datazone.html#list_subscription_requests"},{"doc":"aws_api/datazone","title":"list_subscription_targets","content":"pub fn list_subscription_targets(\n  client: Client,\n  domain_identifier: String,\n  environment_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.list_subscription_targets\naws_api/datazone list_subscription_targets","url":"aws_api/datazone.html#list_subscription_targets"},{"doc":"aws_api/datazone","title":"list_subscriptions","content":"pub fn list_subscriptions(\n  client: Client,\n  domain_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.list_subscriptions\naws_api/datazone list_subscriptions","url":"aws_api/datazone.html#list_subscriptions"},{"doc":"aws_api/datazone","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.list_tags_for_resource\naws_api/datazone list_tags_for_resource","url":"aws_api/datazone.html#list_tags_for_resource"},{"doc":"aws_api/datazone","title":"list_time_series_data_points","content":"pub fn list_time_series_data_points(\n  client: Client,\n  domain_identifier: String,\n  entity_type: String,\n  entity_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.list_time_series_data_points\naws_api/datazone list_time_series_data_points","url":"aws_api/datazone.html#list_time_series_data_points"},{"doc":"aws_api/datazone","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/datazone.new\naws_api/datazone new","url":"aws_api/datazone.html#new"},{"doc":"aws_api/datazone","title":"post_lineage_event","content":"pub fn post_lineage_event(\n  client: Client,\n  domain_identifier: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.post_lineage_event\naws_api/datazone post_lineage_event","url":"aws_api/datazone.html#post_lineage_event"},{"doc":"aws_api/datazone","title":"post_time_series_data_points","content":"pub fn post_time_series_data_points(\n  client: Client,\n  domain_identifier: String,\n  entity_type: String,\n  entity_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.post_time_series_data_points\naws_api/datazone post_time_series_data_points","url":"aws_api/datazone.html#post_time_series_data_points"},{"doc":"aws_api/datazone","title":"reject_predictions","content":"pub fn reject_predictions(\n  client: Client,\n  domain_identifier: String,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.reject_predictions\naws_api/datazone reject_predictions","url":"aws_api/datazone.html#reject_predictions"},{"doc":"aws_api/datazone","title":"reject_subscription_request","content":"pub fn reject_subscription_request(\n  client: Client,\n  domain_identifier: String,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.reject_subscription_request\naws_api/datazone reject_subscription_request","url":"aws_api/datazone.html#reject_subscription_request"},{"doc":"aws_api/datazone","title":"revoke_subscription","content":"pub fn revoke_subscription(\n  client: Client,\n  domain_identifier: String,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.revoke_subscription\naws_api/datazone revoke_subscription","url":"aws_api/datazone.html#revoke_subscription"},{"doc":"aws_api/datazone","title":"search","content":"pub fn search(\n  client: Client,\n  domain_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.search\naws_api/datazone search","url":"aws_api/datazone.html#search"},{"doc":"aws_api/datazone","title":"search_group_profiles","content":"pub fn search_group_profiles(\n  client: Client,\n  domain_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.search_group_profiles\naws_api/datazone search_group_profiles","url":"aws_api/datazone.html#search_group_profiles"},{"doc":"aws_api/datazone","title":"search_listings","content":"pub fn search_listings(\n  client: Client,\n  domain_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.search_listings\naws_api/datazone search_listings","url":"aws_api/datazone.html#search_listings"},{"doc":"aws_api/datazone","title":"search_types","content":"pub fn search_types(\n  client: Client,\n  domain_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.search_types\naws_api/datazone search_types","url":"aws_api/datazone.html#search_types"},{"doc":"aws_api/datazone","title":"search_user_profiles","content":"pub fn search_user_profiles(\n  client: Client,\n  domain_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.search_user_profiles\naws_api/datazone search_user_profiles","url":"aws_api/datazone.html#search_user_profiles"},{"doc":"aws_api/datazone","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.tag_resource\naws_api/datazone tag_resource","url":"aws_api/datazone.html#tag_resource"},{"doc":"aws_api/datazone","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.untag_resource\naws_api/datazone untag_resource","url":"aws_api/datazone.html#untag_resource"},{"doc":"aws_api/datazone","title":"update_asset_filter","content":"pub fn update_asset_filter(\n  client: Client,\n  domain_identifier: String,\n  asset_identifier: String,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.update_asset_filter\naws_api/datazone update_asset_filter","url":"aws_api/datazone.html#update_asset_filter"},{"doc":"aws_api/datazone","title":"update_environment","content":"pub fn update_environment(\n  client: Client,\n  domain_identifier: String,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.update_environment\naws_api/datazone update_environment","url":"aws_api/datazone.html#update_environment"},{"doc":"aws_api/datazone","title":"update_environment_action","content":"pub fn update_environment_action(\n  client: Client,\n  domain_identifier: String,\n  environment_identifier: String,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.update_environment_action\naws_api/datazone update_environment_action","url":"aws_api/datazone.html#update_environment_action"},{"doc":"aws_api/datazone","title":"update_environment_profile","content":"pub fn update_environment_profile(\n  client: Client,\n  domain_identifier: String,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.update_environment_profile\naws_api/datazone update_environment_profile","url":"aws_api/datazone.html#update_environment_profile"},{"doc":"aws_api/datazone","title":"update_group_profile","content":"pub fn update_group_profile(\n  client: Client,\n  domain_identifier: String,\n  group_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.update_group_profile\naws_api/datazone update_group_profile","url":"aws_api/datazone.html#update_group_profile"},{"doc":"aws_api/datazone","title":"update_project","content":"pub fn update_project(\n  client: Client,\n  domain_identifier: String,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.update_project\naws_api/datazone update_project","url":"aws_api/datazone.html#update_project"},{"doc":"aws_api/datazone","title":"update_subscription_grant_status","content":"pub fn update_subscription_grant_status(\n  client: Client,\n  domain_identifier: String,\n  identifier: String,\n  asset_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.update_subscription_grant_status\naws_api/datazone update_subscription_grant_status","url":"aws_api/datazone.html#update_subscription_grant_status"},{"doc":"aws_api/datazone","title":"update_subscription_request","content":"pub fn update_subscription_request(\n  client: Client,\n  domain_identifier: String,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.update_subscription_request\naws_api/datazone update_subscription_request","url":"aws_api/datazone.html#update_subscription_request"},{"doc":"aws_api/datazone","title":"update_subscription_target","content":"pub fn update_subscription_target(\n  client: Client,\n  domain_identifier: String,\n  environment_identifier: String,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.update_subscription_target\naws_api/datazone update_subscription_target","url":"aws_api/datazone.html#update_subscription_target"},{"doc":"aws_api/datazone","title":"update_user_profile","content":"pub fn update_user_profile(\n  client: Client,\n  domain_identifier: String,\n  user_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/datazone.update_user_profile\naws_api/datazone update_user_profile","url":"aws_api/datazone.html#update_user_profile"},{"doc":"aws_api/datazone","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/datazone.with_custom_endpoint\naws_api/datazone with_custom_endpoint","url":"aws_api/datazone.html#with_custom_endpoint"},{"doc":"aws_api/datazone","title":"aws_api/datazone","content":"","url":"aws_api/datazone.html"},{"doc":"aws_api/dax","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/dax.Client\naws_api/dax Client","url":"aws_api/dax.html#Client"},{"doc":"aws_api/dax","title":"create_cluster","content":"pub fn create_cluster(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dax.create_cluster\naws_api/dax create_cluster","url":"aws_api/dax.html#create_cluster"},{"doc":"aws_api/dax","title":"create_parameter_group","content":"pub fn create_parameter_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dax.create_parameter_group\naws_api/dax create_parameter_group","url":"aws_api/dax.html#create_parameter_group"},{"doc":"aws_api/dax","title":"create_subnet_group","content":"pub fn create_subnet_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dax.create_subnet_group\naws_api/dax create_subnet_group","url":"aws_api/dax.html#create_subnet_group"},{"doc":"aws_api/dax","title":"decrease_replication_factor","content":"pub fn decrease_replication_factor(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dax.decrease_replication_factor\naws_api/dax decrease_replication_factor","url":"aws_api/dax.html#decrease_replication_factor"},{"doc":"aws_api/dax","title":"delete_cluster","content":"pub fn delete_cluster(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dax.delete_cluster\naws_api/dax delete_cluster","url":"aws_api/dax.html#delete_cluster"},{"doc":"aws_api/dax","title":"delete_parameter_group","content":"pub fn delete_parameter_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dax.delete_parameter_group\naws_api/dax delete_parameter_group","url":"aws_api/dax.html#delete_parameter_group"},{"doc":"aws_api/dax","title":"delete_subnet_group","content":"pub fn delete_subnet_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dax.delete_subnet_group\naws_api/dax delete_subnet_group","url":"aws_api/dax.html#delete_subnet_group"},{"doc":"aws_api/dax","title":"describe_clusters","content":"pub fn describe_clusters(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dax.describe_clusters\naws_api/dax describe_clusters","url":"aws_api/dax.html#describe_clusters"},{"doc":"aws_api/dax","title":"describe_default_parameters","content":"pub fn describe_default_parameters(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dax.describe_default_parameters\naws_api/dax describe_default_parameters","url":"aws_api/dax.html#describe_default_parameters"},{"doc":"aws_api/dax","title":"describe_events","content":"pub fn describe_events(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dax.describe_events\naws_api/dax describe_events","url":"aws_api/dax.html#describe_events"},{"doc":"aws_api/dax","title":"describe_parameter_groups","content":"pub fn describe_parameter_groups(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dax.describe_parameter_groups\naws_api/dax describe_parameter_groups","url":"aws_api/dax.html#describe_parameter_groups"},{"doc":"aws_api/dax","title":"describe_parameters","content":"pub fn describe_parameters(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dax.describe_parameters\naws_api/dax describe_parameters","url":"aws_api/dax.html#describe_parameters"},{"doc":"aws_api/dax","title":"describe_subnet_groups","content":"pub fn describe_subnet_groups(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dax.describe_subnet_groups\naws_api/dax describe_subnet_groups","url":"aws_api/dax.html#describe_subnet_groups"},{"doc":"aws_api/dax","title":"increase_replication_factor","content":"pub fn increase_replication_factor(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dax.increase_replication_factor\naws_api/dax increase_replication_factor","url":"aws_api/dax.html#increase_replication_factor"},{"doc":"aws_api/dax","title":"list_tags","content":"pub fn list_tags(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dax.list_tags\naws_api/dax list_tags","url":"aws_api/dax.html#list_tags"},{"doc":"aws_api/dax","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/dax.new\naws_api/dax new","url":"aws_api/dax.html#new"},{"doc":"aws_api/dax","title":"reboot_node","content":"pub fn reboot_node(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dax.reboot_node\naws_api/dax reboot_node","url":"aws_api/dax.html#reboot_node"},{"doc":"aws_api/dax","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dax.tag_resource\naws_api/dax tag_resource","url":"aws_api/dax.html#tag_resource"},{"doc":"aws_api/dax","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dax.untag_resource\naws_api/dax untag_resource","url":"aws_api/dax.html#untag_resource"},{"doc":"aws_api/dax","title":"update_cluster","content":"pub fn update_cluster(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dax.update_cluster\naws_api/dax update_cluster","url":"aws_api/dax.html#update_cluster"},{"doc":"aws_api/dax","title":"update_parameter_group","content":"pub fn update_parameter_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dax.update_parameter_group\naws_api/dax update_parameter_group","url":"aws_api/dax.html#update_parameter_group"},{"doc":"aws_api/dax","title":"update_subnet_group","content":"pub fn update_subnet_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dax.update_subnet_group\naws_api/dax update_subnet_group","url":"aws_api/dax.html#update_subnet_group"},{"doc":"aws_api/dax","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/dax.with_custom_endpoint\naws_api/dax with_custom_endpoint","url":"aws_api/dax.html#with_custom_endpoint"},{"doc":"aws_api/dax","title":"aws_api/dax","content":"","url":"aws_api/dax.html"},{"doc":"aws_api/detective","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/detective.Client\naws_api/detective Client","url":"aws_api/detective.html#Client"},{"doc":"aws_api/detective","title":"accept_invitation","content":"pub fn accept_invitation(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/detective.accept_invitation\naws_api/detective accept_invitation","url":"aws_api/detective.html#accept_invitation"},{"doc":"aws_api/detective","title":"batch_get_graph_member_datasources","content":"pub fn batch_get_graph_member_datasources(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/detective.batch_get_graph_member_datasources\naws_api/detective batch_get_graph_member_datasources","url":"aws_api/detective.html#batch_get_graph_member_datasources"},{"doc":"aws_api/detective","title":"batch_get_membership_datasources","content":"pub fn batch_get_membership_datasources(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/detective.batch_get_membership_datasources\naws_api/detective batch_get_membership_datasources","url":"aws_api/detective.html#batch_get_membership_datasources"},{"doc":"aws_api/detective","title":"create_graph","content":"pub fn create_graph(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/detective.create_graph\naws_api/detective create_graph","url":"aws_api/detective.html#create_graph"},{"doc":"aws_api/detective","title":"create_members","content":"pub fn create_members(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/detective.create_members\naws_api/detective create_members","url":"aws_api/detective.html#create_members"},{"doc":"aws_api/detective","title":"delete_graph","content":"pub fn delete_graph(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/detective.delete_graph\naws_api/detective delete_graph","url":"aws_api/detective.html#delete_graph"},{"doc":"aws_api/detective","title":"delete_members","content":"pub fn delete_members(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/detective.delete_members\naws_api/detective delete_members","url":"aws_api/detective.html#delete_members"},{"doc":"aws_api/detective","title":"describe_organization_configuration","content":"pub fn describe_organization_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/detective.describe_organization_configuration\naws_api/detective describe_organization_configuration","url":"aws_api/detective.html#describe_organization_configuration"},{"doc":"aws_api/detective","title":"disable_organization_admin_account","content":"pub fn disable_organization_admin_account(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/detective.disable_organization_admin_account\naws_api/detective disable_organization_admin_account","url":"aws_api/detective.html#disable_organization_admin_account"},{"doc":"aws_api/detective","title":"disassociate_membership","content":"pub fn disassociate_membership(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/detective.disassociate_membership\naws_api/detective disassociate_membership","url":"aws_api/detective.html#disassociate_membership"},{"doc":"aws_api/detective","title":"enable_organization_admin_account","content":"pub fn enable_organization_admin_account(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/detective.enable_organization_admin_account\naws_api/detective enable_organization_admin_account","url":"aws_api/detective.html#enable_organization_admin_account"},{"doc":"aws_api/detective","title":"get_investigation","content":"pub fn get_investigation(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/detective.get_investigation\naws_api/detective get_investigation","url":"aws_api/detective.html#get_investigation"},{"doc":"aws_api/detective","title":"get_members","content":"pub fn get_members(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/detective.get_members\naws_api/detective get_members","url":"aws_api/detective.html#get_members"},{"doc":"aws_api/detective","title":"list_datasource_packages","content":"pub fn list_datasource_packages(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/detective.list_datasource_packages\naws_api/detective list_datasource_packages","url":"aws_api/detective.html#list_datasource_packages"},{"doc":"aws_api/detective","title":"list_graphs","content":"pub fn list_graphs(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/detective.list_graphs\naws_api/detective list_graphs","url":"aws_api/detective.html#list_graphs"},{"doc":"aws_api/detective","title":"list_indicators","content":"pub fn list_indicators(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/detective.list_indicators\naws_api/detective list_indicators","url":"aws_api/detective.html#list_indicators"},{"doc":"aws_api/detective","title":"list_investigations","content":"pub fn list_investigations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/detective.list_investigations\naws_api/detective list_investigations","url":"aws_api/detective.html#list_investigations"},{"doc":"aws_api/detective","title":"list_invitations","content":"pub fn list_invitations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/detective.list_invitations\naws_api/detective list_invitations","url":"aws_api/detective.html#list_invitations"},{"doc":"aws_api/detective","title":"list_members","content":"pub fn list_members(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/detective.list_members\naws_api/detective list_members","url":"aws_api/detective.html#list_members"},{"doc":"aws_api/detective","title":"list_organization_admin_accounts","content":"pub fn list_organization_admin_accounts(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/detective.list_organization_admin_accounts\naws_api/detective list_organization_admin_accounts","url":"aws_api/detective.html#list_organization_admin_accounts"},{"doc":"aws_api/detective","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/detective.list_tags_for_resource\naws_api/detective list_tags_for_resource","url":"aws_api/detective.html#list_tags_for_resource"},{"doc":"aws_api/detective","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/detective.new\naws_api/detective new","url":"aws_api/detective.html#new"},{"doc":"aws_api/detective","title":"reject_invitation","content":"pub fn reject_invitation(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/detective.reject_invitation\naws_api/detective reject_invitation","url":"aws_api/detective.html#reject_invitation"},{"doc":"aws_api/detective","title":"start_investigation","content":"pub fn start_investigation(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/detective.start_investigation\naws_api/detective start_investigation","url":"aws_api/detective.html#start_investigation"},{"doc":"aws_api/detective","title":"start_monitoring_member","content":"pub fn start_monitoring_member(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/detective.start_monitoring_member\naws_api/detective start_monitoring_member","url":"aws_api/detective.html#start_monitoring_member"},{"doc":"aws_api/detective","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/detective.tag_resource\naws_api/detective tag_resource","url":"aws_api/detective.html#tag_resource"},{"doc":"aws_api/detective","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/detective.untag_resource\naws_api/detective untag_resource","url":"aws_api/detective.html#untag_resource"},{"doc":"aws_api/detective","title":"update_datasource_packages","content":"pub fn update_datasource_packages(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/detective.update_datasource_packages\naws_api/detective update_datasource_packages","url":"aws_api/detective.html#update_datasource_packages"},{"doc":"aws_api/detective","title":"update_investigation_state","content":"pub fn update_investigation_state(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/detective.update_investigation_state\naws_api/detective update_investigation_state","url":"aws_api/detective.html#update_investigation_state"},{"doc":"aws_api/detective","title":"update_organization_configuration","content":"pub fn update_organization_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/detective.update_organization_configuration\naws_api/detective update_organization_configuration","url":"aws_api/detective.html#update_organization_configuration"},{"doc":"aws_api/detective","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/detective.with_custom_endpoint\naws_api/detective with_custom_endpoint","url":"aws_api/detective.html#with_custom_endpoint"},{"doc":"aws_api/detective","title":"aws_api/detective","content":"","url":"aws_api/detective.html"},{"doc":"aws_api/device_farm","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/device_farm.Client\naws_api/device_farm Client","url":"aws_api/device_farm.html#Client"},{"doc":"aws_api/device_farm","title":"create_device_pool","content":"pub fn create_device_pool(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.create_device_pool\naws_api/device_farm create_device_pool","url":"aws_api/device_farm.html#create_device_pool"},{"doc":"aws_api/device_farm","title":"create_instance_profile","content":"pub fn create_instance_profile(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.create_instance_profile\naws_api/device_farm create_instance_profile","url":"aws_api/device_farm.html#create_instance_profile"},{"doc":"aws_api/device_farm","title":"create_network_profile","content":"pub fn create_network_profile(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.create_network_profile\naws_api/device_farm create_network_profile","url":"aws_api/device_farm.html#create_network_profile"},{"doc":"aws_api/device_farm","title":"create_project","content":"pub fn create_project(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.create_project\naws_api/device_farm create_project","url":"aws_api/device_farm.html#create_project"},{"doc":"aws_api/device_farm","title":"create_remote_access_session","content":"pub fn create_remote_access_session(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.create_remote_access_session\naws_api/device_farm create_remote_access_session","url":"aws_api/device_farm.html#create_remote_access_session"},{"doc":"aws_api/device_farm","title":"create_test_grid_project","content":"pub fn create_test_grid_project(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.create_test_grid_project\naws_api/device_farm create_test_grid_project","url":"aws_api/device_farm.html#create_test_grid_project"},{"doc":"aws_api/device_farm","title":"create_test_grid_url","content":"pub fn create_test_grid_url(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.create_test_grid_url\naws_api/device_farm create_test_grid_url","url":"aws_api/device_farm.html#create_test_grid_url"},{"doc":"aws_api/device_farm","title":"create_upload","content":"pub fn create_upload(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.create_upload\naws_api/device_farm create_upload","url":"aws_api/device_farm.html#create_upload"},{"doc":"aws_api/device_farm","title":"create_vpce_configuration","content":"pub fn create_vpce_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.create_vpce_configuration\naws_api/device_farm create_vpce_configuration","url":"aws_api/device_farm.html#create_vpce_configuration"},{"doc":"aws_api/device_farm","title":"delete_device_pool","content":"pub fn delete_device_pool(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.delete_device_pool\naws_api/device_farm delete_device_pool","url":"aws_api/device_farm.html#delete_device_pool"},{"doc":"aws_api/device_farm","title":"delete_instance_profile","content":"pub fn delete_instance_profile(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.delete_instance_profile\naws_api/device_farm delete_instance_profile","url":"aws_api/device_farm.html#delete_instance_profile"},{"doc":"aws_api/device_farm","title":"delete_network_profile","content":"pub fn delete_network_profile(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.delete_network_profile\naws_api/device_farm delete_network_profile","url":"aws_api/device_farm.html#delete_network_profile"},{"doc":"aws_api/device_farm","title":"delete_project","content":"pub fn delete_project(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.delete_project\naws_api/device_farm delete_project","url":"aws_api/device_farm.html#delete_project"},{"doc":"aws_api/device_farm","title":"delete_remote_access_session","content":"pub fn delete_remote_access_session(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.delete_remote_access_session\naws_api/device_farm delete_remote_access_session","url":"aws_api/device_farm.html#delete_remote_access_session"},{"doc":"aws_api/device_farm","title":"delete_run","content":"pub fn delete_run(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.delete_run\naws_api/device_farm delete_run","url":"aws_api/device_farm.html#delete_run"},{"doc":"aws_api/device_farm","title":"delete_test_grid_project","content":"pub fn delete_test_grid_project(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.delete_test_grid_project\naws_api/device_farm delete_test_grid_project","url":"aws_api/device_farm.html#delete_test_grid_project"},{"doc":"aws_api/device_farm","title":"delete_upload","content":"pub fn delete_upload(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.delete_upload\naws_api/device_farm delete_upload","url":"aws_api/device_farm.html#delete_upload"},{"doc":"aws_api/device_farm","title":"delete_vpce_configuration","content":"pub fn delete_vpce_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.delete_vpce_configuration\naws_api/device_farm delete_vpce_configuration","url":"aws_api/device_farm.html#delete_vpce_configuration"},{"doc":"aws_api/device_farm","title":"get_account_settings","content":"pub fn get_account_settings(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.get_account_settings\naws_api/device_farm get_account_settings","url":"aws_api/device_farm.html#get_account_settings"},{"doc":"aws_api/device_farm","title":"get_device","content":"pub fn get_device(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.get_device\naws_api/device_farm get_device","url":"aws_api/device_farm.html#get_device"},{"doc":"aws_api/device_farm","title":"get_device_instance","content":"pub fn get_device_instance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.get_device_instance\naws_api/device_farm get_device_instance","url":"aws_api/device_farm.html#get_device_instance"},{"doc":"aws_api/device_farm","title":"get_device_pool","content":"pub fn get_device_pool(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.get_device_pool\naws_api/device_farm get_device_pool","url":"aws_api/device_farm.html#get_device_pool"},{"doc":"aws_api/device_farm","title":"get_device_pool_compatibility","content":"pub fn get_device_pool_compatibility(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.get_device_pool_compatibility\naws_api/device_farm get_device_pool_compatibility","url":"aws_api/device_farm.html#get_device_pool_compatibility"},{"doc":"aws_api/device_farm","title":"get_instance_profile","content":"pub fn get_instance_profile(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.get_instance_profile\naws_api/device_farm get_instance_profile","url":"aws_api/device_farm.html#get_instance_profile"},{"doc":"aws_api/device_farm","title":"get_job","content":"pub fn get_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.get_job\naws_api/device_farm get_job","url":"aws_api/device_farm.html#get_job"},{"doc":"aws_api/device_farm","title":"get_network_profile","content":"pub fn get_network_profile(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.get_network_profile\naws_api/device_farm get_network_profile","url":"aws_api/device_farm.html#get_network_profile"},{"doc":"aws_api/device_farm","title":"get_offering_status","content":"pub fn get_offering_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.get_offering_status\naws_api/device_farm get_offering_status","url":"aws_api/device_farm.html#get_offering_status"},{"doc":"aws_api/device_farm","title":"get_project","content":"pub fn get_project(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.get_project\naws_api/device_farm get_project","url":"aws_api/device_farm.html#get_project"},{"doc":"aws_api/device_farm","title":"get_remote_access_session","content":"pub fn get_remote_access_session(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.get_remote_access_session\naws_api/device_farm get_remote_access_session","url":"aws_api/device_farm.html#get_remote_access_session"},{"doc":"aws_api/device_farm","title":"get_run","content":"pub fn get_run(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.get_run\naws_api/device_farm get_run","url":"aws_api/device_farm.html#get_run"},{"doc":"aws_api/device_farm","title":"get_suite","content":"pub fn get_suite(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.get_suite\naws_api/device_farm get_suite","url":"aws_api/device_farm.html#get_suite"},{"doc":"aws_api/device_farm","title":"get_test","content":"pub fn get_test(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.get_test\naws_api/device_farm get_test","url":"aws_api/device_farm.html#get_test"},{"doc":"aws_api/device_farm","title":"get_test_grid_project","content":"pub fn get_test_grid_project(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.get_test_grid_project\naws_api/device_farm get_test_grid_project","url":"aws_api/device_farm.html#get_test_grid_project"},{"doc":"aws_api/device_farm","title":"get_test_grid_session","content":"pub fn get_test_grid_session(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.get_test_grid_session\naws_api/device_farm get_test_grid_session","url":"aws_api/device_farm.html#get_test_grid_session"},{"doc":"aws_api/device_farm","title":"get_upload","content":"pub fn get_upload(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.get_upload\naws_api/device_farm get_upload","url":"aws_api/device_farm.html#get_upload"},{"doc":"aws_api/device_farm","title":"get_vpce_configuration","content":"pub fn get_vpce_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.get_vpce_configuration\naws_api/device_farm get_vpce_configuration","url":"aws_api/device_farm.html#get_vpce_configuration"},{"doc":"aws_api/device_farm","title":"install_to_remote_access_session","content":"pub fn install_to_remote_access_session(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.install_to_remote_access_session\naws_api/device_farm install_to_remote_access_session","url":"aws_api/device_farm.html#install_to_remote_access_session"},{"doc":"aws_api/device_farm","title":"list_artifacts","content":"pub fn list_artifacts(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.list_artifacts\naws_api/device_farm list_artifacts","url":"aws_api/device_farm.html#list_artifacts"},{"doc":"aws_api/device_farm","title":"list_device_instances","content":"pub fn list_device_instances(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.list_device_instances\naws_api/device_farm list_device_instances","url":"aws_api/device_farm.html#list_device_instances"},{"doc":"aws_api/device_farm","title":"list_device_pools","content":"pub fn list_device_pools(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.list_device_pools\naws_api/device_farm list_device_pools","url":"aws_api/device_farm.html#list_device_pools"},{"doc":"aws_api/device_farm","title":"list_devices","content":"pub fn list_devices(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.list_devices\naws_api/device_farm list_devices","url":"aws_api/device_farm.html#list_devices"},{"doc":"aws_api/device_farm","title":"list_instance_profiles","content":"pub fn list_instance_profiles(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.list_instance_profiles\naws_api/device_farm list_instance_profiles","url":"aws_api/device_farm.html#list_instance_profiles"},{"doc":"aws_api/device_farm","title":"list_jobs","content":"pub fn list_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.list_jobs\naws_api/device_farm list_jobs","url":"aws_api/device_farm.html#list_jobs"},{"doc":"aws_api/device_farm","title":"list_network_profiles","content":"pub fn list_network_profiles(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.list_network_profiles\naws_api/device_farm list_network_profiles","url":"aws_api/device_farm.html#list_network_profiles"},{"doc":"aws_api/device_farm","title":"list_offering_promotions","content":"pub fn list_offering_promotions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.list_offering_promotions\naws_api/device_farm list_offering_promotions","url":"aws_api/device_farm.html#list_offering_promotions"},{"doc":"aws_api/device_farm","title":"list_offering_transactions","content":"pub fn list_offering_transactions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.list_offering_transactions\naws_api/device_farm list_offering_transactions","url":"aws_api/device_farm.html#list_offering_transactions"},{"doc":"aws_api/device_farm","title":"list_offerings","content":"pub fn list_offerings(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.list_offerings\naws_api/device_farm list_offerings","url":"aws_api/device_farm.html#list_offerings"},{"doc":"aws_api/device_farm","title":"list_projects","content":"pub fn list_projects(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.list_projects\naws_api/device_farm list_projects","url":"aws_api/device_farm.html#list_projects"},{"doc":"aws_api/device_farm","title":"list_remote_access_sessions","content":"pub fn list_remote_access_sessions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.list_remote_access_sessions\naws_api/device_farm list_remote_access_sessions","url":"aws_api/device_farm.html#list_remote_access_sessions"},{"doc":"aws_api/device_farm","title":"list_runs","content":"pub fn list_runs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.list_runs\naws_api/device_farm list_runs","url":"aws_api/device_farm.html#list_runs"},{"doc":"aws_api/device_farm","title":"list_samples","content":"pub fn list_samples(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.list_samples\naws_api/device_farm list_samples","url":"aws_api/device_farm.html#list_samples"},{"doc":"aws_api/device_farm","title":"list_suites","content":"pub fn list_suites(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.list_suites\naws_api/device_farm list_suites","url":"aws_api/device_farm.html#list_suites"},{"doc":"aws_api/device_farm","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.list_tags_for_resource\naws_api/device_farm list_tags_for_resource","url":"aws_api/device_farm.html#list_tags_for_resource"},{"doc":"aws_api/device_farm","title":"list_test_grid_projects","content":"pub fn list_test_grid_projects(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.list_test_grid_projects\naws_api/device_farm list_test_grid_projects","url":"aws_api/device_farm.html#list_test_grid_projects"},{"doc":"aws_api/device_farm","title":"list_test_grid_session_actions","content":"pub fn list_test_grid_session_actions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.list_test_grid_session_actions\naws_api/device_farm list_test_grid_session_actions","url":"aws_api/device_farm.html#list_test_grid_session_actions"},{"doc":"aws_api/device_farm","title":"list_test_grid_session_artifacts","content":"pub fn list_test_grid_session_artifacts(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.list_test_grid_session_artifacts\naws_api/device_farm list_test_grid_session_artifacts","url":"aws_api/device_farm.html#list_test_grid_session_artifacts"},{"doc":"aws_api/device_farm","title":"list_test_grid_sessions","content":"pub fn list_test_grid_sessions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.list_test_grid_sessions\naws_api/device_farm list_test_grid_sessions","url":"aws_api/device_farm.html#list_test_grid_sessions"},{"doc":"aws_api/device_farm","title":"list_tests","content":"pub fn list_tests(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.list_tests\naws_api/device_farm list_tests","url":"aws_api/device_farm.html#list_tests"},{"doc":"aws_api/device_farm","title":"list_unique_problems","content":"pub fn list_unique_problems(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.list_unique_problems\naws_api/device_farm list_unique_problems","url":"aws_api/device_farm.html#list_unique_problems"},{"doc":"aws_api/device_farm","title":"list_uploads","content":"pub fn list_uploads(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.list_uploads\naws_api/device_farm list_uploads","url":"aws_api/device_farm.html#list_uploads"},{"doc":"aws_api/device_farm","title":"list_vpce_configurations","content":"pub fn list_vpce_configurations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.list_vpce_configurations\naws_api/device_farm list_vpce_configurations","url":"aws_api/device_farm.html#list_vpce_configurations"},{"doc":"aws_api/device_farm","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/device_farm.new\naws_api/device_farm new","url":"aws_api/device_farm.html#new"},{"doc":"aws_api/device_farm","title":"purchase_offering","content":"pub fn purchase_offering(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.purchase_offering\naws_api/device_farm purchase_offering","url":"aws_api/device_farm.html#purchase_offering"},{"doc":"aws_api/device_farm","title":"renew_offering","content":"pub fn renew_offering(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.renew_offering\naws_api/device_farm renew_offering","url":"aws_api/device_farm.html#renew_offering"},{"doc":"aws_api/device_farm","title":"schedule_run","content":"pub fn schedule_run(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.schedule_run\naws_api/device_farm schedule_run","url":"aws_api/device_farm.html#schedule_run"},{"doc":"aws_api/device_farm","title":"stop_job","content":"pub fn stop_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.stop_job\naws_api/device_farm stop_job","url":"aws_api/device_farm.html#stop_job"},{"doc":"aws_api/device_farm","title":"stop_remote_access_session","content":"pub fn stop_remote_access_session(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.stop_remote_access_session\naws_api/device_farm stop_remote_access_session","url":"aws_api/device_farm.html#stop_remote_access_session"},{"doc":"aws_api/device_farm","title":"stop_run","content":"pub fn stop_run(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.stop_run\naws_api/device_farm stop_run","url":"aws_api/device_farm.html#stop_run"},{"doc":"aws_api/device_farm","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.tag_resource\naws_api/device_farm tag_resource","url":"aws_api/device_farm.html#tag_resource"},{"doc":"aws_api/device_farm","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.untag_resource\naws_api/device_farm untag_resource","url":"aws_api/device_farm.html#untag_resource"},{"doc":"aws_api/device_farm","title":"update_device_instance","content":"pub fn update_device_instance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.update_device_instance\naws_api/device_farm update_device_instance","url":"aws_api/device_farm.html#update_device_instance"},{"doc":"aws_api/device_farm","title":"update_device_pool","content":"pub fn update_device_pool(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.update_device_pool\naws_api/device_farm update_device_pool","url":"aws_api/device_farm.html#update_device_pool"},{"doc":"aws_api/device_farm","title":"update_instance_profile","content":"pub fn update_instance_profile(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.update_instance_profile\naws_api/device_farm update_instance_profile","url":"aws_api/device_farm.html#update_instance_profile"},{"doc":"aws_api/device_farm","title":"update_network_profile","content":"pub fn update_network_profile(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.update_network_profile\naws_api/device_farm update_network_profile","url":"aws_api/device_farm.html#update_network_profile"},{"doc":"aws_api/device_farm","title":"update_project","content":"pub fn update_project(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.update_project\naws_api/device_farm update_project","url":"aws_api/device_farm.html#update_project"},{"doc":"aws_api/device_farm","title":"update_test_grid_project","content":"pub fn update_test_grid_project(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.update_test_grid_project\naws_api/device_farm update_test_grid_project","url":"aws_api/device_farm.html#update_test_grid_project"},{"doc":"aws_api/device_farm","title":"update_upload","content":"pub fn update_upload(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.update_upload\naws_api/device_farm update_upload","url":"aws_api/device_farm.html#update_upload"},{"doc":"aws_api/device_farm","title":"update_vpce_configuration","content":"pub fn update_vpce_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/device_farm.update_vpce_configuration\naws_api/device_farm update_vpce_configuration","url":"aws_api/device_farm.html#update_vpce_configuration"},{"doc":"aws_api/device_farm","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/device_farm.with_custom_endpoint\naws_api/device_farm with_custom_endpoint","url":"aws_api/device_farm.html#with_custom_endpoint"},{"doc":"aws_api/device_farm","title":"aws_api/device_farm","content":"","url":"aws_api/device_farm.html"},{"doc":"aws_api/devops_guru","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/devops_guru.Client\naws_api/devops_guru Client","url":"aws_api/devops_guru.html#Client"},{"doc":"aws_api/devops_guru","title":"add_notification_channel","content":"pub fn add_notification_channel(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/devops_guru.add_notification_channel\naws_api/devops_guru add_notification_channel","url":"aws_api/devops_guru.html#add_notification_channel"},{"doc":"aws_api/devops_guru","title":"delete_insight","content":"pub fn delete_insight(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/devops_guru.delete_insight\naws_api/devops_guru delete_insight","url":"aws_api/devops_guru.html#delete_insight"},{"doc":"aws_api/devops_guru","title":"describe_account_health","content":"pub fn describe_account_health(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/devops_guru.describe_account_health\naws_api/devops_guru describe_account_health","url":"aws_api/devops_guru.html#describe_account_health"},{"doc":"aws_api/devops_guru","title":"describe_account_overview","content":"pub fn describe_account_overview(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/devops_guru.describe_account_overview\naws_api/devops_guru describe_account_overview","url":"aws_api/devops_guru.html#describe_account_overview"},{"doc":"aws_api/devops_guru","title":"describe_anomaly","content":"pub fn describe_anomaly(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/devops_guru.describe_anomaly\naws_api/devops_guru describe_anomaly","url":"aws_api/devops_guru.html#describe_anomaly"},{"doc":"aws_api/devops_guru","title":"describe_event_sources_config","content":"pub fn describe_event_sources_config(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/devops_guru.describe_event_sources_config\naws_api/devops_guru describe_event_sources_config","url":"aws_api/devops_guru.html#describe_event_sources_config"},{"doc":"aws_api/devops_guru","title":"describe_feedback","content":"pub fn describe_feedback(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/devops_guru.describe_feedback\naws_api/devops_guru describe_feedback","url":"aws_api/devops_guru.html#describe_feedback"},{"doc":"aws_api/devops_guru","title":"describe_insight","content":"pub fn describe_insight(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/devops_guru.describe_insight\naws_api/devops_guru describe_insight","url":"aws_api/devops_guru.html#describe_insight"},{"doc":"aws_api/devops_guru","title":"describe_organization_health","content":"pub fn describe_organization_health(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/devops_guru.describe_organization_health\naws_api/devops_guru describe_organization_health","url":"aws_api/devops_guru.html#describe_organization_health"},{"doc":"aws_api/devops_guru","title":"describe_organization_overview","content":"pub fn describe_organization_overview(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/devops_guru.describe_organization_overview\naws_api/devops_guru describe_organization_overview","url":"aws_api/devops_guru.html#describe_organization_overview"},{"doc":"aws_api/devops_guru","title":"describe_organization_resource_collection_health","content":"pub fn describe_organization_resource_collection_health(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/devops_guru.describe_organization_resource_collection_health\naws_api/devops_guru describe_organization_resource_collection_health","url":"aws_api/devops_guru.html#describe_organization_resource_collection_health"},{"doc":"aws_api/devops_guru","title":"describe_resource_collection_health","content":"pub fn describe_resource_collection_health(\n  client: Client,\n  resource_collection_type: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/devops_guru.describe_resource_collection_health\naws_api/devops_guru describe_resource_collection_health","url":"aws_api/devops_guru.html#describe_resource_collection_health"},{"doc":"aws_api/devops_guru","title":"describe_service_integration","content":"pub fn describe_service_integration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/devops_guru.describe_service_integration\naws_api/devops_guru describe_service_integration","url":"aws_api/devops_guru.html#describe_service_integration"},{"doc":"aws_api/devops_guru","title":"get_cost_estimation","content":"pub fn get_cost_estimation(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/devops_guru.get_cost_estimation\naws_api/devops_guru get_cost_estimation","url":"aws_api/devops_guru.html#get_cost_estimation"},{"doc":"aws_api/devops_guru","title":"get_resource_collection","content":"pub fn get_resource_collection(\n  client: Client,\n  resource_collection_type: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/devops_guru.get_resource_collection\naws_api/devops_guru get_resource_collection","url":"aws_api/devops_guru.html#get_resource_collection"},{"doc":"aws_api/devops_guru","title":"list_anomalies_for_insight","content":"pub fn list_anomalies_for_insight(\n  client: Client,\n  insight_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/devops_guru.list_anomalies_for_insight\naws_api/devops_guru list_anomalies_for_insight","url":"aws_api/devops_guru.html#list_anomalies_for_insight"},{"doc":"aws_api/devops_guru","title":"list_anomalous_log_groups","content":"pub fn list_anomalous_log_groups(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/devops_guru.list_anomalous_log_groups\naws_api/devops_guru list_anomalous_log_groups","url":"aws_api/devops_guru.html#list_anomalous_log_groups"},{"doc":"aws_api/devops_guru","title":"list_events","content":"pub fn list_events(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/devops_guru.list_events\naws_api/devops_guru list_events","url":"aws_api/devops_guru.html#list_events"},{"doc":"aws_api/devops_guru","title":"list_insights","content":"pub fn list_insights(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/devops_guru.list_insights\naws_api/devops_guru list_insights","url":"aws_api/devops_guru.html#list_insights"},{"doc":"aws_api/devops_guru","title":"list_monitored_resources","content":"pub fn list_monitored_resources(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/devops_guru.list_monitored_resources\naws_api/devops_guru list_monitored_resources","url":"aws_api/devops_guru.html#list_monitored_resources"},{"doc":"aws_api/devops_guru","title":"list_notification_channels","content":"pub fn list_notification_channels(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/devops_guru.list_notification_channels\naws_api/devops_guru list_notification_channels","url":"aws_api/devops_guru.html#list_notification_channels"},{"doc":"aws_api/devops_guru","title":"list_organization_insights","content":"pub fn list_organization_insights(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/devops_guru.list_organization_insights\naws_api/devops_guru list_organization_insights","url":"aws_api/devops_guru.html#list_organization_insights"},{"doc":"aws_api/devops_guru","title":"list_recommendations","content":"pub fn list_recommendations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/devops_guru.list_recommendations\naws_api/devops_guru list_recommendations","url":"aws_api/devops_guru.html#list_recommendations"},{"doc":"aws_api/devops_guru","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/devops_guru.new\naws_api/devops_guru new","url":"aws_api/devops_guru.html#new"},{"doc":"aws_api/devops_guru","title":"put_feedback","content":"pub fn put_feedback(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/devops_guru.put_feedback\naws_api/devops_guru put_feedback","url":"aws_api/devops_guru.html#put_feedback"},{"doc":"aws_api/devops_guru","title":"remove_notification_channel","content":"pub fn remove_notification_channel(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/devops_guru.remove_notification_channel\naws_api/devops_guru remove_notification_channel","url":"aws_api/devops_guru.html#remove_notification_channel"},{"doc":"aws_api/devops_guru","title":"search_insights","content":"pub fn search_insights(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/devops_guru.search_insights\naws_api/devops_guru search_insights","url":"aws_api/devops_guru.html#search_insights"},{"doc":"aws_api/devops_guru","title":"search_organization_insights","content":"pub fn search_organization_insights(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/devops_guru.search_organization_insights\naws_api/devops_guru search_organization_insights","url":"aws_api/devops_guru.html#search_organization_insights"},{"doc":"aws_api/devops_guru","title":"start_cost_estimation","content":"pub fn start_cost_estimation(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/devops_guru.start_cost_estimation\naws_api/devops_guru start_cost_estimation","url":"aws_api/devops_guru.html#start_cost_estimation"},{"doc":"aws_api/devops_guru","title":"update_event_sources_config","content":"pub fn update_event_sources_config(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/devops_guru.update_event_sources_config\naws_api/devops_guru update_event_sources_config","url":"aws_api/devops_guru.html#update_event_sources_config"},{"doc":"aws_api/devops_guru","title":"update_resource_collection","content":"pub fn update_resource_collection(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/devops_guru.update_resource_collection\naws_api/devops_guru update_resource_collection","url":"aws_api/devops_guru.html#update_resource_collection"},{"doc":"aws_api/devops_guru","title":"update_service_integration","content":"pub fn update_service_integration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/devops_guru.update_service_integration\naws_api/devops_guru update_service_integration","url":"aws_api/devops_guru.html#update_service_integration"},{"doc":"aws_api/devops_guru","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/devops_guru.with_custom_endpoint\naws_api/devops_guru with_custom_endpoint","url":"aws_api/devops_guru.html#with_custom_endpoint"},{"doc":"aws_api/devops_guru","title":"aws_api/devops_guru","content":"","url":"aws_api/devops_guru.html"},{"doc":"aws_api/direct_connect","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/direct_connect.Client\naws_api/direct_connect Client","url":"aws_api/direct_connect.html#Client"},{"doc":"aws_api/direct_connect","title":"accept_direct_connect_gateway_association_proposal","content":"pub fn accept_direct_connect_gateway_association_proposal(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.accept_direct_connect_gateway_association_proposal\naws_api/direct_connect accept_direct_connect_gateway_association_proposal","url":"aws_api/direct_connect.html#accept_direct_connect_gateway_association_proposal"},{"doc":"aws_api/direct_connect","title":"allocate_connection_on_interconnect","content":"pub fn allocate_connection_on_interconnect(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.allocate_connection_on_interconnect\naws_api/direct_connect allocate_connection_on_interconnect","url":"aws_api/direct_connect.html#allocate_connection_on_interconnect"},{"doc":"aws_api/direct_connect","title":"allocate_hosted_connection","content":"pub fn allocate_hosted_connection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.allocate_hosted_connection\naws_api/direct_connect allocate_hosted_connection","url":"aws_api/direct_connect.html#allocate_hosted_connection"},{"doc":"aws_api/direct_connect","title":"allocate_private_virtual_interface","content":"pub fn allocate_private_virtual_interface(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.allocate_private_virtual_interface\naws_api/direct_connect allocate_private_virtual_interface","url":"aws_api/direct_connect.html#allocate_private_virtual_interface"},{"doc":"aws_api/direct_connect","title":"allocate_public_virtual_interface","content":"pub fn allocate_public_virtual_interface(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.allocate_public_virtual_interface\naws_api/direct_connect allocate_public_virtual_interface","url":"aws_api/direct_connect.html#allocate_public_virtual_interface"},{"doc":"aws_api/direct_connect","title":"allocate_transit_virtual_interface","content":"pub fn allocate_transit_virtual_interface(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.allocate_transit_virtual_interface\naws_api/direct_connect allocate_transit_virtual_interface","url":"aws_api/direct_connect.html#allocate_transit_virtual_interface"},{"doc":"aws_api/direct_connect","title":"associate_connection_with_lag","content":"pub fn associate_connection_with_lag(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.associate_connection_with_lag\naws_api/direct_connect associate_connection_with_lag","url":"aws_api/direct_connect.html#associate_connection_with_lag"},{"doc":"aws_api/direct_connect","title":"associate_hosted_connection","content":"pub fn associate_hosted_connection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.associate_hosted_connection\naws_api/direct_connect associate_hosted_connection","url":"aws_api/direct_connect.html#associate_hosted_connection"},{"doc":"aws_api/direct_connect","title":"associate_mac_sec_key","content":"pub fn associate_mac_sec_key(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.associate_mac_sec_key\naws_api/direct_connect associate_mac_sec_key","url":"aws_api/direct_connect.html#associate_mac_sec_key"},{"doc":"aws_api/direct_connect","title":"associate_virtual_interface","content":"pub fn associate_virtual_interface(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.associate_virtual_interface\naws_api/direct_connect associate_virtual_interface","url":"aws_api/direct_connect.html#associate_virtual_interface"},{"doc":"aws_api/direct_connect","title":"confirm_connection","content":"pub fn confirm_connection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.confirm_connection\naws_api/direct_connect confirm_connection","url":"aws_api/direct_connect.html#confirm_connection"},{"doc":"aws_api/direct_connect","title":"confirm_customer_agreement","content":"pub fn confirm_customer_agreement(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.confirm_customer_agreement\naws_api/direct_connect confirm_customer_agreement","url":"aws_api/direct_connect.html#confirm_customer_agreement"},{"doc":"aws_api/direct_connect","title":"confirm_private_virtual_interface","content":"pub fn confirm_private_virtual_interface(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.confirm_private_virtual_interface\naws_api/direct_connect confirm_private_virtual_interface","url":"aws_api/direct_connect.html#confirm_private_virtual_interface"},{"doc":"aws_api/direct_connect","title":"confirm_public_virtual_interface","content":"pub fn confirm_public_virtual_interface(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.confirm_public_virtual_interface\naws_api/direct_connect confirm_public_virtual_interface","url":"aws_api/direct_connect.html#confirm_public_virtual_interface"},{"doc":"aws_api/direct_connect","title":"confirm_transit_virtual_interface","content":"pub fn confirm_transit_virtual_interface(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.confirm_transit_virtual_interface\naws_api/direct_connect confirm_transit_virtual_interface","url":"aws_api/direct_connect.html#confirm_transit_virtual_interface"},{"doc":"aws_api/direct_connect","title":"create_bgp_peer","content":"pub fn create_bgp_peer(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.create_bgp_peer\naws_api/direct_connect create_bgp_peer","url":"aws_api/direct_connect.html#create_bgp_peer"},{"doc":"aws_api/direct_connect","title":"create_connection","content":"pub fn create_connection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.create_connection\naws_api/direct_connect create_connection","url":"aws_api/direct_connect.html#create_connection"},{"doc":"aws_api/direct_connect","title":"create_direct_connect_gateway","content":"pub fn create_direct_connect_gateway(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.create_direct_connect_gateway\naws_api/direct_connect create_direct_connect_gateway","url":"aws_api/direct_connect.html#create_direct_connect_gateway"},{"doc":"aws_api/direct_connect","title":"create_direct_connect_gateway_association","content":"pub fn create_direct_connect_gateway_association(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.create_direct_connect_gateway_association\naws_api/direct_connect create_direct_connect_gateway_association","url":"aws_api/direct_connect.html#create_direct_connect_gateway_association"},{"doc":"aws_api/direct_connect","title":"create_direct_connect_gateway_association_proposal","content":"pub fn create_direct_connect_gateway_association_proposal(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.create_direct_connect_gateway_association_proposal\naws_api/direct_connect create_direct_connect_gateway_association_proposal","url":"aws_api/direct_connect.html#create_direct_connect_gateway_association_proposal"},{"doc":"aws_api/direct_connect","title":"create_interconnect","content":"pub fn create_interconnect(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.create_interconnect\naws_api/direct_connect create_interconnect","url":"aws_api/direct_connect.html#create_interconnect"},{"doc":"aws_api/direct_connect","title":"create_lag","content":"pub fn create_lag(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.create_lag\naws_api/direct_connect create_lag","url":"aws_api/direct_connect.html#create_lag"},{"doc":"aws_api/direct_connect","title":"create_private_virtual_interface","content":"pub fn create_private_virtual_interface(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.create_private_virtual_interface\naws_api/direct_connect create_private_virtual_interface","url":"aws_api/direct_connect.html#create_private_virtual_interface"},{"doc":"aws_api/direct_connect","title":"create_public_virtual_interface","content":"pub fn create_public_virtual_interface(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.create_public_virtual_interface\naws_api/direct_connect create_public_virtual_interface","url":"aws_api/direct_connect.html#create_public_virtual_interface"},{"doc":"aws_api/direct_connect","title":"create_transit_virtual_interface","content":"pub fn create_transit_virtual_interface(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.create_transit_virtual_interface\naws_api/direct_connect create_transit_virtual_interface","url":"aws_api/direct_connect.html#create_transit_virtual_interface"},{"doc":"aws_api/direct_connect","title":"delete_bgp_peer","content":"pub fn delete_bgp_peer(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.delete_bgp_peer\naws_api/direct_connect delete_bgp_peer","url":"aws_api/direct_connect.html#delete_bgp_peer"},{"doc":"aws_api/direct_connect","title":"delete_connection","content":"pub fn delete_connection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.delete_connection\naws_api/direct_connect delete_connection","url":"aws_api/direct_connect.html#delete_connection"},{"doc":"aws_api/direct_connect","title":"delete_direct_connect_gateway","content":"pub fn delete_direct_connect_gateway(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.delete_direct_connect_gateway\naws_api/direct_connect delete_direct_connect_gateway","url":"aws_api/direct_connect.html#delete_direct_connect_gateway"},{"doc":"aws_api/direct_connect","title":"delete_direct_connect_gateway_association","content":"pub fn delete_direct_connect_gateway_association(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.delete_direct_connect_gateway_association\naws_api/direct_connect delete_direct_connect_gateway_association","url":"aws_api/direct_connect.html#delete_direct_connect_gateway_association"},{"doc":"aws_api/direct_connect","title":"delete_direct_connect_gateway_association_proposal","content":"pub fn delete_direct_connect_gateway_association_proposal(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.delete_direct_connect_gateway_association_proposal\naws_api/direct_connect delete_direct_connect_gateway_association_proposal","url":"aws_api/direct_connect.html#delete_direct_connect_gateway_association_proposal"},{"doc":"aws_api/direct_connect","title":"delete_interconnect","content":"pub fn delete_interconnect(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.delete_interconnect\naws_api/direct_connect delete_interconnect","url":"aws_api/direct_connect.html#delete_interconnect"},{"doc":"aws_api/direct_connect","title":"delete_lag","content":"pub fn delete_lag(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.delete_lag\naws_api/direct_connect delete_lag","url":"aws_api/direct_connect.html#delete_lag"},{"doc":"aws_api/direct_connect","title":"delete_virtual_interface","content":"pub fn delete_virtual_interface(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.delete_virtual_interface\naws_api/direct_connect delete_virtual_interface","url":"aws_api/direct_connect.html#delete_virtual_interface"},{"doc":"aws_api/direct_connect","title":"describe_connection_loa","content":"pub fn describe_connection_loa(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.describe_connection_loa\naws_api/direct_connect describe_connection_loa","url":"aws_api/direct_connect.html#describe_connection_loa"},{"doc":"aws_api/direct_connect","title":"describe_connections","content":"pub fn describe_connections(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.describe_connections\naws_api/direct_connect describe_connections","url":"aws_api/direct_connect.html#describe_connections"},{"doc":"aws_api/direct_connect","title":"describe_connections_on_interconnect","content":"pub fn describe_connections_on_interconnect(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.describe_connections_on_interconnect\naws_api/direct_connect describe_connections_on_interconnect","url":"aws_api/direct_connect.html#describe_connections_on_interconnect"},{"doc":"aws_api/direct_connect","title":"describe_customer_metadata","content":"pub fn describe_customer_metadata(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.describe_customer_metadata\naws_api/direct_connect describe_customer_metadata","url":"aws_api/direct_connect.html#describe_customer_metadata"},{"doc":"aws_api/direct_connect","title":"describe_direct_connect_gateway_association_proposals","content":"pub fn describe_direct_connect_gateway_association_proposals(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.describe_direct_connect_gateway_association_proposals\naws_api/direct_connect describe_direct_connect_gateway_association_proposals","url":"aws_api/direct_connect.html#describe_direct_connect_gateway_association_proposals"},{"doc":"aws_api/direct_connect","title":"describe_direct_connect_gateway_associations","content":"pub fn describe_direct_connect_gateway_associations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.describe_direct_connect_gateway_associations\naws_api/direct_connect describe_direct_connect_gateway_associations","url":"aws_api/direct_connect.html#describe_direct_connect_gateway_associations"},{"doc":"aws_api/direct_connect","title":"describe_direct_connect_gateway_attachments","content":"pub fn describe_direct_connect_gateway_attachments(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.describe_direct_connect_gateway_attachments\naws_api/direct_connect describe_direct_connect_gateway_attachments","url":"aws_api/direct_connect.html#describe_direct_connect_gateway_attachments"},{"doc":"aws_api/direct_connect","title":"describe_direct_connect_gateways","content":"pub fn describe_direct_connect_gateways(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.describe_direct_connect_gateways\naws_api/direct_connect describe_direct_connect_gateways","url":"aws_api/direct_connect.html#describe_direct_connect_gateways"},{"doc":"aws_api/direct_connect","title":"describe_hosted_connections","content":"pub fn describe_hosted_connections(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.describe_hosted_connections\naws_api/direct_connect describe_hosted_connections","url":"aws_api/direct_connect.html#describe_hosted_connections"},{"doc":"aws_api/direct_connect","title":"describe_interconnect_loa","content":"pub fn describe_interconnect_loa(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.describe_interconnect_loa\naws_api/direct_connect describe_interconnect_loa","url":"aws_api/direct_connect.html#describe_interconnect_loa"},{"doc":"aws_api/direct_connect","title":"describe_interconnects","content":"pub fn describe_interconnects(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.describe_interconnects\naws_api/direct_connect describe_interconnects","url":"aws_api/direct_connect.html#describe_interconnects"},{"doc":"aws_api/direct_connect","title":"describe_lags","content":"pub fn describe_lags(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.describe_lags\naws_api/direct_connect describe_lags","url":"aws_api/direct_connect.html#describe_lags"},{"doc":"aws_api/direct_connect","title":"describe_loa","content":"pub fn describe_loa(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.describe_loa\naws_api/direct_connect describe_loa","url":"aws_api/direct_connect.html#describe_loa"},{"doc":"aws_api/direct_connect","title":"describe_locations","content":"pub fn describe_locations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.describe_locations\naws_api/direct_connect describe_locations","url":"aws_api/direct_connect.html#describe_locations"},{"doc":"aws_api/direct_connect","title":"describe_router_configuration","content":"pub fn describe_router_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.describe_router_configuration\naws_api/direct_connect describe_router_configuration","url":"aws_api/direct_connect.html#describe_router_configuration"},{"doc":"aws_api/direct_connect","title":"describe_tags","content":"pub fn describe_tags(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.describe_tags\naws_api/direct_connect describe_tags","url":"aws_api/direct_connect.html#describe_tags"},{"doc":"aws_api/direct_connect","title":"describe_virtual_gateways","content":"pub fn describe_virtual_gateways(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.describe_virtual_gateways\naws_api/direct_connect describe_virtual_gateways","url":"aws_api/direct_connect.html#describe_virtual_gateways"},{"doc":"aws_api/direct_connect","title":"describe_virtual_interfaces","content":"pub fn describe_virtual_interfaces(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.describe_virtual_interfaces\naws_api/direct_connect describe_virtual_interfaces","url":"aws_api/direct_connect.html#describe_virtual_interfaces"},{"doc":"aws_api/direct_connect","title":"disassociate_connection_from_lag","content":"pub fn disassociate_connection_from_lag(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.disassociate_connection_from_lag\naws_api/direct_connect disassociate_connection_from_lag","url":"aws_api/direct_connect.html#disassociate_connection_from_lag"},{"doc":"aws_api/direct_connect","title":"disassociate_mac_sec_key","content":"pub fn disassociate_mac_sec_key(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.disassociate_mac_sec_key\naws_api/direct_connect disassociate_mac_sec_key","url":"aws_api/direct_connect.html#disassociate_mac_sec_key"},{"doc":"aws_api/direct_connect","title":"list_virtual_interface_test_history","content":"pub fn list_virtual_interface_test_history(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.list_virtual_interface_test_history\naws_api/direct_connect list_virtual_interface_test_history","url":"aws_api/direct_connect.html#list_virtual_interface_test_history"},{"doc":"aws_api/direct_connect","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/direct_connect.new\naws_api/direct_connect new","url":"aws_api/direct_connect.html#new"},{"doc":"aws_api/direct_connect","title":"start_bgp_failover_test","content":"pub fn start_bgp_failover_test(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.start_bgp_failover_test\naws_api/direct_connect start_bgp_failover_test","url":"aws_api/direct_connect.html#start_bgp_failover_test"},{"doc":"aws_api/direct_connect","title":"stop_bgp_failover_test","content":"pub fn stop_bgp_failover_test(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.stop_bgp_failover_test\naws_api/direct_connect stop_bgp_failover_test","url":"aws_api/direct_connect.html#stop_bgp_failover_test"},{"doc":"aws_api/direct_connect","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.tag_resource\naws_api/direct_connect tag_resource","url":"aws_api/direct_connect.html#tag_resource"},{"doc":"aws_api/direct_connect","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.untag_resource\naws_api/direct_connect untag_resource","url":"aws_api/direct_connect.html#untag_resource"},{"doc":"aws_api/direct_connect","title":"update_connection","content":"pub fn update_connection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.update_connection\naws_api/direct_connect update_connection","url":"aws_api/direct_connect.html#update_connection"},{"doc":"aws_api/direct_connect","title":"update_direct_connect_gateway","content":"pub fn update_direct_connect_gateway(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.update_direct_connect_gateway\naws_api/direct_connect update_direct_connect_gateway","url":"aws_api/direct_connect.html#update_direct_connect_gateway"},{"doc":"aws_api/direct_connect","title":"update_direct_connect_gateway_association","content":"pub fn update_direct_connect_gateway_association(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.update_direct_connect_gateway_association\naws_api/direct_connect update_direct_connect_gateway_association","url":"aws_api/direct_connect.html#update_direct_connect_gateway_association"},{"doc":"aws_api/direct_connect","title":"update_lag","content":"pub fn update_lag(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.update_lag\naws_api/direct_connect update_lag","url":"aws_api/direct_connect.html#update_lag"},{"doc":"aws_api/direct_connect","title":"update_virtual_interface_attributes","content":"pub fn update_virtual_interface_attributes(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/direct_connect.update_virtual_interface_attributes\naws_api/direct_connect update_virtual_interface_attributes","url":"aws_api/direct_connect.html#update_virtual_interface_attributes"},{"doc":"aws_api/direct_connect","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/direct_connect.with_custom_endpoint\naws_api/direct_connect with_custom_endpoint","url":"aws_api/direct_connect.html#with_custom_endpoint"},{"doc":"aws_api/direct_connect","title":"aws_api/direct_connect","content":"","url":"aws_api/direct_connect.html"},{"doc":"aws_api/directory_service","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/directory_service.Client\naws_api/directory_service Client","url":"aws_api/directory_service.html#Client"},{"doc":"aws_api/directory_service","title":"accept_shared_directory","content":"pub fn accept_shared_directory(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.accept_shared_directory\naws_api/directory_service accept_shared_directory","url":"aws_api/directory_service.html#accept_shared_directory"},{"doc":"aws_api/directory_service","title":"add_ip_routes","content":"pub fn add_ip_routes(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.add_ip_routes\naws_api/directory_service add_ip_routes","url":"aws_api/directory_service.html#add_ip_routes"},{"doc":"aws_api/directory_service","title":"add_region","content":"pub fn add_region(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.add_region\naws_api/directory_service add_region","url":"aws_api/directory_service.html#add_region"},{"doc":"aws_api/directory_service","title":"add_tags_to_resource","content":"pub fn add_tags_to_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.add_tags_to_resource\naws_api/directory_service add_tags_to_resource","url":"aws_api/directory_service.html#add_tags_to_resource"},{"doc":"aws_api/directory_service","title":"cancel_schema_extension","content":"pub fn cancel_schema_extension(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.cancel_schema_extension\naws_api/directory_service cancel_schema_extension","url":"aws_api/directory_service.html#cancel_schema_extension"},{"doc":"aws_api/directory_service","title":"connect_directory","content":"pub fn connect_directory(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.connect_directory\naws_api/directory_service connect_directory","url":"aws_api/directory_service.html#connect_directory"},{"doc":"aws_api/directory_service","title":"create_alias","content":"pub fn create_alias(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.create_alias\naws_api/directory_service create_alias","url":"aws_api/directory_service.html#create_alias"},{"doc":"aws_api/directory_service","title":"create_computer","content":"pub fn create_computer(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.create_computer\naws_api/directory_service create_computer","url":"aws_api/directory_service.html#create_computer"},{"doc":"aws_api/directory_service","title":"create_conditional_forwarder","content":"pub fn create_conditional_forwarder(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.create_conditional_forwarder\naws_api/directory_service create_conditional_forwarder","url":"aws_api/directory_service.html#create_conditional_forwarder"},{"doc":"aws_api/directory_service","title":"create_directory","content":"pub fn create_directory(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.create_directory\naws_api/directory_service create_directory","url":"aws_api/directory_service.html#create_directory"},{"doc":"aws_api/directory_service","title":"create_log_subscription","content":"pub fn create_log_subscription(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.create_log_subscription\naws_api/directory_service create_log_subscription","url":"aws_api/directory_service.html#create_log_subscription"},{"doc":"aws_api/directory_service","title":"create_microsoft_ad","content":"pub fn create_microsoft_ad(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.create_microsoft_ad\naws_api/directory_service create_microsoft_ad","url":"aws_api/directory_service.html#create_microsoft_ad"},{"doc":"aws_api/directory_service","title":"create_snapshot","content":"pub fn create_snapshot(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.create_snapshot\naws_api/directory_service create_snapshot","url":"aws_api/directory_service.html#create_snapshot"},{"doc":"aws_api/directory_service","title":"create_trust","content":"pub fn create_trust(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.create_trust\naws_api/directory_service create_trust","url":"aws_api/directory_service.html#create_trust"},{"doc":"aws_api/directory_service","title":"delete_conditional_forwarder","content":"pub fn delete_conditional_forwarder(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.delete_conditional_forwarder\naws_api/directory_service delete_conditional_forwarder","url":"aws_api/directory_service.html#delete_conditional_forwarder"},{"doc":"aws_api/directory_service","title":"delete_directory","content":"pub fn delete_directory(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.delete_directory\naws_api/directory_service delete_directory","url":"aws_api/directory_service.html#delete_directory"},{"doc":"aws_api/directory_service","title":"delete_log_subscription","content":"pub fn delete_log_subscription(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.delete_log_subscription\naws_api/directory_service delete_log_subscription","url":"aws_api/directory_service.html#delete_log_subscription"},{"doc":"aws_api/directory_service","title":"delete_snapshot","content":"pub fn delete_snapshot(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.delete_snapshot\naws_api/directory_service delete_snapshot","url":"aws_api/directory_service.html#delete_snapshot"},{"doc":"aws_api/directory_service","title":"delete_trust","content":"pub fn delete_trust(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.delete_trust\naws_api/directory_service delete_trust","url":"aws_api/directory_service.html#delete_trust"},{"doc":"aws_api/directory_service","title":"deregister_certificate","content":"pub fn deregister_certificate(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.deregister_certificate\naws_api/directory_service deregister_certificate","url":"aws_api/directory_service.html#deregister_certificate"},{"doc":"aws_api/directory_service","title":"deregister_event_topic","content":"pub fn deregister_event_topic(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.deregister_event_topic\naws_api/directory_service deregister_event_topic","url":"aws_api/directory_service.html#deregister_event_topic"},{"doc":"aws_api/directory_service","title":"describe_certificate","content":"pub fn describe_certificate(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.describe_certificate\naws_api/directory_service describe_certificate","url":"aws_api/directory_service.html#describe_certificate"},{"doc":"aws_api/directory_service","title":"describe_client_authentication_settings","content":"pub fn describe_client_authentication_settings(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.describe_client_authentication_settings\naws_api/directory_service describe_client_authentication_settings","url":"aws_api/directory_service.html#describe_client_authentication_settings"},{"doc":"aws_api/directory_service","title":"describe_conditional_forwarders","content":"pub fn describe_conditional_forwarders(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.describe_conditional_forwarders\naws_api/directory_service describe_conditional_forwarders","url":"aws_api/directory_service.html#describe_conditional_forwarders"},{"doc":"aws_api/directory_service","title":"describe_directories","content":"pub fn describe_directories(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.describe_directories\naws_api/directory_service describe_directories","url":"aws_api/directory_service.html#describe_directories"},{"doc":"aws_api/directory_service","title":"describe_domain_controllers","content":"pub fn describe_domain_controllers(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.describe_domain_controllers\naws_api/directory_service describe_domain_controllers","url":"aws_api/directory_service.html#describe_domain_controllers"},{"doc":"aws_api/directory_service","title":"describe_event_topics","content":"pub fn describe_event_topics(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.describe_event_topics\naws_api/directory_service describe_event_topics","url":"aws_api/directory_service.html#describe_event_topics"},{"doc":"aws_api/directory_service","title":"describe_ldaps_settings","content":"pub fn describe_ldaps_settings(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.describe_ldaps_settings\naws_api/directory_service describe_ldaps_settings","url":"aws_api/directory_service.html#describe_ldaps_settings"},{"doc":"aws_api/directory_service","title":"describe_regions","content":"pub fn describe_regions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.describe_regions\naws_api/directory_service describe_regions","url":"aws_api/directory_service.html#describe_regions"},{"doc":"aws_api/directory_service","title":"describe_settings","content":"pub fn describe_settings(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.describe_settings\naws_api/directory_service describe_settings","url":"aws_api/directory_service.html#describe_settings"},{"doc":"aws_api/directory_service","title":"describe_shared_directories","content":"pub fn describe_shared_directories(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.describe_shared_directories\naws_api/directory_service describe_shared_directories","url":"aws_api/directory_service.html#describe_shared_directories"},{"doc":"aws_api/directory_service","title":"describe_snapshots","content":"pub fn describe_snapshots(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.describe_snapshots\naws_api/directory_service describe_snapshots","url":"aws_api/directory_service.html#describe_snapshots"},{"doc":"aws_api/directory_service","title":"describe_trusts","content":"pub fn describe_trusts(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.describe_trusts\naws_api/directory_service describe_trusts","url":"aws_api/directory_service.html#describe_trusts"},{"doc":"aws_api/directory_service","title":"describe_update_directory","content":"pub fn describe_update_directory(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.describe_update_directory\naws_api/directory_service describe_update_directory","url":"aws_api/directory_service.html#describe_update_directory"},{"doc":"aws_api/directory_service","title":"disable_client_authentication","content":"pub fn disable_client_authentication(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.disable_client_authentication\naws_api/directory_service disable_client_authentication","url":"aws_api/directory_service.html#disable_client_authentication"},{"doc":"aws_api/directory_service","title":"disable_ldaps","content":"pub fn disable_ldaps(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.disable_ldaps\naws_api/directory_service disable_ldaps","url":"aws_api/directory_service.html#disable_ldaps"},{"doc":"aws_api/directory_service","title":"disable_radius","content":"pub fn disable_radius(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.disable_radius\naws_api/directory_service disable_radius","url":"aws_api/directory_service.html#disable_radius"},{"doc":"aws_api/directory_service","title":"disable_sso","content":"pub fn disable_sso(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.disable_sso\naws_api/directory_service disable_sso","url":"aws_api/directory_service.html#disable_sso"},{"doc":"aws_api/directory_service","title":"enable_client_authentication","content":"pub fn enable_client_authentication(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.enable_client_authentication\naws_api/directory_service enable_client_authentication","url":"aws_api/directory_service.html#enable_client_authentication"},{"doc":"aws_api/directory_service","title":"enable_ldaps","content":"pub fn enable_ldaps(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.enable_ldaps\naws_api/directory_service enable_ldaps","url":"aws_api/directory_service.html#enable_ldaps"},{"doc":"aws_api/directory_service","title":"enable_radius","content":"pub fn enable_radius(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.enable_radius\naws_api/directory_service enable_radius","url":"aws_api/directory_service.html#enable_radius"},{"doc":"aws_api/directory_service","title":"enable_sso","content":"pub fn enable_sso(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.enable_sso\naws_api/directory_service enable_sso","url":"aws_api/directory_service.html#enable_sso"},{"doc":"aws_api/directory_service","title":"get_directory_limits","content":"pub fn get_directory_limits(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.get_directory_limits\naws_api/directory_service get_directory_limits","url":"aws_api/directory_service.html#get_directory_limits"},{"doc":"aws_api/directory_service","title":"get_snapshot_limits","content":"pub fn get_snapshot_limits(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.get_snapshot_limits\naws_api/directory_service get_snapshot_limits","url":"aws_api/directory_service.html#get_snapshot_limits"},{"doc":"aws_api/directory_service","title":"list_certificates","content":"pub fn list_certificates(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.list_certificates\naws_api/directory_service list_certificates","url":"aws_api/directory_service.html#list_certificates"},{"doc":"aws_api/directory_service","title":"list_ip_routes","content":"pub fn list_ip_routes(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.list_ip_routes\naws_api/directory_service list_ip_routes","url":"aws_api/directory_service.html#list_ip_routes"},{"doc":"aws_api/directory_service","title":"list_log_subscriptions","content":"pub fn list_log_subscriptions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.list_log_subscriptions\naws_api/directory_service list_log_subscriptions","url":"aws_api/directory_service.html#list_log_subscriptions"},{"doc":"aws_api/directory_service","title":"list_schema_extensions","content":"pub fn list_schema_extensions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.list_schema_extensions\naws_api/directory_service list_schema_extensions","url":"aws_api/directory_service.html#list_schema_extensions"},{"doc":"aws_api/directory_service","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.list_tags_for_resource\naws_api/directory_service list_tags_for_resource","url":"aws_api/directory_service.html#list_tags_for_resource"},{"doc":"aws_api/directory_service","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/directory_service.new\naws_api/directory_service new","url":"aws_api/directory_service.html#new"},{"doc":"aws_api/directory_service","title":"register_certificate","content":"pub fn register_certificate(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.register_certificate\naws_api/directory_service register_certificate","url":"aws_api/directory_service.html#register_certificate"},{"doc":"aws_api/directory_service","title":"register_event_topic","content":"pub fn register_event_topic(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.register_event_topic\naws_api/directory_service register_event_topic","url":"aws_api/directory_service.html#register_event_topic"},{"doc":"aws_api/directory_service","title":"reject_shared_directory","content":"pub fn reject_shared_directory(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.reject_shared_directory\naws_api/directory_service reject_shared_directory","url":"aws_api/directory_service.html#reject_shared_directory"},{"doc":"aws_api/directory_service","title":"remove_ip_routes","content":"pub fn remove_ip_routes(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.remove_ip_routes\naws_api/directory_service remove_ip_routes","url":"aws_api/directory_service.html#remove_ip_routes"},{"doc":"aws_api/directory_service","title":"remove_region","content":"pub fn remove_region(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.remove_region\naws_api/directory_service remove_region","url":"aws_api/directory_service.html#remove_region"},{"doc":"aws_api/directory_service","title":"remove_tags_from_resource","content":"pub fn remove_tags_from_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.remove_tags_from_resource\naws_api/directory_service remove_tags_from_resource","url":"aws_api/directory_service.html#remove_tags_from_resource"},{"doc":"aws_api/directory_service","title":"reset_user_password","content":"pub fn reset_user_password(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.reset_user_password\naws_api/directory_service reset_user_password","url":"aws_api/directory_service.html#reset_user_password"},{"doc":"aws_api/directory_service","title":"restore_from_snapshot","content":"pub fn restore_from_snapshot(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.restore_from_snapshot\naws_api/directory_service restore_from_snapshot","url":"aws_api/directory_service.html#restore_from_snapshot"},{"doc":"aws_api/directory_service","title":"share_directory","content":"pub fn share_directory(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.share_directory\naws_api/directory_service share_directory","url":"aws_api/directory_service.html#share_directory"},{"doc":"aws_api/directory_service","title":"start_schema_extension","content":"pub fn start_schema_extension(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.start_schema_extension\naws_api/directory_service start_schema_extension","url":"aws_api/directory_service.html#start_schema_extension"},{"doc":"aws_api/directory_service","title":"unshare_directory","content":"pub fn unshare_directory(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.unshare_directory\naws_api/directory_service unshare_directory","url":"aws_api/directory_service.html#unshare_directory"},{"doc":"aws_api/directory_service","title":"update_conditional_forwarder","content":"pub fn update_conditional_forwarder(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.update_conditional_forwarder\naws_api/directory_service update_conditional_forwarder","url":"aws_api/directory_service.html#update_conditional_forwarder"},{"doc":"aws_api/directory_service","title":"update_directory_setup","content":"pub fn update_directory_setup(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.update_directory_setup\naws_api/directory_service update_directory_setup","url":"aws_api/directory_service.html#update_directory_setup"},{"doc":"aws_api/directory_service","title":"update_number_of_domain_controllers","content":"pub fn update_number_of_domain_controllers(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.update_number_of_domain_controllers\naws_api/directory_service update_number_of_domain_controllers","url":"aws_api/directory_service.html#update_number_of_domain_controllers"},{"doc":"aws_api/directory_service","title":"update_radius","content":"pub fn update_radius(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.update_radius\naws_api/directory_service update_radius","url":"aws_api/directory_service.html#update_radius"},{"doc":"aws_api/directory_service","title":"update_settings","content":"pub fn update_settings(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.update_settings\naws_api/directory_service update_settings","url":"aws_api/directory_service.html#update_settings"},{"doc":"aws_api/directory_service","title":"update_trust","content":"pub fn update_trust(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.update_trust\naws_api/directory_service update_trust","url":"aws_api/directory_service.html#update_trust"},{"doc":"aws_api/directory_service","title":"verify_trust","content":"pub fn verify_trust(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/directory_service.verify_trust\naws_api/directory_service verify_trust","url":"aws_api/directory_service.html#verify_trust"},{"doc":"aws_api/directory_service","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/directory_service.with_custom_endpoint\naws_api/directory_service with_custom_endpoint","url":"aws_api/directory_service.html#with_custom_endpoint"},{"doc":"aws_api/directory_service","title":"aws_api/directory_service","content":"","url":"aws_api/directory_service.html"},{"doc":"aws_api/dlm","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/dlm.Client\naws_api/dlm Client","url":"aws_api/dlm.html#Client"},{"doc":"aws_api/dlm","title":"create_lifecycle_policy","content":"pub fn create_lifecycle_policy(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dlm.create_lifecycle_policy\naws_api/dlm create_lifecycle_policy","url":"aws_api/dlm.html#create_lifecycle_policy"},{"doc":"aws_api/dlm","title":"delete_lifecycle_policy","content":"pub fn delete_lifecycle_policy(\n  client: Client,\n  policy_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dlm.delete_lifecycle_policy\naws_api/dlm delete_lifecycle_policy","url":"aws_api/dlm.html#delete_lifecycle_policy"},{"doc":"aws_api/dlm","title":"get_lifecycle_policies","content":"pub fn get_lifecycle_policies(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dlm.get_lifecycle_policies\naws_api/dlm get_lifecycle_policies","url":"aws_api/dlm.html#get_lifecycle_policies"},{"doc":"aws_api/dlm","title":"get_lifecycle_policy","content":"pub fn get_lifecycle_policy(\n  client: Client,\n  policy_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dlm.get_lifecycle_policy\naws_api/dlm get_lifecycle_policy","url":"aws_api/dlm.html#get_lifecycle_policy"},{"doc":"aws_api/dlm","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dlm.list_tags_for_resource\naws_api/dlm list_tags_for_resource","url":"aws_api/dlm.html#list_tags_for_resource"},{"doc":"aws_api/dlm","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/dlm.new\naws_api/dlm new","url":"aws_api/dlm.html#new"},{"doc":"aws_api/dlm","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dlm.tag_resource\naws_api/dlm tag_resource","url":"aws_api/dlm.html#tag_resource"},{"doc":"aws_api/dlm","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dlm.untag_resource\naws_api/dlm untag_resource","url":"aws_api/dlm.html#untag_resource"},{"doc":"aws_api/dlm","title":"update_lifecycle_policy","content":"pub fn update_lifecycle_policy(\n  client: Client,\n  policy_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dlm.update_lifecycle_policy\naws_api/dlm update_lifecycle_policy","url":"aws_api/dlm.html#update_lifecycle_policy"},{"doc":"aws_api/dlm","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/dlm.with_custom_endpoint\naws_api/dlm with_custom_endpoint","url":"aws_api/dlm.html#with_custom_endpoint"},{"doc":"aws_api/dlm","title":"aws_api/dlm","content":"","url":"aws_api/dlm.html"},{"doc":"aws_api/docdb","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/docdb.Client\naws_api/docdb Client","url":"aws_api/docdb.html#Client"},{"doc":"aws_api/docdb","title":"add_source_identifier_to_subscription","content":"pub fn add_source_identifier_to_subscription(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.add_source_identifier_to_subscription\naws_api/docdb add_source_identifier_to_subscription","url":"aws_api/docdb.html#add_source_identifier_to_subscription"},{"doc":"aws_api/docdb","title":"add_tags_to_resource","content":"pub fn add_tags_to_resource(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.add_tags_to_resource\naws_api/docdb add_tags_to_resource","url":"aws_api/docdb.html#add_tags_to_resource"},{"doc":"aws_api/docdb","title":"apply_pending_maintenance_action","content":"pub fn apply_pending_maintenance_action(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.apply_pending_maintenance_action\naws_api/docdb apply_pending_maintenance_action","url":"aws_api/docdb.html#apply_pending_maintenance_action"},{"doc":"aws_api/docdb","title":"copy_db_cluster_parameter_group","content":"pub fn copy_db_cluster_parameter_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.copy_db_cluster_parameter_group\naws_api/docdb copy_db_cluster_parameter_group","url":"aws_api/docdb.html#copy_db_cluster_parameter_group"},{"doc":"aws_api/docdb","title":"copy_db_cluster_snapshot","content":"pub fn copy_db_cluster_snapshot(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.copy_db_cluster_snapshot\naws_api/docdb copy_db_cluster_snapshot","url":"aws_api/docdb.html#copy_db_cluster_snapshot"},{"doc":"aws_api/docdb","title":"create_db_cluster","content":"pub fn create_db_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.create_db_cluster\naws_api/docdb create_db_cluster","url":"aws_api/docdb.html#create_db_cluster"},{"doc":"aws_api/docdb","title":"create_db_cluster_parameter_group","content":"pub fn create_db_cluster_parameter_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.create_db_cluster_parameter_group\naws_api/docdb create_db_cluster_parameter_group","url":"aws_api/docdb.html#create_db_cluster_parameter_group"},{"doc":"aws_api/docdb","title":"create_db_cluster_snapshot","content":"pub fn create_db_cluster_snapshot(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.create_db_cluster_snapshot\naws_api/docdb create_db_cluster_snapshot","url":"aws_api/docdb.html#create_db_cluster_snapshot"},{"doc":"aws_api/docdb","title":"create_db_instance","content":"pub fn create_db_instance(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.create_db_instance\naws_api/docdb create_db_instance","url":"aws_api/docdb.html#create_db_instance"},{"doc":"aws_api/docdb","title":"create_db_subnet_group","content":"pub fn create_db_subnet_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.create_db_subnet_group\naws_api/docdb create_db_subnet_group","url":"aws_api/docdb.html#create_db_subnet_group"},{"doc":"aws_api/docdb","title":"create_event_subscription","content":"pub fn create_event_subscription(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.create_event_subscription\naws_api/docdb create_event_subscription","url":"aws_api/docdb.html#create_event_subscription"},{"doc":"aws_api/docdb","title":"create_global_cluster","content":"pub fn create_global_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.create_global_cluster\naws_api/docdb create_global_cluster","url":"aws_api/docdb.html#create_global_cluster"},{"doc":"aws_api/docdb","title":"delete_db_cluster","content":"pub fn delete_db_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.delete_db_cluster\naws_api/docdb delete_db_cluster","url":"aws_api/docdb.html#delete_db_cluster"},{"doc":"aws_api/docdb","title":"delete_db_cluster_parameter_group","content":"pub fn delete_db_cluster_parameter_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.delete_db_cluster_parameter_group\naws_api/docdb delete_db_cluster_parameter_group","url":"aws_api/docdb.html#delete_db_cluster_parameter_group"},{"doc":"aws_api/docdb","title":"delete_db_cluster_snapshot","content":"pub fn delete_db_cluster_snapshot(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.delete_db_cluster_snapshot\naws_api/docdb delete_db_cluster_snapshot","url":"aws_api/docdb.html#delete_db_cluster_snapshot"},{"doc":"aws_api/docdb","title":"delete_db_instance","content":"pub fn delete_db_instance(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.delete_db_instance\naws_api/docdb delete_db_instance","url":"aws_api/docdb.html#delete_db_instance"},{"doc":"aws_api/docdb","title":"delete_db_subnet_group","content":"pub fn delete_db_subnet_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.delete_db_subnet_group\naws_api/docdb delete_db_subnet_group","url":"aws_api/docdb.html#delete_db_subnet_group"},{"doc":"aws_api/docdb","title":"delete_event_subscription","content":"pub fn delete_event_subscription(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.delete_event_subscription\naws_api/docdb delete_event_subscription","url":"aws_api/docdb.html#delete_event_subscription"},{"doc":"aws_api/docdb","title":"delete_global_cluster","content":"pub fn delete_global_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.delete_global_cluster\naws_api/docdb delete_global_cluster","url":"aws_api/docdb.html#delete_global_cluster"},{"doc":"aws_api/docdb","title":"describe_certificates","content":"pub fn describe_certificates(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.describe_certificates\naws_api/docdb describe_certificates","url":"aws_api/docdb.html#describe_certificates"},{"doc":"aws_api/docdb","title":"describe_db_cluster_parameter_groups","content":"pub fn describe_db_cluster_parameter_groups(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.describe_db_cluster_parameter_groups\naws_api/docdb describe_db_cluster_parameter_groups","url":"aws_api/docdb.html#describe_db_cluster_parameter_groups"},{"doc":"aws_api/docdb","title":"describe_db_cluster_parameters","content":"pub fn describe_db_cluster_parameters(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.describe_db_cluster_parameters\naws_api/docdb describe_db_cluster_parameters","url":"aws_api/docdb.html#describe_db_cluster_parameters"},{"doc":"aws_api/docdb","title":"describe_db_cluster_snapshot_attributes","content":"pub fn describe_db_cluster_snapshot_attributes(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.describe_db_cluster_snapshot_attributes\naws_api/docdb describe_db_cluster_snapshot_attributes","url":"aws_api/docdb.html#describe_db_cluster_snapshot_attributes"},{"doc":"aws_api/docdb","title":"describe_db_cluster_snapshots","content":"pub fn describe_db_cluster_snapshots(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.describe_db_cluster_snapshots\naws_api/docdb describe_db_cluster_snapshots","url":"aws_api/docdb.html#describe_db_cluster_snapshots"},{"doc":"aws_api/docdb","title":"describe_db_clusters","content":"pub fn describe_db_clusters(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.describe_db_clusters\naws_api/docdb describe_db_clusters","url":"aws_api/docdb.html#describe_db_clusters"},{"doc":"aws_api/docdb","title":"describe_db_engine_versions","content":"pub fn describe_db_engine_versions(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.describe_db_engine_versions\naws_api/docdb describe_db_engine_versions","url":"aws_api/docdb.html#describe_db_engine_versions"},{"doc":"aws_api/docdb","title":"describe_db_instances","content":"pub fn describe_db_instances(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.describe_db_instances\naws_api/docdb describe_db_instances","url":"aws_api/docdb.html#describe_db_instances"},{"doc":"aws_api/docdb","title":"describe_db_subnet_groups","content":"pub fn describe_db_subnet_groups(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.describe_db_subnet_groups\naws_api/docdb describe_db_subnet_groups","url":"aws_api/docdb.html#describe_db_subnet_groups"},{"doc":"aws_api/docdb","title":"describe_engine_default_cluster_parameters","content":"pub fn describe_engine_default_cluster_parameters(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.describe_engine_default_cluster_parameters\naws_api/docdb describe_engine_default_cluster_parameters","url":"aws_api/docdb.html#describe_engine_default_cluster_parameters"},{"doc":"aws_api/docdb","title":"describe_event_categories","content":"pub fn describe_event_categories(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.describe_event_categories\naws_api/docdb describe_event_categories","url":"aws_api/docdb.html#describe_event_categories"},{"doc":"aws_api/docdb","title":"describe_event_subscriptions","content":"pub fn describe_event_subscriptions(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.describe_event_subscriptions\naws_api/docdb describe_event_subscriptions","url":"aws_api/docdb.html#describe_event_subscriptions"},{"doc":"aws_api/docdb","title":"describe_events","content":"pub fn describe_events(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.describe_events\naws_api/docdb describe_events","url":"aws_api/docdb.html#describe_events"},{"doc":"aws_api/docdb","title":"describe_global_clusters","content":"pub fn describe_global_clusters(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.describe_global_clusters\naws_api/docdb describe_global_clusters","url":"aws_api/docdb.html#describe_global_clusters"},{"doc":"aws_api/docdb","title":"describe_orderable_db_instance_options","content":"pub fn describe_orderable_db_instance_options(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.describe_orderable_db_instance_options\naws_api/docdb describe_orderable_db_instance_options","url":"aws_api/docdb.html#describe_orderable_db_instance_options"},{"doc":"aws_api/docdb","title":"describe_pending_maintenance_actions","content":"pub fn describe_pending_maintenance_actions(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.describe_pending_maintenance_actions\naws_api/docdb describe_pending_maintenance_actions","url":"aws_api/docdb.html#describe_pending_maintenance_actions"},{"doc":"aws_api/docdb","title":"failover_db_cluster","content":"pub fn failover_db_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.failover_db_cluster\naws_api/docdb failover_db_cluster","url":"aws_api/docdb.html#failover_db_cluster"},{"doc":"aws_api/docdb","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.list_tags_for_resource\naws_api/docdb list_tags_for_resource","url":"aws_api/docdb.html#list_tags_for_resource"},{"doc":"aws_api/docdb","title":"modify_db_cluster","content":"pub fn modify_db_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.modify_db_cluster\naws_api/docdb modify_db_cluster","url":"aws_api/docdb.html#modify_db_cluster"},{"doc":"aws_api/docdb","title":"modify_db_cluster_parameter_group","content":"pub fn modify_db_cluster_parameter_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.modify_db_cluster_parameter_group\naws_api/docdb modify_db_cluster_parameter_group","url":"aws_api/docdb.html#modify_db_cluster_parameter_group"},{"doc":"aws_api/docdb","title":"modify_db_cluster_snapshot_attribute","content":"pub fn modify_db_cluster_snapshot_attribute(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.modify_db_cluster_snapshot_attribute\naws_api/docdb modify_db_cluster_snapshot_attribute","url":"aws_api/docdb.html#modify_db_cluster_snapshot_attribute"},{"doc":"aws_api/docdb","title":"modify_db_instance","content":"pub fn modify_db_instance(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.modify_db_instance\naws_api/docdb modify_db_instance","url":"aws_api/docdb.html#modify_db_instance"},{"doc":"aws_api/docdb","title":"modify_db_subnet_group","content":"pub fn modify_db_subnet_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.modify_db_subnet_group\naws_api/docdb modify_db_subnet_group","url":"aws_api/docdb.html#modify_db_subnet_group"},{"doc":"aws_api/docdb","title":"modify_event_subscription","content":"pub fn modify_event_subscription(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.modify_event_subscription\naws_api/docdb modify_event_subscription","url":"aws_api/docdb.html#modify_event_subscription"},{"doc":"aws_api/docdb","title":"modify_global_cluster","content":"pub fn modify_global_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.modify_global_cluster\naws_api/docdb modify_global_cluster","url":"aws_api/docdb.html#modify_global_cluster"},{"doc":"aws_api/docdb","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/docdb.new\naws_api/docdb new","url":"aws_api/docdb.html#new"},{"doc":"aws_api/docdb","title":"reboot_db_instance","content":"pub fn reboot_db_instance(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.reboot_db_instance\naws_api/docdb reboot_db_instance","url":"aws_api/docdb.html#reboot_db_instance"},{"doc":"aws_api/docdb","title":"remove_from_global_cluster","content":"pub fn remove_from_global_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.remove_from_global_cluster\naws_api/docdb remove_from_global_cluster","url":"aws_api/docdb.html#remove_from_global_cluster"},{"doc":"aws_api/docdb","title":"remove_source_identifier_from_subscription","content":"pub fn remove_source_identifier_from_subscription(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.remove_source_identifier_from_subscription\naws_api/docdb remove_source_identifier_from_subscription","url":"aws_api/docdb.html#remove_source_identifier_from_subscription"},{"doc":"aws_api/docdb","title":"remove_tags_from_resource","content":"pub fn remove_tags_from_resource(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.remove_tags_from_resource\naws_api/docdb remove_tags_from_resource","url":"aws_api/docdb.html#remove_tags_from_resource"},{"doc":"aws_api/docdb","title":"reset_db_cluster_parameter_group","content":"pub fn reset_db_cluster_parameter_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.reset_db_cluster_parameter_group\naws_api/docdb reset_db_cluster_parameter_group","url":"aws_api/docdb.html#reset_db_cluster_parameter_group"},{"doc":"aws_api/docdb","title":"restore_db_cluster_from_snapshot","content":"pub fn restore_db_cluster_from_snapshot(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.restore_db_cluster_from_snapshot\naws_api/docdb restore_db_cluster_from_snapshot","url":"aws_api/docdb.html#restore_db_cluster_from_snapshot"},{"doc":"aws_api/docdb","title":"restore_db_cluster_to_point_in_time","content":"pub fn restore_db_cluster_to_point_in_time(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.restore_db_cluster_to_point_in_time\naws_api/docdb restore_db_cluster_to_point_in_time","url":"aws_api/docdb.html#restore_db_cluster_to_point_in_time"},{"doc":"aws_api/docdb","title":"start_db_cluster","content":"pub fn start_db_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.start_db_cluster\naws_api/docdb start_db_cluster","url":"aws_api/docdb.html#start_db_cluster"},{"doc":"aws_api/docdb","title":"stop_db_cluster","content":"pub fn stop_db_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.stop_db_cluster\naws_api/docdb stop_db_cluster","url":"aws_api/docdb.html#stop_db_cluster"},{"doc":"aws_api/docdb","title":"switchover_global_cluster","content":"pub fn switchover_global_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/docdb.switchover_global_cluster\naws_api/docdb switchover_global_cluster","url":"aws_api/docdb.html#switchover_global_cluster"},{"doc":"aws_api/docdb","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/docdb.with_custom_endpoint\naws_api/docdb with_custom_endpoint","url":"aws_api/docdb.html#with_custom_endpoint"},{"doc":"aws_api/docdb","title":"aws_api/docdb","content":"","url":"aws_api/docdb.html"},{"doc":"aws_api/drs","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/drs.Client\naws_api/drs Client","url":"aws_api/drs.html#Client"},{"doc":"aws_api/drs","title":"create_extended_source_server","content":"pub fn create_extended_source_server(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/drs.create_extended_source_server\naws_api/drs create_extended_source_server","url":"aws_api/drs.html#create_extended_source_server"},{"doc":"aws_api/drs","title":"delete_launch_action","content":"pub fn delete_launch_action(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/drs.delete_launch_action\naws_api/drs delete_launch_action","url":"aws_api/drs.html#delete_launch_action"},{"doc":"aws_api/drs","title":"initialize_service","content":"pub fn initialize_service(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/drs.initialize_service\naws_api/drs initialize_service","url":"aws_api/drs.html#initialize_service"},{"doc":"aws_api/drs","title":"list_extensible_source_servers","content":"pub fn list_extensible_source_servers(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/drs.list_extensible_source_servers\naws_api/drs list_extensible_source_servers","url":"aws_api/drs.html#list_extensible_source_servers"},{"doc":"aws_api/drs","title":"list_launch_actions","content":"pub fn list_launch_actions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/drs.list_launch_actions\naws_api/drs list_launch_actions","url":"aws_api/drs.html#list_launch_actions"},{"doc":"aws_api/drs","title":"list_staging_accounts","content":"pub fn list_staging_accounts(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/drs.list_staging_accounts\naws_api/drs list_staging_accounts","url":"aws_api/drs.html#list_staging_accounts"},{"doc":"aws_api/drs","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/drs.list_tags_for_resource\naws_api/drs list_tags_for_resource","url":"aws_api/drs.html#list_tags_for_resource"},{"doc":"aws_api/drs","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/drs.new\naws_api/drs new","url":"aws_api/drs.html#new"},{"doc":"aws_api/drs","title":"put_launch_action","content":"pub fn put_launch_action(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/drs.put_launch_action\naws_api/drs put_launch_action","url":"aws_api/drs.html#put_launch_action"},{"doc":"aws_api/drs","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/drs.tag_resource\naws_api/drs tag_resource","url":"aws_api/drs.html#tag_resource"},{"doc":"aws_api/drs","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/drs.untag_resource\naws_api/drs untag_resource","url":"aws_api/drs.html#untag_resource"},{"doc":"aws_api/drs","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/drs.with_custom_endpoint\naws_api/drs with_custom_endpoint","url":"aws_api/drs.html#with_custom_endpoint"},{"doc":"aws_api/drs","title":"aws_api/drs","content":"","url":"aws_api/drs.html"},{"doc":"aws_api/dynamodb","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/dynamodb.Client\naws_api/dynamodb Client","url":"aws_api/dynamodb.html#Client"},{"doc":"aws_api/dynamodb","title":"batch_execute_statement","content":"pub fn batch_execute_statement(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.batch_execute_statement\naws_api/dynamodb batch_execute_statement","url":"aws_api/dynamodb.html#batch_execute_statement"},{"doc":"aws_api/dynamodb","title":"batch_get_item","content":"pub fn batch_get_item(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.batch_get_item\naws_api/dynamodb batch_get_item","url":"aws_api/dynamodb.html#batch_get_item"},{"doc":"aws_api/dynamodb","title":"batch_write_item","content":"pub fn batch_write_item(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.batch_write_item\naws_api/dynamodb batch_write_item","url":"aws_api/dynamodb.html#batch_write_item"},{"doc":"aws_api/dynamodb","title":"create_backup","content":"pub fn create_backup(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.create_backup\naws_api/dynamodb create_backup","url":"aws_api/dynamodb.html#create_backup"},{"doc":"aws_api/dynamodb","title":"create_global_table","content":"pub fn create_global_table(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.create_global_table\naws_api/dynamodb create_global_table","url":"aws_api/dynamodb.html#create_global_table"},{"doc":"aws_api/dynamodb","title":"create_table","content":"pub fn create_table(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.create_table\naws_api/dynamodb create_table","url":"aws_api/dynamodb.html#create_table"},{"doc":"aws_api/dynamodb","title":"delete_backup","content":"pub fn delete_backup(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.delete_backup\naws_api/dynamodb delete_backup","url":"aws_api/dynamodb.html#delete_backup"},{"doc":"aws_api/dynamodb","title":"delete_item","content":"pub fn delete_item(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.delete_item\naws_api/dynamodb delete_item","url":"aws_api/dynamodb.html#delete_item"},{"doc":"aws_api/dynamodb","title":"delete_resource_policy","content":"pub fn delete_resource_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.delete_resource_policy\naws_api/dynamodb delete_resource_policy","url":"aws_api/dynamodb.html#delete_resource_policy"},{"doc":"aws_api/dynamodb","title":"delete_table","content":"pub fn delete_table(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.delete_table\naws_api/dynamodb delete_table","url":"aws_api/dynamodb.html#delete_table"},{"doc":"aws_api/dynamodb","title":"describe_backup","content":"pub fn describe_backup(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.describe_backup\naws_api/dynamodb describe_backup","url":"aws_api/dynamodb.html#describe_backup"},{"doc":"aws_api/dynamodb","title":"describe_continuous_backups","content":"pub fn describe_continuous_backups(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.describe_continuous_backups\naws_api/dynamodb describe_continuous_backups","url":"aws_api/dynamodb.html#describe_continuous_backups"},{"doc":"aws_api/dynamodb","title":"describe_contributor_insights","content":"pub fn describe_contributor_insights(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.describe_contributor_insights\naws_api/dynamodb describe_contributor_insights","url":"aws_api/dynamodb.html#describe_contributor_insights"},{"doc":"aws_api/dynamodb","title":"describe_endpoints","content":"pub fn describe_endpoints(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.describe_endpoints\naws_api/dynamodb describe_endpoints","url":"aws_api/dynamodb.html#describe_endpoints"},{"doc":"aws_api/dynamodb","title":"describe_export","content":"pub fn describe_export(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.describe_export\naws_api/dynamodb describe_export","url":"aws_api/dynamodb.html#describe_export"},{"doc":"aws_api/dynamodb","title":"describe_global_table","content":"pub fn describe_global_table(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.describe_global_table\naws_api/dynamodb describe_global_table","url":"aws_api/dynamodb.html#describe_global_table"},{"doc":"aws_api/dynamodb","title":"describe_global_table_settings","content":"pub fn describe_global_table_settings(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.describe_global_table_settings\naws_api/dynamodb describe_global_table_settings","url":"aws_api/dynamodb.html#describe_global_table_settings"},{"doc":"aws_api/dynamodb","title":"describe_import","content":"pub fn describe_import(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.describe_import\naws_api/dynamodb describe_import","url":"aws_api/dynamodb.html#describe_import"},{"doc":"aws_api/dynamodb","title":"describe_kinesis_streaming_destination","content":"pub fn describe_kinesis_streaming_destination(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.describe_kinesis_streaming_destination\naws_api/dynamodb describe_kinesis_streaming_destination","url":"aws_api/dynamodb.html#describe_kinesis_streaming_destination"},{"doc":"aws_api/dynamodb","title":"describe_limits","content":"pub fn describe_limits(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.describe_limits\naws_api/dynamodb describe_limits","url":"aws_api/dynamodb.html#describe_limits"},{"doc":"aws_api/dynamodb","title":"describe_table","content":"pub fn describe_table(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.describe_table\naws_api/dynamodb describe_table","url":"aws_api/dynamodb.html#describe_table"},{"doc":"aws_api/dynamodb","title":"describe_table_replica_auto_scaling","content":"pub fn describe_table_replica_auto_scaling(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.describe_table_replica_auto_scaling\naws_api/dynamodb describe_table_replica_auto_scaling","url":"aws_api/dynamodb.html#describe_table_replica_auto_scaling"},{"doc":"aws_api/dynamodb","title":"describe_time_to_live","content":"pub fn describe_time_to_live(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.describe_time_to_live\naws_api/dynamodb describe_time_to_live","url":"aws_api/dynamodb.html#describe_time_to_live"},{"doc":"aws_api/dynamodb","title":"disable_kinesis_streaming_destination","content":"pub fn disable_kinesis_streaming_destination(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.disable_kinesis_streaming_destination\naws_api/dynamodb disable_kinesis_streaming_destination","url":"aws_api/dynamodb.html#disable_kinesis_streaming_destination"},{"doc":"aws_api/dynamodb","title":"enable_kinesis_streaming_destination","content":"pub fn enable_kinesis_streaming_destination(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.enable_kinesis_streaming_destination\naws_api/dynamodb enable_kinesis_streaming_destination","url":"aws_api/dynamodb.html#enable_kinesis_streaming_destination"},{"doc":"aws_api/dynamodb","title":"execute_statement","content":"pub fn execute_statement(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.execute_statement\naws_api/dynamodb execute_statement","url":"aws_api/dynamodb.html#execute_statement"},{"doc":"aws_api/dynamodb","title":"execute_transaction","content":"pub fn execute_transaction(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.execute_transaction\naws_api/dynamodb execute_transaction","url":"aws_api/dynamodb.html#execute_transaction"},{"doc":"aws_api/dynamodb","title":"export_table_to_point_in_time","content":"pub fn export_table_to_point_in_time(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.export_table_to_point_in_time\naws_api/dynamodb export_table_to_point_in_time","url":"aws_api/dynamodb.html#export_table_to_point_in_time"},{"doc":"aws_api/dynamodb","title":"get_item","content":"pub fn get_item(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.get_item\naws_api/dynamodb get_item","url":"aws_api/dynamodb.html#get_item"},{"doc":"aws_api/dynamodb","title":"get_resource_policy","content":"pub fn get_resource_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.get_resource_policy\naws_api/dynamodb get_resource_policy","url":"aws_api/dynamodb.html#get_resource_policy"},{"doc":"aws_api/dynamodb","title":"import_table","content":"pub fn import_table(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.import_table\naws_api/dynamodb import_table","url":"aws_api/dynamodb.html#import_table"},{"doc":"aws_api/dynamodb","title":"list_backups","content":"pub fn list_backups(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.list_backups\naws_api/dynamodb list_backups","url":"aws_api/dynamodb.html#list_backups"},{"doc":"aws_api/dynamodb","title":"list_contributor_insights","content":"pub fn list_contributor_insights(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.list_contributor_insights\naws_api/dynamodb list_contributor_insights","url":"aws_api/dynamodb.html#list_contributor_insights"},{"doc":"aws_api/dynamodb","title":"list_exports","content":"pub fn list_exports(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.list_exports\naws_api/dynamodb list_exports","url":"aws_api/dynamodb.html#list_exports"},{"doc":"aws_api/dynamodb","title":"list_global_tables","content":"pub fn list_global_tables(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.list_global_tables\naws_api/dynamodb list_global_tables","url":"aws_api/dynamodb.html#list_global_tables"},{"doc":"aws_api/dynamodb","title":"list_imports","content":"pub fn list_imports(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.list_imports\naws_api/dynamodb list_imports","url":"aws_api/dynamodb.html#list_imports"},{"doc":"aws_api/dynamodb","title":"list_tables","content":"pub fn list_tables(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.list_tables\naws_api/dynamodb list_tables","url":"aws_api/dynamodb.html#list_tables"},{"doc":"aws_api/dynamodb","title":"list_tags_of_resource","content":"pub fn list_tags_of_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.list_tags_of_resource\naws_api/dynamodb list_tags_of_resource","url":"aws_api/dynamodb.html#list_tags_of_resource"},{"doc":"aws_api/dynamodb","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/dynamodb.new\naws_api/dynamodb new","url":"aws_api/dynamodb.html#new"},{"doc":"aws_api/dynamodb","title":"put_item","content":"pub fn put_item(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.put_item\naws_api/dynamodb put_item","url":"aws_api/dynamodb.html#put_item"},{"doc":"aws_api/dynamodb","title":"put_resource_policy","content":"pub fn put_resource_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.put_resource_policy\naws_api/dynamodb put_resource_policy","url":"aws_api/dynamodb.html#put_resource_policy"},{"doc":"aws_api/dynamodb","title":"query","content":"pub fn query(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.query\naws_api/dynamodb query","url":"aws_api/dynamodb.html#query"},{"doc":"aws_api/dynamodb","title":"restore_table_from_backup","content":"pub fn restore_table_from_backup(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.restore_table_from_backup\naws_api/dynamodb restore_table_from_backup","url":"aws_api/dynamodb.html#restore_table_from_backup"},{"doc":"aws_api/dynamodb","title":"restore_table_to_point_in_time","content":"pub fn restore_table_to_point_in_time(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.restore_table_to_point_in_time\naws_api/dynamodb restore_table_to_point_in_time","url":"aws_api/dynamodb.html#restore_table_to_point_in_time"},{"doc":"aws_api/dynamodb","title":"scan","content":"pub fn scan(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.scan\naws_api/dynamodb scan","url":"aws_api/dynamodb.html#scan"},{"doc":"aws_api/dynamodb","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.tag_resource\naws_api/dynamodb tag_resource","url":"aws_api/dynamodb.html#tag_resource"},{"doc":"aws_api/dynamodb","title":"transact_get_items","content":"pub fn transact_get_items(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.transact_get_items\naws_api/dynamodb transact_get_items","url":"aws_api/dynamodb.html#transact_get_items"},{"doc":"aws_api/dynamodb","title":"transact_write_items","content":"pub fn transact_write_items(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.transact_write_items\naws_api/dynamodb transact_write_items","url":"aws_api/dynamodb.html#transact_write_items"},{"doc":"aws_api/dynamodb","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.untag_resource\naws_api/dynamodb untag_resource","url":"aws_api/dynamodb.html#untag_resource"},{"doc":"aws_api/dynamodb","title":"update_continuous_backups","content":"pub fn update_continuous_backups(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.update_continuous_backups\naws_api/dynamodb update_continuous_backups","url":"aws_api/dynamodb.html#update_continuous_backups"},{"doc":"aws_api/dynamodb","title":"update_contributor_insights","content":"pub fn update_contributor_insights(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.update_contributor_insights\naws_api/dynamodb update_contributor_insights","url":"aws_api/dynamodb.html#update_contributor_insights"},{"doc":"aws_api/dynamodb","title":"update_global_table","content":"pub fn update_global_table(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.update_global_table\naws_api/dynamodb update_global_table","url":"aws_api/dynamodb.html#update_global_table"},{"doc":"aws_api/dynamodb","title":"update_global_table_settings","content":"pub fn update_global_table_settings(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.update_global_table_settings\naws_api/dynamodb update_global_table_settings","url":"aws_api/dynamodb.html#update_global_table_settings"},{"doc":"aws_api/dynamodb","title":"update_item","content":"pub fn update_item(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.update_item\naws_api/dynamodb update_item","url":"aws_api/dynamodb.html#update_item"},{"doc":"aws_api/dynamodb","title":"update_kinesis_streaming_destination","content":"pub fn update_kinesis_streaming_destination(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.update_kinesis_streaming_destination\naws_api/dynamodb update_kinesis_streaming_destination","url":"aws_api/dynamodb.html#update_kinesis_streaming_destination"},{"doc":"aws_api/dynamodb","title":"update_table","content":"pub fn update_table(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.update_table\naws_api/dynamodb update_table","url":"aws_api/dynamodb.html#update_table"},{"doc":"aws_api/dynamodb","title":"update_table_replica_auto_scaling","content":"pub fn update_table_replica_auto_scaling(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.update_table_replica_auto_scaling\naws_api/dynamodb update_table_replica_auto_scaling","url":"aws_api/dynamodb.html#update_table_replica_auto_scaling"},{"doc":"aws_api/dynamodb","title":"update_time_to_live","content":"pub fn update_time_to_live(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb.update_time_to_live\naws_api/dynamodb update_time_to_live","url":"aws_api/dynamodb.html#update_time_to_live"},{"doc":"aws_api/dynamodb","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/dynamodb.with_custom_endpoint\naws_api/dynamodb with_custom_endpoint","url":"aws_api/dynamodb.html#with_custom_endpoint"},{"doc":"aws_api/dynamodb","title":"aws_api/dynamodb","content":"","url":"aws_api/dynamodb.html"},{"doc":"aws_api/dynamodb_streams","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/dynamodb_streams.Client\naws_api/dynamodb_streams Client","url":"aws_api/dynamodb_streams.html#Client"},{"doc":"aws_api/dynamodb_streams","title":"describe_stream","content":"pub fn describe_stream(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb_streams.describe_stream\naws_api/dynamodb_streams describe_stream","url":"aws_api/dynamodb_streams.html#describe_stream"},{"doc":"aws_api/dynamodb_streams","title":"get_records","content":"pub fn get_records(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb_streams.get_records\naws_api/dynamodb_streams get_records","url":"aws_api/dynamodb_streams.html#get_records"},{"doc":"aws_api/dynamodb_streams","title":"get_shard_iterator","content":"pub fn get_shard_iterator(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb_streams.get_shard_iterator\naws_api/dynamodb_streams get_shard_iterator","url":"aws_api/dynamodb_streams.html#get_shard_iterator"},{"doc":"aws_api/dynamodb_streams","title":"list_streams","content":"pub fn list_streams(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/dynamodb_streams.list_streams\naws_api/dynamodb_streams list_streams","url":"aws_api/dynamodb_streams.html#list_streams"},{"doc":"aws_api/dynamodb_streams","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/dynamodb_streams.new\naws_api/dynamodb_streams new","url":"aws_api/dynamodb_streams.html#new"},{"doc":"aws_api/dynamodb_streams","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/dynamodb_streams.with_custom_endpoint\naws_api/dynamodb_streams with_custom_endpoint","url":"aws_api/dynamodb_streams.html#with_custom_endpoint"},{"doc":"aws_api/dynamodb_streams","title":"aws_api/dynamodb_streams","content":"","url":"aws_api/dynamodb_streams.html"},{"doc":"aws_api/ebs","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/ebs.Client\naws_api/ebs Client","url":"aws_api/ebs.html#Client"},{"doc":"aws_api/ebs","title":"complete_snapshot","content":"pub fn complete_snapshot(\n  client: Client,\n  snapshot_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ebs.complete_snapshot\naws_api/ebs complete_snapshot","url":"aws_api/ebs.html#complete_snapshot"},{"doc":"aws_api/ebs","title":"get_snapshot_block","content":"pub fn get_snapshot_block(\n  client: Client,\n  snapshot_id: String,\n  block_index: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ebs.get_snapshot_block\naws_api/ebs get_snapshot_block","url":"aws_api/ebs.html#get_snapshot_block"},{"doc":"aws_api/ebs","title":"list_changed_blocks","content":"pub fn list_changed_blocks(\n  client: Client,\n  second_snapshot_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ebs.list_changed_blocks\naws_api/ebs list_changed_blocks","url":"aws_api/ebs.html#list_changed_blocks"},{"doc":"aws_api/ebs","title":"list_snapshot_blocks","content":"pub fn list_snapshot_blocks(\n  client: Client,\n  snapshot_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ebs.list_snapshot_blocks\naws_api/ebs list_snapshot_blocks","url":"aws_api/ebs.html#list_snapshot_blocks"},{"doc":"aws_api/ebs","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/ebs.new\naws_api/ebs new","url":"aws_api/ebs.html#new"},{"doc":"aws_api/ebs","title":"put_snapshot_block","content":"pub fn put_snapshot_block(\n  client: Client,\n  snapshot_id: String,\n  block_index: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ebs.put_snapshot_block\naws_api/ebs put_snapshot_block","url":"aws_api/ebs.html#put_snapshot_block"},{"doc":"aws_api/ebs","title":"start_snapshot","content":"pub fn start_snapshot(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ebs.start_snapshot\naws_api/ebs start_snapshot","url":"aws_api/ebs.html#start_snapshot"},{"doc":"aws_api/ebs","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/ebs.with_custom_endpoint\naws_api/ebs with_custom_endpoint","url":"aws_api/ebs.html#with_custom_endpoint"},{"doc":"aws_api/ebs","title":"aws_api/ebs","content":"","url":"aws_api/ebs.html"},{"doc":"aws_api/ec2","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/ec2.Client\naws_api/ec2 Client","url":"aws_api/ec2.html#Client"},{"doc":"aws_api/ec2","title":"accept_address_transfer","content":"pub fn accept_address_transfer(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.accept_address_transfer\naws_api/ec2 accept_address_transfer","url":"aws_api/ec2.html#accept_address_transfer"},{"doc":"aws_api/ec2","title":"accept_reserved_instances_exchange_quote","content":"pub fn accept_reserved_instances_exchange_quote(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.accept_reserved_instances_exchange_quote\naws_api/ec2 accept_reserved_instances_exchange_quote","url":"aws_api/ec2.html#accept_reserved_instances_exchange_quote"},{"doc":"aws_api/ec2","title":"accept_transit_gateway_multicast_domain_associations","content":"pub fn accept_transit_gateway_multicast_domain_associations(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.accept_transit_gateway_multicast_domain_associations\naws_api/ec2 accept_transit_gateway_multicast_domain_associations","url":"aws_api/ec2.html#accept_transit_gateway_multicast_domain_associations"},{"doc":"aws_api/ec2","title":"accept_transit_gateway_peering_attachment","content":"pub fn accept_transit_gateway_peering_attachment(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.accept_transit_gateway_peering_attachment\naws_api/ec2 accept_transit_gateway_peering_attachment","url":"aws_api/ec2.html#accept_transit_gateway_peering_attachment"},{"doc":"aws_api/ec2","title":"accept_transit_gateway_vpc_attachment","content":"pub fn accept_transit_gateway_vpc_attachment(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.accept_transit_gateway_vpc_attachment\naws_api/ec2 accept_transit_gateway_vpc_attachment","url":"aws_api/ec2.html#accept_transit_gateway_vpc_attachment"},{"doc":"aws_api/ec2","title":"accept_vpc_endpoint_connections","content":"pub fn accept_vpc_endpoint_connections(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.accept_vpc_endpoint_connections\naws_api/ec2 accept_vpc_endpoint_connections","url":"aws_api/ec2.html#accept_vpc_endpoint_connections"},{"doc":"aws_api/ec2","title":"accept_vpc_peering_connection","content":"pub fn accept_vpc_peering_connection(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.accept_vpc_peering_connection\naws_api/ec2 accept_vpc_peering_connection","url":"aws_api/ec2.html#accept_vpc_peering_connection"},{"doc":"aws_api/ec2","title":"advertise_byoip_cidr","content":"pub fn advertise_byoip_cidr(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.advertise_byoip_cidr\naws_api/ec2 advertise_byoip_cidr","url":"aws_api/ec2.html#advertise_byoip_cidr"},{"doc":"aws_api/ec2","title":"allocate_address","content":"pub fn allocate_address(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.allocate_address\naws_api/ec2 allocate_address","url":"aws_api/ec2.html#allocate_address"},{"doc":"aws_api/ec2","title":"allocate_hosts","content":"pub fn allocate_hosts(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.allocate_hosts\naws_api/ec2 allocate_hosts","url":"aws_api/ec2.html#allocate_hosts"},{"doc":"aws_api/ec2","title":"allocate_ipam_pool_cidr","content":"pub fn allocate_ipam_pool_cidr(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.allocate_ipam_pool_cidr\naws_api/ec2 allocate_ipam_pool_cidr","url":"aws_api/ec2.html#allocate_ipam_pool_cidr"},{"doc":"aws_api/ec2","title":"apply_security_groups_to_client_vpn_target_network","content":"pub fn apply_security_groups_to_client_vpn_target_network(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.apply_security_groups_to_client_vpn_target_network\naws_api/ec2 apply_security_groups_to_client_vpn_target_network","url":"aws_api/ec2.html#apply_security_groups_to_client_vpn_target_network"},{"doc":"aws_api/ec2","title":"assign_ipv6_addresses","content":"pub fn assign_ipv6_addresses(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.assign_ipv6_addresses\naws_api/ec2 assign_ipv6_addresses","url":"aws_api/ec2.html#assign_ipv6_addresses"},{"doc":"aws_api/ec2","title":"assign_private_ip_addresses","content":"pub fn assign_private_ip_addresses(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.assign_private_ip_addresses\naws_api/ec2 assign_private_ip_addresses","url":"aws_api/ec2.html#assign_private_ip_addresses"},{"doc":"aws_api/ec2","title":"assign_private_nat_gateway_address","content":"pub fn assign_private_nat_gateway_address(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.assign_private_nat_gateway_address\naws_api/ec2 assign_private_nat_gateway_address","url":"aws_api/ec2.html#assign_private_nat_gateway_address"},{"doc":"aws_api/ec2","title":"associate_address","content":"pub fn associate_address(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.associate_address\naws_api/ec2 associate_address","url":"aws_api/ec2.html#associate_address"},{"doc":"aws_api/ec2","title":"associate_client_vpn_target_network","content":"pub fn associate_client_vpn_target_network(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.associate_client_vpn_target_network\naws_api/ec2 associate_client_vpn_target_network","url":"aws_api/ec2.html#associate_client_vpn_target_network"},{"doc":"aws_api/ec2","title":"associate_dhcp_options","content":"pub fn associate_dhcp_options(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.associate_dhcp_options\naws_api/ec2 associate_dhcp_options","url":"aws_api/ec2.html#associate_dhcp_options"},{"doc":"aws_api/ec2","title":"associate_enclave_certificate_iam_role","content":"pub fn associate_enclave_certificate_iam_role(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.associate_enclave_certificate_iam_role\naws_api/ec2 associate_enclave_certificate_iam_role","url":"aws_api/ec2.html#associate_enclave_certificate_iam_role"},{"doc":"aws_api/ec2","title":"associate_iam_instance_profile","content":"pub fn associate_iam_instance_profile(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.associate_iam_instance_profile\naws_api/ec2 associate_iam_instance_profile","url":"aws_api/ec2.html#associate_iam_instance_profile"},{"doc":"aws_api/ec2","title":"associate_instance_event_window","content":"pub fn associate_instance_event_window(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.associate_instance_event_window\naws_api/ec2 associate_instance_event_window","url":"aws_api/ec2.html#associate_instance_event_window"},{"doc":"aws_api/ec2","title":"associate_ipam_byoasn","content":"pub fn associate_ipam_byoasn(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.associate_ipam_byoasn\naws_api/ec2 associate_ipam_byoasn","url":"aws_api/ec2.html#associate_ipam_byoasn"},{"doc":"aws_api/ec2","title":"associate_ipam_resource_discovery","content":"pub fn associate_ipam_resource_discovery(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.associate_ipam_resource_discovery\naws_api/ec2 associate_ipam_resource_discovery","url":"aws_api/ec2.html#associate_ipam_resource_discovery"},{"doc":"aws_api/ec2","title":"associate_nat_gateway_address","content":"pub fn associate_nat_gateway_address(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.associate_nat_gateway_address\naws_api/ec2 associate_nat_gateway_address","url":"aws_api/ec2.html#associate_nat_gateway_address"},{"doc":"aws_api/ec2","title":"associate_route_table","content":"pub fn associate_route_table(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.associate_route_table\naws_api/ec2 associate_route_table","url":"aws_api/ec2.html#associate_route_table"},{"doc":"aws_api/ec2","title":"associate_subnet_cidr_block","content":"pub fn associate_subnet_cidr_block(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.associate_subnet_cidr_block\naws_api/ec2 associate_subnet_cidr_block","url":"aws_api/ec2.html#associate_subnet_cidr_block"},{"doc":"aws_api/ec2","title":"associate_transit_gateway_multicast_domain","content":"pub fn associate_transit_gateway_multicast_domain(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.associate_transit_gateway_multicast_domain\naws_api/ec2 associate_transit_gateway_multicast_domain","url":"aws_api/ec2.html#associate_transit_gateway_multicast_domain"},{"doc":"aws_api/ec2","title":"associate_transit_gateway_policy_table","content":"pub fn associate_transit_gateway_policy_table(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.associate_transit_gateway_policy_table\naws_api/ec2 associate_transit_gateway_policy_table","url":"aws_api/ec2.html#associate_transit_gateway_policy_table"},{"doc":"aws_api/ec2","title":"associate_transit_gateway_route_table","content":"pub fn associate_transit_gateway_route_table(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.associate_transit_gateway_route_table\naws_api/ec2 associate_transit_gateway_route_table","url":"aws_api/ec2.html#associate_transit_gateway_route_table"},{"doc":"aws_api/ec2","title":"associate_trunk_interface","content":"pub fn associate_trunk_interface(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.associate_trunk_interface\naws_api/ec2 associate_trunk_interface","url":"aws_api/ec2.html#associate_trunk_interface"},{"doc":"aws_api/ec2","title":"associate_vpc_cidr_block","content":"pub fn associate_vpc_cidr_block(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.associate_vpc_cidr_block\naws_api/ec2 associate_vpc_cidr_block","url":"aws_api/ec2.html#associate_vpc_cidr_block"},{"doc":"aws_api/ec2","title":"attach_classic_link_vpc","content":"pub fn attach_classic_link_vpc(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.attach_classic_link_vpc\naws_api/ec2 attach_classic_link_vpc","url":"aws_api/ec2.html#attach_classic_link_vpc"},{"doc":"aws_api/ec2","title":"attach_internet_gateway","content":"pub fn attach_internet_gateway(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.attach_internet_gateway\naws_api/ec2 attach_internet_gateway","url":"aws_api/ec2.html#attach_internet_gateway"},{"doc":"aws_api/ec2","title":"attach_network_interface","content":"pub fn attach_network_interface(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.attach_network_interface\naws_api/ec2 attach_network_interface","url":"aws_api/ec2.html#attach_network_interface"},{"doc":"aws_api/ec2","title":"attach_verified_access_trust_provider","content":"pub fn attach_verified_access_trust_provider(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.attach_verified_access_trust_provider\naws_api/ec2 attach_verified_access_trust_provider","url":"aws_api/ec2.html#attach_verified_access_trust_provider"},{"doc":"aws_api/ec2","title":"attach_volume","content":"pub fn attach_volume(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.attach_volume\naws_api/ec2 attach_volume","url":"aws_api/ec2.html#attach_volume"},{"doc":"aws_api/ec2","title":"attach_vpn_gateway","content":"pub fn attach_vpn_gateway(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.attach_vpn_gateway\naws_api/ec2 attach_vpn_gateway","url":"aws_api/ec2.html#attach_vpn_gateway"},{"doc":"aws_api/ec2","title":"authorize_client_vpn_ingress","content":"pub fn authorize_client_vpn_ingress(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.authorize_client_vpn_ingress\naws_api/ec2 authorize_client_vpn_ingress","url":"aws_api/ec2.html#authorize_client_vpn_ingress"},{"doc":"aws_api/ec2","title":"authorize_security_group_egress","content":"pub fn authorize_security_group_egress(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.authorize_security_group_egress\naws_api/ec2 authorize_security_group_egress","url":"aws_api/ec2.html#authorize_security_group_egress"},{"doc":"aws_api/ec2","title":"authorize_security_group_ingress","content":"pub fn authorize_security_group_ingress(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.authorize_security_group_ingress\naws_api/ec2 authorize_security_group_ingress","url":"aws_api/ec2.html#authorize_security_group_ingress"},{"doc":"aws_api/ec2","title":"bundle_instance","content":"pub fn bundle_instance(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.bundle_instance\naws_api/ec2 bundle_instance","url":"aws_api/ec2.html#bundle_instance"},{"doc":"aws_api/ec2","title":"cancel_bundle_task","content":"pub fn cancel_bundle_task(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.cancel_bundle_task\naws_api/ec2 cancel_bundle_task","url":"aws_api/ec2.html#cancel_bundle_task"},{"doc":"aws_api/ec2","title":"cancel_capacity_reservation","content":"pub fn cancel_capacity_reservation(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.cancel_capacity_reservation\naws_api/ec2 cancel_capacity_reservation","url":"aws_api/ec2.html#cancel_capacity_reservation"},{"doc":"aws_api/ec2","title":"cancel_capacity_reservation_fleets","content":"pub fn cancel_capacity_reservation_fleets(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.cancel_capacity_reservation_fleets\naws_api/ec2 cancel_capacity_reservation_fleets","url":"aws_api/ec2.html#cancel_capacity_reservation_fleets"},{"doc":"aws_api/ec2","title":"cancel_conversion_task","content":"pub fn cancel_conversion_task(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.cancel_conversion_task\naws_api/ec2 cancel_conversion_task","url":"aws_api/ec2.html#cancel_conversion_task"},{"doc":"aws_api/ec2","title":"cancel_export_task","content":"pub fn cancel_export_task(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.cancel_export_task\naws_api/ec2 cancel_export_task","url":"aws_api/ec2.html#cancel_export_task"},{"doc":"aws_api/ec2","title":"cancel_image_launch_permission","content":"pub fn cancel_image_launch_permission(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.cancel_image_launch_permission\naws_api/ec2 cancel_image_launch_permission","url":"aws_api/ec2.html#cancel_image_launch_permission"},{"doc":"aws_api/ec2","title":"cancel_import_task","content":"pub fn cancel_import_task(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.cancel_import_task\naws_api/ec2 cancel_import_task","url":"aws_api/ec2.html#cancel_import_task"},{"doc":"aws_api/ec2","title":"cancel_reserved_instances_listing","content":"pub fn cancel_reserved_instances_listing(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.cancel_reserved_instances_listing\naws_api/ec2 cancel_reserved_instances_listing","url":"aws_api/ec2.html#cancel_reserved_instances_listing"},{"doc":"aws_api/ec2","title":"cancel_spot_fleet_requests","content":"pub fn cancel_spot_fleet_requests(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.cancel_spot_fleet_requests\naws_api/ec2 cancel_spot_fleet_requests","url":"aws_api/ec2.html#cancel_spot_fleet_requests"},{"doc":"aws_api/ec2","title":"cancel_spot_instance_requests","content":"pub fn cancel_spot_instance_requests(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.cancel_spot_instance_requests\naws_api/ec2 cancel_spot_instance_requests","url":"aws_api/ec2.html#cancel_spot_instance_requests"},{"doc":"aws_api/ec2","title":"confirm_product_instance","content":"pub fn confirm_product_instance(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.confirm_product_instance\naws_api/ec2 confirm_product_instance","url":"aws_api/ec2.html#confirm_product_instance"},{"doc":"aws_api/ec2","title":"copy_fpga_image","content":"pub fn copy_fpga_image(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.copy_fpga_image\naws_api/ec2 copy_fpga_image","url":"aws_api/ec2.html#copy_fpga_image"},{"doc":"aws_api/ec2","title":"copy_image","content":"pub fn copy_image(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.copy_image\naws_api/ec2 copy_image","url":"aws_api/ec2.html#copy_image"},{"doc":"aws_api/ec2","title":"copy_snapshot","content":"pub fn copy_snapshot(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.copy_snapshot\naws_api/ec2 copy_snapshot","url":"aws_api/ec2.html#copy_snapshot"},{"doc":"aws_api/ec2","title":"create_capacity_reservation","content":"pub fn create_capacity_reservation(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_capacity_reservation\naws_api/ec2 create_capacity_reservation","url":"aws_api/ec2.html#create_capacity_reservation"},{"doc":"aws_api/ec2","title":"create_capacity_reservation_fleet","content":"pub fn create_capacity_reservation_fleet(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_capacity_reservation_fleet\naws_api/ec2 create_capacity_reservation_fleet","url":"aws_api/ec2.html#create_capacity_reservation_fleet"},{"doc":"aws_api/ec2","title":"create_carrier_gateway","content":"pub fn create_carrier_gateway(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_carrier_gateway\naws_api/ec2 create_carrier_gateway","url":"aws_api/ec2.html#create_carrier_gateway"},{"doc":"aws_api/ec2","title":"create_client_vpn_endpoint","content":"pub fn create_client_vpn_endpoint(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_client_vpn_endpoint\naws_api/ec2 create_client_vpn_endpoint","url":"aws_api/ec2.html#create_client_vpn_endpoint"},{"doc":"aws_api/ec2","title":"create_client_vpn_route","content":"pub fn create_client_vpn_route(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_client_vpn_route\naws_api/ec2 create_client_vpn_route","url":"aws_api/ec2.html#create_client_vpn_route"},{"doc":"aws_api/ec2","title":"create_coip_cidr","content":"pub fn create_coip_cidr(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_coip_cidr\naws_api/ec2 create_coip_cidr","url":"aws_api/ec2.html#create_coip_cidr"},{"doc":"aws_api/ec2","title":"create_coip_pool","content":"pub fn create_coip_pool(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_coip_pool\naws_api/ec2 create_coip_pool","url":"aws_api/ec2.html#create_coip_pool"},{"doc":"aws_api/ec2","title":"create_customer_gateway","content":"pub fn create_customer_gateway(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_customer_gateway\naws_api/ec2 create_customer_gateway","url":"aws_api/ec2.html#create_customer_gateway"},{"doc":"aws_api/ec2","title":"create_default_subnet","content":"pub fn create_default_subnet(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_default_subnet\naws_api/ec2 create_default_subnet","url":"aws_api/ec2.html#create_default_subnet"},{"doc":"aws_api/ec2","title":"create_default_vpc","content":"pub fn create_default_vpc(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_default_vpc\naws_api/ec2 create_default_vpc","url":"aws_api/ec2.html#create_default_vpc"},{"doc":"aws_api/ec2","title":"create_dhcp_options","content":"pub fn create_dhcp_options(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_dhcp_options\naws_api/ec2 create_dhcp_options","url":"aws_api/ec2.html#create_dhcp_options"},{"doc":"aws_api/ec2","title":"create_egress_only_internet_gateway","content":"pub fn create_egress_only_internet_gateway(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_egress_only_internet_gateway\naws_api/ec2 create_egress_only_internet_gateway","url":"aws_api/ec2.html#create_egress_only_internet_gateway"},{"doc":"aws_api/ec2","title":"create_fleet","content":"pub fn create_fleet(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_fleet\naws_api/ec2 create_fleet","url":"aws_api/ec2.html#create_fleet"},{"doc":"aws_api/ec2","title":"create_flow_logs","content":"pub fn create_flow_logs(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_flow_logs\naws_api/ec2 create_flow_logs","url":"aws_api/ec2.html#create_flow_logs"},{"doc":"aws_api/ec2","title":"create_fpga_image","content":"pub fn create_fpga_image(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_fpga_image\naws_api/ec2 create_fpga_image","url":"aws_api/ec2.html#create_fpga_image"},{"doc":"aws_api/ec2","title":"create_image","content":"pub fn create_image(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_image\naws_api/ec2 create_image","url":"aws_api/ec2.html#create_image"},{"doc":"aws_api/ec2","title":"create_instance_connect_endpoint","content":"pub fn create_instance_connect_endpoint(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_instance_connect_endpoint\naws_api/ec2 create_instance_connect_endpoint","url":"aws_api/ec2.html#create_instance_connect_endpoint"},{"doc":"aws_api/ec2","title":"create_instance_event_window","content":"pub fn create_instance_event_window(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_instance_event_window\naws_api/ec2 create_instance_event_window","url":"aws_api/ec2.html#create_instance_event_window"},{"doc":"aws_api/ec2","title":"create_instance_export_task","content":"pub fn create_instance_export_task(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_instance_export_task\naws_api/ec2 create_instance_export_task","url":"aws_api/ec2.html#create_instance_export_task"},{"doc":"aws_api/ec2","title":"create_internet_gateway","content":"pub fn create_internet_gateway(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_internet_gateway\naws_api/ec2 create_internet_gateway","url":"aws_api/ec2.html#create_internet_gateway"},{"doc":"aws_api/ec2","title":"create_ipam","content":"pub fn create_ipam(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_ipam\naws_api/ec2 create_ipam","url":"aws_api/ec2.html#create_ipam"},{"doc":"aws_api/ec2","title":"create_ipam_external_resource_verification_token","content":"pub fn create_ipam_external_resource_verification_token(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_ipam_external_resource_verification_token\naws_api/ec2 create_ipam_external_resource_verification_token","url":"aws_api/ec2.html#create_ipam_external_resource_verification_token"},{"doc":"aws_api/ec2","title":"create_ipam_pool","content":"pub fn create_ipam_pool(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_ipam_pool\naws_api/ec2 create_ipam_pool","url":"aws_api/ec2.html#create_ipam_pool"},{"doc":"aws_api/ec2","title":"create_ipam_resource_discovery","content":"pub fn create_ipam_resource_discovery(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_ipam_resource_discovery\naws_api/ec2 create_ipam_resource_discovery","url":"aws_api/ec2.html#create_ipam_resource_discovery"},{"doc":"aws_api/ec2","title":"create_ipam_scope","content":"pub fn create_ipam_scope(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_ipam_scope\naws_api/ec2 create_ipam_scope","url":"aws_api/ec2.html#create_ipam_scope"},{"doc":"aws_api/ec2","title":"create_key_pair","content":"pub fn create_key_pair(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_key_pair\naws_api/ec2 create_key_pair","url":"aws_api/ec2.html#create_key_pair"},{"doc":"aws_api/ec2","title":"create_launch_template","content":"pub fn create_launch_template(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_launch_template\naws_api/ec2 create_launch_template","url":"aws_api/ec2.html#create_launch_template"},{"doc":"aws_api/ec2","title":"create_launch_template_version","content":"pub fn create_launch_template_version(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_launch_template_version\naws_api/ec2 create_launch_template_version","url":"aws_api/ec2.html#create_launch_template_version"},{"doc":"aws_api/ec2","title":"create_local_gateway_route","content":"pub fn create_local_gateway_route(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_local_gateway_route\naws_api/ec2 create_local_gateway_route","url":"aws_api/ec2.html#create_local_gateway_route"},{"doc":"aws_api/ec2","title":"create_local_gateway_route_table","content":"pub fn create_local_gateway_route_table(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_local_gateway_route_table\naws_api/ec2 create_local_gateway_route_table","url":"aws_api/ec2.html#create_local_gateway_route_table"},{"doc":"aws_api/ec2","title":"create_local_gateway_route_table_virtual_interface_group_association","content":"pub fn create_local_gateway_route_table_virtual_interface_group_association(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_local_gateway_route_table_virtual_interface_group_association\naws_api/ec2 create_local_gateway_route_table_virtual_interface_group_association","url":"aws_api/ec2.html#create_local_gateway_route_table_virtual_interface_group_association"},{"doc":"aws_api/ec2","title":"create_local_gateway_route_table_vpc_association","content":"pub fn create_local_gateway_route_table_vpc_association(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_local_gateway_route_table_vpc_association\naws_api/ec2 create_local_gateway_route_table_vpc_association","url":"aws_api/ec2.html#create_local_gateway_route_table_vpc_association"},{"doc":"aws_api/ec2","title":"create_managed_prefix_list","content":"pub fn create_managed_prefix_list(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_managed_prefix_list\naws_api/ec2 create_managed_prefix_list","url":"aws_api/ec2.html#create_managed_prefix_list"},{"doc":"aws_api/ec2","title":"create_nat_gateway","content":"pub fn create_nat_gateway(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_nat_gateway\naws_api/ec2 create_nat_gateway","url":"aws_api/ec2.html#create_nat_gateway"},{"doc":"aws_api/ec2","title":"create_network_acl","content":"pub fn create_network_acl(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_network_acl\naws_api/ec2 create_network_acl","url":"aws_api/ec2.html#create_network_acl"},{"doc":"aws_api/ec2","title":"create_network_acl_entry","content":"pub fn create_network_acl_entry(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_network_acl_entry\naws_api/ec2 create_network_acl_entry","url":"aws_api/ec2.html#create_network_acl_entry"},{"doc":"aws_api/ec2","title":"create_network_insights_access_scope","content":"pub fn create_network_insights_access_scope(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_network_insights_access_scope\naws_api/ec2 create_network_insights_access_scope","url":"aws_api/ec2.html#create_network_insights_access_scope"},{"doc":"aws_api/ec2","title":"create_network_insights_path","content":"pub fn create_network_insights_path(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_network_insights_path\naws_api/ec2 create_network_insights_path","url":"aws_api/ec2.html#create_network_insights_path"},{"doc":"aws_api/ec2","title":"create_network_interface","content":"pub fn create_network_interface(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_network_interface\naws_api/ec2 create_network_interface","url":"aws_api/ec2.html#create_network_interface"},{"doc":"aws_api/ec2","title":"create_network_interface_permission","content":"pub fn create_network_interface_permission(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_network_interface_permission\naws_api/ec2 create_network_interface_permission","url":"aws_api/ec2.html#create_network_interface_permission"},{"doc":"aws_api/ec2","title":"create_placement_group","content":"pub fn create_placement_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_placement_group\naws_api/ec2 create_placement_group","url":"aws_api/ec2.html#create_placement_group"},{"doc":"aws_api/ec2","title":"create_public_ipv4_pool","content":"pub fn create_public_ipv4_pool(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_public_ipv4_pool\naws_api/ec2 create_public_ipv4_pool","url":"aws_api/ec2.html#create_public_ipv4_pool"},{"doc":"aws_api/ec2","title":"create_replace_root_volume_task","content":"pub fn create_replace_root_volume_task(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_replace_root_volume_task\naws_api/ec2 create_replace_root_volume_task","url":"aws_api/ec2.html#create_replace_root_volume_task"},{"doc":"aws_api/ec2","title":"create_reserved_instances_listing","content":"pub fn create_reserved_instances_listing(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_reserved_instances_listing\naws_api/ec2 create_reserved_instances_listing","url":"aws_api/ec2.html#create_reserved_instances_listing"},{"doc":"aws_api/ec2","title":"create_restore_image_task","content":"pub fn create_restore_image_task(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_restore_image_task\naws_api/ec2 create_restore_image_task","url":"aws_api/ec2.html#create_restore_image_task"},{"doc":"aws_api/ec2","title":"create_route","content":"pub fn create_route(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_route\naws_api/ec2 create_route","url":"aws_api/ec2.html#create_route"},{"doc":"aws_api/ec2","title":"create_route_table","content":"pub fn create_route_table(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_route_table\naws_api/ec2 create_route_table","url":"aws_api/ec2.html#create_route_table"},{"doc":"aws_api/ec2","title":"create_security_group","content":"pub fn create_security_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_security_group\naws_api/ec2 create_security_group","url":"aws_api/ec2.html#create_security_group"},{"doc":"aws_api/ec2","title":"create_snapshot","content":"pub fn create_snapshot(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_snapshot\naws_api/ec2 create_snapshot","url":"aws_api/ec2.html#create_snapshot"},{"doc":"aws_api/ec2","title":"create_snapshots","content":"pub fn create_snapshots(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_snapshots\naws_api/ec2 create_snapshots","url":"aws_api/ec2.html#create_snapshots"},{"doc":"aws_api/ec2","title":"create_spot_datafeed_subscription","content":"pub fn create_spot_datafeed_subscription(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_spot_datafeed_subscription\naws_api/ec2 create_spot_datafeed_subscription","url":"aws_api/ec2.html#create_spot_datafeed_subscription"},{"doc":"aws_api/ec2","title":"create_store_image_task","content":"pub fn create_store_image_task(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_store_image_task\naws_api/ec2 create_store_image_task","url":"aws_api/ec2.html#create_store_image_task"},{"doc":"aws_api/ec2","title":"create_subnet","content":"pub fn create_subnet(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_subnet\naws_api/ec2 create_subnet","url":"aws_api/ec2.html#create_subnet"},{"doc":"aws_api/ec2","title":"create_subnet_cidr_reservation","content":"pub fn create_subnet_cidr_reservation(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_subnet_cidr_reservation\naws_api/ec2 create_subnet_cidr_reservation","url":"aws_api/ec2.html#create_subnet_cidr_reservation"},{"doc":"aws_api/ec2","title":"create_tags","content":"pub fn create_tags(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_tags\naws_api/ec2 create_tags","url":"aws_api/ec2.html#create_tags"},{"doc":"aws_api/ec2","title":"create_traffic_mirror_filter","content":"pub fn create_traffic_mirror_filter(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_traffic_mirror_filter\naws_api/ec2 create_traffic_mirror_filter","url":"aws_api/ec2.html#create_traffic_mirror_filter"},{"doc":"aws_api/ec2","title":"create_traffic_mirror_filter_rule","content":"pub fn create_traffic_mirror_filter_rule(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_traffic_mirror_filter_rule\naws_api/ec2 create_traffic_mirror_filter_rule","url":"aws_api/ec2.html#create_traffic_mirror_filter_rule"},{"doc":"aws_api/ec2","title":"create_traffic_mirror_session","content":"pub fn create_traffic_mirror_session(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_traffic_mirror_session\naws_api/ec2 create_traffic_mirror_session","url":"aws_api/ec2.html#create_traffic_mirror_session"},{"doc":"aws_api/ec2","title":"create_traffic_mirror_target","content":"pub fn create_traffic_mirror_target(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_traffic_mirror_target\naws_api/ec2 create_traffic_mirror_target","url":"aws_api/ec2.html#create_traffic_mirror_target"},{"doc":"aws_api/ec2","title":"create_transit_gateway","content":"pub fn create_transit_gateway(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_transit_gateway\naws_api/ec2 create_transit_gateway","url":"aws_api/ec2.html#create_transit_gateway"},{"doc":"aws_api/ec2","title":"create_transit_gateway_connect","content":"pub fn create_transit_gateway_connect(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_transit_gateway_connect\naws_api/ec2 create_transit_gateway_connect","url":"aws_api/ec2.html#create_transit_gateway_connect"},{"doc":"aws_api/ec2","title":"create_transit_gateway_connect_peer","content":"pub fn create_transit_gateway_connect_peer(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_transit_gateway_connect_peer\naws_api/ec2 create_transit_gateway_connect_peer","url":"aws_api/ec2.html#create_transit_gateway_connect_peer"},{"doc":"aws_api/ec2","title":"create_transit_gateway_multicast_domain","content":"pub fn create_transit_gateway_multicast_domain(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_transit_gateway_multicast_domain\naws_api/ec2 create_transit_gateway_multicast_domain","url":"aws_api/ec2.html#create_transit_gateway_multicast_domain"},{"doc":"aws_api/ec2","title":"create_transit_gateway_peering_attachment","content":"pub fn create_transit_gateway_peering_attachment(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_transit_gateway_peering_attachment\naws_api/ec2 create_transit_gateway_peering_attachment","url":"aws_api/ec2.html#create_transit_gateway_peering_attachment"},{"doc":"aws_api/ec2","title":"create_transit_gateway_policy_table","content":"pub fn create_transit_gateway_policy_table(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_transit_gateway_policy_table\naws_api/ec2 create_transit_gateway_policy_table","url":"aws_api/ec2.html#create_transit_gateway_policy_table"},{"doc":"aws_api/ec2","title":"create_transit_gateway_prefix_list_reference","content":"pub fn create_transit_gateway_prefix_list_reference(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_transit_gateway_prefix_list_reference\naws_api/ec2 create_transit_gateway_prefix_list_reference","url":"aws_api/ec2.html#create_transit_gateway_prefix_list_reference"},{"doc":"aws_api/ec2","title":"create_transit_gateway_route","content":"pub fn create_transit_gateway_route(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_transit_gateway_route\naws_api/ec2 create_transit_gateway_route","url":"aws_api/ec2.html#create_transit_gateway_route"},{"doc":"aws_api/ec2","title":"create_transit_gateway_route_table","content":"pub fn create_transit_gateway_route_table(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_transit_gateway_route_table\naws_api/ec2 create_transit_gateway_route_table","url":"aws_api/ec2.html#create_transit_gateway_route_table"},{"doc":"aws_api/ec2","title":"create_transit_gateway_route_table_announcement","content":"pub fn create_transit_gateway_route_table_announcement(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_transit_gateway_route_table_announcement\naws_api/ec2 create_transit_gateway_route_table_announcement","url":"aws_api/ec2.html#create_transit_gateway_route_table_announcement"},{"doc":"aws_api/ec2","title":"create_transit_gateway_vpc_attachment","content":"pub fn create_transit_gateway_vpc_attachment(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_transit_gateway_vpc_attachment\naws_api/ec2 create_transit_gateway_vpc_attachment","url":"aws_api/ec2.html#create_transit_gateway_vpc_attachment"},{"doc":"aws_api/ec2","title":"create_verified_access_endpoint","content":"pub fn create_verified_access_endpoint(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_verified_access_endpoint\naws_api/ec2 create_verified_access_endpoint","url":"aws_api/ec2.html#create_verified_access_endpoint"},{"doc":"aws_api/ec2","title":"create_verified_access_group","content":"pub fn create_verified_access_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_verified_access_group\naws_api/ec2 create_verified_access_group","url":"aws_api/ec2.html#create_verified_access_group"},{"doc":"aws_api/ec2","title":"create_verified_access_instance","content":"pub fn create_verified_access_instance(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_verified_access_instance\naws_api/ec2 create_verified_access_instance","url":"aws_api/ec2.html#create_verified_access_instance"},{"doc":"aws_api/ec2","title":"create_verified_access_trust_provider","content":"pub fn create_verified_access_trust_provider(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_verified_access_trust_provider\naws_api/ec2 create_verified_access_trust_provider","url":"aws_api/ec2.html#create_verified_access_trust_provider"},{"doc":"aws_api/ec2","title":"create_volume","content":"pub fn create_volume(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_volume\naws_api/ec2 create_volume","url":"aws_api/ec2.html#create_volume"},{"doc":"aws_api/ec2","title":"create_vpc","content":"pub fn create_vpc(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_vpc\naws_api/ec2 create_vpc","url":"aws_api/ec2.html#create_vpc"},{"doc":"aws_api/ec2","title":"create_vpc_endpoint","content":"pub fn create_vpc_endpoint(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_vpc_endpoint\naws_api/ec2 create_vpc_endpoint","url":"aws_api/ec2.html#create_vpc_endpoint"},{"doc":"aws_api/ec2","title":"create_vpc_endpoint_connection_notification","content":"pub fn create_vpc_endpoint_connection_notification(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_vpc_endpoint_connection_notification\naws_api/ec2 create_vpc_endpoint_connection_notification","url":"aws_api/ec2.html#create_vpc_endpoint_connection_notification"},{"doc":"aws_api/ec2","title":"create_vpc_endpoint_service_configuration","content":"pub fn create_vpc_endpoint_service_configuration(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_vpc_endpoint_service_configuration\naws_api/ec2 create_vpc_endpoint_service_configuration","url":"aws_api/ec2.html#create_vpc_endpoint_service_configuration"},{"doc":"aws_api/ec2","title":"create_vpc_peering_connection","content":"pub fn create_vpc_peering_connection(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_vpc_peering_connection\naws_api/ec2 create_vpc_peering_connection","url":"aws_api/ec2.html#create_vpc_peering_connection"},{"doc":"aws_api/ec2","title":"create_vpn_connection","content":"pub fn create_vpn_connection(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_vpn_connection\naws_api/ec2 create_vpn_connection","url":"aws_api/ec2.html#create_vpn_connection"},{"doc":"aws_api/ec2","title":"create_vpn_connection_route","content":"pub fn create_vpn_connection_route(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_vpn_connection_route\naws_api/ec2 create_vpn_connection_route","url":"aws_api/ec2.html#create_vpn_connection_route"},{"doc":"aws_api/ec2","title":"create_vpn_gateway","content":"pub fn create_vpn_gateway(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.create_vpn_gateway\naws_api/ec2 create_vpn_gateway","url":"aws_api/ec2.html#create_vpn_gateway"},{"doc":"aws_api/ec2","title":"delete_carrier_gateway","content":"pub fn delete_carrier_gateway(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_carrier_gateway\naws_api/ec2 delete_carrier_gateway","url":"aws_api/ec2.html#delete_carrier_gateway"},{"doc":"aws_api/ec2","title":"delete_client_vpn_endpoint","content":"pub fn delete_client_vpn_endpoint(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_client_vpn_endpoint\naws_api/ec2 delete_client_vpn_endpoint","url":"aws_api/ec2.html#delete_client_vpn_endpoint"},{"doc":"aws_api/ec2","title":"delete_client_vpn_route","content":"pub fn delete_client_vpn_route(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_client_vpn_route\naws_api/ec2 delete_client_vpn_route","url":"aws_api/ec2.html#delete_client_vpn_route"},{"doc":"aws_api/ec2","title":"delete_coip_cidr","content":"pub fn delete_coip_cidr(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_coip_cidr\naws_api/ec2 delete_coip_cidr","url":"aws_api/ec2.html#delete_coip_cidr"},{"doc":"aws_api/ec2","title":"delete_coip_pool","content":"pub fn delete_coip_pool(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_coip_pool\naws_api/ec2 delete_coip_pool","url":"aws_api/ec2.html#delete_coip_pool"},{"doc":"aws_api/ec2","title":"delete_customer_gateway","content":"pub fn delete_customer_gateway(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_customer_gateway\naws_api/ec2 delete_customer_gateway","url":"aws_api/ec2.html#delete_customer_gateway"},{"doc":"aws_api/ec2","title":"delete_dhcp_options","content":"pub fn delete_dhcp_options(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_dhcp_options\naws_api/ec2 delete_dhcp_options","url":"aws_api/ec2.html#delete_dhcp_options"},{"doc":"aws_api/ec2","title":"delete_egress_only_internet_gateway","content":"pub fn delete_egress_only_internet_gateway(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_egress_only_internet_gateway\naws_api/ec2 delete_egress_only_internet_gateway","url":"aws_api/ec2.html#delete_egress_only_internet_gateway"},{"doc":"aws_api/ec2","title":"delete_fleets","content":"pub fn delete_fleets(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_fleets\naws_api/ec2 delete_fleets","url":"aws_api/ec2.html#delete_fleets"},{"doc":"aws_api/ec2","title":"delete_flow_logs","content":"pub fn delete_flow_logs(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_flow_logs\naws_api/ec2 delete_flow_logs","url":"aws_api/ec2.html#delete_flow_logs"},{"doc":"aws_api/ec2","title":"delete_fpga_image","content":"pub fn delete_fpga_image(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_fpga_image\naws_api/ec2 delete_fpga_image","url":"aws_api/ec2.html#delete_fpga_image"},{"doc":"aws_api/ec2","title":"delete_instance_connect_endpoint","content":"pub fn delete_instance_connect_endpoint(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_instance_connect_endpoint\naws_api/ec2 delete_instance_connect_endpoint","url":"aws_api/ec2.html#delete_instance_connect_endpoint"},{"doc":"aws_api/ec2","title":"delete_instance_event_window","content":"pub fn delete_instance_event_window(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_instance_event_window\naws_api/ec2 delete_instance_event_window","url":"aws_api/ec2.html#delete_instance_event_window"},{"doc":"aws_api/ec2","title":"delete_internet_gateway","content":"pub fn delete_internet_gateway(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_internet_gateway\naws_api/ec2 delete_internet_gateway","url":"aws_api/ec2.html#delete_internet_gateway"},{"doc":"aws_api/ec2","title":"delete_ipam","content":"pub fn delete_ipam(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_ipam\naws_api/ec2 delete_ipam","url":"aws_api/ec2.html#delete_ipam"},{"doc":"aws_api/ec2","title":"delete_ipam_external_resource_verification_token","content":"pub fn delete_ipam_external_resource_verification_token(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_ipam_external_resource_verification_token\naws_api/ec2 delete_ipam_external_resource_verification_token","url":"aws_api/ec2.html#delete_ipam_external_resource_verification_token"},{"doc":"aws_api/ec2","title":"delete_ipam_pool","content":"pub fn delete_ipam_pool(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_ipam_pool\naws_api/ec2 delete_ipam_pool","url":"aws_api/ec2.html#delete_ipam_pool"},{"doc":"aws_api/ec2","title":"delete_ipam_resource_discovery","content":"pub fn delete_ipam_resource_discovery(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_ipam_resource_discovery\naws_api/ec2 delete_ipam_resource_discovery","url":"aws_api/ec2.html#delete_ipam_resource_discovery"},{"doc":"aws_api/ec2","title":"delete_ipam_scope","content":"pub fn delete_ipam_scope(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_ipam_scope\naws_api/ec2 delete_ipam_scope","url":"aws_api/ec2.html#delete_ipam_scope"},{"doc":"aws_api/ec2","title":"delete_key_pair","content":"pub fn delete_key_pair(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_key_pair\naws_api/ec2 delete_key_pair","url":"aws_api/ec2.html#delete_key_pair"},{"doc":"aws_api/ec2","title":"delete_launch_template","content":"pub fn delete_launch_template(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_launch_template\naws_api/ec2 delete_launch_template","url":"aws_api/ec2.html#delete_launch_template"},{"doc":"aws_api/ec2","title":"delete_launch_template_versions","content":"pub fn delete_launch_template_versions(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_launch_template_versions\naws_api/ec2 delete_launch_template_versions","url":"aws_api/ec2.html#delete_launch_template_versions"},{"doc":"aws_api/ec2","title":"delete_local_gateway_route","content":"pub fn delete_local_gateway_route(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_local_gateway_route\naws_api/ec2 delete_local_gateway_route","url":"aws_api/ec2.html#delete_local_gateway_route"},{"doc":"aws_api/ec2","title":"delete_local_gateway_route_table","content":"pub fn delete_local_gateway_route_table(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_local_gateway_route_table\naws_api/ec2 delete_local_gateway_route_table","url":"aws_api/ec2.html#delete_local_gateway_route_table"},{"doc":"aws_api/ec2","title":"delete_local_gateway_route_table_virtual_interface_group_association","content":"pub fn delete_local_gateway_route_table_virtual_interface_group_association(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_local_gateway_route_table_virtual_interface_group_association\naws_api/ec2 delete_local_gateway_route_table_virtual_interface_group_association","url":"aws_api/ec2.html#delete_local_gateway_route_table_virtual_interface_group_association"},{"doc":"aws_api/ec2","title":"delete_local_gateway_route_table_vpc_association","content":"pub fn delete_local_gateway_route_table_vpc_association(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_local_gateway_route_table_vpc_association\naws_api/ec2 delete_local_gateway_route_table_vpc_association","url":"aws_api/ec2.html#delete_local_gateway_route_table_vpc_association"},{"doc":"aws_api/ec2","title":"delete_managed_prefix_list","content":"pub fn delete_managed_prefix_list(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_managed_prefix_list\naws_api/ec2 delete_managed_prefix_list","url":"aws_api/ec2.html#delete_managed_prefix_list"},{"doc":"aws_api/ec2","title":"delete_nat_gateway","content":"pub fn delete_nat_gateway(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_nat_gateway\naws_api/ec2 delete_nat_gateway","url":"aws_api/ec2.html#delete_nat_gateway"},{"doc":"aws_api/ec2","title":"delete_network_acl","content":"pub fn delete_network_acl(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_network_acl\naws_api/ec2 delete_network_acl","url":"aws_api/ec2.html#delete_network_acl"},{"doc":"aws_api/ec2","title":"delete_network_acl_entry","content":"pub fn delete_network_acl_entry(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_network_acl_entry\naws_api/ec2 delete_network_acl_entry","url":"aws_api/ec2.html#delete_network_acl_entry"},{"doc":"aws_api/ec2","title":"delete_network_insights_access_scope","content":"pub fn delete_network_insights_access_scope(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_network_insights_access_scope\naws_api/ec2 delete_network_insights_access_scope","url":"aws_api/ec2.html#delete_network_insights_access_scope"},{"doc":"aws_api/ec2","title":"delete_network_insights_access_scope_analysis","content":"pub fn delete_network_insights_access_scope_analysis(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_network_insights_access_scope_analysis\naws_api/ec2 delete_network_insights_access_scope_analysis","url":"aws_api/ec2.html#delete_network_insights_access_scope_analysis"},{"doc":"aws_api/ec2","title":"delete_network_insights_analysis","content":"pub fn delete_network_insights_analysis(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_network_insights_analysis\naws_api/ec2 delete_network_insights_analysis","url":"aws_api/ec2.html#delete_network_insights_analysis"},{"doc":"aws_api/ec2","title":"delete_network_insights_path","content":"pub fn delete_network_insights_path(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_network_insights_path\naws_api/ec2 delete_network_insights_path","url":"aws_api/ec2.html#delete_network_insights_path"},{"doc":"aws_api/ec2","title":"delete_network_interface","content":"pub fn delete_network_interface(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_network_interface\naws_api/ec2 delete_network_interface","url":"aws_api/ec2.html#delete_network_interface"},{"doc":"aws_api/ec2","title":"delete_network_interface_permission","content":"pub fn delete_network_interface_permission(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_network_interface_permission\naws_api/ec2 delete_network_interface_permission","url":"aws_api/ec2.html#delete_network_interface_permission"},{"doc":"aws_api/ec2","title":"delete_placement_group","content":"pub fn delete_placement_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_placement_group\naws_api/ec2 delete_placement_group","url":"aws_api/ec2.html#delete_placement_group"},{"doc":"aws_api/ec2","title":"delete_public_ipv4_pool","content":"pub fn delete_public_ipv4_pool(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_public_ipv4_pool\naws_api/ec2 delete_public_ipv4_pool","url":"aws_api/ec2.html#delete_public_ipv4_pool"},{"doc":"aws_api/ec2","title":"delete_queued_reserved_instances","content":"pub fn delete_queued_reserved_instances(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_queued_reserved_instances\naws_api/ec2 delete_queued_reserved_instances","url":"aws_api/ec2.html#delete_queued_reserved_instances"},{"doc":"aws_api/ec2","title":"delete_route","content":"pub fn delete_route(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_route\naws_api/ec2 delete_route","url":"aws_api/ec2.html#delete_route"},{"doc":"aws_api/ec2","title":"delete_route_table","content":"pub fn delete_route_table(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_route_table\naws_api/ec2 delete_route_table","url":"aws_api/ec2.html#delete_route_table"},{"doc":"aws_api/ec2","title":"delete_security_group","content":"pub fn delete_security_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_security_group\naws_api/ec2 delete_security_group","url":"aws_api/ec2.html#delete_security_group"},{"doc":"aws_api/ec2","title":"delete_snapshot","content":"pub fn delete_snapshot(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_snapshot\naws_api/ec2 delete_snapshot","url":"aws_api/ec2.html#delete_snapshot"},{"doc":"aws_api/ec2","title":"delete_spot_datafeed_subscription","content":"pub fn delete_spot_datafeed_subscription(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_spot_datafeed_subscription\naws_api/ec2 delete_spot_datafeed_subscription","url":"aws_api/ec2.html#delete_spot_datafeed_subscription"},{"doc":"aws_api/ec2","title":"delete_subnet","content":"pub fn delete_subnet(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_subnet\naws_api/ec2 delete_subnet","url":"aws_api/ec2.html#delete_subnet"},{"doc":"aws_api/ec2","title":"delete_subnet_cidr_reservation","content":"pub fn delete_subnet_cidr_reservation(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_subnet_cidr_reservation\naws_api/ec2 delete_subnet_cidr_reservation","url":"aws_api/ec2.html#delete_subnet_cidr_reservation"},{"doc":"aws_api/ec2","title":"delete_tags","content":"pub fn delete_tags(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_tags\naws_api/ec2 delete_tags","url":"aws_api/ec2.html#delete_tags"},{"doc":"aws_api/ec2","title":"delete_traffic_mirror_filter","content":"pub fn delete_traffic_mirror_filter(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_traffic_mirror_filter\naws_api/ec2 delete_traffic_mirror_filter","url":"aws_api/ec2.html#delete_traffic_mirror_filter"},{"doc":"aws_api/ec2","title":"delete_traffic_mirror_filter_rule","content":"pub fn delete_traffic_mirror_filter_rule(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_traffic_mirror_filter_rule\naws_api/ec2 delete_traffic_mirror_filter_rule","url":"aws_api/ec2.html#delete_traffic_mirror_filter_rule"},{"doc":"aws_api/ec2","title":"delete_traffic_mirror_session","content":"pub fn delete_traffic_mirror_session(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_traffic_mirror_session\naws_api/ec2 delete_traffic_mirror_session","url":"aws_api/ec2.html#delete_traffic_mirror_session"},{"doc":"aws_api/ec2","title":"delete_traffic_mirror_target","content":"pub fn delete_traffic_mirror_target(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_traffic_mirror_target\naws_api/ec2 delete_traffic_mirror_target","url":"aws_api/ec2.html#delete_traffic_mirror_target"},{"doc":"aws_api/ec2","title":"delete_transit_gateway","content":"pub fn delete_transit_gateway(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_transit_gateway\naws_api/ec2 delete_transit_gateway","url":"aws_api/ec2.html#delete_transit_gateway"},{"doc":"aws_api/ec2","title":"delete_transit_gateway_connect","content":"pub fn delete_transit_gateway_connect(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_transit_gateway_connect\naws_api/ec2 delete_transit_gateway_connect","url":"aws_api/ec2.html#delete_transit_gateway_connect"},{"doc":"aws_api/ec2","title":"delete_transit_gateway_connect_peer","content":"pub fn delete_transit_gateway_connect_peer(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_transit_gateway_connect_peer\naws_api/ec2 delete_transit_gateway_connect_peer","url":"aws_api/ec2.html#delete_transit_gateway_connect_peer"},{"doc":"aws_api/ec2","title":"delete_transit_gateway_multicast_domain","content":"pub fn delete_transit_gateway_multicast_domain(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_transit_gateway_multicast_domain\naws_api/ec2 delete_transit_gateway_multicast_domain","url":"aws_api/ec2.html#delete_transit_gateway_multicast_domain"},{"doc":"aws_api/ec2","title":"delete_transit_gateway_peering_attachment","content":"pub fn delete_transit_gateway_peering_attachment(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_transit_gateway_peering_attachment\naws_api/ec2 delete_transit_gateway_peering_attachment","url":"aws_api/ec2.html#delete_transit_gateway_peering_attachment"},{"doc":"aws_api/ec2","title":"delete_transit_gateway_policy_table","content":"pub fn delete_transit_gateway_policy_table(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_transit_gateway_policy_table\naws_api/ec2 delete_transit_gateway_policy_table","url":"aws_api/ec2.html#delete_transit_gateway_policy_table"},{"doc":"aws_api/ec2","title":"delete_transit_gateway_prefix_list_reference","content":"pub fn delete_transit_gateway_prefix_list_reference(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_transit_gateway_prefix_list_reference\naws_api/ec2 delete_transit_gateway_prefix_list_reference","url":"aws_api/ec2.html#delete_transit_gateway_prefix_list_reference"},{"doc":"aws_api/ec2","title":"delete_transit_gateway_route","content":"pub fn delete_transit_gateway_route(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_transit_gateway_route\naws_api/ec2 delete_transit_gateway_route","url":"aws_api/ec2.html#delete_transit_gateway_route"},{"doc":"aws_api/ec2","title":"delete_transit_gateway_route_table","content":"pub fn delete_transit_gateway_route_table(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_transit_gateway_route_table\naws_api/ec2 delete_transit_gateway_route_table","url":"aws_api/ec2.html#delete_transit_gateway_route_table"},{"doc":"aws_api/ec2","title":"delete_transit_gateway_route_table_announcement","content":"pub fn delete_transit_gateway_route_table_announcement(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_transit_gateway_route_table_announcement\naws_api/ec2 delete_transit_gateway_route_table_announcement","url":"aws_api/ec2.html#delete_transit_gateway_route_table_announcement"},{"doc":"aws_api/ec2","title":"delete_transit_gateway_vpc_attachment","content":"pub fn delete_transit_gateway_vpc_attachment(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_transit_gateway_vpc_attachment\naws_api/ec2 delete_transit_gateway_vpc_attachment","url":"aws_api/ec2.html#delete_transit_gateway_vpc_attachment"},{"doc":"aws_api/ec2","title":"delete_verified_access_endpoint","content":"pub fn delete_verified_access_endpoint(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_verified_access_endpoint\naws_api/ec2 delete_verified_access_endpoint","url":"aws_api/ec2.html#delete_verified_access_endpoint"},{"doc":"aws_api/ec2","title":"delete_verified_access_group","content":"pub fn delete_verified_access_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_verified_access_group\naws_api/ec2 delete_verified_access_group","url":"aws_api/ec2.html#delete_verified_access_group"},{"doc":"aws_api/ec2","title":"delete_verified_access_instance","content":"pub fn delete_verified_access_instance(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_verified_access_instance\naws_api/ec2 delete_verified_access_instance","url":"aws_api/ec2.html#delete_verified_access_instance"},{"doc":"aws_api/ec2","title":"delete_verified_access_trust_provider","content":"pub fn delete_verified_access_trust_provider(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_verified_access_trust_provider\naws_api/ec2 delete_verified_access_trust_provider","url":"aws_api/ec2.html#delete_verified_access_trust_provider"},{"doc":"aws_api/ec2","title":"delete_volume","content":"pub fn delete_volume(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_volume\naws_api/ec2 delete_volume","url":"aws_api/ec2.html#delete_volume"},{"doc":"aws_api/ec2","title":"delete_vpc","content":"pub fn delete_vpc(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_vpc\naws_api/ec2 delete_vpc","url":"aws_api/ec2.html#delete_vpc"},{"doc":"aws_api/ec2","title":"delete_vpc_endpoint_connection_notifications","content":"pub fn delete_vpc_endpoint_connection_notifications(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_vpc_endpoint_connection_notifications\naws_api/ec2 delete_vpc_endpoint_connection_notifications","url":"aws_api/ec2.html#delete_vpc_endpoint_connection_notifications"},{"doc":"aws_api/ec2","title":"delete_vpc_endpoint_service_configurations","content":"pub fn delete_vpc_endpoint_service_configurations(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_vpc_endpoint_service_configurations\naws_api/ec2 delete_vpc_endpoint_service_configurations","url":"aws_api/ec2.html#delete_vpc_endpoint_service_configurations"},{"doc":"aws_api/ec2","title":"delete_vpc_endpoints","content":"pub fn delete_vpc_endpoints(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_vpc_endpoints\naws_api/ec2 delete_vpc_endpoints","url":"aws_api/ec2.html#delete_vpc_endpoints"},{"doc":"aws_api/ec2","title":"delete_vpc_peering_connection","content":"pub fn delete_vpc_peering_connection(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_vpc_peering_connection\naws_api/ec2 delete_vpc_peering_connection","url":"aws_api/ec2.html#delete_vpc_peering_connection"},{"doc":"aws_api/ec2","title":"delete_vpn_connection","content":"pub fn delete_vpn_connection(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_vpn_connection\naws_api/ec2 delete_vpn_connection","url":"aws_api/ec2.html#delete_vpn_connection"},{"doc":"aws_api/ec2","title":"delete_vpn_connection_route","content":"pub fn delete_vpn_connection_route(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_vpn_connection_route\naws_api/ec2 delete_vpn_connection_route","url":"aws_api/ec2.html#delete_vpn_connection_route"},{"doc":"aws_api/ec2","title":"delete_vpn_gateway","content":"pub fn delete_vpn_gateway(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.delete_vpn_gateway\naws_api/ec2 delete_vpn_gateway","url":"aws_api/ec2.html#delete_vpn_gateway"},{"doc":"aws_api/ec2","title":"deprovision_byoip_cidr","content":"pub fn deprovision_byoip_cidr(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.deprovision_byoip_cidr\naws_api/ec2 deprovision_byoip_cidr","url":"aws_api/ec2.html#deprovision_byoip_cidr"},{"doc":"aws_api/ec2","title":"deprovision_ipam_byoasn","content":"pub fn deprovision_ipam_byoasn(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.deprovision_ipam_byoasn\naws_api/ec2 deprovision_ipam_byoasn","url":"aws_api/ec2.html#deprovision_ipam_byoasn"},{"doc":"aws_api/ec2","title":"deprovision_ipam_pool_cidr","content":"pub fn deprovision_ipam_pool_cidr(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.deprovision_ipam_pool_cidr\naws_api/ec2 deprovision_ipam_pool_cidr","url":"aws_api/ec2.html#deprovision_ipam_pool_cidr"},{"doc":"aws_api/ec2","title":"deprovision_public_ipv4_pool_cidr","content":"pub fn deprovision_public_ipv4_pool_cidr(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.deprovision_public_ipv4_pool_cidr\naws_api/ec2 deprovision_public_ipv4_pool_cidr","url":"aws_api/ec2.html#deprovision_public_ipv4_pool_cidr"},{"doc":"aws_api/ec2","title":"deregister_image","content":"pub fn deregister_image(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.deregister_image\naws_api/ec2 deregister_image","url":"aws_api/ec2.html#deregister_image"},{"doc":"aws_api/ec2","title":"deregister_instance_event_notification_attributes","content":"pub fn deregister_instance_event_notification_attributes(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.deregister_instance_event_notification_attributes\naws_api/ec2 deregister_instance_event_notification_attributes","url":"aws_api/ec2.html#deregister_instance_event_notification_attributes"},{"doc":"aws_api/ec2","title":"deregister_transit_gateway_multicast_group_members","content":"pub fn deregister_transit_gateway_multicast_group_members(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.deregister_transit_gateway_multicast_group_members\naws_api/ec2 deregister_transit_gateway_multicast_group_members","url":"aws_api/ec2.html#deregister_transit_gateway_multicast_group_members"},{"doc":"aws_api/ec2","title":"deregister_transit_gateway_multicast_group_sources","content":"pub fn deregister_transit_gateway_multicast_group_sources(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.deregister_transit_gateway_multicast_group_sources\naws_api/ec2 deregister_transit_gateway_multicast_group_sources","url":"aws_api/ec2.html#deregister_transit_gateway_multicast_group_sources"},{"doc":"aws_api/ec2","title":"describe_account_attributes","content":"pub fn describe_account_attributes(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_account_attributes\naws_api/ec2 describe_account_attributes","url":"aws_api/ec2.html#describe_account_attributes"},{"doc":"aws_api/ec2","title":"describe_address_transfers","content":"pub fn describe_address_transfers(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_address_transfers\naws_api/ec2 describe_address_transfers","url":"aws_api/ec2.html#describe_address_transfers"},{"doc":"aws_api/ec2","title":"describe_addresses","content":"pub fn describe_addresses(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_addresses\naws_api/ec2 describe_addresses","url":"aws_api/ec2.html#describe_addresses"},{"doc":"aws_api/ec2","title":"describe_addresses_attribute","content":"pub fn describe_addresses_attribute(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_addresses_attribute\naws_api/ec2 describe_addresses_attribute","url":"aws_api/ec2.html#describe_addresses_attribute"},{"doc":"aws_api/ec2","title":"describe_aggregate_id_format","content":"pub fn describe_aggregate_id_format(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_aggregate_id_format\naws_api/ec2 describe_aggregate_id_format","url":"aws_api/ec2.html#describe_aggregate_id_format"},{"doc":"aws_api/ec2","title":"describe_availability_zones","content":"pub fn describe_availability_zones(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_availability_zones\naws_api/ec2 describe_availability_zones","url":"aws_api/ec2.html#describe_availability_zones"},{"doc":"aws_api/ec2","title":"describe_aws_network_performance_metric_subscriptions","content":"pub fn describe_aws_network_performance_metric_subscriptions(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_aws_network_performance_metric_subscriptions\naws_api/ec2 describe_aws_network_performance_metric_subscriptions","url":"aws_api/ec2.html#describe_aws_network_performance_metric_subscriptions"},{"doc":"aws_api/ec2","title":"describe_bundle_tasks","content":"pub fn describe_bundle_tasks(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_bundle_tasks\naws_api/ec2 describe_bundle_tasks","url":"aws_api/ec2.html#describe_bundle_tasks"},{"doc":"aws_api/ec2","title":"describe_byoip_cidrs","content":"pub fn describe_byoip_cidrs(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_byoip_cidrs\naws_api/ec2 describe_byoip_cidrs","url":"aws_api/ec2.html#describe_byoip_cidrs"},{"doc":"aws_api/ec2","title":"describe_capacity_block_offerings","content":"pub fn describe_capacity_block_offerings(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_capacity_block_offerings\naws_api/ec2 describe_capacity_block_offerings","url":"aws_api/ec2.html#describe_capacity_block_offerings"},{"doc":"aws_api/ec2","title":"describe_capacity_reservation_fleets","content":"pub fn describe_capacity_reservation_fleets(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_capacity_reservation_fleets\naws_api/ec2 describe_capacity_reservation_fleets","url":"aws_api/ec2.html#describe_capacity_reservation_fleets"},{"doc":"aws_api/ec2","title":"describe_capacity_reservations","content":"pub fn describe_capacity_reservations(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_capacity_reservations\naws_api/ec2 describe_capacity_reservations","url":"aws_api/ec2.html#describe_capacity_reservations"},{"doc":"aws_api/ec2","title":"describe_carrier_gateways","content":"pub fn describe_carrier_gateways(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_carrier_gateways\naws_api/ec2 describe_carrier_gateways","url":"aws_api/ec2.html#describe_carrier_gateways"},{"doc":"aws_api/ec2","title":"describe_classic_link_instances","content":"pub fn describe_classic_link_instances(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_classic_link_instances\naws_api/ec2 describe_classic_link_instances","url":"aws_api/ec2.html#describe_classic_link_instances"},{"doc":"aws_api/ec2","title":"describe_client_vpn_authorization_rules","content":"pub fn describe_client_vpn_authorization_rules(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_client_vpn_authorization_rules\naws_api/ec2 describe_client_vpn_authorization_rules","url":"aws_api/ec2.html#describe_client_vpn_authorization_rules"},{"doc":"aws_api/ec2","title":"describe_client_vpn_connections","content":"pub fn describe_client_vpn_connections(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_client_vpn_connections\naws_api/ec2 describe_client_vpn_connections","url":"aws_api/ec2.html#describe_client_vpn_connections"},{"doc":"aws_api/ec2","title":"describe_client_vpn_endpoints","content":"pub fn describe_client_vpn_endpoints(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_client_vpn_endpoints\naws_api/ec2 describe_client_vpn_endpoints","url":"aws_api/ec2.html#describe_client_vpn_endpoints"},{"doc":"aws_api/ec2","title":"describe_client_vpn_routes","content":"pub fn describe_client_vpn_routes(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_client_vpn_routes\naws_api/ec2 describe_client_vpn_routes","url":"aws_api/ec2.html#describe_client_vpn_routes"},{"doc":"aws_api/ec2","title":"describe_client_vpn_target_networks","content":"pub fn describe_client_vpn_target_networks(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_client_vpn_target_networks\naws_api/ec2 describe_client_vpn_target_networks","url":"aws_api/ec2.html#describe_client_vpn_target_networks"},{"doc":"aws_api/ec2","title":"describe_coip_pools","content":"pub fn describe_coip_pools(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_coip_pools\naws_api/ec2 describe_coip_pools","url":"aws_api/ec2.html#describe_coip_pools"},{"doc":"aws_api/ec2","title":"describe_conversion_tasks","content":"pub fn describe_conversion_tasks(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_conversion_tasks\naws_api/ec2 describe_conversion_tasks","url":"aws_api/ec2.html#describe_conversion_tasks"},{"doc":"aws_api/ec2","title":"describe_customer_gateways","content":"pub fn describe_customer_gateways(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_customer_gateways\naws_api/ec2 describe_customer_gateways","url":"aws_api/ec2.html#describe_customer_gateways"},{"doc":"aws_api/ec2","title":"describe_dhcp_options","content":"pub fn describe_dhcp_options(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_dhcp_options\naws_api/ec2 describe_dhcp_options","url":"aws_api/ec2.html#describe_dhcp_options"},{"doc":"aws_api/ec2","title":"describe_egress_only_internet_gateways","content":"pub fn describe_egress_only_internet_gateways(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_egress_only_internet_gateways\naws_api/ec2 describe_egress_only_internet_gateways","url":"aws_api/ec2.html#describe_egress_only_internet_gateways"},{"doc":"aws_api/ec2","title":"describe_elastic_gpus","content":"pub fn describe_elastic_gpus(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_elastic_gpus\naws_api/ec2 describe_elastic_gpus","url":"aws_api/ec2.html#describe_elastic_gpus"},{"doc":"aws_api/ec2","title":"describe_export_image_tasks","content":"pub fn describe_export_image_tasks(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_export_image_tasks\naws_api/ec2 describe_export_image_tasks","url":"aws_api/ec2.html#describe_export_image_tasks"},{"doc":"aws_api/ec2","title":"describe_export_tasks","content":"pub fn describe_export_tasks(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_export_tasks\naws_api/ec2 describe_export_tasks","url":"aws_api/ec2.html#describe_export_tasks"},{"doc":"aws_api/ec2","title":"describe_fast_launch_images","content":"pub fn describe_fast_launch_images(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_fast_launch_images\naws_api/ec2 describe_fast_launch_images","url":"aws_api/ec2.html#describe_fast_launch_images"},{"doc":"aws_api/ec2","title":"describe_fast_snapshot_restores","content":"pub fn describe_fast_snapshot_restores(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_fast_snapshot_restores\naws_api/ec2 describe_fast_snapshot_restores","url":"aws_api/ec2.html#describe_fast_snapshot_restores"},{"doc":"aws_api/ec2","title":"describe_fleet_history","content":"pub fn describe_fleet_history(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_fleet_history\naws_api/ec2 describe_fleet_history","url":"aws_api/ec2.html#describe_fleet_history"},{"doc":"aws_api/ec2","title":"describe_fleet_instances","content":"pub fn describe_fleet_instances(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_fleet_instances\naws_api/ec2 describe_fleet_instances","url":"aws_api/ec2.html#describe_fleet_instances"},{"doc":"aws_api/ec2","title":"describe_fleets","content":"pub fn describe_fleets(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_fleets\naws_api/ec2 describe_fleets","url":"aws_api/ec2.html#describe_fleets"},{"doc":"aws_api/ec2","title":"describe_flow_logs","content":"pub fn describe_flow_logs(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_flow_logs\naws_api/ec2 describe_flow_logs","url":"aws_api/ec2.html#describe_flow_logs"},{"doc":"aws_api/ec2","title":"describe_fpga_image_attribute","content":"pub fn describe_fpga_image_attribute(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_fpga_image_attribute\naws_api/ec2 describe_fpga_image_attribute","url":"aws_api/ec2.html#describe_fpga_image_attribute"},{"doc":"aws_api/ec2","title":"describe_fpga_images","content":"pub fn describe_fpga_images(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_fpga_images\naws_api/ec2 describe_fpga_images","url":"aws_api/ec2.html#describe_fpga_images"},{"doc":"aws_api/ec2","title":"describe_host_reservation_offerings","content":"pub fn describe_host_reservation_offerings(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_host_reservation_offerings\naws_api/ec2 describe_host_reservation_offerings","url":"aws_api/ec2.html#describe_host_reservation_offerings"},{"doc":"aws_api/ec2","title":"describe_host_reservations","content":"pub fn describe_host_reservations(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_host_reservations\naws_api/ec2 describe_host_reservations","url":"aws_api/ec2.html#describe_host_reservations"},{"doc":"aws_api/ec2","title":"describe_hosts","content":"pub fn describe_hosts(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_hosts\naws_api/ec2 describe_hosts","url":"aws_api/ec2.html#describe_hosts"},{"doc":"aws_api/ec2","title":"describe_iam_instance_profile_associations","content":"pub fn describe_iam_instance_profile_associations(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_iam_instance_profile_associations\naws_api/ec2 describe_iam_instance_profile_associations","url":"aws_api/ec2.html#describe_iam_instance_profile_associations"},{"doc":"aws_api/ec2","title":"describe_id_format","content":"pub fn describe_id_format(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_id_format\naws_api/ec2 describe_id_format","url":"aws_api/ec2.html#describe_id_format"},{"doc":"aws_api/ec2","title":"describe_identity_id_format","content":"pub fn describe_identity_id_format(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_identity_id_format\naws_api/ec2 describe_identity_id_format","url":"aws_api/ec2.html#describe_identity_id_format"},{"doc":"aws_api/ec2","title":"describe_image_attribute","content":"pub fn describe_image_attribute(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_image_attribute\naws_api/ec2 describe_image_attribute","url":"aws_api/ec2.html#describe_image_attribute"},{"doc":"aws_api/ec2","title":"describe_images","content":"pub fn describe_images(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_images\naws_api/ec2 describe_images","url":"aws_api/ec2.html#describe_images"},{"doc":"aws_api/ec2","title":"describe_import_image_tasks","content":"pub fn describe_import_image_tasks(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_import_image_tasks\naws_api/ec2 describe_import_image_tasks","url":"aws_api/ec2.html#describe_import_image_tasks"},{"doc":"aws_api/ec2","title":"describe_import_snapshot_tasks","content":"pub fn describe_import_snapshot_tasks(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_import_snapshot_tasks\naws_api/ec2 describe_import_snapshot_tasks","url":"aws_api/ec2.html#describe_import_snapshot_tasks"},{"doc":"aws_api/ec2","title":"describe_instance_attribute","content":"pub fn describe_instance_attribute(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_instance_attribute\naws_api/ec2 describe_instance_attribute","url":"aws_api/ec2.html#describe_instance_attribute"},{"doc":"aws_api/ec2","title":"describe_instance_connect_endpoints","content":"pub fn describe_instance_connect_endpoints(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_instance_connect_endpoints\naws_api/ec2 describe_instance_connect_endpoints","url":"aws_api/ec2.html#describe_instance_connect_endpoints"},{"doc":"aws_api/ec2","title":"describe_instance_credit_specifications","content":"pub fn describe_instance_credit_specifications(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_instance_credit_specifications\naws_api/ec2 describe_instance_credit_specifications","url":"aws_api/ec2.html#describe_instance_credit_specifications"},{"doc":"aws_api/ec2","title":"describe_instance_event_notification_attributes","content":"pub fn describe_instance_event_notification_attributes(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_instance_event_notification_attributes\naws_api/ec2 describe_instance_event_notification_attributes","url":"aws_api/ec2.html#describe_instance_event_notification_attributes"},{"doc":"aws_api/ec2","title":"describe_instance_event_windows","content":"pub fn describe_instance_event_windows(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_instance_event_windows\naws_api/ec2 describe_instance_event_windows","url":"aws_api/ec2.html#describe_instance_event_windows"},{"doc":"aws_api/ec2","title":"describe_instance_status","content":"pub fn describe_instance_status(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_instance_status\naws_api/ec2 describe_instance_status","url":"aws_api/ec2.html#describe_instance_status"},{"doc":"aws_api/ec2","title":"describe_instance_topology","content":"pub fn describe_instance_topology(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_instance_topology\naws_api/ec2 describe_instance_topology","url":"aws_api/ec2.html#describe_instance_topology"},{"doc":"aws_api/ec2","title":"describe_instance_type_offerings","content":"pub fn describe_instance_type_offerings(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_instance_type_offerings\naws_api/ec2 describe_instance_type_offerings","url":"aws_api/ec2.html#describe_instance_type_offerings"},{"doc":"aws_api/ec2","title":"describe_instance_types","content":"pub fn describe_instance_types(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_instance_types\naws_api/ec2 describe_instance_types","url":"aws_api/ec2.html#describe_instance_types"},{"doc":"aws_api/ec2","title":"describe_instances","content":"pub fn describe_instances(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_instances\naws_api/ec2 describe_instances","url":"aws_api/ec2.html#describe_instances"},{"doc":"aws_api/ec2","title":"describe_internet_gateways","content":"pub fn describe_internet_gateways(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_internet_gateways\naws_api/ec2 describe_internet_gateways","url":"aws_api/ec2.html#describe_internet_gateways"},{"doc":"aws_api/ec2","title":"describe_ipam_byoasn","content":"pub fn describe_ipam_byoasn(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_ipam_byoasn\naws_api/ec2 describe_ipam_byoasn","url":"aws_api/ec2.html#describe_ipam_byoasn"},{"doc":"aws_api/ec2","title":"describe_ipam_external_resource_verification_tokens","content":"pub fn describe_ipam_external_resource_verification_tokens(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_ipam_external_resource_verification_tokens\naws_api/ec2 describe_ipam_external_resource_verification_tokens","url":"aws_api/ec2.html#describe_ipam_external_resource_verification_tokens"},{"doc":"aws_api/ec2","title":"describe_ipam_pools","content":"pub fn describe_ipam_pools(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_ipam_pools\naws_api/ec2 describe_ipam_pools","url":"aws_api/ec2.html#describe_ipam_pools"},{"doc":"aws_api/ec2","title":"describe_ipam_resource_discoveries","content":"pub fn describe_ipam_resource_discoveries(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_ipam_resource_discoveries\naws_api/ec2 describe_ipam_resource_discoveries","url":"aws_api/ec2.html#describe_ipam_resource_discoveries"},{"doc":"aws_api/ec2","title":"describe_ipam_resource_discovery_associations","content":"pub fn describe_ipam_resource_discovery_associations(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_ipam_resource_discovery_associations\naws_api/ec2 describe_ipam_resource_discovery_associations","url":"aws_api/ec2.html#describe_ipam_resource_discovery_associations"},{"doc":"aws_api/ec2","title":"describe_ipam_scopes","content":"pub fn describe_ipam_scopes(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_ipam_scopes\naws_api/ec2 describe_ipam_scopes","url":"aws_api/ec2.html#describe_ipam_scopes"},{"doc":"aws_api/ec2","title":"describe_ipams","content":"pub fn describe_ipams(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_ipams\naws_api/ec2 describe_ipams","url":"aws_api/ec2.html#describe_ipams"},{"doc":"aws_api/ec2","title":"describe_ipv6_pools","content":"pub fn describe_ipv6_pools(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_ipv6_pools\naws_api/ec2 describe_ipv6_pools","url":"aws_api/ec2.html#describe_ipv6_pools"},{"doc":"aws_api/ec2","title":"describe_key_pairs","content":"pub fn describe_key_pairs(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_key_pairs\naws_api/ec2 describe_key_pairs","url":"aws_api/ec2.html#describe_key_pairs"},{"doc":"aws_api/ec2","title":"describe_launch_template_versions","content":"pub fn describe_launch_template_versions(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_launch_template_versions\naws_api/ec2 describe_launch_template_versions","url":"aws_api/ec2.html#describe_launch_template_versions"},{"doc":"aws_api/ec2","title":"describe_launch_templates","content":"pub fn describe_launch_templates(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_launch_templates\naws_api/ec2 describe_launch_templates","url":"aws_api/ec2.html#describe_launch_templates"},{"doc":"aws_api/ec2","title":"describe_local_gateway_route_table_virtual_interface_group_associations","content":"pub fn describe_local_gateway_route_table_virtual_interface_group_associations(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_local_gateway_route_table_virtual_interface_group_associations\naws_api/ec2 describe_local_gateway_route_table_virtual_interface_group_associations","url":"aws_api/ec2.html#describe_local_gateway_route_table_virtual_interface_group_associations"},{"doc":"aws_api/ec2","title":"describe_local_gateway_route_table_vpc_associations","content":"pub fn describe_local_gateway_route_table_vpc_associations(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_local_gateway_route_table_vpc_associations\naws_api/ec2 describe_local_gateway_route_table_vpc_associations","url":"aws_api/ec2.html#describe_local_gateway_route_table_vpc_associations"},{"doc":"aws_api/ec2","title":"describe_local_gateway_route_tables","content":"pub fn describe_local_gateway_route_tables(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_local_gateway_route_tables\naws_api/ec2 describe_local_gateway_route_tables","url":"aws_api/ec2.html#describe_local_gateway_route_tables"},{"doc":"aws_api/ec2","title":"describe_local_gateway_virtual_interface_groups","content":"pub fn describe_local_gateway_virtual_interface_groups(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_local_gateway_virtual_interface_groups\naws_api/ec2 describe_local_gateway_virtual_interface_groups","url":"aws_api/ec2.html#describe_local_gateway_virtual_interface_groups"},{"doc":"aws_api/ec2","title":"describe_local_gateway_virtual_interfaces","content":"pub fn describe_local_gateway_virtual_interfaces(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_local_gateway_virtual_interfaces\naws_api/ec2 describe_local_gateway_virtual_interfaces","url":"aws_api/ec2.html#describe_local_gateway_virtual_interfaces"},{"doc":"aws_api/ec2","title":"describe_local_gateways","content":"pub fn describe_local_gateways(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_local_gateways\naws_api/ec2 describe_local_gateways","url":"aws_api/ec2.html#describe_local_gateways"},{"doc":"aws_api/ec2","title":"describe_locked_snapshots","content":"pub fn describe_locked_snapshots(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_locked_snapshots\naws_api/ec2 describe_locked_snapshots","url":"aws_api/ec2.html#describe_locked_snapshots"},{"doc":"aws_api/ec2","title":"describe_mac_hosts","content":"pub fn describe_mac_hosts(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_mac_hosts\naws_api/ec2 describe_mac_hosts","url":"aws_api/ec2.html#describe_mac_hosts"},{"doc":"aws_api/ec2","title":"describe_managed_prefix_lists","content":"pub fn describe_managed_prefix_lists(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_managed_prefix_lists\naws_api/ec2 describe_managed_prefix_lists","url":"aws_api/ec2.html#describe_managed_prefix_lists"},{"doc":"aws_api/ec2","title":"describe_moving_addresses","content":"pub fn describe_moving_addresses(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_moving_addresses\naws_api/ec2 describe_moving_addresses","url":"aws_api/ec2.html#describe_moving_addresses"},{"doc":"aws_api/ec2","title":"describe_nat_gateways","content":"pub fn describe_nat_gateways(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_nat_gateways\naws_api/ec2 describe_nat_gateways","url":"aws_api/ec2.html#describe_nat_gateways"},{"doc":"aws_api/ec2","title":"describe_network_acls","content":"pub fn describe_network_acls(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_network_acls\naws_api/ec2 describe_network_acls","url":"aws_api/ec2.html#describe_network_acls"},{"doc":"aws_api/ec2","title":"describe_network_insights_access_scope_analyses","content":"pub fn describe_network_insights_access_scope_analyses(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_network_insights_access_scope_analyses\naws_api/ec2 describe_network_insights_access_scope_analyses","url":"aws_api/ec2.html#describe_network_insights_access_scope_analyses"},{"doc":"aws_api/ec2","title":"describe_network_insights_access_scopes","content":"pub fn describe_network_insights_access_scopes(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_network_insights_access_scopes\naws_api/ec2 describe_network_insights_access_scopes","url":"aws_api/ec2.html#describe_network_insights_access_scopes"},{"doc":"aws_api/ec2","title":"describe_network_insights_analyses","content":"pub fn describe_network_insights_analyses(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_network_insights_analyses\naws_api/ec2 describe_network_insights_analyses","url":"aws_api/ec2.html#describe_network_insights_analyses"},{"doc":"aws_api/ec2","title":"describe_network_insights_paths","content":"pub fn describe_network_insights_paths(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_network_insights_paths\naws_api/ec2 describe_network_insights_paths","url":"aws_api/ec2.html#describe_network_insights_paths"},{"doc":"aws_api/ec2","title":"describe_network_interface_attribute","content":"pub fn describe_network_interface_attribute(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_network_interface_attribute\naws_api/ec2 describe_network_interface_attribute","url":"aws_api/ec2.html#describe_network_interface_attribute"},{"doc":"aws_api/ec2","title":"describe_network_interface_permissions","content":"pub fn describe_network_interface_permissions(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_network_interface_permissions\naws_api/ec2 describe_network_interface_permissions","url":"aws_api/ec2.html#describe_network_interface_permissions"},{"doc":"aws_api/ec2","title":"describe_network_interfaces","content":"pub fn describe_network_interfaces(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_network_interfaces\naws_api/ec2 describe_network_interfaces","url":"aws_api/ec2.html#describe_network_interfaces"},{"doc":"aws_api/ec2","title":"describe_placement_groups","content":"pub fn describe_placement_groups(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_placement_groups\naws_api/ec2 describe_placement_groups","url":"aws_api/ec2.html#describe_placement_groups"},{"doc":"aws_api/ec2","title":"describe_prefix_lists","content":"pub fn describe_prefix_lists(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_prefix_lists\naws_api/ec2 describe_prefix_lists","url":"aws_api/ec2.html#describe_prefix_lists"},{"doc":"aws_api/ec2","title":"describe_principal_id_format","content":"pub fn describe_principal_id_format(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_principal_id_format\naws_api/ec2 describe_principal_id_format","url":"aws_api/ec2.html#describe_principal_id_format"},{"doc":"aws_api/ec2","title":"describe_public_ipv4_pools","content":"pub fn describe_public_ipv4_pools(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_public_ipv4_pools\naws_api/ec2 describe_public_ipv4_pools","url":"aws_api/ec2.html#describe_public_ipv4_pools"},{"doc":"aws_api/ec2","title":"describe_regions","content":"pub fn describe_regions(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_regions\naws_api/ec2 describe_regions","url":"aws_api/ec2.html#describe_regions"},{"doc":"aws_api/ec2","title":"describe_replace_root_volume_tasks","content":"pub fn describe_replace_root_volume_tasks(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_replace_root_volume_tasks\naws_api/ec2 describe_replace_root_volume_tasks","url":"aws_api/ec2.html#describe_replace_root_volume_tasks"},{"doc":"aws_api/ec2","title":"describe_reserved_instances","content":"pub fn describe_reserved_instances(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_reserved_instances\naws_api/ec2 describe_reserved_instances","url":"aws_api/ec2.html#describe_reserved_instances"},{"doc":"aws_api/ec2","title":"describe_reserved_instances_listings","content":"pub fn describe_reserved_instances_listings(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_reserved_instances_listings\naws_api/ec2 describe_reserved_instances_listings","url":"aws_api/ec2.html#describe_reserved_instances_listings"},{"doc":"aws_api/ec2","title":"describe_reserved_instances_modifications","content":"pub fn describe_reserved_instances_modifications(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_reserved_instances_modifications\naws_api/ec2 describe_reserved_instances_modifications","url":"aws_api/ec2.html#describe_reserved_instances_modifications"},{"doc":"aws_api/ec2","title":"describe_reserved_instances_offerings","content":"pub fn describe_reserved_instances_offerings(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_reserved_instances_offerings\naws_api/ec2 describe_reserved_instances_offerings","url":"aws_api/ec2.html#describe_reserved_instances_offerings"},{"doc":"aws_api/ec2","title":"describe_route_tables","content":"pub fn describe_route_tables(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_route_tables\naws_api/ec2 describe_route_tables","url":"aws_api/ec2.html#describe_route_tables"},{"doc":"aws_api/ec2","title":"describe_scheduled_instance_availability","content":"pub fn describe_scheduled_instance_availability(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_scheduled_instance_availability\naws_api/ec2 describe_scheduled_instance_availability","url":"aws_api/ec2.html#describe_scheduled_instance_availability"},{"doc":"aws_api/ec2","title":"describe_scheduled_instances","content":"pub fn describe_scheduled_instances(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_scheduled_instances\naws_api/ec2 describe_scheduled_instances","url":"aws_api/ec2.html#describe_scheduled_instances"},{"doc":"aws_api/ec2","title":"describe_security_group_references","content":"pub fn describe_security_group_references(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_security_group_references\naws_api/ec2 describe_security_group_references","url":"aws_api/ec2.html#describe_security_group_references"},{"doc":"aws_api/ec2","title":"describe_security_group_rules","content":"pub fn describe_security_group_rules(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_security_group_rules\naws_api/ec2 describe_security_group_rules","url":"aws_api/ec2.html#describe_security_group_rules"},{"doc":"aws_api/ec2","title":"describe_security_groups","content":"pub fn describe_security_groups(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_security_groups\naws_api/ec2 describe_security_groups","url":"aws_api/ec2.html#describe_security_groups"},{"doc":"aws_api/ec2","title":"describe_snapshot_attribute","content":"pub fn describe_snapshot_attribute(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_snapshot_attribute\naws_api/ec2 describe_snapshot_attribute","url":"aws_api/ec2.html#describe_snapshot_attribute"},{"doc":"aws_api/ec2","title":"describe_snapshot_tier_status","content":"pub fn describe_snapshot_tier_status(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_snapshot_tier_status\naws_api/ec2 describe_snapshot_tier_status","url":"aws_api/ec2.html#describe_snapshot_tier_status"},{"doc":"aws_api/ec2","title":"describe_snapshots","content":"pub fn describe_snapshots(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_snapshots\naws_api/ec2 describe_snapshots","url":"aws_api/ec2.html#describe_snapshots"},{"doc":"aws_api/ec2","title":"describe_spot_datafeed_subscription","content":"pub fn describe_spot_datafeed_subscription(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_spot_datafeed_subscription\naws_api/ec2 describe_spot_datafeed_subscription","url":"aws_api/ec2.html#describe_spot_datafeed_subscription"},{"doc":"aws_api/ec2","title":"describe_spot_fleet_instances","content":"pub fn describe_spot_fleet_instances(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_spot_fleet_instances\naws_api/ec2 describe_spot_fleet_instances","url":"aws_api/ec2.html#describe_spot_fleet_instances"},{"doc":"aws_api/ec2","title":"describe_spot_fleet_request_history","content":"pub fn describe_spot_fleet_request_history(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_spot_fleet_request_history\naws_api/ec2 describe_spot_fleet_request_history","url":"aws_api/ec2.html#describe_spot_fleet_request_history"},{"doc":"aws_api/ec2","title":"describe_spot_fleet_requests","content":"pub fn describe_spot_fleet_requests(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_spot_fleet_requests\naws_api/ec2 describe_spot_fleet_requests","url":"aws_api/ec2.html#describe_spot_fleet_requests"},{"doc":"aws_api/ec2","title":"describe_spot_instance_requests","content":"pub fn describe_spot_instance_requests(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_spot_instance_requests\naws_api/ec2 describe_spot_instance_requests","url":"aws_api/ec2.html#describe_spot_instance_requests"},{"doc":"aws_api/ec2","title":"describe_spot_price_history","content":"pub fn describe_spot_price_history(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_spot_price_history\naws_api/ec2 describe_spot_price_history","url":"aws_api/ec2.html#describe_spot_price_history"},{"doc":"aws_api/ec2","title":"describe_stale_security_groups","content":"pub fn describe_stale_security_groups(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_stale_security_groups\naws_api/ec2 describe_stale_security_groups","url":"aws_api/ec2.html#describe_stale_security_groups"},{"doc":"aws_api/ec2","title":"describe_store_image_tasks","content":"pub fn describe_store_image_tasks(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_store_image_tasks\naws_api/ec2 describe_store_image_tasks","url":"aws_api/ec2.html#describe_store_image_tasks"},{"doc":"aws_api/ec2","title":"describe_subnets","content":"pub fn describe_subnets(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_subnets\naws_api/ec2 describe_subnets","url":"aws_api/ec2.html#describe_subnets"},{"doc":"aws_api/ec2","title":"describe_tags","content":"pub fn describe_tags(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_tags\naws_api/ec2 describe_tags","url":"aws_api/ec2.html#describe_tags"},{"doc":"aws_api/ec2","title":"describe_traffic_mirror_filter_rules","content":"pub fn describe_traffic_mirror_filter_rules(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_traffic_mirror_filter_rules\naws_api/ec2 describe_traffic_mirror_filter_rules","url":"aws_api/ec2.html#describe_traffic_mirror_filter_rules"},{"doc":"aws_api/ec2","title":"describe_traffic_mirror_filters","content":"pub fn describe_traffic_mirror_filters(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_traffic_mirror_filters\naws_api/ec2 describe_traffic_mirror_filters","url":"aws_api/ec2.html#describe_traffic_mirror_filters"},{"doc":"aws_api/ec2","title":"describe_traffic_mirror_sessions","content":"pub fn describe_traffic_mirror_sessions(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_traffic_mirror_sessions\naws_api/ec2 describe_traffic_mirror_sessions","url":"aws_api/ec2.html#describe_traffic_mirror_sessions"},{"doc":"aws_api/ec2","title":"describe_traffic_mirror_targets","content":"pub fn describe_traffic_mirror_targets(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_traffic_mirror_targets\naws_api/ec2 describe_traffic_mirror_targets","url":"aws_api/ec2.html#describe_traffic_mirror_targets"},{"doc":"aws_api/ec2","title":"describe_transit_gateway_attachments","content":"pub fn describe_transit_gateway_attachments(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_transit_gateway_attachments\naws_api/ec2 describe_transit_gateway_attachments","url":"aws_api/ec2.html#describe_transit_gateway_attachments"},{"doc":"aws_api/ec2","title":"describe_transit_gateway_connect_peers","content":"pub fn describe_transit_gateway_connect_peers(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_transit_gateway_connect_peers\naws_api/ec2 describe_transit_gateway_connect_peers","url":"aws_api/ec2.html#describe_transit_gateway_connect_peers"},{"doc":"aws_api/ec2","title":"describe_transit_gateway_connects","content":"pub fn describe_transit_gateway_connects(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_transit_gateway_connects\naws_api/ec2 describe_transit_gateway_connects","url":"aws_api/ec2.html#describe_transit_gateway_connects"},{"doc":"aws_api/ec2","title":"describe_transit_gateway_multicast_domains","content":"pub fn describe_transit_gateway_multicast_domains(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_transit_gateway_multicast_domains\naws_api/ec2 describe_transit_gateway_multicast_domains","url":"aws_api/ec2.html#describe_transit_gateway_multicast_domains"},{"doc":"aws_api/ec2","title":"describe_transit_gateway_peering_attachments","content":"pub fn describe_transit_gateway_peering_attachments(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_transit_gateway_peering_attachments\naws_api/ec2 describe_transit_gateway_peering_attachments","url":"aws_api/ec2.html#describe_transit_gateway_peering_attachments"},{"doc":"aws_api/ec2","title":"describe_transit_gateway_policy_tables","content":"pub fn describe_transit_gateway_policy_tables(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_transit_gateway_policy_tables\naws_api/ec2 describe_transit_gateway_policy_tables","url":"aws_api/ec2.html#describe_transit_gateway_policy_tables"},{"doc":"aws_api/ec2","title":"describe_transit_gateway_route_table_announcements","content":"pub fn describe_transit_gateway_route_table_announcements(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_transit_gateway_route_table_announcements\naws_api/ec2 describe_transit_gateway_route_table_announcements","url":"aws_api/ec2.html#describe_transit_gateway_route_table_announcements"},{"doc":"aws_api/ec2","title":"describe_transit_gateway_route_tables","content":"pub fn describe_transit_gateway_route_tables(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_transit_gateway_route_tables\naws_api/ec2 describe_transit_gateway_route_tables","url":"aws_api/ec2.html#describe_transit_gateway_route_tables"},{"doc":"aws_api/ec2","title":"describe_transit_gateway_vpc_attachments","content":"pub fn describe_transit_gateway_vpc_attachments(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_transit_gateway_vpc_attachments\naws_api/ec2 describe_transit_gateway_vpc_attachments","url":"aws_api/ec2.html#describe_transit_gateway_vpc_attachments"},{"doc":"aws_api/ec2","title":"describe_transit_gateways","content":"pub fn describe_transit_gateways(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_transit_gateways\naws_api/ec2 describe_transit_gateways","url":"aws_api/ec2.html#describe_transit_gateways"},{"doc":"aws_api/ec2","title":"describe_trunk_interface_associations","content":"pub fn describe_trunk_interface_associations(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_trunk_interface_associations\naws_api/ec2 describe_trunk_interface_associations","url":"aws_api/ec2.html#describe_trunk_interface_associations"},{"doc":"aws_api/ec2","title":"describe_verified_access_endpoints","content":"pub fn describe_verified_access_endpoints(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_verified_access_endpoints\naws_api/ec2 describe_verified_access_endpoints","url":"aws_api/ec2.html#describe_verified_access_endpoints"},{"doc":"aws_api/ec2","title":"describe_verified_access_groups","content":"pub fn describe_verified_access_groups(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_verified_access_groups\naws_api/ec2 describe_verified_access_groups","url":"aws_api/ec2.html#describe_verified_access_groups"},{"doc":"aws_api/ec2","title":"describe_verified_access_instance_logging_configurations","content":"pub fn describe_verified_access_instance_logging_configurations(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_verified_access_instance_logging_configurations\naws_api/ec2 describe_verified_access_instance_logging_configurations","url":"aws_api/ec2.html#describe_verified_access_instance_logging_configurations"},{"doc":"aws_api/ec2","title":"describe_verified_access_instances","content":"pub fn describe_verified_access_instances(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_verified_access_instances\naws_api/ec2 describe_verified_access_instances","url":"aws_api/ec2.html#describe_verified_access_instances"},{"doc":"aws_api/ec2","title":"describe_verified_access_trust_providers","content":"pub fn describe_verified_access_trust_providers(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_verified_access_trust_providers\naws_api/ec2 describe_verified_access_trust_providers","url":"aws_api/ec2.html#describe_verified_access_trust_providers"},{"doc":"aws_api/ec2","title":"describe_volume_attribute","content":"pub fn describe_volume_attribute(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_volume_attribute\naws_api/ec2 describe_volume_attribute","url":"aws_api/ec2.html#describe_volume_attribute"},{"doc":"aws_api/ec2","title":"describe_volume_status","content":"pub fn describe_volume_status(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_volume_status\naws_api/ec2 describe_volume_status","url":"aws_api/ec2.html#describe_volume_status"},{"doc":"aws_api/ec2","title":"describe_volumes","content":"pub fn describe_volumes(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_volumes\naws_api/ec2 describe_volumes","url":"aws_api/ec2.html#describe_volumes"},{"doc":"aws_api/ec2","title":"describe_volumes_modifications","content":"pub fn describe_volumes_modifications(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_volumes_modifications\naws_api/ec2 describe_volumes_modifications","url":"aws_api/ec2.html#describe_volumes_modifications"},{"doc":"aws_api/ec2","title":"describe_vpc_attribute","content":"pub fn describe_vpc_attribute(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_vpc_attribute\naws_api/ec2 describe_vpc_attribute","url":"aws_api/ec2.html#describe_vpc_attribute"},{"doc":"aws_api/ec2","title":"describe_vpc_classic_link","content":"pub fn describe_vpc_classic_link(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_vpc_classic_link\naws_api/ec2 describe_vpc_classic_link","url":"aws_api/ec2.html#describe_vpc_classic_link"},{"doc":"aws_api/ec2","title":"describe_vpc_classic_link_dns_support","content":"pub fn describe_vpc_classic_link_dns_support(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_vpc_classic_link_dns_support\naws_api/ec2 describe_vpc_classic_link_dns_support","url":"aws_api/ec2.html#describe_vpc_classic_link_dns_support"},{"doc":"aws_api/ec2","title":"describe_vpc_endpoint_connection_notifications","content":"pub fn describe_vpc_endpoint_connection_notifications(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_vpc_endpoint_connection_notifications\naws_api/ec2 describe_vpc_endpoint_connection_notifications","url":"aws_api/ec2.html#describe_vpc_endpoint_connection_notifications"},{"doc":"aws_api/ec2","title":"describe_vpc_endpoint_connections","content":"pub fn describe_vpc_endpoint_connections(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_vpc_endpoint_connections\naws_api/ec2 describe_vpc_endpoint_connections","url":"aws_api/ec2.html#describe_vpc_endpoint_connections"},{"doc":"aws_api/ec2","title":"describe_vpc_endpoint_service_configurations","content":"pub fn describe_vpc_endpoint_service_configurations(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_vpc_endpoint_service_configurations\naws_api/ec2 describe_vpc_endpoint_service_configurations","url":"aws_api/ec2.html#describe_vpc_endpoint_service_configurations"},{"doc":"aws_api/ec2","title":"describe_vpc_endpoint_service_permissions","content":"pub fn describe_vpc_endpoint_service_permissions(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_vpc_endpoint_service_permissions\naws_api/ec2 describe_vpc_endpoint_service_permissions","url":"aws_api/ec2.html#describe_vpc_endpoint_service_permissions"},{"doc":"aws_api/ec2","title":"describe_vpc_endpoint_services","content":"pub fn describe_vpc_endpoint_services(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_vpc_endpoint_services\naws_api/ec2 describe_vpc_endpoint_services","url":"aws_api/ec2.html#describe_vpc_endpoint_services"},{"doc":"aws_api/ec2","title":"describe_vpc_endpoints","content":"pub fn describe_vpc_endpoints(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_vpc_endpoints\naws_api/ec2 describe_vpc_endpoints","url":"aws_api/ec2.html#describe_vpc_endpoints"},{"doc":"aws_api/ec2","title":"describe_vpc_peering_connections","content":"pub fn describe_vpc_peering_connections(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_vpc_peering_connections\naws_api/ec2 describe_vpc_peering_connections","url":"aws_api/ec2.html#describe_vpc_peering_connections"},{"doc":"aws_api/ec2","title":"describe_vpcs","content":"pub fn describe_vpcs(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_vpcs\naws_api/ec2 describe_vpcs","url":"aws_api/ec2.html#describe_vpcs"},{"doc":"aws_api/ec2","title":"describe_vpn_connections","content":"pub fn describe_vpn_connections(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_vpn_connections\naws_api/ec2 describe_vpn_connections","url":"aws_api/ec2.html#describe_vpn_connections"},{"doc":"aws_api/ec2","title":"describe_vpn_gateways","content":"pub fn describe_vpn_gateways(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.describe_vpn_gateways\naws_api/ec2 describe_vpn_gateways","url":"aws_api/ec2.html#describe_vpn_gateways"},{"doc":"aws_api/ec2","title":"detach_classic_link_vpc","content":"pub fn detach_classic_link_vpc(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.detach_classic_link_vpc\naws_api/ec2 detach_classic_link_vpc","url":"aws_api/ec2.html#detach_classic_link_vpc"},{"doc":"aws_api/ec2","title":"detach_internet_gateway","content":"pub fn detach_internet_gateway(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.detach_internet_gateway\naws_api/ec2 detach_internet_gateway","url":"aws_api/ec2.html#detach_internet_gateway"},{"doc":"aws_api/ec2","title":"detach_network_interface","content":"pub fn detach_network_interface(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.detach_network_interface\naws_api/ec2 detach_network_interface","url":"aws_api/ec2.html#detach_network_interface"},{"doc":"aws_api/ec2","title":"detach_verified_access_trust_provider","content":"pub fn detach_verified_access_trust_provider(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.detach_verified_access_trust_provider\naws_api/ec2 detach_verified_access_trust_provider","url":"aws_api/ec2.html#detach_verified_access_trust_provider"},{"doc":"aws_api/ec2","title":"detach_volume","content":"pub fn detach_volume(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.detach_volume\naws_api/ec2 detach_volume","url":"aws_api/ec2.html#detach_volume"},{"doc":"aws_api/ec2","title":"detach_vpn_gateway","content":"pub fn detach_vpn_gateway(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.detach_vpn_gateway\naws_api/ec2 detach_vpn_gateway","url":"aws_api/ec2.html#detach_vpn_gateway"},{"doc":"aws_api/ec2","title":"disable_address_transfer","content":"pub fn disable_address_transfer(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.disable_address_transfer\naws_api/ec2 disable_address_transfer","url":"aws_api/ec2.html#disable_address_transfer"},{"doc":"aws_api/ec2","title":"disable_aws_network_performance_metric_subscription","content":"pub fn disable_aws_network_performance_metric_subscription(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.disable_aws_network_performance_metric_subscription\naws_api/ec2 disable_aws_network_performance_metric_subscription","url":"aws_api/ec2.html#disable_aws_network_performance_metric_subscription"},{"doc":"aws_api/ec2","title":"disable_ebs_encryption_by_default","content":"pub fn disable_ebs_encryption_by_default(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.disable_ebs_encryption_by_default\naws_api/ec2 disable_ebs_encryption_by_default","url":"aws_api/ec2.html#disable_ebs_encryption_by_default"},{"doc":"aws_api/ec2","title":"disable_fast_launch","content":"pub fn disable_fast_launch(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.disable_fast_launch\naws_api/ec2 disable_fast_launch","url":"aws_api/ec2.html#disable_fast_launch"},{"doc":"aws_api/ec2","title":"disable_fast_snapshot_restores","content":"pub fn disable_fast_snapshot_restores(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.disable_fast_snapshot_restores\naws_api/ec2 disable_fast_snapshot_restores","url":"aws_api/ec2.html#disable_fast_snapshot_restores"},{"doc":"aws_api/ec2","title":"disable_image","content":"pub fn disable_image(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.disable_image\naws_api/ec2 disable_image","url":"aws_api/ec2.html#disable_image"},{"doc":"aws_api/ec2","title":"disable_image_block_public_access","content":"pub fn disable_image_block_public_access(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.disable_image_block_public_access\naws_api/ec2 disable_image_block_public_access","url":"aws_api/ec2.html#disable_image_block_public_access"},{"doc":"aws_api/ec2","title":"disable_image_deprecation","content":"pub fn disable_image_deprecation(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.disable_image_deprecation\naws_api/ec2 disable_image_deprecation","url":"aws_api/ec2.html#disable_image_deprecation"},{"doc":"aws_api/ec2","title":"disable_image_deregistration_protection","content":"pub fn disable_image_deregistration_protection(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.disable_image_deregistration_protection\naws_api/ec2 disable_image_deregistration_protection","url":"aws_api/ec2.html#disable_image_deregistration_protection"},{"doc":"aws_api/ec2","title":"disable_ipam_organization_admin_account","content":"pub fn disable_ipam_organization_admin_account(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.disable_ipam_organization_admin_account\naws_api/ec2 disable_ipam_organization_admin_account","url":"aws_api/ec2.html#disable_ipam_organization_admin_account"},{"doc":"aws_api/ec2","title":"disable_serial_console_access","content":"pub fn disable_serial_console_access(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.disable_serial_console_access\naws_api/ec2 disable_serial_console_access","url":"aws_api/ec2.html#disable_serial_console_access"},{"doc":"aws_api/ec2","title":"disable_snapshot_block_public_access","content":"pub fn disable_snapshot_block_public_access(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.disable_snapshot_block_public_access\naws_api/ec2 disable_snapshot_block_public_access","url":"aws_api/ec2.html#disable_snapshot_block_public_access"},{"doc":"aws_api/ec2","title":"disable_transit_gateway_route_table_propagation","content":"pub fn disable_transit_gateway_route_table_propagation(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.disable_transit_gateway_route_table_propagation\naws_api/ec2 disable_transit_gateway_route_table_propagation","url":"aws_api/ec2.html#disable_transit_gateway_route_table_propagation"},{"doc":"aws_api/ec2","title":"disable_vgw_route_propagation","content":"pub fn disable_vgw_route_propagation(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.disable_vgw_route_propagation\naws_api/ec2 disable_vgw_route_propagation","url":"aws_api/ec2.html#disable_vgw_route_propagation"},{"doc":"aws_api/ec2","title":"disable_vpc_classic_link","content":"pub fn disable_vpc_classic_link(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.disable_vpc_classic_link\naws_api/ec2 disable_vpc_classic_link","url":"aws_api/ec2.html#disable_vpc_classic_link"},{"doc":"aws_api/ec2","title":"disable_vpc_classic_link_dns_support","content":"pub fn disable_vpc_classic_link_dns_support(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.disable_vpc_classic_link_dns_support\naws_api/ec2 disable_vpc_classic_link_dns_support","url":"aws_api/ec2.html#disable_vpc_classic_link_dns_support"},{"doc":"aws_api/ec2","title":"disassociate_address","content":"pub fn disassociate_address(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.disassociate_address\naws_api/ec2 disassociate_address","url":"aws_api/ec2.html#disassociate_address"},{"doc":"aws_api/ec2","title":"disassociate_client_vpn_target_network","content":"pub fn disassociate_client_vpn_target_network(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.disassociate_client_vpn_target_network\naws_api/ec2 disassociate_client_vpn_target_network","url":"aws_api/ec2.html#disassociate_client_vpn_target_network"},{"doc":"aws_api/ec2","title":"disassociate_enclave_certificate_iam_role","content":"pub fn disassociate_enclave_certificate_iam_role(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.disassociate_enclave_certificate_iam_role\naws_api/ec2 disassociate_enclave_certificate_iam_role","url":"aws_api/ec2.html#disassociate_enclave_certificate_iam_role"},{"doc":"aws_api/ec2","title":"disassociate_iam_instance_profile","content":"pub fn disassociate_iam_instance_profile(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.disassociate_iam_instance_profile\naws_api/ec2 disassociate_iam_instance_profile","url":"aws_api/ec2.html#disassociate_iam_instance_profile"},{"doc":"aws_api/ec2","title":"disassociate_instance_event_window","content":"pub fn disassociate_instance_event_window(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.disassociate_instance_event_window\naws_api/ec2 disassociate_instance_event_window","url":"aws_api/ec2.html#disassociate_instance_event_window"},{"doc":"aws_api/ec2","title":"disassociate_ipam_byoasn","content":"pub fn disassociate_ipam_byoasn(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.disassociate_ipam_byoasn\naws_api/ec2 disassociate_ipam_byoasn","url":"aws_api/ec2.html#disassociate_ipam_byoasn"},{"doc":"aws_api/ec2","title":"disassociate_ipam_resource_discovery","content":"pub fn disassociate_ipam_resource_discovery(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.disassociate_ipam_resource_discovery\naws_api/ec2 disassociate_ipam_resource_discovery","url":"aws_api/ec2.html#disassociate_ipam_resource_discovery"},{"doc":"aws_api/ec2","title":"disassociate_nat_gateway_address","content":"pub fn disassociate_nat_gateway_address(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.disassociate_nat_gateway_address\naws_api/ec2 disassociate_nat_gateway_address","url":"aws_api/ec2.html#disassociate_nat_gateway_address"},{"doc":"aws_api/ec2","title":"disassociate_route_table","content":"pub fn disassociate_route_table(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.disassociate_route_table\naws_api/ec2 disassociate_route_table","url":"aws_api/ec2.html#disassociate_route_table"},{"doc":"aws_api/ec2","title":"disassociate_subnet_cidr_block","content":"pub fn disassociate_subnet_cidr_block(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.disassociate_subnet_cidr_block\naws_api/ec2 disassociate_subnet_cidr_block","url":"aws_api/ec2.html#disassociate_subnet_cidr_block"},{"doc":"aws_api/ec2","title":"disassociate_transit_gateway_multicast_domain","content":"pub fn disassociate_transit_gateway_multicast_domain(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.disassociate_transit_gateway_multicast_domain\naws_api/ec2 disassociate_transit_gateway_multicast_domain","url":"aws_api/ec2.html#disassociate_transit_gateway_multicast_domain"},{"doc":"aws_api/ec2","title":"disassociate_transit_gateway_policy_table","content":"pub fn disassociate_transit_gateway_policy_table(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.disassociate_transit_gateway_policy_table\naws_api/ec2 disassociate_transit_gateway_policy_table","url":"aws_api/ec2.html#disassociate_transit_gateway_policy_table"},{"doc":"aws_api/ec2","title":"disassociate_transit_gateway_route_table","content":"pub fn disassociate_transit_gateway_route_table(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.disassociate_transit_gateway_route_table\naws_api/ec2 disassociate_transit_gateway_route_table","url":"aws_api/ec2.html#disassociate_transit_gateway_route_table"},{"doc":"aws_api/ec2","title":"disassociate_trunk_interface","content":"pub fn disassociate_trunk_interface(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.disassociate_trunk_interface\naws_api/ec2 disassociate_trunk_interface","url":"aws_api/ec2.html#disassociate_trunk_interface"},{"doc":"aws_api/ec2","title":"disassociate_vpc_cidr_block","content":"pub fn disassociate_vpc_cidr_block(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.disassociate_vpc_cidr_block\naws_api/ec2 disassociate_vpc_cidr_block","url":"aws_api/ec2.html#disassociate_vpc_cidr_block"},{"doc":"aws_api/ec2","title":"enable_address_transfer","content":"pub fn enable_address_transfer(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.enable_address_transfer\naws_api/ec2 enable_address_transfer","url":"aws_api/ec2.html#enable_address_transfer"},{"doc":"aws_api/ec2","title":"enable_aws_network_performance_metric_subscription","content":"pub fn enable_aws_network_performance_metric_subscription(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.enable_aws_network_performance_metric_subscription\naws_api/ec2 enable_aws_network_performance_metric_subscription","url":"aws_api/ec2.html#enable_aws_network_performance_metric_subscription"},{"doc":"aws_api/ec2","title":"enable_ebs_encryption_by_default","content":"pub fn enable_ebs_encryption_by_default(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.enable_ebs_encryption_by_default\naws_api/ec2 enable_ebs_encryption_by_default","url":"aws_api/ec2.html#enable_ebs_encryption_by_default"},{"doc":"aws_api/ec2","title":"enable_fast_launch","content":"pub fn enable_fast_launch(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.enable_fast_launch\naws_api/ec2 enable_fast_launch","url":"aws_api/ec2.html#enable_fast_launch"},{"doc":"aws_api/ec2","title":"enable_fast_snapshot_restores","content":"pub fn enable_fast_snapshot_restores(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.enable_fast_snapshot_restores\naws_api/ec2 enable_fast_snapshot_restores","url":"aws_api/ec2.html#enable_fast_snapshot_restores"},{"doc":"aws_api/ec2","title":"enable_image","content":"pub fn enable_image(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.enable_image\naws_api/ec2 enable_image","url":"aws_api/ec2.html#enable_image"},{"doc":"aws_api/ec2","title":"enable_image_block_public_access","content":"pub fn enable_image_block_public_access(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.enable_image_block_public_access\naws_api/ec2 enable_image_block_public_access","url":"aws_api/ec2.html#enable_image_block_public_access"},{"doc":"aws_api/ec2","title":"enable_image_deprecation","content":"pub fn enable_image_deprecation(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.enable_image_deprecation\naws_api/ec2 enable_image_deprecation","url":"aws_api/ec2.html#enable_image_deprecation"},{"doc":"aws_api/ec2","title":"enable_image_deregistration_protection","content":"pub fn enable_image_deregistration_protection(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.enable_image_deregistration_protection\naws_api/ec2 enable_image_deregistration_protection","url":"aws_api/ec2.html#enable_image_deregistration_protection"},{"doc":"aws_api/ec2","title":"enable_ipam_organization_admin_account","content":"pub fn enable_ipam_organization_admin_account(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.enable_ipam_organization_admin_account\naws_api/ec2 enable_ipam_organization_admin_account","url":"aws_api/ec2.html#enable_ipam_organization_admin_account"},{"doc":"aws_api/ec2","title":"enable_reachability_analyzer_organization_sharing","content":"pub fn enable_reachability_analyzer_organization_sharing(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.enable_reachability_analyzer_organization_sharing\naws_api/ec2 enable_reachability_analyzer_organization_sharing","url":"aws_api/ec2.html#enable_reachability_analyzer_organization_sharing"},{"doc":"aws_api/ec2","title":"enable_serial_console_access","content":"pub fn enable_serial_console_access(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.enable_serial_console_access\naws_api/ec2 enable_serial_console_access","url":"aws_api/ec2.html#enable_serial_console_access"},{"doc":"aws_api/ec2","title":"enable_snapshot_block_public_access","content":"pub fn enable_snapshot_block_public_access(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.enable_snapshot_block_public_access\naws_api/ec2 enable_snapshot_block_public_access","url":"aws_api/ec2.html#enable_snapshot_block_public_access"},{"doc":"aws_api/ec2","title":"enable_transit_gateway_route_table_propagation","content":"pub fn enable_transit_gateway_route_table_propagation(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.enable_transit_gateway_route_table_propagation\naws_api/ec2 enable_transit_gateway_route_table_propagation","url":"aws_api/ec2.html#enable_transit_gateway_route_table_propagation"},{"doc":"aws_api/ec2","title":"enable_vgw_route_propagation","content":"pub fn enable_vgw_route_propagation(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.enable_vgw_route_propagation\naws_api/ec2 enable_vgw_route_propagation","url":"aws_api/ec2.html#enable_vgw_route_propagation"},{"doc":"aws_api/ec2","title":"enable_volume_io","content":"pub fn enable_volume_io(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.enable_volume_io\naws_api/ec2 enable_volume_io","url":"aws_api/ec2.html#enable_volume_io"},{"doc":"aws_api/ec2","title":"enable_vpc_classic_link","content":"pub fn enable_vpc_classic_link(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.enable_vpc_classic_link\naws_api/ec2 enable_vpc_classic_link","url":"aws_api/ec2.html#enable_vpc_classic_link"},{"doc":"aws_api/ec2","title":"enable_vpc_classic_link_dns_support","content":"pub fn enable_vpc_classic_link_dns_support(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.enable_vpc_classic_link_dns_support\naws_api/ec2 enable_vpc_classic_link_dns_support","url":"aws_api/ec2.html#enable_vpc_classic_link_dns_support"},{"doc":"aws_api/ec2","title":"export_client_vpn_client_certificate_revocation_list","content":"pub fn export_client_vpn_client_certificate_revocation_list(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.export_client_vpn_client_certificate_revocation_list\naws_api/ec2 export_client_vpn_client_certificate_revocation_list","url":"aws_api/ec2.html#export_client_vpn_client_certificate_revocation_list"},{"doc":"aws_api/ec2","title":"export_client_vpn_client_configuration","content":"pub fn export_client_vpn_client_configuration(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.export_client_vpn_client_configuration\naws_api/ec2 export_client_vpn_client_configuration","url":"aws_api/ec2.html#export_client_vpn_client_configuration"},{"doc":"aws_api/ec2","title":"export_image","content":"pub fn export_image(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.export_image\naws_api/ec2 export_image","url":"aws_api/ec2.html#export_image"},{"doc":"aws_api/ec2","title":"export_transit_gateway_routes","content":"pub fn export_transit_gateway_routes(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.export_transit_gateway_routes\naws_api/ec2 export_transit_gateway_routes","url":"aws_api/ec2.html#export_transit_gateway_routes"},{"doc":"aws_api/ec2","title":"get_associated_enclave_certificate_iam_roles","content":"pub fn get_associated_enclave_certificate_iam_roles(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.get_associated_enclave_certificate_iam_roles\naws_api/ec2 get_associated_enclave_certificate_iam_roles","url":"aws_api/ec2.html#get_associated_enclave_certificate_iam_roles"},{"doc":"aws_api/ec2","title":"get_associated_ipv6_pool_cidrs","content":"pub fn get_associated_ipv6_pool_cidrs(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.get_associated_ipv6_pool_cidrs\naws_api/ec2 get_associated_ipv6_pool_cidrs","url":"aws_api/ec2.html#get_associated_ipv6_pool_cidrs"},{"doc":"aws_api/ec2","title":"get_aws_network_performance_data","content":"pub fn get_aws_network_performance_data(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.get_aws_network_performance_data\naws_api/ec2 get_aws_network_performance_data","url":"aws_api/ec2.html#get_aws_network_performance_data"},{"doc":"aws_api/ec2","title":"get_capacity_reservation_usage","content":"pub fn get_capacity_reservation_usage(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.get_capacity_reservation_usage\naws_api/ec2 get_capacity_reservation_usage","url":"aws_api/ec2.html#get_capacity_reservation_usage"},{"doc":"aws_api/ec2","title":"get_coip_pool_usage","content":"pub fn get_coip_pool_usage(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.get_coip_pool_usage\naws_api/ec2 get_coip_pool_usage","url":"aws_api/ec2.html#get_coip_pool_usage"},{"doc":"aws_api/ec2","title":"get_console_output","content":"pub fn get_console_output(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.get_console_output\naws_api/ec2 get_console_output","url":"aws_api/ec2.html#get_console_output"},{"doc":"aws_api/ec2","title":"get_console_screenshot","content":"pub fn get_console_screenshot(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.get_console_screenshot\naws_api/ec2 get_console_screenshot","url":"aws_api/ec2.html#get_console_screenshot"},{"doc":"aws_api/ec2","title":"get_default_credit_specification","content":"pub fn get_default_credit_specification(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.get_default_credit_specification\naws_api/ec2 get_default_credit_specification","url":"aws_api/ec2.html#get_default_credit_specification"},{"doc":"aws_api/ec2","title":"get_ebs_default_kms_key_id","content":"pub fn get_ebs_default_kms_key_id(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.get_ebs_default_kms_key_id\naws_api/ec2 get_ebs_default_kms_key_id","url":"aws_api/ec2.html#get_ebs_default_kms_key_id"},{"doc":"aws_api/ec2","title":"get_ebs_encryption_by_default","content":"pub fn get_ebs_encryption_by_default(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.get_ebs_encryption_by_default\naws_api/ec2 get_ebs_encryption_by_default","url":"aws_api/ec2.html#get_ebs_encryption_by_default"},{"doc":"aws_api/ec2","title":"get_flow_logs_integration_template","content":"pub fn get_flow_logs_integration_template(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.get_flow_logs_integration_template\naws_api/ec2 get_flow_logs_integration_template","url":"aws_api/ec2.html#get_flow_logs_integration_template"},{"doc":"aws_api/ec2","title":"get_groups_for_capacity_reservation","content":"pub fn get_groups_for_capacity_reservation(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.get_groups_for_capacity_reservation\naws_api/ec2 get_groups_for_capacity_reservation","url":"aws_api/ec2.html#get_groups_for_capacity_reservation"},{"doc":"aws_api/ec2","title":"get_host_reservation_purchase_preview","content":"pub fn get_host_reservation_purchase_preview(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.get_host_reservation_purchase_preview\naws_api/ec2 get_host_reservation_purchase_preview","url":"aws_api/ec2.html#get_host_reservation_purchase_preview"},{"doc":"aws_api/ec2","title":"get_image_block_public_access_state","content":"pub fn get_image_block_public_access_state(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.get_image_block_public_access_state\naws_api/ec2 get_image_block_public_access_state","url":"aws_api/ec2.html#get_image_block_public_access_state"},{"doc":"aws_api/ec2","title":"get_instance_metadata_defaults","content":"pub fn get_instance_metadata_defaults(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.get_instance_metadata_defaults\naws_api/ec2 get_instance_metadata_defaults","url":"aws_api/ec2.html#get_instance_metadata_defaults"},{"doc":"aws_api/ec2","title":"get_instance_tpm_ek_pub","content":"pub fn get_instance_tpm_ek_pub(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.get_instance_tpm_ek_pub\naws_api/ec2 get_instance_tpm_ek_pub","url":"aws_api/ec2.html#get_instance_tpm_ek_pub"},{"doc":"aws_api/ec2","title":"get_instance_types_from_instance_requirements","content":"pub fn get_instance_types_from_instance_requirements(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.get_instance_types_from_instance_requirements\naws_api/ec2 get_instance_types_from_instance_requirements","url":"aws_api/ec2.html#get_instance_types_from_instance_requirements"},{"doc":"aws_api/ec2","title":"get_instance_uefi_data","content":"pub fn get_instance_uefi_data(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.get_instance_uefi_data\naws_api/ec2 get_instance_uefi_data","url":"aws_api/ec2.html#get_instance_uefi_data"},{"doc":"aws_api/ec2","title":"get_ipam_address_history","content":"pub fn get_ipam_address_history(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.get_ipam_address_history\naws_api/ec2 get_ipam_address_history","url":"aws_api/ec2.html#get_ipam_address_history"},{"doc":"aws_api/ec2","title":"get_ipam_discovered_accounts","content":"pub fn get_ipam_discovered_accounts(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.get_ipam_discovered_accounts\naws_api/ec2 get_ipam_discovered_accounts","url":"aws_api/ec2.html#get_ipam_discovered_accounts"},{"doc":"aws_api/ec2","title":"get_ipam_discovered_public_addresses","content":"pub fn get_ipam_discovered_public_addresses(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.get_ipam_discovered_public_addresses\naws_api/ec2 get_ipam_discovered_public_addresses","url":"aws_api/ec2.html#get_ipam_discovered_public_addresses"},{"doc":"aws_api/ec2","title":"get_ipam_discovered_resource_cidrs","content":"pub fn get_ipam_discovered_resource_cidrs(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.get_ipam_discovered_resource_cidrs\naws_api/ec2 get_ipam_discovered_resource_cidrs","url":"aws_api/ec2.html#get_ipam_discovered_resource_cidrs"},{"doc":"aws_api/ec2","title":"get_ipam_pool_allocations","content":"pub fn get_ipam_pool_allocations(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.get_ipam_pool_allocations\naws_api/ec2 get_ipam_pool_allocations","url":"aws_api/ec2.html#get_ipam_pool_allocations"},{"doc":"aws_api/ec2","title":"get_ipam_pool_cidrs","content":"pub fn get_ipam_pool_cidrs(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.get_ipam_pool_cidrs\naws_api/ec2 get_ipam_pool_cidrs","url":"aws_api/ec2.html#get_ipam_pool_cidrs"},{"doc":"aws_api/ec2","title":"get_ipam_resource_cidrs","content":"pub fn get_ipam_resource_cidrs(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.get_ipam_resource_cidrs\naws_api/ec2 get_ipam_resource_cidrs","url":"aws_api/ec2.html#get_ipam_resource_cidrs"},{"doc":"aws_api/ec2","title":"get_launch_template_data","content":"pub fn get_launch_template_data(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.get_launch_template_data\naws_api/ec2 get_launch_template_data","url":"aws_api/ec2.html#get_launch_template_data"},{"doc":"aws_api/ec2","title":"get_managed_prefix_list_associations","content":"pub fn get_managed_prefix_list_associations(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.get_managed_prefix_list_associations\naws_api/ec2 get_managed_prefix_list_associations","url":"aws_api/ec2.html#get_managed_prefix_list_associations"},{"doc":"aws_api/ec2","title":"get_managed_prefix_list_entries","content":"pub fn get_managed_prefix_list_entries(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.get_managed_prefix_list_entries\naws_api/ec2 get_managed_prefix_list_entries","url":"aws_api/ec2.html#get_managed_prefix_list_entries"},{"doc":"aws_api/ec2","title":"get_network_insights_access_scope_analysis_findings","content":"pub fn get_network_insights_access_scope_analysis_findings(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.get_network_insights_access_scope_analysis_findings\naws_api/ec2 get_network_insights_access_scope_analysis_findings","url":"aws_api/ec2.html#get_network_insights_access_scope_analysis_findings"},{"doc":"aws_api/ec2","title":"get_network_insights_access_scope_content","content":"pub fn get_network_insights_access_scope_content(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.get_network_insights_access_scope_content\naws_api/ec2 get_network_insights_access_scope_content","url":"aws_api/ec2.html#get_network_insights_access_scope_content"},{"doc":"aws_api/ec2","title":"get_password_data","content":"pub fn get_password_data(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.get_password_data\naws_api/ec2 get_password_data","url":"aws_api/ec2.html#get_password_data"},{"doc":"aws_api/ec2","title":"get_reserved_instances_exchange_quote","content":"pub fn get_reserved_instances_exchange_quote(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.get_reserved_instances_exchange_quote\naws_api/ec2 get_reserved_instances_exchange_quote","url":"aws_api/ec2.html#get_reserved_instances_exchange_quote"},{"doc":"aws_api/ec2","title":"get_security_groups_for_vpc","content":"pub fn get_security_groups_for_vpc(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.get_security_groups_for_vpc\naws_api/ec2 get_security_groups_for_vpc","url":"aws_api/ec2.html#get_security_groups_for_vpc"},{"doc":"aws_api/ec2","title":"get_serial_console_access_status","content":"pub fn get_serial_console_access_status(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.get_serial_console_access_status\naws_api/ec2 get_serial_console_access_status","url":"aws_api/ec2.html#get_serial_console_access_status"},{"doc":"aws_api/ec2","title":"get_snapshot_block_public_access_state","content":"pub fn get_snapshot_block_public_access_state(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.get_snapshot_block_public_access_state\naws_api/ec2 get_snapshot_block_public_access_state","url":"aws_api/ec2.html#get_snapshot_block_public_access_state"},{"doc":"aws_api/ec2","title":"get_spot_placement_scores","content":"pub fn get_spot_placement_scores(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.get_spot_placement_scores\naws_api/ec2 get_spot_placement_scores","url":"aws_api/ec2.html#get_spot_placement_scores"},{"doc":"aws_api/ec2","title":"get_subnet_cidr_reservations","content":"pub fn get_subnet_cidr_reservations(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.get_subnet_cidr_reservations\naws_api/ec2 get_subnet_cidr_reservations","url":"aws_api/ec2.html#get_subnet_cidr_reservations"},{"doc":"aws_api/ec2","title":"get_transit_gateway_attachment_propagations","content":"pub fn get_transit_gateway_attachment_propagations(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.get_transit_gateway_attachment_propagations\naws_api/ec2 get_transit_gateway_attachment_propagations","url":"aws_api/ec2.html#get_transit_gateway_attachment_propagations"},{"doc":"aws_api/ec2","title":"get_transit_gateway_multicast_domain_associations","content":"pub fn get_transit_gateway_multicast_domain_associations(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.get_transit_gateway_multicast_domain_associations\naws_api/ec2 get_transit_gateway_multicast_domain_associations","url":"aws_api/ec2.html#get_transit_gateway_multicast_domain_associations"},{"doc":"aws_api/ec2","title":"get_transit_gateway_policy_table_associations","content":"pub fn get_transit_gateway_policy_table_associations(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.get_transit_gateway_policy_table_associations\naws_api/ec2 get_transit_gateway_policy_table_associations","url":"aws_api/ec2.html#get_transit_gateway_policy_table_associations"},{"doc":"aws_api/ec2","title":"get_transit_gateway_policy_table_entries","content":"pub fn get_transit_gateway_policy_table_entries(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.get_transit_gateway_policy_table_entries\naws_api/ec2 get_transit_gateway_policy_table_entries","url":"aws_api/ec2.html#get_transit_gateway_policy_table_entries"},{"doc":"aws_api/ec2","title":"get_transit_gateway_prefix_list_references","content":"pub fn get_transit_gateway_prefix_list_references(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.get_transit_gateway_prefix_list_references\naws_api/ec2 get_transit_gateway_prefix_list_references","url":"aws_api/ec2.html#get_transit_gateway_prefix_list_references"},{"doc":"aws_api/ec2","title":"get_transit_gateway_route_table_associations","content":"pub fn get_transit_gateway_route_table_associations(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.get_transit_gateway_route_table_associations\naws_api/ec2 get_transit_gateway_route_table_associations","url":"aws_api/ec2.html#get_transit_gateway_route_table_associations"},{"doc":"aws_api/ec2","title":"get_transit_gateway_route_table_propagations","content":"pub fn get_transit_gateway_route_table_propagations(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.get_transit_gateway_route_table_propagations\naws_api/ec2 get_transit_gateway_route_table_propagations","url":"aws_api/ec2.html#get_transit_gateway_route_table_propagations"},{"doc":"aws_api/ec2","title":"get_verified_access_endpoint_policy","content":"pub fn get_verified_access_endpoint_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.get_verified_access_endpoint_policy\naws_api/ec2 get_verified_access_endpoint_policy","url":"aws_api/ec2.html#get_verified_access_endpoint_policy"},{"doc":"aws_api/ec2","title":"get_verified_access_group_policy","content":"pub fn get_verified_access_group_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.get_verified_access_group_policy\naws_api/ec2 get_verified_access_group_policy","url":"aws_api/ec2.html#get_verified_access_group_policy"},{"doc":"aws_api/ec2","title":"get_vpn_connection_device_sample_configuration","content":"pub fn get_vpn_connection_device_sample_configuration(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.get_vpn_connection_device_sample_configuration\naws_api/ec2 get_vpn_connection_device_sample_configuration","url":"aws_api/ec2.html#get_vpn_connection_device_sample_configuration"},{"doc":"aws_api/ec2","title":"get_vpn_connection_device_types","content":"pub fn get_vpn_connection_device_types(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.get_vpn_connection_device_types\naws_api/ec2 get_vpn_connection_device_types","url":"aws_api/ec2.html#get_vpn_connection_device_types"},{"doc":"aws_api/ec2","title":"get_vpn_tunnel_replacement_status","content":"pub fn get_vpn_tunnel_replacement_status(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.get_vpn_tunnel_replacement_status\naws_api/ec2 get_vpn_tunnel_replacement_status","url":"aws_api/ec2.html#get_vpn_tunnel_replacement_status"},{"doc":"aws_api/ec2","title":"import_client_vpn_client_certificate_revocation_list","content":"pub fn import_client_vpn_client_certificate_revocation_list(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.import_client_vpn_client_certificate_revocation_list\naws_api/ec2 import_client_vpn_client_certificate_revocation_list","url":"aws_api/ec2.html#import_client_vpn_client_certificate_revocation_list"},{"doc":"aws_api/ec2","title":"import_image","content":"pub fn import_image(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.import_image\naws_api/ec2 import_image","url":"aws_api/ec2.html#import_image"},{"doc":"aws_api/ec2","title":"import_instance","content":"pub fn import_instance(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.import_instance\naws_api/ec2 import_instance","url":"aws_api/ec2.html#import_instance"},{"doc":"aws_api/ec2","title":"import_key_pair","content":"pub fn import_key_pair(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.import_key_pair\naws_api/ec2 import_key_pair","url":"aws_api/ec2.html#import_key_pair"},{"doc":"aws_api/ec2","title":"import_snapshot","content":"pub fn import_snapshot(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.import_snapshot\naws_api/ec2 import_snapshot","url":"aws_api/ec2.html#import_snapshot"},{"doc":"aws_api/ec2","title":"import_volume","content":"pub fn import_volume(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.import_volume\naws_api/ec2 import_volume","url":"aws_api/ec2.html#import_volume"},{"doc":"aws_api/ec2","title":"list_images_in_recycle_bin","content":"pub fn list_images_in_recycle_bin(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.list_images_in_recycle_bin\naws_api/ec2 list_images_in_recycle_bin","url":"aws_api/ec2.html#list_images_in_recycle_bin"},{"doc":"aws_api/ec2","title":"list_snapshots_in_recycle_bin","content":"pub fn list_snapshots_in_recycle_bin(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.list_snapshots_in_recycle_bin\naws_api/ec2 list_snapshots_in_recycle_bin","url":"aws_api/ec2.html#list_snapshots_in_recycle_bin"},{"doc":"aws_api/ec2","title":"lock_snapshot","content":"pub fn lock_snapshot(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.lock_snapshot\naws_api/ec2 lock_snapshot","url":"aws_api/ec2.html#lock_snapshot"},{"doc":"aws_api/ec2","title":"modify_address_attribute","content":"pub fn modify_address_attribute(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_address_attribute\naws_api/ec2 modify_address_attribute","url":"aws_api/ec2.html#modify_address_attribute"},{"doc":"aws_api/ec2","title":"modify_availability_zone_group","content":"pub fn modify_availability_zone_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_availability_zone_group\naws_api/ec2 modify_availability_zone_group","url":"aws_api/ec2.html#modify_availability_zone_group"},{"doc":"aws_api/ec2","title":"modify_capacity_reservation","content":"pub fn modify_capacity_reservation(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_capacity_reservation\naws_api/ec2 modify_capacity_reservation","url":"aws_api/ec2.html#modify_capacity_reservation"},{"doc":"aws_api/ec2","title":"modify_capacity_reservation_fleet","content":"pub fn modify_capacity_reservation_fleet(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_capacity_reservation_fleet\naws_api/ec2 modify_capacity_reservation_fleet","url":"aws_api/ec2.html#modify_capacity_reservation_fleet"},{"doc":"aws_api/ec2","title":"modify_client_vpn_endpoint","content":"pub fn modify_client_vpn_endpoint(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_client_vpn_endpoint\naws_api/ec2 modify_client_vpn_endpoint","url":"aws_api/ec2.html#modify_client_vpn_endpoint"},{"doc":"aws_api/ec2","title":"modify_default_credit_specification","content":"pub fn modify_default_credit_specification(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_default_credit_specification\naws_api/ec2 modify_default_credit_specification","url":"aws_api/ec2.html#modify_default_credit_specification"},{"doc":"aws_api/ec2","title":"modify_ebs_default_kms_key_id","content":"pub fn modify_ebs_default_kms_key_id(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_ebs_default_kms_key_id\naws_api/ec2 modify_ebs_default_kms_key_id","url":"aws_api/ec2.html#modify_ebs_default_kms_key_id"},{"doc":"aws_api/ec2","title":"modify_fleet","content":"pub fn modify_fleet(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_fleet\naws_api/ec2 modify_fleet","url":"aws_api/ec2.html#modify_fleet"},{"doc":"aws_api/ec2","title":"modify_fpga_image_attribute","content":"pub fn modify_fpga_image_attribute(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_fpga_image_attribute\naws_api/ec2 modify_fpga_image_attribute","url":"aws_api/ec2.html#modify_fpga_image_attribute"},{"doc":"aws_api/ec2","title":"modify_hosts","content":"pub fn modify_hosts(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_hosts\naws_api/ec2 modify_hosts","url":"aws_api/ec2.html#modify_hosts"},{"doc":"aws_api/ec2","title":"modify_id_format","content":"pub fn modify_id_format(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_id_format\naws_api/ec2 modify_id_format","url":"aws_api/ec2.html#modify_id_format"},{"doc":"aws_api/ec2","title":"modify_identity_id_format","content":"pub fn modify_identity_id_format(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_identity_id_format\naws_api/ec2 modify_identity_id_format","url":"aws_api/ec2.html#modify_identity_id_format"},{"doc":"aws_api/ec2","title":"modify_image_attribute","content":"pub fn modify_image_attribute(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_image_attribute\naws_api/ec2 modify_image_attribute","url":"aws_api/ec2.html#modify_image_attribute"},{"doc":"aws_api/ec2","title":"modify_instance_attribute","content":"pub fn modify_instance_attribute(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_instance_attribute\naws_api/ec2 modify_instance_attribute","url":"aws_api/ec2.html#modify_instance_attribute"},{"doc":"aws_api/ec2","title":"modify_instance_capacity_reservation_attributes","content":"pub fn modify_instance_capacity_reservation_attributes(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_instance_capacity_reservation_attributes\naws_api/ec2 modify_instance_capacity_reservation_attributes","url":"aws_api/ec2.html#modify_instance_capacity_reservation_attributes"},{"doc":"aws_api/ec2","title":"modify_instance_credit_specification","content":"pub fn modify_instance_credit_specification(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_instance_credit_specification\naws_api/ec2 modify_instance_credit_specification","url":"aws_api/ec2.html#modify_instance_credit_specification"},{"doc":"aws_api/ec2","title":"modify_instance_event_start_time","content":"pub fn modify_instance_event_start_time(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_instance_event_start_time\naws_api/ec2 modify_instance_event_start_time","url":"aws_api/ec2.html#modify_instance_event_start_time"},{"doc":"aws_api/ec2","title":"modify_instance_event_window","content":"pub fn modify_instance_event_window(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_instance_event_window\naws_api/ec2 modify_instance_event_window","url":"aws_api/ec2.html#modify_instance_event_window"},{"doc":"aws_api/ec2","title":"modify_instance_maintenance_options","content":"pub fn modify_instance_maintenance_options(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_instance_maintenance_options\naws_api/ec2 modify_instance_maintenance_options","url":"aws_api/ec2.html#modify_instance_maintenance_options"},{"doc":"aws_api/ec2","title":"modify_instance_metadata_defaults","content":"pub fn modify_instance_metadata_defaults(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_instance_metadata_defaults\naws_api/ec2 modify_instance_metadata_defaults","url":"aws_api/ec2.html#modify_instance_metadata_defaults"},{"doc":"aws_api/ec2","title":"modify_instance_metadata_options","content":"pub fn modify_instance_metadata_options(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_instance_metadata_options\naws_api/ec2 modify_instance_metadata_options","url":"aws_api/ec2.html#modify_instance_metadata_options"},{"doc":"aws_api/ec2","title":"modify_instance_placement","content":"pub fn modify_instance_placement(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_instance_placement\naws_api/ec2 modify_instance_placement","url":"aws_api/ec2.html#modify_instance_placement"},{"doc":"aws_api/ec2","title":"modify_ipam","content":"pub fn modify_ipam(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_ipam\naws_api/ec2 modify_ipam","url":"aws_api/ec2.html#modify_ipam"},{"doc":"aws_api/ec2","title":"modify_ipam_pool","content":"pub fn modify_ipam_pool(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_ipam_pool\naws_api/ec2 modify_ipam_pool","url":"aws_api/ec2.html#modify_ipam_pool"},{"doc":"aws_api/ec2","title":"modify_ipam_resource_cidr","content":"pub fn modify_ipam_resource_cidr(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_ipam_resource_cidr\naws_api/ec2 modify_ipam_resource_cidr","url":"aws_api/ec2.html#modify_ipam_resource_cidr"},{"doc":"aws_api/ec2","title":"modify_ipam_resource_discovery","content":"pub fn modify_ipam_resource_discovery(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_ipam_resource_discovery\naws_api/ec2 modify_ipam_resource_discovery","url":"aws_api/ec2.html#modify_ipam_resource_discovery"},{"doc":"aws_api/ec2","title":"modify_ipam_scope","content":"pub fn modify_ipam_scope(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_ipam_scope\naws_api/ec2 modify_ipam_scope","url":"aws_api/ec2.html#modify_ipam_scope"},{"doc":"aws_api/ec2","title":"modify_launch_template","content":"pub fn modify_launch_template(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_launch_template\naws_api/ec2 modify_launch_template","url":"aws_api/ec2.html#modify_launch_template"},{"doc":"aws_api/ec2","title":"modify_local_gateway_route","content":"pub fn modify_local_gateway_route(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_local_gateway_route\naws_api/ec2 modify_local_gateway_route","url":"aws_api/ec2.html#modify_local_gateway_route"},{"doc":"aws_api/ec2","title":"modify_managed_prefix_list","content":"pub fn modify_managed_prefix_list(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_managed_prefix_list\naws_api/ec2 modify_managed_prefix_list","url":"aws_api/ec2.html#modify_managed_prefix_list"},{"doc":"aws_api/ec2","title":"modify_network_interface_attribute","content":"pub fn modify_network_interface_attribute(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_network_interface_attribute\naws_api/ec2 modify_network_interface_attribute","url":"aws_api/ec2.html#modify_network_interface_attribute"},{"doc":"aws_api/ec2","title":"modify_private_dns_name_options","content":"pub fn modify_private_dns_name_options(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_private_dns_name_options\naws_api/ec2 modify_private_dns_name_options","url":"aws_api/ec2.html#modify_private_dns_name_options"},{"doc":"aws_api/ec2","title":"modify_reserved_instances","content":"pub fn modify_reserved_instances(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_reserved_instances\naws_api/ec2 modify_reserved_instances","url":"aws_api/ec2.html#modify_reserved_instances"},{"doc":"aws_api/ec2","title":"modify_security_group_rules","content":"pub fn modify_security_group_rules(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_security_group_rules\naws_api/ec2 modify_security_group_rules","url":"aws_api/ec2.html#modify_security_group_rules"},{"doc":"aws_api/ec2","title":"modify_snapshot_attribute","content":"pub fn modify_snapshot_attribute(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_snapshot_attribute\naws_api/ec2 modify_snapshot_attribute","url":"aws_api/ec2.html#modify_snapshot_attribute"},{"doc":"aws_api/ec2","title":"modify_snapshot_tier","content":"pub fn modify_snapshot_tier(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_snapshot_tier\naws_api/ec2 modify_snapshot_tier","url":"aws_api/ec2.html#modify_snapshot_tier"},{"doc":"aws_api/ec2","title":"modify_spot_fleet_request","content":"pub fn modify_spot_fleet_request(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_spot_fleet_request\naws_api/ec2 modify_spot_fleet_request","url":"aws_api/ec2.html#modify_spot_fleet_request"},{"doc":"aws_api/ec2","title":"modify_subnet_attribute","content":"pub fn modify_subnet_attribute(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_subnet_attribute\naws_api/ec2 modify_subnet_attribute","url":"aws_api/ec2.html#modify_subnet_attribute"},{"doc":"aws_api/ec2","title":"modify_traffic_mirror_filter_network_services","content":"pub fn modify_traffic_mirror_filter_network_services(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_traffic_mirror_filter_network_services\naws_api/ec2 modify_traffic_mirror_filter_network_services","url":"aws_api/ec2.html#modify_traffic_mirror_filter_network_services"},{"doc":"aws_api/ec2","title":"modify_traffic_mirror_filter_rule","content":"pub fn modify_traffic_mirror_filter_rule(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_traffic_mirror_filter_rule\naws_api/ec2 modify_traffic_mirror_filter_rule","url":"aws_api/ec2.html#modify_traffic_mirror_filter_rule"},{"doc":"aws_api/ec2","title":"modify_traffic_mirror_session","content":"pub fn modify_traffic_mirror_session(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_traffic_mirror_session\naws_api/ec2 modify_traffic_mirror_session","url":"aws_api/ec2.html#modify_traffic_mirror_session"},{"doc":"aws_api/ec2","title":"modify_transit_gateway","content":"pub fn modify_transit_gateway(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_transit_gateway\naws_api/ec2 modify_transit_gateway","url":"aws_api/ec2.html#modify_transit_gateway"},{"doc":"aws_api/ec2","title":"modify_transit_gateway_prefix_list_reference","content":"pub fn modify_transit_gateway_prefix_list_reference(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_transit_gateway_prefix_list_reference\naws_api/ec2 modify_transit_gateway_prefix_list_reference","url":"aws_api/ec2.html#modify_transit_gateway_prefix_list_reference"},{"doc":"aws_api/ec2","title":"modify_transit_gateway_vpc_attachment","content":"pub fn modify_transit_gateway_vpc_attachment(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_transit_gateway_vpc_attachment\naws_api/ec2 modify_transit_gateway_vpc_attachment","url":"aws_api/ec2.html#modify_transit_gateway_vpc_attachment"},{"doc":"aws_api/ec2","title":"modify_verified_access_endpoint","content":"pub fn modify_verified_access_endpoint(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_verified_access_endpoint\naws_api/ec2 modify_verified_access_endpoint","url":"aws_api/ec2.html#modify_verified_access_endpoint"},{"doc":"aws_api/ec2","title":"modify_verified_access_endpoint_policy","content":"pub fn modify_verified_access_endpoint_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_verified_access_endpoint_policy\naws_api/ec2 modify_verified_access_endpoint_policy","url":"aws_api/ec2.html#modify_verified_access_endpoint_policy"},{"doc":"aws_api/ec2","title":"modify_verified_access_group","content":"pub fn modify_verified_access_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_verified_access_group\naws_api/ec2 modify_verified_access_group","url":"aws_api/ec2.html#modify_verified_access_group"},{"doc":"aws_api/ec2","title":"modify_verified_access_group_policy","content":"pub fn modify_verified_access_group_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_verified_access_group_policy\naws_api/ec2 modify_verified_access_group_policy","url":"aws_api/ec2.html#modify_verified_access_group_policy"},{"doc":"aws_api/ec2","title":"modify_verified_access_instance","content":"pub fn modify_verified_access_instance(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_verified_access_instance\naws_api/ec2 modify_verified_access_instance","url":"aws_api/ec2.html#modify_verified_access_instance"},{"doc":"aws_api/ec2","title":"modify_verified_access_instance_logging_configuration","content":"pub fn modify_verified_access_instance_logging_configuration(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_verified_access_instance_logging_configuration\naws_api/ec2 modify_verified_access_instance_logging_configuration","url":"aws_api/ec2.html#modify_verified_access_instance_logging_configuration"},{"doc":"aws_api/ec2","title":"modify_verified_access_trust_provider","content":"pub fn modify_verified_access_trust_provider(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_verified_access_trust_provider\naws_api/ec2 modify_verified_access_trust_provider","url":"aws_api/ec2.html#modify_verified_access_trust_provider"},{"doc":"aws_api/ec2","title":"modify_volume","content":"pub fn modify_volume(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_volume\naws_api/ec2 modify_volume","url":"aws_api/ec2.html#modify_volume"},{"doc":"aws_api/ec2","title":"modify_volume_attribute","content":"pub fn modify_volume_attribute(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_volume_attribute\naws_api/ec2 modify_volume_attribute","url":"aws_api/ec2.html#modify_volume_attribute"},{"doc":"aws_api/ec2","title":"modify_vpc_attribute","content":"pub fn modify_vpc_attribute(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_vpc_attribute\naws_api/ec2 modify_vpc_attribute","url":"aws_api/ec2.html#modify_vpc_attribute"},{"doc":"aws_api/ec2","title":"modify_vpc_endpoint","content":"pub fn modify_vpc_endpoint(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_vpc_endpoint\naws_api/ec2 modify_vpc_endpoint","url":"aws_api/ec2.html#modify_vpc_endpoint"},{"doc":"aws_api/ec2","title":"modify_vpc_endpoint_connection_notification","content":"pub fn modify_vpc_endpoint_connection_notification(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_vpc_endpoint_connection_notification\naws_api/ec2 modify_vpc_endpoint_connection_notification","url":"aws_api/ec2.html#modify_vpc_endpoint_connection_notification"},{"doc":"aws_api/ec2","title":"modify_vpc_endpoint_service_configuration","content":"pub fn modify_vpc_endpoint_service_configuration(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_vpc_endpoint_service_configuration\naws_api/ec2 modify_vpc_endpoint_service_configuration","url":"aws_api/ec2.html#modify_vpc_endpoint_service_configuration"},{"doc":"aws_api/ec2","title":"modify_vpc_endpoint_service_payer_responsibility","content":"pub fn modify_vpc_endpoint_service_payer_responsibility(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_vpc_endpoint_service_payer_responsibility\naws_api/ec2 modify_vpc_endpoint_service_payer_responsibility","url":"aws_api/ec2.html#modify_vpc_endpoint_service_payer_responsibility"},{"doc":"aws_api/ec2","title":"modify_vpc_endpoint_service_permissions","content":"pub fn modify_vpc_endpoint_service_permissions(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_vpc_endpoint_service_permissions\naws_api/ec2 modify_vpc_endpoint_service_permissions","url":"aws_api/ec2.html#modify_vpc_endpoint_service_permissions"},{"doc":"aws_api/ec2","title":"modify_vpc_peering_connection_options","content":"pub fn modify_vpc_peering_connection_options(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_vpc_peering_connection_options\naws_api/ec2 modify_vpc_peering_connection_options","url":"aws_api/ec2.html#modify_vpc_peering_connection_options"},{"doc":"aws_api/ec2","title":"modify_vpc_tenancy","content":"pub fn modify_vpc_tenancy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_vpc_tenancy\naws_api/ec2 modify_vpc_tenancy","url":"aws_api/ec2.html#modify_vpc_tenancy"},{"doc":"aws_api/ec2","title":"modify_vpn_connection","content":"pub fn modify_vpn_connection(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_vpn_connection\naws_api/ec2 modify_vpn_connection","url":"aws_api/ec2.html#modify_vpn_connection"},{"doc":"aws_api/ec2","title":"modify_vpn_connection_options","content":"pub fn modify_vpn_connection_options(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_vpn_connection_options\naws_api/ec2 modify_vpn_connection_options","url":"aws_api/ec2.html#modify_vpn_connection_options"},{"doc":"aws_api/ec2","title":"modify_vpn_tunnel_certificate","content":"pub fn modify_vpn_tunnel_certificate(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_vpn_tunnel_certificate\naws_api/ec2 modify_vpn_tunnel_certificate","url":"aws_api/ec2.html#modify_vpn_tunnel_certificate"},{"doc":"aws_api/ec2","title":"modify_vpn_tunnel_options","content":"pub fn modify_vpn_tunnel_options(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.modify_vpn_tunnel_options\naws_api/ec2 modify_vpn_tunnel_options","url":"aws_api/ec2.html#modify_vpn_tunnel_options"},{"doc":"aws_api/ec2","title":"monitor_instances","content":"pub fn monitor_instances(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.monitor_instances\naws_api/ec2 monitor_instances","url":"aws_api/ec2.html#monitor_instances"},{"doc":"aws_api/ec2","title":"move_address_to_vpc","content":"pub fn move_address_to_vpc(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.move_address_to_vpc\naws_api/ec2 move_address_to_vpc","url":"aws_api/ec2.html#move_address_to_vpc"},{"doc":"aws_api/ec2","title":"move_byoip_cidr_to_ipam","content":"pub fn move_byoip_cidr_to_ipam(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.move_byoip_cidr_to_ipam\naws_api/ec2 move_byoip_cidr_to_ipam","url":"aws_api/ec2.html#move_byoip_cidr_to_ipam"},{"doc":"aws_api/ec2","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/ec2.new\naws_api/ec2 new","url":"aws_api/ec2.html#new"},{"doc":"aws_api/ec2","title":"provision_byoip_cidr","content":"pub fn provision_byoip_cidr(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.provision_byoip_cidr\naws_api/ec2 provision_byoip_cidr","url":"aws_api/ec2.html#provision_byoip_cidr"},{"doc":"aws_api/ec2","title":"provision_ipam_byoasn","content":"pub fn provision_ipam_byoasn(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.provision_ipam_byoasn\naws_api/ec2 provision_ipam_byoasn","url":"aws_api/ec2.html#provision_ipam_byoasn"},{"doc":"aws_api/ec2","title":"provision_ipam_pool_cidr","content":"pub fn provision_ipam_pool_cidr(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.provision_ipam_pool_cidr\naws_api/ec2 provision_ipam_pool_cidr","url":"aws_api/ec2.html#provision_ipam_pool_cidr"},{"doc":"aws_api/ec2","title":"provision_public_ipv4_pool_cidr","content":"pub fn provision_public_ipv4_pool_cidr(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.provision_public_ipv4_pool_cidr\naws_api/ec2 provision_public_ipv4_pool_cidr","url":"aws_api/ec2.html#provision_public_ipv4_pool_cidr"},{"doc":"aws_api/ec2","title":"purchase_capacity_block","content":"pub fn purchase_capacity_block(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.purchase_capacity_block\naws_api/ec2 purchase_capacity_block","url":"aws_api/ec2.html#purchase_capacity_block"},{"doc":"aws_api/ec2","title":"purchase_host_reservation","content":"pub fn purchase_host_reservation(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.purchase_host_reservation\naws_api/ec2 purchase_host_reservation","url":"aws_api/ec2.html#purchase_host_reservation"},{"doc":"aws_api/ec2","title":"purchase_reserved_instances_offering","content":"pub fn purchase_reserved_instances_offering(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.purchase_reserved_instances_offering\naws_api/ec2 purchase_reserved_instances_offering","url":"aws_api/ec2.html#purchase_reserved_instances_offering"},{"doc":"aws_api/ec2","title":"purchase_scheduled_instances","content":"pub fn purchase_scheduled_instances(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.purchase_scheduled_instances\naws_api/ec2 purchase_scheduled_instances","url":"aws_api/ec2.html#purchase_scheduled_instances"},{"doc":"aws_api/ec2","title":"reboot_instances","content":"pub fn reboot_instances(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.reboot_instances\naws_api/ec2 reboot_instances","url":"aws_api/ec2.html#reboot_instances"},{"doc":"aws_api/ec2","title":"register_image","content":"pub fn register_image(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.register_image\naws_api/ec2 register_image","url":"aws_api/ec2.html#register_image"},{"doc":"aws_api/ec2","title":"register_instance_event_notification_attributes","content":"pub fn register_instance_event_notification_attributes(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.register_instance_event_notification_attributes\naws_api/ec2 register_instance_event_notification_attributes","url":"aws_api/ec2.html#register_instance_event_notification_attributes"},{"doc":"aws_api/ec2","title":"register_transit_gateway_multicast_group_members","content":"pub fn register_transit_gateway_multicast_group_members(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.register_transit_gateway_multicast_group_members\naws_api/ec2 register_transit_gateway_multicast_group_members","url":"aws_api/ec2.html#register_transit_gateway_multicast_group_members"},{"doc":"aws_api/ec2","title":"register_transit_gateway_multicast_group_sources","content":"pub fn register_transit_gateway_multicast_group_sources(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.register_transit_gateway_multicast_group_sources\naws_api/ec2 register_transit_gateway_multicast_group_sources","url":"aws_api/ec2.html#register_transit_gateway_multicast_group_sources"},{"doc":"aws_api/ec2","title":"reject_transit_gateway_multicast_domain_associations","content":"pub fn reject_transit_gateway_multicast_domain_associations(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.reject_transit_gateway_multicast_domain_associations\naws_api/ec2 reject_transit_gateway_multicast_domain_associations","url":"aws_api/ec2.html#reject_transit_gateway_multicast_domain_associations"},{"doc":"aws_api/ec2","title":"reject_transit_gateway_peering_attachment","content":"pub fn reject_transit_gateway_peering_attachment(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.reject_transit_gateway_peering_attachment\naws_api/ec2 reject_transit_gateway_peering_attachment","url":"aws_api/ec2.html#reject_transit_gateway_peering_attachment"},{"doc":"aws_api/ec2","title":"reject_transit_gateway_vpc_attachment","content":"pub fn reject_transit_gateway_vpc_attachment(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.reject_transit_gateway_vpc_attachment\naws_api/ec2 reject_transit_gateway_vpc_attachment","url":"aws_api/ec2.html#reject_transit_gateway_vpc_attachment"},{"doc":"aws_api/ec2","title":"reject_vpc_endpoint_connections","content":"pub fn reject_vpc_endpoint_connections(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.reject_vpc_endpoint_connections\naws_api/ec2 reject_vpc_endpoint_connections","url":"aws_api/ec2.html#reject_vpc_endpoint_connections"},{"doc":"aws_api/ec2","title":"reject_vpc_peering_connection","content":"pub fn reject_vpc_peering_connection(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.reject_vpc_peering_connection\naws_api/ec2 reject_vpc_peering_connection","url":"aws_api/ec2.html#reject_vpc_peering_connection"},{"doc":"aws_api/ec2","title":"release_address","content":"pub fn release_address(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.release_address\naws_api/ec2 release_address","url":"aws_api/ec2.html#release_address"},{"doc":"aws_api/ec2","title":"release_hosts","content":"pub fn release_hosts(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.release_hosts\naws_api/ec2 release_hosts","url":"aws_api/ec2.html#release_hosts"},{"doc":"aws_api/ec2","title":"release_ipam_pool_allocation","content":"pub fn release_ipam_pool_allocation(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.release_ipam_pool_allocation\naws_api/ec2 release_ipam_pool_allocation","url":"aws_api/ec2.html#release_ipam_pool_allocation"},{"doc":"aws_api/ec2","title":"replace_iam_instance_profile_association","content":"pub fn replace_iam_instance_profile_association(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.replace_iam_instance_profile_association\naws_api/ec2 replace_iam_instance_profile_association","url":"aws_api/ec2.html#replace_iam_instance_profile_association"},{"doc":"aws_api/ec2","title":"replace_network_acl_association","content":"pub fn replace_network_acl_association(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.replace_network_acl_association\naws_api/ec2 replace_network_acl_association","url":"aws_api/ec2.html#replace_network_acl_association"},{"doc":"aws_api/ec2","title":"replace_network_acl_entry","content":"pub fn replace_network_acl_entry(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.replace_network_acl_entry\naws_api/ec2 replace_network_acl_entry","url":"aws_api/ec2.html#replace_network_acl_entry"},{"doc":"aws_api/ec2","title":"replace_route","content":"pub fn replace_route(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.replace_route\naws_api/ec2 replace_route","url":"aws_api/ec2.html#replace_route"},{"doc":"aws_api/ec2","title":"replace_route_table_association","content":"pub fn replace_route_table_association(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.replace_route_table_association\naws_api/ec2 replace_route_table_association","url":"aws_api/ec2.html#replace_route_table_association"},{"doc":"aws_api/ec2","title":"replace_transit_gateway_route","content":"pub fn replace_transit_gateway_route(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.replace_transit_gateway_route\naws_api/ec2 replace_transit_gateway_route","url":"aws_api/ec2.html#replace_transit_gateway_route"},{"doc":"aws_api/ec2","title":"replace_vpn_tunnel","content":"pub fn replace_vpn_tunnel(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.replace_vpn_tunnel\naws_api/ec2 replace_vpn_tunnel","url":"aws_api/ec2.html#replace_vpn_tunnel"},{"doc":"aws_api/ec2","title":"report_instance_status","content":"pub fn report_instance_status(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.report_instance_status\naws_api/ec2 report_instance_status","url":"aws_api/ec2.html#report_instance_status"},{"doc":"aws_api/ec2","title":"request_spot_fleet","content":"pub fn request_spot_fleet(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.request_spot_fleet\naws_api/ec2 request_spot_fleet","url":"aws_api/ec2.html#request_spot_fleet"},{"doc":"aws_api/ec2","title":"request_spot_instances","content":"pub fn request_spot_instances(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.request_spot_instances\naws_api/ec2 request_spot_instances","url":"aws_api/ec2.html#request_spot_instances"},{"doc":"aws_api/ec2","title":"reset_address_attribute","content":"pub fn reset_address_attribute(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.reset_address_attribute\naws_api/ec2 reset_address_attribute","url":"aws_api/ec2.html#reset_address_attribute"},{"doc":"aws_api/ec2","title":"reset_ebs_default_kms_key_id","content":"pub fn reset_ebs_default_kms_key_id(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.reset_ebs_default_kms_key_id\naws_api/ec2 reset_ebs_default_kms_key_id","url":"aws_api/ec2.html#reset_ebs_default_kms_key_id"},{"doc":"aws_api/ec2","title":"reset_fpga_image_attribute","content":"pub fn reset_fpga_image_attribute(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.reset_fpga_image_attribute\naws_api/ec2 reset_fpga_image_attribute","url":"aws_api/ec2.html#reset_fpga_image_attribute"},{"doc":"aws_api/ec2","title":"reset_image_attribute","content":"pub fn reset_image_attribute(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.reset_image_attribute\naws_api/ec2 reset_image_attribute","url":"aws_api/ec2.html#reset_image_attribute"},{"doc":"aws_api/ec2","title":"reset_instance_attribute","content":"pub fn reset_instance_attribute(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.reset_instance_attribute\naws_api/ec2 reset_instance_attribute","url":"aws_api/ec2.html#reset_instance_attribute"},{"doc":"aws_api/ec2","title":"reset_network_interface_attribute","content":"pub fn reset_network_interface_attribute(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.reset_network_interface_attribute\naws_api/ec2 reset_network_interface_attribute","url":"aws_api/ec2.html#reset_network_interface_attribute"},{"doc":"aws_api/ec2","title":"reset_snapshot_attribute","content":"pub fn reset_snapshot_attribute(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.reset_snapshot_attribute\naws_api/ec2 reset_snapshot_attribute","url":"aws_api/ec2.html#reset_snapshot_attribute"},{"doc":"aws_api/ec2","title":"restore_address_to_classic","content":"pub fn restore_address_to_classic(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.restore_address_to_classic\naws_api/ec2 restore_address_to_classic","url":"aws_api/ec2.html#restore_address_to_classic"},{"doc":"aws_api/ec2","title":"restore_image_from_recycle_bin","content":"pub fn restore_image_from_recycle_bin(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.restore_image_from_recycle_bin\naws_api/ec2 restore_image_from_recycle_bin","url":"aws_api/ec2.html#restore_image_from_recycle_bin"},{"doc":"aws_api/ec2","title":"restore_managed_prefix_list_version","content":"pub fn restore_managed_prefix_list_version(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.restore_managed_prefix_list_version\naws_api/ec2 restore_managed_prefix_list_version","url":"aws_api/ec2.html#restore_managed_prefix_list_version"},{"doc":"aws_api/ec2","title":"restore_snapshot_from_recycle_bin","content":"pub fn restore_snapshot_from_recycle_bin(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.restore_snapshot_from_recycle_bin\naws_api/ec2 restore_snapshot_from_recycle_bin","url":"aws_api/ec2.html#restore_snapshot_from_recycle_bin"},{"doc":"aws_api/ec2","title":"restore_snapshot_tier","content":"pub fn restore_snapshot_tier(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.restore_snapshot_tier\naws_api/ec2 restore_snapshot_tier","url":"aws_api/ec2.html#restore_snapshot_tier"},{"doc":"aws_api/ec2","title":"revoke_client_vpn_ingress","content":"pub fn revoke_client_vpn_ingress(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.revoke_client_vpn_ingress\naws_api/ec2 revoke_client_vpn_ingress","url":"aws_api/ec2.html#revoke_client_vpn_ingress"},{"doc":"aws_api/ec2","title":"revoke_security_group_egress","content":"pub fn revoke_security_group_egress(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.revoke_security_group_egress\naws_api/ec2 revoke_security_group_egress","url":"aws_api/ec2.html#revoke_security_group_egress"},{"doc":"aws_api/ec2","title":"revoke_security_group_ingress","content":"pub fn revoke_security_group_ingress(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.revoke_security_group_ingress\naws_api/ec2 revoke_security_group_ingress","url":"aws_api/ec2.html#revoke_security_group_ingress"},{"doc":"aws_api/ec2","title":"run_instances","content":"pub fn run_instances(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.run_instances\naws_api/ec2 run_instances","url":"aws_api/ec2.html#run_instances"},{"doc":"aws_api/ec2","title":"run_scheduled_instances","content":"pub fn run_scheduled_instances(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.run_scheduled_instances\naws_api/ec2 run_scheduled_instances","url":"aws_api/ec2.html#run_scheduled_instances"},{"doc":"aws_api/ec2","title":"search_local_gateway_routes","content":"pub fn search_local_gateway_routes(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.search_local_gateway_routes\naws_api/ec2 search_local_gateway_routes","url":"aws_api/ec2.html#search_local_gateway_routes"},{"doc":"aws_api/ec2","title":"search_transit_gateway_multicast_groups","content":"pub fn search_transit_gateway_multicast_groups(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.search_transit_gateway_multicast_groups\naws_api/ec2 search_transit_gateway_multicast_groups","url":"aws_api/ec2.html#search_transit_gateway_multicast_groups"},{"doc":"aws_api/ec2","title":"search_transit_gateway_routes","content":"pub fn search_transit_gateway_routes(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.search_transit_gateway_routes\naws_api/ec2 search_transit_gateway_routes","url":"aws_api/ec2.html#search_transit_gateway_routes"},{"doc":"aws_api/ec2","title":"send_diagnostic_interrupt","content":"pub fn send_diagnostic_interrupt(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.send_diagnostic_interrupt\naws_api/ec2 send_diagnostic_interrupt","url":"aws_api/ec2.html#send_diagnostic_interrupt"},{"doc":"aws_api/ec2","title":"start_instances","content":"pub fn start_instances(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.start_instances\naws_api/ec2 start_instances","url":"aws_api/ec2.html#start_instances"},{"doc":"aws_api/ec2","title":"start_network_insights_access_scope_analysis","content":"pub fn start_network_insights_access_scope_analysis(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.start_network_insights_access_scope_analysis\naws_api/ec2 start_network_insights_access_scope_analysis","url":"aws_api/ec2.html#start_network_insights_access_scope_analysis"},{"doc":"aws_api/ec2","title":"start_network_insights_analysis","content":"pub fn start_network_insights_analysis(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.start_network_insights_analysis\naws_api/ec2 start_network_insights_analysis","url":"aws_api/ec2.html#start_network_insights_analysis"},{"doc":"aws_api/ec2","title":"start_vpc_endpoint_service_private_dns_verification","content":"pub fn start_vpc_endpoint_service_private_dns_verification(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.start_vpc_endpoint_service_private_dns_verification\naws_api/ec2 start_vpc_endpoint_service_private_dns_verification","url":"aws_api/ec2.html#start_vpc_endpoint_service_private_dns_verification"},{"doc":"aws_api/ec2","title":"stop_instances","content":"pub fn stop_instances(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.stop_instances\naws_api/ec2 stop_instances","url":"aws_api/ec2.html#stop_instances"},{"doc":"aws_api/ec2","title":"terminate_client_vpn_connections","content":"pub fn terminate_client_vpn_connections(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.terminate_client_vpn_connections\naws_api/ec2 terminate_client_vpn_connections","url":"aws_api/ec2.html#terminate_client_vpn_connections"},{"doc":"aws_api/ec2","title":"terminate_instances","content":"pub fn terminate_instances(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.terminate_instances\naws_api/ec2 terminate_instances","url":"aws_api/ec2.html#terminate_instances"},{"doc":"aws_api/ec2","title":"unassign_ipv6_addresses","content":"pub fn unassign_ipv6_addresses(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.unassign_ipv6_addresses\naws_api/ec2 unassign_ipv6_addresses","url":"aws_api/ec2.html#unassign_ipv6_addresses"},{"doc":"aws_api/ec2","title":"unassign_private_ip_addresses","content":"pub fn unassign_private_ip_addresses(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.unassign_private_ip_addresses\naws_api/ec2 unassign_private_ip_addresses","url":"aws_api/ec2.html#unassign_private_ip_addresses"},{"doc":"aws_api/ec2","title":"unassign_private_nat_gateway_address","content":"pub fn unassign_private_nat_gateway_address(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.unassign_private_nat_gateway_address\naws_api/ec2 unassign_private_nat_gateway_address","url":"aws_api/ec2.html#unassign_private_nat_gateway_address"},{"doc":"aws_api/ec2","title":"unlock_snapshot","content":"pub fn unlock_snapshot(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.unlock_snapshot\naws_api/ec2 unlock_snapshot","url":"aws_api/ec2.html#unlock_snapshot"},{"doc":"aws_api/ec2","title":"unmonitor_instances","content":"pub fn unmonitor_instances(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.unmonitor_instances\naws_api/ec2 unmonitor_instances","url":"aws_api/ec2.html#unmonitor_instances"},{"doc":"aws_api/ec2","title":"update_security_group_rule_descriptions_egress","content":"pub fn update_security_group_rule_descriptions_egress(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.update_security_group_rule_descriptions_egress\naws_api/ec2 update_security_group_rule_descriptions_egress","url":"aws_api/ec2.html#update_security_group_rule_descriptions_egress"},{"doc":"aws_api/ec2","title":"update_security_group_rule_descriptions_ingress","content":"pub fn update_security_group_rule_descriptions_ingress(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.update_security_group_rule_descriptions_ingress\naws_api/ec2 update_security_group_rule_descriptions_ingress","url":"aws_api/ec2.html#update_security_group_rule_descriptions_ingress"},{"doc":"aws_api/ec2","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/ec2.with_custom_endpoint\naws_api/ec2 with_custom_endpoint","url":"aws_api/ec2.html#with_custom_endpoint"},{"doc":"aws_api/ec2","title":"withdraw_byoip_cidr","content":"pub fn withdraw_byoip_cidr(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ec2.withdraw_byoip_cidr\naws_api/ec2 withdraw_byoip_cidr","url":"aws_api/ec2.html#withdraw_byoip_cidr"},{"doc":"aws_api/ec2","title":"aws_api/ec2","content":"","url":"aws_api/ec2.html"},{"doc":"aws_api/ecr","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/ecr.Client\naws_api/ecr Client","url":"aws_api/ecr.html#Client"},{"doc":"aws_api/ecr","title":"batch_check_layer_availability","content":"pub fn batch_check_layer_availability(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr.batch_check_layer_availability\naws_api/ecr batch_check_layer_availability","url":"aws_api/ecr.html#batch_check_layer_availability"},{"doc":"aws_api/ecr","title":"batch_delete_image","content":"pub fn batch_delete_image(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr.batch_delete_image\naws_api/ecr batch_delete_image","url":"aws_api/ecr.html#batch_delete_image"},{"doc":"aws_api/ecr","title":"batch_get_image","content":"pub fn batch_get_image(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr.batch_get_image\naws_api/ecr batch_get_image","url":"aws_api/ecr.html#batch_get_image"},{"doc":"aws_api/ecr","title":"batch_get_repository_scanning_configuration","content":"pub fn batch_get_repository_scanning_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr.batch_get_repository_scanning_configuration\naws_api/ecr batch_get_repository_scanning_configuration","url":"aws_api/ecr.html#batch_get_repository_scanning_configuration"},{"doc":"aws_api/ecr","title":"complete_layer_upload","content":"pub fn complete_layer_upload(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr.complete_layer_upload\naws_api/ecr complete_layer_upload","url":"aws_api/ecr.html#complete_layer_upload"},{"doc":"aws_api/ecr","title":"create_pull_through_cache_rule","content":"pub fn create_pull_through_cache_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr.create_pull_through_cache_rule\naws_api/ecr create_pull_through_cache_rule","url":"aws_api/ecr.html#create_pull_through_cache_rule"},{"doc":"aws_api/ecr","title":"create_repository","content":"pub fn create_repository(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr.create_repository\naws_api/ecr create_repository","url":"aws_api/ecr.html#create_repository"},{"doc":"aws_api/ecr","title":"create_repository_creation_template","content":"pub fn create_repository_creation_template(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr.create_repository_creation_template\naws_api/ecr create_repository_creation_template","url":"aws_api/ecr.html#create_repository_creation_template"},{"doc":"aws_api/ecr","title":"delete_lifecycle_policy","content":"pub fn delete_lifecycle_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr.delete_lifecycle_policy\naws_api/ecr delete_lifecycle_policy","url":"aws_api/ecr.html#delete_lifecycle_policy"},{"doc":"aws_api/ecr","title":"delete_pull_through_cache_rule","content":"pub fn delete_pull_through_cache_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr.delete_pull_through_cache_rule\naws_api/ecr delete_pull_through_cache_rule","url":"aws_api/ecr.html#delete_pull_through_cache_rule"},{"doc":"aws_api/ecr","title":"delete_registry_policy","content":"pub fn delete_registry_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr.delete_registry_policy\naws_api/ecr delete_registry_policy","url":"aws_api/ecr.html#delete_registry_policy"},{"doc":"aws_api/ecr","title":"delete_repository","content":"pub fn delete_repository(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr.delete_repository\naws_api/ecr delete_repository","url":"aws_api/ecr.html#delete_repository"},{"doc":"aws_api/ecr","title":"delete_repository_creation_template","content":"pub fn delete_repository_creation_template(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr.delete_repository_creation_template\naws_api/ecr delete_repository_creation_template","url":"aws_api/ecr.html#delete_repository_creation_template"},{"doc":"aws_api/ecr","title":"delete_repository_policy","content":"pub fn delete_repository_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr.delete_repository_policy\naws_api/ecr delete_repository_policy","url":"aws_api/ecr.html#delete_repository_policy"},{"doc":"aws_api/ecr","title":"describe_image_replication_status","content":"pub fn describe_image_replication_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr.describe_image_replication_status\naws_api/ecr describe_image_replication_status","url":"aws_api/ecr.html#describe_image_replication_status"},{"doc":"aws_api/ecr","title":"describe_image_scan_findings","content":"pub fn describe_image_scan_findings(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr.describe_image_scan_findings\naws_api/ecr describe_image_scan_findings","url":"aws_api/ecr.html#describe_image_scan_findings"},{"doc":"aws_api/ecr","title":"describe_images","content":"pub fn describe_images(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr.describe_images\naws_api/ecr describe_images","url":"aws_api/ecr.html#describe_images"},{"doc":"aws_api/ecr","title":"describe_pull_through_cache_rules","content":"pub fn describe_pull_through_cache_rules(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr.describe_pull_through_cache_rules\naws_api/ecr describe_pull_through_cache_rules","url":"aws_api/ecr.html#describe_pull_through_cache_rules"},{"doc":"aws_api/ecr","title":"describe_registry","content":"pub fn describe_registry(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr.describe_registry\naws_api/ecr describe_registry","url":"aws_api/ecr.html#describe_registry"},{"doc":"aws_api/ecr","title":"describe_repositories","content":"pub fn describe_repositories(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr.describe_repositories\naws_api/ecr describe_repositories","url":"aws_api/ecr.html#describe_repositories"},{"doc":"aws_api/ecr","title":"describe_repository_creation_templates","content":"pub fn describe_repository_creation_templates(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr.describe_repository_creation_templates\naws_api/ecr describe_repository_creation_templates","url":"aws_api/ecr.html#describe_repository_creation_templates"},{"doc":"aws_api/ecr","title":"get_account_setting","content":"pub fn get_account_setting(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr.get_account_setting\naws_api/ecr get_account_setting","url":"aws_api/ecr.html#get_account_setting"},{"doc":"aws_api/ecr","title":"get_authorization_token","content":"pub fn get_authorization_token(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr.get_authorization_token\naws_api/ecr get_authorization_token","url":"aws_api/ecr.html#get_authorization_token"},{"doc":"aws_api/ecr","title":"get_download_url_for_layer","content":"pub fn get_download_url_for_layer(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr.get_download_url_for_layer\naws_api/ecr get_download_url_for_layer","url":"aws_api/ecr.html#get_download_url_for_layer"},{"doc":"aws_api/ecr","title":"get_lifecycle_policy","content":"pub fn get_lifecycle_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr.get_lifecycle_policy\naws_api/ecr get_lifecycle_policy","url":"aws_api/ecr.html#get_lifecycle_policy"},{"doc":"aws_api/ecr","title":"get_lifecycle_policy_preview","content":"pub fn get_lifecycle_policy_preview(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr.get_lifecycle_policy_preview\naws_api/ecr get_lifecycle_policy_preview","url":"aws_api/ecr.html#get_lifecycle_policy_preview"},{"doc":"aws_api/ecr","title":"get_registry_policy","content":"pub fn get_registry_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr.get_registry_policy\naws_api/ecr get_registry_policy","url":"aws_api/ecr.html#get_registry_policy"},{"doc":"aws_api/ecr","title":"get_registry_scanning_configuration","content":"pub fn get_registry_scanning_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr.get_registry_scanning_configuration\naws_api/ecr get_registry_scanning_configuration","url":"aws_api/ecr.html#get_registry_scanning_configuration"},{"doc":"aws_api/ecr","title":"get_repository_policy","content":"pub fn get_repository_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr.get_repository_policy\naws_api/ecr get_repository_policy","url":"aws_api/ecr.html#get_repository_policy"},{"doc":"aws_api/ecr","title":"initiate_layer_upload","content":"pub fn initiate_layer_upload(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr.initiate_layer_upload\naws_api/ecr initiate_layer_upload","url":"aws_api/ecr.html#initiate_layer_upload"},{"doc":"aws_api/ecr","title":"list_images","content":"pub fn list_images(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr.list_images\naws_api/ecr list_images","url":"aws_api/ecr.html#list_images"},{"doc":"aws_api/ecr","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr.list_tags_for_resource\naws_api/ecr list_tags_for_resource","url":"aws_api/ecr.html#list_tags_for_resource"},{"doc":"aws_api/ecr","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/ecr.new\naws_api/ecr new","url":"aws_api/ecr.html#new"},{"doc":"aws_api/ecr","title":"put_account_setting","content":"pub fn put_account_setting(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr.put_account_setting\naws_api/ecr put_account_setting","url":"aws_api/ecr.html#put_account_setting"},{"doc":"aws_api/ecr","title":"put_image","content":"pub fn put_image(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr.put_image\naws_api/ecr put_image","url":"aws_api/ecr.html#put_image"},{"doc":"aws_api/ecr","title":"put_image_scanning_configuration","content":"pub fn put_image_scanning_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr.put_image_scanning_configuration\naws_api/ecr put_image_scanning_configuration","url":"aws_api/ecr.html#put_image_scanning_configuration"},{"doc":"aws_api/ecr","title":"put_image_tag_mutability","content":"pub fn put_image_tag_mutability(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr.put_image_tag_mutability\naws_api/ecr put_image_tag_mutability","url":"aws_api/ecr.html#put_image_tag_mutability"},{"doc":"aws_api/ecr","title":"put_lifecycle_policy","content":"pub fn put_lifecycle_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr.put_lifecycle_policy\naws_api/ecr put_lifecycle_policy","url":"aws_api/ecr.html#put_lifecycle_policy"},{"doc":"aws_api/ecr","title":"put_registry_policy","content":"pub fn put_registry_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr.put_registry_policy\naws_api/ecr put_registry_policy","url":"aws_api/ecr.html#put_registry_policy"},{"doc":"aws_api/ecr","title":"put_registry_scanning_configuration","content":"pub fn put_registry_scanning_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr.put_registry_scanning_configuration\naws_api/ecr put_registry_scanning_configuration","url":"aws_api/ecr.html#put_registry_scanning_configuration"},{"doc":"aws_api/ecr","title":"put_replication_configuration","content":"pub fn put_replication_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr.put_replication_configuration\naws_api/ecr put_replication_configuration","url":"aws_api/ecr.html#put_replication_configuration"},{"doc":"aws_api/ecr","title":"set_repository_policy","content":"pub fn set_repository_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr.set_repository_policy\naws_api/ecr set_repository_policy","url":"aws_api/ecr.html#set_repository_policy"},{"doc":"aws_api/ecr","title":"start_image_scan","content":"pub fn start_image_scan(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr.start_image_scan\naws_api/ecr start_image_scan","url":"aws_api/ecr.html#start_image_scan"},{"doc":"aws_api/ecr","title":"start_lifecycle_policy_preview","content":"pub fn start_lifecycle_policy_preview(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr.start_lifecycle_policy_preview\naws_api/ecr start_lifecycle_policy_preview","url":"aws_api/ecr.html#start_lifecycle_policy_preview"},{"doc":"aws_api/ecr","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr.tag_resource\naws_api/ecr tag_resource","url":"aws_api/ecr.html#tag_resource"},{"doc":"aws_api/ecr","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr.untag_resource\naws_api/ecr untag_resource","url":"aws_api/ecr.html#untag_resource"},{"doc":"aws_api/ecr","title":"update_pull_through_cache_rule","content":"pub fn update_pull_through_cache_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr.update_pull_through_cache_rule\naws_api/ecr update_pull_through_cache_rule","url":"aws_api/ecr.html#update_pull_through_cache_rule"},{"doc":"aws_api/ecr","title":"update_repository_creation_template","content":"pub fn update_repository_creation_template(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr.update_repository_creation_template\naws_api/ecr update_repository_creation_template","url":"aws_api/ecr.html#update_repository_creation_template"},{"doc":"aws_api/ecr","title":"upload_layer_part","content":"pub fn upload_layer_part(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr.upload_layer_part\naws_api/ecr upload_layer_part","url":"aws_api/ecr.html#upload_layer_part"},{"doc":"aws_api/ecr","title":"validate_pull_through_cache_rule","content":"pub fn validate_pull_through_cache_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr.validate_pull_through_cache_rule\naws_api/ecr validate_pull_through_cache_rule","url":"aws_api/ecr.html#validate_pull_through_cache_rule"},{"doc":"aws_api/ecr","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/ecr.with_custom_endpoint\naws_api/ecr with_custom_endpoint","url":"aws_api/ecr.html#with_custom_endpoint"},{"doc":"aws_api/ecr","title":"aws_api/ecr","content":"","url":"aws_api/ecr.html"},{"doc":"aws_api/ecr_public","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/ecr_public.Client\naws_api/ecr_public Client","url":"aws_api/ecr_public.html#Client"},{"doc":"aws_api/ecr_public","title":"batch_check_layer_availability","content":"pub fn batch_check_layer_availability(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr_public.batch_check_layer_availability\naws_api/ecr_public batch_check_layer_availability","url":"aws_api/ecr_public.html#batch_check_layer_availability"},{"doc":"aws_api/ecr_public","title":"batch_delete_image","content":"pub fn batch_delete_image(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr_public.batch_delete_image\naws_api/ecr_public batch_delete_image","url":"aws_api/ecr_public.html#batch_delete_image"},{"doc":"aws_api/ecr_public","title":"complete_layer_upload","content":"pub fn complete_layer_upload(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr_public.complete_layer_upload\naws_api/ecr_public complete_layer_upload","url":"aws_api/ecr_public.html#complete_layer_upload"},{"doc":"aws_api/ecr_public","title":"create_repository","content":"pub fn create_repository(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr_public.create_repository\naws_api/ecr_public create_repository","url":"aws_api/ecr_public.html#create_repository"},{"doc":"aws_api/ecr_public","title":"delete_repository","content":"pub fn delete_repository(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr_public.delete_repository\naws_api/ecr_public delete_repository","url":"aws_api/ecr_public.html#delete_repository"},{"doc":"aws_api/ecr_public","title":"delete_repository_policy","content":"pub fn delete_repository_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr_public.delete_repository_policy\naws_api/ecr_public delete_repository_policy","url":"aws_api/ecr_public.html#delete_repository_policy"},{"doc":"aws_api/ecr_public","title":"describe_image_tags","content":"pub fn describe_image_tags(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr_public.describe_image_tags\naws_api/ecr_public describe_image_tags","url":"aws_api/ecr_public.html#describe_image_tags"},{"doc":"aws_api/ecr_public","title":"describe_images","content":"pub fn describe_images(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr_public.describe_images\naws_api/ecr_public describe_images","url":"aws_api/ecr_public.html#describe_images"},{"doc":"aws_api/ecr_public","title":"describe_registries","content":"pub fn describe_registries(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr_public.describe_registries\naws_api/ecr_public describe_registries","url":"aws_api/ecr_public.html#describe_registries"},{"doc":"aws_api/ecr_public","title":"describe_repositories","content":"pub fn describe_repositories(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr_public.describe_repositories\naws_api/ecr_public describe_repositories","url":"aws_api/ecr_public.html#describe_repositories"},{"doc":"aws_api/ecr_public","title":"get_authorization_token","content":"pub fn get_authorization_token(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr_public.get_authorization_token\naws_api/ecr_public get_authorization_token","url":"aws_api/ecr_public.html#get_authorization_token"},{"doc":"aws_api/ecr_public","title":"get_registry_catalog_data","content":"pub fn get_registry_catalog_data(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr_public.get_registry_catalog_data\naws_api/ecr_public get_registry_catalog_data","url":"aws_api/ecr_public.html#get_registry_catalog_data"},{"doc":"aws_api/ecr_public","title":"get_repository_catalog_data","content":"pub fn get_repository_catalog_data(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr_public.get_repository_catalog_data\naws_api/ecr_public get_repository_catalog_data","url":"aws_api/ecr_public.html#get_repository_catalog_data"},{"doc":"aws_api/ecr_public","title":"get_repository_policy","content":"pub fn get_repository_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr_public.get_repository_policy\naws_api/ecr_public get_repository_policy","url":"aws_api/ecr_public.html#get_repository_policy"},{"doc":"aws_api/ecr_public","title":"initiate_layer_upload","content":"pub fn initiate_layer_upload(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr_public.initiate_layer_upload\naws_api/ecr_public initiate_layer_upload","url":"aws_api/ecr_public.html#initiate_layer_upload"},{"doc":"aws_api/ecr_public","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr_public.list_tags_for_resource\naws_api/ecr_public list_tags_for_resource","url":"aws_api/ecr_public.html#list_tags_for_resource"},{"doc":"aws_api/ecr_public","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/ecr_public.new\naws_api/ecr_public new","url":"aws_api/ecr_public.html#new"},{"doc":"aws_api/ecr_public","title":"put_image","content":"pub fn put_image(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr_public.put_image\naws_api/ecr_public put_image","url":"aws_api/ecr_public.html#put_image"},{"doc":"aws_api/ecr_public","title":"put_registry_catalog_data","content":"pub fn put_registry_catalog_data(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr_public.put_registry_catalog_data\naws_api/ecr_public put_registry_catalog_data","url":"aws_api/ecr_public.html#put_registry_catalog_data"},{"doc":"aws_api/ecr_public","title":"put_repository_catalog_data","content":"pub fn put_repository_catalog_data(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr_public.put_repository_catalog_data\naws_api/ecr_public put_repository_catalog_data","url":"aws_api/ecr_public.html#put_repository_catalog_data"},{"doc":"aws_api/ecr_public","title":"set_repository_policy","content":"pub fn set_repository_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr_public.set_repository_policy\naws_api/ecr_public set_repository_policy","url":"aws_api/ecr_public.html#set_repository_policy"},{"doc":"aws_api/ecr_public","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr_public.tag_resource\naws_api/ecr_public tag_resource","url":"aws_api/ecr_public.html#tag_resource"},{"doc":"aws_api/ecr_public","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr_public.untag_resource\naws_api/ecr_public untag_resource","url":"aws_api/ecr_public.html#untag_resource"},{"doc":"aws_api/ecr_public","title":"upload_layer_part","content":"pub fn upload_layer_part(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecr_public.upload_layer_part\naws_api/ecr_public upload_layer_part","url":"aws_api/ecr_public.html#upload_layer_part"},{"doc":"aws_api/ecr_public","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/ecr_public.with_custom_endpoint\naws_api/ecr_public with_custom_endpoint","url":"aws_api/ecr_public.html#with_custom_endpoint"},{"doc":"aws_api/ecr_public","title":"aws_api/ecr_public","content":"","url":"aws_api/ecr_public.html"},{"doc":"aws_api/ecs","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/ecs.Client\naws_api/ecs Client","url":"aws_api/ecs.html#Client"},{"doc":"aws_api/ecs","title":"create_capacity_provider","content":"pub fn create_capacity_provider(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.create_capacity_provider\naws_api/ecs create_capacity_provider","url":"aws_api/ecs.html#create_capacity_provider"},{"doc":"aws_api/ecs","title":"create_cluster","content":"pub fn create_cluster(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.create_cluster\naws_api/ecs create_cluster","url":"aws_api/ecs.html#create_cluster"},{"doc":"aws_api/ecs","title":"create_service","content":"pub fn create_service(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.create_service\naws_api/ecs create_service","url":"aws_api/ecs.html#create_service"},{"doc":"aws_api/ecs","title":"create_task_set","content":"pub fn create_task_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.create_task_set\naws_api/ecs create_task_set","url":"aws_api/ecs.html#create_task_set"},{"doc":"aws_api/ecs","title":"delete_account_setting","content":"pub fn delete_account_setting(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.delete_account_setting\naws_api/ecs delete_account_setting","url":"aws_api/ecs.html#delete_account_setting"},{"doc":"aws_api/ecs","title":"delete_attributes","content":"pub fn delete_attributes(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.delete_attributes\naws_api/ecs delete_attributes","url":"aws_api/ecs.html#delete_attributes"},{"doc":"aws_api/ecs","title":"delete_capacity_provider","content":"pub fn delete_capacity_provider(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.delete_capacity_provider\naws_api/ecs delete_capacity_provider","url":"aws_api/ecs.html#delete_capacity_provider"},{"doc":"aws_api/ecs","title":"delete_cluster","content":"pub fn delete_cluster(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.delete_cluster\naws_api/ecs delete_cluster","url":"aws_api/ecs.html#delete_cluster"},{"doc":"aws_api/ecs","title":"delete_service","content":"pub fn delete_service(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.delete_service\naws_api/ecs delete_service","url":"aws_api/ecs.html#delete_service"},{"doc":"aws_api/ecs","title":"delete_task_definitions","content":"pub fn delete_task_definitions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.delete_task_definitions\naws_api/ecs delete_task_definitions","url":"aws_api/ecs.html#delete_task_definitions"},{"doc":"aws_api/ecs","title":"delete_task_set","content":"pub fn delete_task_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.delete_task_set\naws_api/ecs delete_task_set","url":"aws_api/ecs.html#delete_task_set"},{"doc":"aws_api/ecs","title":"deregister_container_instance","content":"pub fn deregister_container_instance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.deregister_container_instance\naws_api/ecs deregister_container_instance","url":"aws_api/ecs.html#deregister_container_instance"},{"doc":"aws_api/ecs","title":"deregister_task_definition","content":"pub fn deregister_task_definition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.deregister_task_definition\naws_api/ecs deregister_task_definition","url":"aws_api/ecs.html#deregister_task_definition"},{"doc":"aws_api/ecs","title":"describe_capacity_providers","content":"pub fn describe_capacity_providers(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.describe_capacity_providers\naws_api/ecs describe_capacity_providers","url":"aws_api/ecs.html#describe_capacity_providers"},{"doc":"aws_api/ecs","title":"describe_clusters","content":"pub fn describe_clusters(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.describe_clusters\naws_api/ecs describe_clusters","url":"aws_api/ecs.html#describe_clusters"},{"doc":"aws_api/ecs","title":"describe_container_instances","content":"pub fn describe_container_instances(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.describe_container_instances\naws_api/ecs describe_container_instances","url":"aws_api/ecs.html#describe_container_instances"},{"doc":"aws_api/ecs","title":"describe_services","content":"pub fn describe_services(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.describe_services\naws_api/ecs describe_services","url":"aws_api/ecs.html#describe_services"},{"doc":"aws_api/ecs","title":"describe_task_definition","content":"pub fn describe_task_definition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.describe_task_definition\naws_api/ecs describe_task_definition","url":"aws_api/ecs.html#describe_task_definition"},{"doc":"aws_api/ecs","title":"describe_task_sets","content":"pub fn describe_task_sets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.describe_task_sets\naws_api/ecs describe_task_sets","url":"aws_api/ecs.html#describe_task_sets"},{"doc":"aws_api/ecs","title":"describe_tasks","content":"pub fn describe_tasks(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.describe_tasks\naws_api/ecs describe_tasks","url":"aws_api/ecs.html#describe_tasks"},{"doc":"aws_api/ecs","title":"discover_poll_endpoint","content":"pub fn discover_poll_endpoint(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.discover_poll_endpoint\naws_api/ecs discover_poll_endpoint","url":"aws_api/ecs.html#discover_poll_endpoint"},{"doc":"aws_api/ecs","title":"execute_command","content":"pub fn execute_command(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.execute_command\naws_api/ecs execute_command","url":"aws_api/ecs.html#execute_command"},{"doc":"aws_api/ecs","title":"get_task_protection","content":"pub fn get_task_protection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.get_task_protection\naws_api/ecs get_task_protection","url":"aws_api/ecs.html#get_task_protection"},{"doc":"aws_api/ecs","title":"list_account_settings","content":"pub fn list_account_settings(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.list_account_settings\naws_api/ecs list_account_settings","url":"aws_api/ecs.html#list_account_settings"},{"doc":"aws_api/ecs","title":"list_attributes","content":"pub fn list_attributes(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.list_attributes\naws_api/ecs list_attributes","url":"aws_api/ecs.html#list_attributes"},{"doc":"aws_api/ecs","title":"list_clusters","content":"pub fn list_clusters(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.list_clusters\naws_api/ecs list_clusters","url":"aws_api/ecs.html#list_clusters"},{"doc":"aws_api/ecs","title":"list_container_instances","content":"pub fn list_container_instances(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.list_container_instances\naws_api/ecs list_container_instances","url":"aws_api/ecs.html#list_container_instances"},{"doc":"aws_api/ecs","title":"list_services","content":"pub fn list_services(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.list_services\naws_api/ecs list_services","url":"aws_api/ecs.html#list_services"},{"doc":"aws_api/ecs","title":"list_services_by_namespace","content":"pub fn list_services_by_namespace(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.list_services_by_namespace\naws_api/ecs list_services_by_namespace","url":"aws_api/ecs.html#list_services_by_namespace"},{"doc":"aws_api/ecs","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.list_tags_for_resource\naws_api/ecs list_tags_for_resource","url":"aws_api/ecs.html#list_tags_for_resource"},{"doc":"aws_api/ecs","title":"list_task_definition_families","content":"pub fn list_task_definition_families(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.list_task_definition_families\naws_api/ecs list_task_definition_families","url":"aws_api/ecs.html#list_task_definition_families"},{"doc":"aws_api/ecs","title":"list_task_definitions","content":"pub fn list_task_definitions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.list_task_definitions\naws_api/ecs list_task_definitions","url":"aws_api/ecs.html#list_task_definitions"},{"doc":"aws_api/ecs","title":"list_tasks","content":"pub fn list_tasks(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.list_tasks\naws_api/ecs list_tasks","url":"aws_api/ecs.html#list_tasks"},{"doc":"aws_api/ecs","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/ecs.new\naws_api/ecs new","url":"aws_api/ecs.html#new"},{"doc":"aws_api/ecs","title":"put_account_setting","content":"pub fn put_account_setting(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.put_account_setting\naws_api/ecs put_account_setting","url":"aws_api/ecs.html#put_account_setting"},{"doc":"aws_api/ecs","title":"put_account_setting_default","content":"pub fn put_account_setting_default(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.put_account_setting_default\naws_api/ecs put_account_setting_default","url":"aws_api/ecs.html#put_account_setting_default"},{"doc":"aws_api/ecs","title":"put_attributes","content":"pub fn put_attributes(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.put_attributes\naws_api/ecs put_attributes","url":"aws_api/ecs.html#put_attributes"},{"doc":"aws_api/ecs","title":"put_cluster_capacity_providers","content":"pub fn put_cluster_capacity_providers(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.put_cluster_capacity_providers\naws_api/ecs put_cluster_capacity_providers","url":"aws_api/ecs.html#put_cluster_capacity_providers"},{"doc":"aws_api/ecs","title":"register_container_instance","content":"pub fn register_container_instance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.register_container_instance\naws_api/ecs register_container_instance","url":"aws_api/ecs.html#register_container_instance"},{"doc":"aws_api/ecs","title":"register_task_definition","content":"pub fn register_task_definition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.register_task_definition\naws_api/ecs register_task_definition","url":"aws_api/ecs.html#register_task_definition"},{"doc":"aws_api/ecs","title":"run_task","content":"pub fn run_task(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.run_task\naws_api/ecs run_task","url":"aws_api/ecs.html#run_task"},{"doc":"aws_api/ecs","title":"start_task","content":"pub fn start_task(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.start_task\naws_api/ecs start_task","url":"aws_api/ecs.html#start_task"},{"doc":"aws_api/ecs","title":"stop_task","content":"pub fn stop_task(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.stop_task\naws_api/ecs stop_task","url":"aws_api/ecs.html#stop_task"},{"doc":"aws_api/ecs","title":"submit_attachment_state_changes","content":"pub fn submit_attachment_state_changes(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.submit_attachment_state_changes\naws_api/ecs submit_attachment_state_changes","url":"aws_api/ecs.html#submit_attachment_state_changes"},{"doc":"aws_api/ecs","title":"submit_container_state_change","content":"pub fn submit_container_state_change(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.submit_container_state_change\naws_api/ecs submit_container_state_change","url":"aws_api/ecs.html#submit_container_state_change"},{"doc":"aws_api/ecs","title":"submit_task_state_change","content":"pub fn submit_task_state_change(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.submit_task_state_change\naws_api/ecs submit_task_state_change","url":"aws_api/ecs.html#submit_task_state_change"},{"doc":"aws_api/ecs","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.tag_resource\naws_api/ecs tag_resource","url":"aws_api/ecs.html#tag_resource"},{"doc":"aws_api/ecs","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.untag_resource\naws_api/ecs untag_resource","url":"aws_api/ecs.html#untag_resource"},{"doc":"aws_api/ecs","title":"update_capacity_provider","content":"pub fn update_capacity_provider(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.update_capacity_provider\naws_api/ecs update_capacity_provider","url":"aws_api/ecs.html#update_capacity_provider"},{"doc":"aws_api/ecs","title":"update_cluster","content":"pub fn update_cluster(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.update_cluster\naws_api/ecs update_cluster","url":"aws_api/ecs.html#update_cluster"},{"doc":"aws_api/ecs","title":"update_cluster_settings","content":"pub fn update_cluster_settings(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.update_cluster_settings\naws_api/ecs update_cluster_settings","url":"aws_api/ecs.html#update_cluster_settings"},{"doc":"aws_api/ecs","title":"update_container_agent","content":"pub fn update_container_agent(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.update_container_agent\naws_api/ecs update_container_agent","url":"aws_api/ecs.html#update_container_agent"},{"doc":"aws_api/ecs","title":"update_container_instances_state","content":"pub fn update_container_instances_state(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.update_container_instances_state\naws_api/ecs update_container_instances_state","url":"aws_api/ecs.html#update_container_instances_state"},{"doc":"aws_api/ecs","title":"update_service","content":"pub fn update_service(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.update_service\naws_api/ecs update_service","url":"aws_api/ecs.html#update_service"},{"doc":"aws_api/ecs","title":"update_service_primary_task_set","content":"pub fn update_service_primary_task_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.update_service_primary_task_set\naws_api/ecs update_service_primary_task_set","url":"aws_api/ecs.html#update_service_primary_task_set"},{"doc":"aws_api/ecs","title":"update_task_protection","content":"pub fn update_task_protection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.update_task_protection\naws_api/ecs update_task_protection","url":"aws_api/ecs.html#update_task_protection"},{"doc":"aws_api/ecs","title":"update_task_set","content":"pub fn update_task_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ecs.update_task_set\naws_api/ecs update_task_set","url":"aws_api/ecs.html#update_task_set"},{"doc":"aws_api/ecs","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/ecs.with_custom_endpoint\naws_api/ecs with_custom_endpoint","url":"aws_api/ecs.html#with_custom_endpoint"},{"doc":"aws_api/ecs","title":"aws_api/ecs","content":"","url":"aws_api/ecs.html"},{"doc":"aws_api/efs","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/efs.Client\naws_api/efs Client","url":"aws_api/efs.html#Client"},{"doc":"aws_api/efs","title":"create_access_point","content":"pub fn create_access_point(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/efs.create_access_point\naws_api/efs create_access_point","url":"aws_api/efs.html#create_access_point"},{"doc":"aws_api/efs","title":"create_file_system","content":"pub fn create_file_system(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/efs.create_file_system\naws_api/efs create_file_system","url":"aws_api/efs.html#create_file_system"},{"doc":"aws_api/efs","title":"create_mount_target","content":"pub fn create_mount_target(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/efs.create_mount_target\naws_api/efs create_mount_target","url":"aws_api/efs.html#create_mount_target"},{"doc":"aws_api/efs","title":"create_replication_configuration","content":"pub fn create_replication_configuration(\n  client: Client,\n  source_file_system_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/efs.create_replication_configuration\naws_api/efs create_replication_configuration","url":"aws_api/efs.html#create_replication_configuration"},{"doc":"aws_api/efs","title":"create_tags","content":"pub fn create_tags(\n  client: Client,\n  file_system_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/efs.create_tags\naws_api/efs create_tags","url":"aws_api/efs.html#create_tags"},{"doc":"aws_api/efs","title":"delete_access_point","content":"pub fn delete_access_point(\n  client: Client,\n  access_point_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/efs.delete_access_point\naws_api/efs delete_access_point","url":"aws_api/efs.html#delete_access_point"},{"doc":"aws_api/efs","title":"delete_file_system","content":"pub fn delete_file_system(\n  client: Client,\n  file_system_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/efs.delete_file_system\naws_api/efs delete_file_system","url":"aws_api/efs.html#delete_file_system"},{"doc":"aws_api/efs","title":"delete_file_system_policy","content":"pub fn delete_file_system_policy(\n  client: Client,\n  file_system_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/efs.delete_file_system_policy\naws_api/efs delete_file_system_policy","url":"aws_api/efs.html#delete_file_system_policy"},{"doc":"aws_api/efs","title":"delete_mount_target","content":"pub fn delete_mount_target(\n  client: Client,\n  mount_target_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/efs.delete_mount_target\naws_api/efs delete_mount_target","url":"aws_api/efs.html#delete_mount_target"},{"doc":"aws_api/efs","title":"delete_replication_configuration","content":"pub fn delete_replication_configuration(\n  client: Client,\n  source_file_system_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/efs.delete_replication_configuration\naws_api/efs delete_replication_configuration","url":"aws_api/efs.html#delete_replication_configuration"},{"doc":"aws_api/efs","title":"delete_tags","content":"pub fn delete_tags(\n  client: Client,\n  file_system_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/efs.delete_tags\naws_api/efs delete_tags","url":"aws_api/efs.html#delete_tags"},{"doc":"aws_api/efs","title":"describe_access_points","content":"pub fn describe_access_points(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/efs.describe_access_points\naws_api/efs describe_access_points","url":"aws_api/efs.html#describe_access_points"},{"doc":"aws_api/efs","title":"describe_account_preferences","content":"pub fn describe_account_preferences(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/efs.describe_account_preferences\naws_api/efs describe_account_preferences","url":"aws_api/efs.html#describe_account_preferences"},{"doc":"aws_api/efs","title":"describe_backup_policy","content":"pub fn describe_backup_policy(\n  client: Client,\n  file_system_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/efs.describe_backup_policy\naws_api/efs describe_backup_policy","url":"aws_api/efs.html#describe_backup_policy"},{"doc":"aws_api/efs","title":"describe_file_system_policy","content":"pub fn describe_file_system_policy(\n  client: Client,\n  file_system_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/efs.describe_file_system_policy\naws_api/efs describe_file_system_policy","url":"aws_api/efs.html#describe_file_system_policy"},{"doc":"aws_api/efs","title":"describe_file_systems","content":"pub fn describe_file_systems(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/efs.describe_file_systems\naws_api/efs describe_file_systems","url":"aws_api/efs.html#describe_file_systems"},{"doc":"aws_api/efs","title":"describe_lifecycle_configuration","content":"pub fn describe_lifecycle_configuration(\n  client: Client,\n  file_system_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/efs.describe_lifecycle_configuration\naws_api/efs describe_lifecycle_configuration","url":"aws_api/efs.html#describe_lifecycle_configuration"},{"doc":"aws_api/efs","title":"describe_mount_target_security_groups","content":"pub fn describe_mount_target_security_groups(\n  client: Client,\n  mount_target_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/efs.describe_mount_target_security_groups\naws_api/efs describe_mount_target_security_groups","url":"aws_api/efs.html#describe_mount_target_security_groups"},{"doc":"aws_api/efs","title":"describe_mount_targets","content":"pub fn describe_mount_targets(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/efs.describe_mount_targets\naws_api/efs describe_mount_targets","url":"aws_api/efs.html#describe_mount_targets"},{"doc":"aws_api/efs","title":"describe_replication_configurations","content":"pub fn describe_replication_configurations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/efs.describe_replication_configurations\naws_api/efs describe_replication_configurations","url":"aws_api/efs.html#describe_replication_configurations"},{"doc":"aws_api/efs","title":"describe_tags","content":"pub fn describe_tags(\n  client: Client,\n  file_system_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/efs.describe_tags\naws_api/efs describe_tags","url":"aws_api/efs.html#describe_tags"},{"doc":"aws_api/efs","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/efs.list_tags_for_resource\naws_api/efs list_tags_for_resource","url":"aws_api/efs.html#list_tags_for_resource"},{"doc":"aws_api/efs","title":"modify_mount_target_security_groups","content":"pub fn modify_mount_target_security_groups(\n  client: Client,\n  mount_target_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/efs.modify_mount_target_security_groups\naws_api/efs modify_mount_target_security_groups","url":"aws_api/efs.html#modify_mount_target_security_groups"},{"doc":"aws_api/efs","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/efs.new\naws_api/efs new","url":"aws_api/efs.html#new"},{"doc":"aws_api/efs","title":"put_account_preferences","content":"pub fn put_account_preferences(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/efs.put_account_preferences\naws_api/efs put_account_preferences","url":"aws_api/efs.html#put_account_preferences"},{"doc":"aws_api/efs","title":"put_backup_policy","content":"pub fn put_backup_policy(\n  client: Client,\n  file_system_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/efs.put_backup_policy\naws_api/efs put_backup_policy","url":"aws_api/efs.html#put_backup_policy"},{"doc":"aws_api/efs","title":"put_file_system_policy","content":"pub fn put_file_system_policy(\n  client: Client,\n  file_system_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/efs.put_file_system_policy\naws_api/efs put_file_system_policy","url":"aws_api/efs.html#put_file_system_policy"},{"doc":"aws_api/efs","title":"put_lifecycle_configuration","content":"pub fn put_lifecycle_configuration(\n  client: Client,\n  file_system_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/efs.put_lifecycle_configuration\naws_api/efs put_lifecycle_configuration","url":"aws_api/efs.html#put_lifecycle_configuration"},{"doc":"aws_api/efs","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/efs.tag_resource\naws_api/efs tag_resource","url":"aws_api/efs.html#tag_resource"},{"doc":"aws_api/efs","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/efs.untag_resource\naws_api/efs untag_resource","url":"aws_api/efs.html#untag_resource"},{"doc":"aws_api/efs","title":"update_file_system","content":"pub fn update_file_system(\n  client: Client,\n  file_system_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/efs.update_file_system\naws_api/efs update_file_system","url":"aws_api/efs.html#update_file_system"},{"doc":"aws_api/efs","title":"update_file_system_protection","content":"pub fn update_file_system_protection(\n  client: Client,\n  file_system_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/efs.update_file_system_protection\naws_api/efs update_file_system_protection","url":"aws_api/efs.html#update_file_system_protection"},{"doc":"aws_api/efs","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/efs.with_custom_endpoint\naws_api/efs with_custom_endpoint","url":"aws_api/efs.html#with_custom_endpoint"},{"doc":"aws_api/efs","title":"aws_api/efs","content":"","url":"aws_api/efs.html"},{"doc":"aws_api/eks","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/eks.Client\naws_api/eks Client","url":"aws_api/eks.html#Client"},{"doc":"aws_api/eks","title":"associate_access_policy","content":"pub fn associate_access_policy(\n  client: Client,\n  cluster_name: String,\n  principal_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.associate_access_policy\naws_api/eks associate_access_policy","url":"aws_api/eks.html#associate_access_policy"},{"doc":"aws_api/eks","title":"associate_encryption_config","content":"pub fn associate_encryption_config(\n  client: Client,\n  cluster_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.associate_encryption_config\naws_api/eks associate_encryption_config","url":"aws_api/eks.html#associate_encryption_config"},{"doc":"aws_api/eks","title":"associate_identity_provider_config","content":"pub fn associate_identity_provider_config(\n  client: Client,\n  cluster_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.associate_identity_provider_config\naws_api/eks associate_identity_provider_config","url":"aws_api/eks.html#associate_identity_provider_config"},{"doc":"aws_api/eks","title":"create_access_entry","content":"pub fn create_access_entry(\n  client: Client,\n  cluster_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.create_access_entry\naws_api/eks create_access_entry","url":"aws_api/eks.html#create_access_entry"},{"doc":"aws_api/eks","title":"create_addon","content":"pub fn create_addon(\n  client: Client,\n  cluster_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.create_addon\naws_api/eks create_addon","url":"aws_api/eks.html#create_addon"},{"doc":"aws_api/eks","title":"create_cluster","content":"pub fn create_cluster(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.create_cluster\naws_api/eks create_cluster","url":"aws_api/eks.html#create_cluster"},{"doc":"aws_api/eks","title":"create_eks_anywhere_subscription","content":"pub fn create_eks_anywhere_subscription(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.create_eks_anywhere_subscription\naws_api/eks create_eks_anywhere_subscription","url":"aws_api/eks.html#create_eks_anywhere_subscription"},{"doc":"aws_api/eks","title":"create_fargate_profile","content":"pub fn create_fargate_profile(\n  client: Client,\n  cluster_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.create_fargate_profile\naws_api/eks create_fargate_profile","url":"aws_api/eks.html#create_fargate_profile"},{"doc":"aws_api/eks","title":"create_nodegroup","content":"pub fn create_nodegroup(\n  client: Client,\n  cluster_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.create_nodegroup\naws_api/eks create_nodegroup","url":"aws_api/eks.html#create_nodegroup"},{"doc":"aws_api/eks","title":"create_pod_identity_association","content":"pub fn create_pod_identity_association(\n  client: Client,\n  cluster_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.create_pod_identity_association\naws_api/eks create_pod_identity_association","url":"aws_api/eks.html#create_pod_identity_association"},{"doc":"aws_api/eks","title":"delete_access_entry","content":"pub fn delete_access_entry(\n  client: Client,\n  cluster_name: String,\n  principal_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.delete_access_entry\naws_api/eks delete_access_entry","url":"aws_api/eks.html#delete_access_entry"},{"doc":"aws_api/eks","title":"delete_addon","content":"pub fn delete_addon(\n  client: Client,\n  cluster_name: String,\n  addon_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.delete_addon\naws_api/eks delete_addon","url":"aws_api/eks.html#delete_addon"},{"doc":"aws_api/eks","title":"delete_cluster","content":"pub fn delete_cluster(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.delete_cluster\naws_api/eks delete_cluster","url":"aws_api/eks.html#delete_cluster"},{"doc":"aws_api/eks","title":"delete_eks_anywhere_subscription","content":"pub fn delete_eks_anywhere_subscription(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.delete_eks_anywhere_subscription\naws_api/eks delete_eks_anywhere_subscription","url":"aws_api/eks.html#delete_eks_anywhere_subscription"},{"doc":"aws_api/eks","title":"delete_fargate_profile","content":"pub fn delete_fargate_profile(\n  client: Client,\n  cluster_name: String,\n  fargate_profile_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.delete_fargate_profile\naws_api/eks delete_fargate_profile","url":"aws_api/eks.html#delete_fargate_profile"},{"doc":"aws_api/eks","title":"delete_nodegroup","content":"pub fn delete_nodegroup(\n  client: Client,\n  cluster_name: String,\n  nodegroup_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.delete_nodegroup\naws_api/eks delete_nodegroup","url":"aws_api/eks.html#delete_nodegroup"},{"doc":"aws_api/eks","title":"delete_pod_identity_association","content":"pub fn delete_pod_identity_association(\n  client: Client,\n  cluster_name: String,\n  association_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.delete_pod_identity_association\naws_api/eks delete_pod_identity_association","url":"aws_api/eks.html#delete_pod_identity_association"},{"doc":"aws_api/eks","title":"deregister_cluster","content":"pub fn deregister_cluster(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.deregister_cluster\naws_api/eks deregister_cluster","url":"aws_api/eks.html#deregister_cluster"},{"doc":"aws_api/eks","title":"describe_access_entry","content":"pub fn describe_access_entry(\n  client: Client,\n  cluster_name: String,\n  principal_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.describe_access_entry\naws_api/eks describe_access_entry","url":"aws_api/eks.html#describe_access_entry"},{"doc":"aws_api/eks","title":"describe_addon","content":"pub fn describe_addon(\n  client: Client,\n  cluster_name: String,\n  addon_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.describe_addon\naws_api/eks describe_addon","url":"aws_api/eks.html#describe_addon"},{"doc":"aws_api/eks","title":"describe_addon_configuration","content":"pub fn describe_addon_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.describe_addon_configuration\naws_api/eks describe_addon_configuration","url":"aws_api/eks.html#describe_addon_configuration"},{"doc":"aws_api/eks","title":"describe_addon_versions","content":"pub fn describe_addon_versions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.describe_addon_versions\naws_api/eks describe_addon_versions","url":"aws_api/eks.html#describe_addon_versions"},{"doc":"aws_api/eks","title":"describe_cluster","content":"pub fn describe_cluster(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.describe_cluster\naws_api/eks describe_cluster","url":"aws_api/eks.html#describe_cluster"},{"doc":"aws_api/eks","title":"describe_eks_anywhere_subscription","content":"pub fn describe_eks_anywhere_subscription(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.describe_eks_anywhere_subscription\naws_api/eks describe_eks_anywhere_subscription","url":"aws_api/eks.html#describe_eks_anywhere_subscription"},{"doc":"aws_api/eks","title":"describe_fargate_profile","content":"pub fn describe_fargate_profile(\n  client: Client,\n  cluster_name: String,\n  fargate_profile_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.describe_fargate_profile\naws_api/eks describe_fargate_profile","url":"aws_api/eks.html#describe_fargate_profile"},{"doc":"aws_api/eks","title":"describe_identity_provider_config","content":"pub fn describe_identity_provider_config(\n  client: Client,\n  cluster_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.describe_identity_provider_config\naws_api/eks describe_identity_provider_config","url":"aws_api/eks.html#describe_identity_provider_config"},{"doc":"aws_api/eks","title":"describe_insight","content":"pub fn describe_insight(\n  client: Client,\n  cluster_name: String,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.describe_insight\naws_api/eks describe_insight","url":"aws_api/eks.html#describe_insight"},{"doc":"aws_api/eks","title":"describe_nodegroup","content":"pub fn describe_nodegroup(\n  client: Client,\n  cluster_name: String,\n  nodegroup_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.describe_nodegroup\naws_api/eks describe_nodegroup","url":"aws_api/eks.html#describe_nodegroup"},{"doc":"aws_api/eks","title":"describe_pod_identity_association","content":"pub fn describe_pod_identity_association(\n  client: Client,\n  cluster_name: String,\n  association_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.describe_pod_identity_association\naws_api/eks describe_pod_identity_association","url":"aws_api/eks.html#describe_pod_identity_association"},{"doc":"aws_api/eks","title":"describe_update","content":"pub fn describe_update(\n  client: Client,\n  name: String,\n  update_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.describe_update\naws_api/eks describe_update","url":"aws_api/eks.html#describe_update"},{"doc":"aws_api/eks","title":"disassociate_access_policy","content":"pub fn disassociate_access_policy(\n  client: Client,\n  cluster_name: String,\n  principal_arn: String,\n  policy_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.disassociate_access_policy\naws_api/eks disassociate_access_policy","url":"aws_api/eks.html#disassociate_access_policy"},{"doc":"aws_api/eks","title":"disassociate_identity_provider_config","content":"pub fn disassociate_identity_provider_config(\n  client: Client,\n  cluster_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.disassociate_identity_provider_config\naws_api/eks disassociate_identity_provider_config","url":"aws_api/eks.html#disassociate_identity_provider_config"},{"doc":"aws_api/eks","title":"list_access_entries","content":"pub fn list_access_entries(\n  client: Client,\n  cluster_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.list_access_entries\naws_api/eks list_access_entries","url":"aws_api/eks.html#list_access_entries"},{"doc":"aws_api/eks","title":"list_access_policies","content":"pub fn list_access_policies(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.list_access_policies\naws_api/eks list_access_policies","url":"aws_api/eks.html#list_access_policies"},{"doc":"aws_api/eks","title":"list_addons","content":"pub fn list_addons(\n  client: Client,\n  cluster_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.list_addons\naws_api/eks list_addons","url":"aws_api/eks.html#list_addons"},{"doc":"aws_api/eks","title":"list_associated_access_policies","content":"pub fn list_associated_access_policies(\n  client: Client,\n  cluster_name: String,\n  principal_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.list_associated_access_policies\naws_api/eks list_associated_access_policies","url":"aws_api/eks.html#list_associated_access_policies"},{"doc":"aws_api/eks","title":"list_clusters","content":"pub fn list_clusters(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.list_clusters\naws_api/eks list_clusters","url":"aws_api/eks.html#list_clusters"},{"doc":"aws_api/eks","title":"list_eks_anywhere_subscriptions","content":"pub fn list_eks_anywhere_subscriptions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.list_eks_anywhere_subscriptions\naws_api/eks list_eks_anywhere_subscriptions","url":"aws_api/eks.html#list_eks_anywhere_subscriptions"},{"doc":"aws_api/eks","title":"list_fargate_profiles","content":"pub fn list_fargate_profiles(\n  client: Client,\n  cluster_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.list_fargate_profiles\naws_api/eks list_fargate_profiles","url":"aws_api/eks.html#list_fargate_profiles"},{"doc":"aws_api/eks","title":"list_identity_provider_configs","content":"pub fn list_identity_provider_configs(\n  client: Client,\n  cluster_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.list_identity_provider_configs\naws_api/eks list_identity_provider_configs","url":"aws_api/eks.html#list_identity_provider_configs"},{"doc":"aws_api/eks","title":"list_insights","content":"pub fn list_insights(\n  client: Client,\n  cluster_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.list_insights\naws_api/eks list_insights","url":"aws_api/eks.html#list_insights"},{"doc":"aws_api/eks","title":"list_nodegroups","content":"pub fn list_nodegroups(\n  client: Client,\n  cluster_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.list_nodegroups\naws_api/eks list_nodegroups","url":"aws_api/eks.html#list_nodegroups"},{"doc":"aws_api/eks","title":"list_pod_identity_associations","content":"pub fn list_pod_identity_associations(\n  client: Client,\n  cluster_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.list_pod_identity_associations\naws_api/eks list_pod_identity_associations","url":"aws_api/eks.html#list_pod_identity_associations"},{"doc":"aws_api/eks","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.list_tags_for_resource\naws_api/eks list_tags_for_resource","url":"aws_api/eks.html#list_tags_for_resource"},{"doc":"aws_api/eks","title":"list_updates","content":"pub fn list_updates(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.list_updates\naws_api/eks list_updates","url":"aws_api/eks.html#list_updates"},{"doc":"aws_api/eks","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/eks.new\naws_api/eks new","url":"aws_api/eks.html#new"},{"doc":"aws_api/eks","title":"register_cluster","content":"pub fn register_cluster(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.register_cluster\naws_api/eks register_cluster","url":"aws_api/eks.html#register_cluster"},{"doc":"aws_api/eks","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.tag_resource\naws_api/eks tag_resource","url":"aws_api/eks.html#tag_resource"},{"doc":"aws_api/eks","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.untag_resource\naws_api/eks untag_resource","url":"aws_api/eks.html#untag_resource"},{"doc":"aws_api/eks","title":"update_access_entry","content":"pub fn update_access_entry(\n  client: Client,\n  cluster_name: String,\n  principal_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.update_access_entry\naws_api/eks update_access_entry","url":"aws_api/eks.html#update_access_entry"},{"doc":"aws_api/eks","title":"update_addon","content":"pub fn update_addon(\n  client: Client,\n  cluster_name: String,\n  addon_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.update_addon\naws_api/eks update_addon","url":"aws_api/eks.html#update_addon"},{"doc":"aws_api/eks","title":"update_cluster_config","content":"pub fn update_cluster_config(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.update_cluster_config\naws_api/eks update_cluster_config","url":"aws_api/eks.html#update_cluster_config"},{"doc":"aws_api/eks","title":"update_cluster_version","content":"pub fn update_cluster_version(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.update_cluster_version\naws_api/eks update_cluster_version","url":"aws_api/eks.html#update_cluster_version"},{"doc":"aws_api/eks","title":"update_eks_anywhere_subscription","content":"pub fn update_eks_anywhere_subscription(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.update_eks_anywhere_subscription\naws_api/eks update_eks_anywhere_subscription","url":"aws_api/eks.html#update_eks_anywhere_subscription"},{"doc":"aws_api/eks","title":"update_nodegroup_config","content":"pub fn update_nodegroup_config(\n  client: Client,\n  cluster_name: String,\n  nodegroup_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.update_nodegroup_config\naws_api/eks update_nodegroup_config","url":"aws_api/eks.html#update_nodegroup_config"},{"doc":"aws_api/eks","title":"update_nodegroup_version","content":"pub fn update_nodegroup_version(\n  client: Client,\n  cluster_name: String,\n  nodegroup_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.update_nodegroup_version\naws_api/eks update_nodegroup_version","url":"aws_api/eks.html#update_nodegroup_version"},{"doc":"aws_api/eks","title":"update_pod_identity_association","content":"pub fn update_pod_identity_association(\n  client: Client,\n  cluster_name: String,\n  association_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks.update_pod_identity_association\naws_api/eks update_pod_identity_association","url":"aws_api/eks.html#update_pod_identity_association"},{"doc":"aws_api/eks","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/eks.with_custom_endpoint\naws_api/eks with_custom_endpoint","url":"aws_api/eks.html#with_custom_endpoint"},{"doc":"aws_api/eks","title":"aws_api/eks","content":"","url":"aws_api/eks.html"},{"doc":"aws_api/eks_auth","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/eks_auth.Client\naws_api/eks_auth Client","url":"aws_api/eks_auth.html#Client"},{"doc":"aws_api/eks_auth","title":"assume_role_for_pod_identity","content":"pub fn assume_role_for_pod_identity(\n  client: Client,\n  cluster_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eks_auth.assume_role_for_pod_identity\naws_api/eks_auth assume_role_for_pod_identity","url":"aws_api/eks_auth.html#assume_role_for_pod_identity"},{"doc":"aws_api/eks_auth","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/eks_auth.new\naws_api/eks_auth new","url":"aws_api/eks_auth.html#new"},{"doc":"aws_api/eks_auth","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/eks_auth.with_custom_endpoint\naws_api/eks_auth with_custom_endpoint","url":"aws_api/eks_auth.html#with_custom_endpoint"},{"doc":"aws_api/eks_auth","title":"aws_api/eks_auth","content":"","url":"aws_api/eks_auth.html"},{"doc":"aws_api/elastic_beanstalk","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/elastic_beanstalk.Client\naws_api/elastic_beanstalk Client","url":"aws_api/elastic_beanstalk.html#Client"},{"doc":"aws_api/elastic_beanstalk","title":"abort_environment_update","content":"pub fn abort_environment_update(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_beanstalk.abort_environment_update\naws_api/elastic_beanstalk abort_environment_update","url":"aws_api/elastic_beanstalk.html#abort_environment_update"},{"doc":"aws_api/elastic_beanstalk","title":"apply_environment_managed_action","content":"pub fn apply_environment_managed_action(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_beanstalk.apply_environment_managed_action\naws_api/elastic_beanstalk apply_environment_managed_action","url":"aws_api/elastic_beanstalk.html#apply_environment_managed_action"},{"doc":"aws_api/elastic_beanstalk","title":"associate_environment_operations_role","content":"pub fn associate_environment_operations_role(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_beanstalk.associate_environment_operations_role\naws_api/elastic_beanstalk associate_environment_operations_role","url":"aws_api/elastic_beanstalk.html#associate_environment_operations_role"},{"doc":"aws_api/elastic_beanstalk","title":"check_dns_availability","content":"pub fn check_dns_availability(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_beanstalk.check_dns_availability\naws_api/elastic_beanstalk check_dns_availability","url":"aws_api/elastic_beanstalk.html#check_dns_availability"},{"doc":"aws_api/elastic_beanstalk","title":"compose_environments","content":"pub fn compose_environments(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_beanstalk.compose_environments\naws_api/elastic_beanstalk compose_environments","url":"aws_api/elastic_beanstalk.html#compose_environments"},{"doc":"aws_api/elastic_beanstalk","title":"create_application","content":"pub fn create_application(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_beanstalk.create_application\naws_api/elastic_beanstalk create_application","url":"aws_api/elastic_beanstalk.html#create_application"},{"doc":"aws_api/elastic_beanstalk","title":"create_application_version","content":"pub fn create_application_version(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_beanstalk.create_application_version\naws_api/elastic_beanstalk create_application_version","url":"aws_api/elastic_beanstalk.html#create_application_version"},{"doc":"aws_api/elastic_beanstalk","title":"create_configuration_template","content":"pub fn create_configuration_template(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_beanstalk.create_configuration_template\naws_api/elastic_beanstalk create_configuration_template","url":"aws_api/elastic_beanstalk.html#create_configuration_template"},{"doc":"aws_api/elastic_beanstalk","title":"create_environment","content":"pub fn create_environment(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_beanstalk.create_environment\naws_api/elastic_beanstalk create_environment","url":"aws_api/elastic_beanstalk.html#create_environment"},{"doc":"aws_api/elastic_beanstalk","title":"create_platform_version","content":"pub fn create_platform_version(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_beanstalk.create_platform_version\naws_api/elastic_beanstalk create_platform_version","url":"aws_api/elastic_beanstalk.html#create_platform_version"},{"doc":"aws_api/elastic_beanstalk","title":"create_storage_location","content":"pub fn create_storage_location(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_beanstalk.create_storage_location\naws_api/elastic_beanstalk create_storage_location","url":"aws_api/elastic_beanstalk.html#create_storage_location"},{"doc":"aws_api/elastic_beanstalk","title":"delete_application","content":"pub fn delete_application(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_beanstalk.delete_application\naws_api/elastic_beanstalk delete_application","url":"aws_api/elastic_beanstalk.html#delete_application"},{"doc":"aws_api/elastic_beanstalk","title":"delete_application_version","content":"pub fn delete_application_version(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_beanstalk.delete_application_version\naws_api/elastic_beanstalk delete_application_version","url":"aws_api/elastic_beanstalk.html#delete_application_version"},{"doc":"aws_api/elastic_beanstalk","title":"delete_configuration_template","content":"pub fn delete_configuration_template(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_beanstalk.delete_configuration_template\naws_api/elastic_beanstalk delete_configuration_template","url":"aws_api/elastic_beanstalk.html#delete_configuration_template"},{"doc":"aws_api/elastic_beanstalk","title":"delete_environment_configuration","content":"pub fn delete_environment_configuration(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_beanstalk.delete_environment_configuration\naws_api/elastic_beanstalk delete_environment_configuration","url":"aws_api/elastic_beanstalk.html#delete_environment_configuration"},{"doc":"aws_api/elastic_beanstalk","title":"delete_platform_version","content":"pub fn delete_platform_version(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_beanstalk.delete_platform_version\naws_api/elastic_beanstalk delete_platform_version","url":"aws_api/elastic_beanstalk.html#delete_platform_version"},{"doc":"aws_api/elastic_beanstalk","title":"describe_account_attributes","content":"pub fn describe_account_attributes(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_beanstalk.describe_account_attributes\naws_api/elastic_beanstalk describe_account_attributes","url":"aws_api/elastic_beanstalk.html#describe_account_attributes"},{"doc":"aws_api/elastic_beanstalk","title":"describe_application_versions","content":"pub fn describe_application_versions(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_beanstalk.describe_application_versions\naws_api/elastic_beanstalk describe_application_versions","url":"aws_api/elastic_beanstalk.html#describe_application_versions"},{"doc":"aws_api/elastic_beanstalk","title":"describe_applications","content":"pub fn describe_applications(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_beanstalk.describe_applications\naws_api/elastic_beanstalk describe_applications","url":"aws_api/elastic_beanstalk.html#describe_applications"},{"doc":"aws_api/elastic_beanstalk","title":"describe_configuration_options","content":"pub fn describe_configuration_options(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_beanstalk.describe_configuration_options\naws_api/elastic_beanstalk describe_configuration_options","url":"aws_api/elastic_beanstalk.html#describe_configuration_options"},{"doc":"aws_api/elastic_beanstalk","title":"describe_configuration_settings","content":"pub fn describe_configuration_settings(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_beanstalk.describe_configuration_settings\naws_api/elastic_beanstalk describe_configuration_settings","url":"aws_api/elastic_beanstalk.html#describe_configuration_settings"},{"doc":"aws_api/elastic_beanstalk","title":"describe_environment_health","content":"pub fn describe_environment_health(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_beanstalk.describe_environment_health\naws_api/elastic_beanstalk describe_environment_health","url":"aws_api/elastic_beanstalk.html#describe_environment_health"},{"doc":"aws_api/elastic_beanstalk","title":"describe_environment_managed_action_history","content":"pub fn describe_environment_managed_action_history(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_beanstalk.describe_environment_managed_action_history\naws_api/elastic_beanstalk describe_environment_managed_action_history","url":"aws_api/elastic_beanstalk.html#describe_environment_managed_action_history"},{"doc":"aws_api/elastic_beanstalk","title":"describe_environment_managed_actions","content":"pub fn describe_environment_managed_actions(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_beanstalk.describe_environment_managed_actions\naws_api/elastic_beanstalk describe_environment_managed_actions","url":"aws_api/elastic_beanstalk.html#describe_environment_managed_actions"},{"doc":"aws_api/elastic_beanstalk","title":"describe_environment_resources","content":"pub fn describe_environment_resources(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_beanstalk.describe_environment_resources\naws_api/elastic_beanstalk describe_environment_resources","url":"aws_api/elastic_beanstalk.html#describe_environment_resources"},{"doc":"aws_api/elastic_beanstalk","title":"describe_environments","content":"pub fn describe_environments(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_beanstalk.describe_environments\naws_api/elastic_beanstalk describe_environments","url":"aws_api/elastic_beanstalk.html#describe_environments"},{"doc":"aws_api/elastic_beanstalk","title":"describe_events","content":"pub fn describe_events(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_beanstalk.describe_events\naws_api/elastic_beanstalk describe_events","url":"aws_api/elastic_beanstalk.html#describe_events"},{"doc":"aws_api/elastic_beanstalk","title":"describe_instances_health","content":"pub fn describe_instances_health(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_beanstalk.describe_instances_health\naws_api/elastic_beanstalk describe_instances_health","url":"aws_api/elastic_beanstalk.html#describe_instances_health"},{"doc":"aws_api/elastic_beanstalk","title":"describe_platform_version","content":"pub fn describe_platform_version(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_beanstalk.describe_platform_version\naws_api/elastic_beanstalk describe_platform_version","url":"aws_api/elastic_beanstalk.html#describe_platform_version"},{"doc":"aws_api/elastic_beanstalk","title":"disassociate_environment_operations_role","content":"pub fn disassociate_environment_operations_role(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_beanstalk.disassociate_environment_operations_role\naws_api/elastic_beanstalk disassociate_environment_operations_role","url":"aws_api/elastic_beanstalk.html#disassociate_environment_operations_role"},{"doc":"aws_api/elastic_beanstalk","title":"list_available_solution_stacks","content":"pub fn list_available_solution_stacks(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_beanstalk.list_available_solution_stacks\naws_api/elastic_beanstalk list_available_solution_stacks","url":"aws_api/elastic_beanstalk.html#list_available_solution_stacks"},{"doc":"aws_api/elastic_beanstalk","title":"list_platform_branches","content":"pub fn list_platform_branches(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_beanstalk.list_platform_branches\naws_api/elastic_beanstalk list_platform_branches","url":"aws_api/elastic_beanstalk.html#list_platform_branches"},{"doc":"aws_api/elastic_beanstalk","title":"list_platform_versions","content":"pub fn list_platform_versions(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_beanstalk.list_platform_versions\naws_api/elastic_beanstalk list_platform_versions","url":"aws_api/elastic_beanstalk.html#list_platform_versions"},{"doc":"aws_api/elastic_beanstalk","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_beanstalk.list_tags_for_resource\naws_api/elastic_beanstalk list_tags_for_resource","url":"aws_api/elastic_beanstalk.html#list_tags_for_resource"},{"doc":"aws_api/elastic_beanstalk","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/elastic_beanstalk.new\naws_api/elastic_beanstalk new","url":"aws_api/elastic_beanstalk.html#new"},{"doc":"aws_api/elastic_beanstalk","title":"rebuild_environment","content":"pub fn rebuild_environment(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_beanstalk.rebuild_environment\naws_api/elastic_beanstalk rebuild_environment","url":"aws_api/elastic_beanstalk.html#rebuild_environment"},{"doc":"aws_api/elastic_beanstalk","title":"request_environment_info","content":"pub fn request_environment_info(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_beanstalk.request_environment_info\naws_api/elastic_beanstalk request_environment_info","url":"aws_api/elastic_beanstalk.html#request_environment_info"},{"doc":"aws_api/elastic_beanstalk","title":"restart_app_server","content":"pub fn restart_app_server(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_beanstalk.restart_app_server\naws_api/elastic_beanstalk restart_app_server","url":"aws_api/elastic_beanstalk.html#restart_app_server"},{"doc":"aws_api/elastic_beanstalk","title":"retrieve_environment_info","content":"pub fn retrieve_environment_info(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_beanstalk.retrieve_environment_info\naws_api/elastic_beanstalk retrieve_environment_info","url":"aws_api/elastic_beanstalk.html#retrieve_environment_info"},{"doc":"aws_api/elastic_beanstalk","title":"swap_environment_cnam_es","content":"pub fn swap_environment_cnam_es(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_beanstalk.swap_environment_cnam_es\naws_api/elastic_beanstalk swap_environment_cnam_es","url":"aws_api/elastic_beanstalk.html#swap_environment_cnam_es"},{"doc":"aws_api/elastic_beanstalk","title":"terminate_environment","content":"pub fn terminate_environment(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_beanstalk.terminate_environment\naws_api/elastic_beanstalk terminate_environment","url":"aws_api/elastic_beanstalk.html#terminate_environment"},{"doc":"aws_api/elastic_beanstalk","title":"update_application","content":"pub fn update_application(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_beanstalk.update_application\naws_api/elastic_beanstalk update_application","url":"aws_api/elastic_beanstalk.html#update_application"},{"doc":"aws_api/elastic_beanstalk","title":"update_application_resource_lifecycle","content":"pub fn update_application_resource_lifecycle(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_beanstalk.update_application_resource_lifecycle\naws_api/elastic_beanstalk update_application_resource_lifecycle","url":"aws_api/elastic_beanstalk.html#update_application_resource_lifecycle"},{"doc":"aws_api/elastic_beanstalk","title":"update_application_version","content":"pub fn update_application_version(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_beanstalk.update_application_version\naws_api/elastic_beanstalk update_application_version","url":"aws_api/elastic_beanstalk.html#update_application_version"},{"doc":"aws_api/elastic_beanstalk","title":"update_configuration_template","content":"pub fn update_configuration_template(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_beanstalk.update_configuration_template\naws_api/elastic_beanstalk update_configuration_template","url":"aws_api/elastic_beanstalk.html#update_configuration_template"},{"doc":"aws_api/elastic_beanstalk","title":"update_environment","content":"pub fn update_environment(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_beanstalk.update_environment\naws_api/elastic_beanstalk update_environment","url":"aws_api/elastic_beanstalk.html#update_environment"},{"doc":"aws_api/elastic_beanstalk","title":"update_tags_for_resource","content":"pub fn update_tags_for_resource(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_beanstalk.update_tags_for_resource\naws_api/elastic_beanstalk update_tags_for_resource","url":"aws_api/elastic_beanstalk.html#update_tags_for_resource"},{"doc":"aws_api/elastic_beanstalk","title":"validate_configuration_settings","content":"pub fn validate_configuration_settings(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_beanstalk.validate_configuration_settings\naws_api/elastic_beanstalk validate_configuration_settings","url":"aws_api/elastic_beanstalk.html#validate_configuration_settings"},{"doc":"aws_api/elastic_beanstalk","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/elastic_beanstalk.with_custom_endpoint\naws_api/elastic_beanstalk with_custom_endpoint","url":"aws_api/elastic_beanstalk.html#with_custom_endpoint"},{"doc":"aws_api/elastic_beanstalk","title":"aws_api/elastic_beanstalk","content":"","url":"aws_api/elastic_beanstalk.html"},{"doc":"aws_api/elastic_inference","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/elastic_inference.Client\naws_api/elastic_inference Client","url":"aws_api/elastic_inference.html#Client"},{"doc":"aws_api/elastic_inference","title":"describe_accelerator_offerings","content":"pub fn describe_accelerator_offerings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_inference.describe_accelerator_offerings\naws_api/elastic_inference describe_accelerator_offerings","url":"aws_api/elastic_inference.html#describe_accelerator_offerings"},{"doc":"aws_api/elastic_inference","title":"describe_accelerator_types","content":"pub fn describe_accelerator_types(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_inference.describe_accelerator_types\naws_api/elastic_inference describe_accelerator_types","url":"aws_api/elastic_inference.html#describe_accelerator_types"},{"doc":"aws_api/elastic_inference","title":"describe_accelerators","content":"pub fn describe_accelerators(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_inference.describe_accelerators\naws_api/elastic_inference describe_accelerators","url":"aws_api/elastic_inference.html#describe_accelerators"},{"doc":"aws_api/elastic_inference","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_inference.list_tags_for_resource\naws_api/elastic_inference list_tags_for_resource","url":"aws_api/elastic_inference.html#list_tags_for_resource"},{"doc":"aws_api/elastic_inference","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/elastic_inference.new\naws_api/elastic_inference new","url":"aws_api/elastic_inference.html#new"},{"doc":"aws_api/elastic_inference","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_inference.tag_resource\naws_api/elastic_inference tag_resource","url":"aws_api/elastic_inference.html#tag_resource"},{"doc":"aws_api/elastic_inference","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_inference.untag_resource\naws_api/elastic_inference untag_resource","url":"aws_api/elastic_inference.html#untag_resource"},{"doc":"aws_api/elastic_inference","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/elastic_inference.with_custom_endpoint\naws_api/elastic_inference with_custom_endpoint","url":"aws_api/elastic_inference.html#with_custom_endpoint"},{"doc":"aws_api/elastic_inference","title":"aws_api/elastic_inference","content":"","url":"aws_api/elastic_inference.html"},{"doc":"aws_api/elastic_load_balancing","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/elastic_load_balancing.Client\naws_api/elastic_load_balancing Client","url":"aws_api/elastic_load_balancing.html#Client"},{"doc":"aws_api/elastic_load_balancing","title":"add_tags","content":"pub fn add_tags(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing.add_tags\naws_api/elastic_load_balancing add_tags","url":"aws_api/elastic_load_balancing.html#add_tags"},{"doc":"aws_api/elastic_load_balancing","title":"apply_security_groups_to_load_balancer","content":"pub fn apply_security_groups_to_load_balancer(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing.apply_security_groups_to_load_balancer\naws_api/elastic_load_balancing apply_security_groups_to_load_balancer","url":"aws_api/elastic_load_balancing.html#apply_security_groups_to_load_balancer"},{"doc":"aws_api/elastic_load_balancing","title":"attach_load_balancer_to_subnets","content":"pub fn attach_load_balancer_to_subnets(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing.attach_load_balancer_to_subnets\naws_api/elastic_load_balancing attach_load_balancer_to_subnets","url":"aws_api/elastic_load_balancing.html#attach_load_balancer_to_subnets"},{"doc":"aws_api/elastic_load_balancing","title":"configure_health_check","content":"pub fn configure_health_check(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing.configure_health_check\naws_api/elastic_load_balancing configure_health_check","url":"aws_api/elastic_load_balancing.html#configure_health_check"},{"doc":"aws_api/elastic_load_balancing","title":"create_app_cookie_stickiness_policy","content":"pub fn create_app_cookie_stickiness_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing.create_app_cookie_stickiness_policy\naws_api/elastic_load_balancing create_app_cookie_stickiness_policy","url":"aws_api/elastic_load_balancing.html#create_app_cookie_stickiness_policy"},{"doc":"aws_api/elastic_load_balancing","title":"create_lb_cookie_stickiness_policy","content":"pub fn create_lb_cookie_stickiness_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing.create_lb_cookie_stickiness_policy\naws_api/elastic_load_balancing create_lb_cookie_stickiness_policy","url":"aws_api/elastic_load_balancing.html#create_lb_cookie_stickiness_policy"},{"doc":"aws_api/elastic_load_balancing","title":"create_load_balancer","content":"pub fn create_load_balancer(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing.create_load_balancer\naws_api/elastic_load_balancing create_load_balancer","url":"aws_api/elastic_load_balancing.html#create_load_balancer"},{"doc":"aws_api/elastic_load_balancing","title":"create_load_balancer_listeners","content":"pub fn create_load_balancer_listeners(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing.create_load_balancer_listeners\naws_api/elastic_load_balancing create_load_balancer_listeners","url":"aws_api/elastic_load_balancing.html#create_load_balancer_listeners"},{"doc":"aws_api/elastic_load_balancing","title":"create_load_balancer_policy","content":"pub fn create_load_balancer_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing.create_load_balancer_policy\naws_api/elastic_load_balancing create_load_balancer_policy","url":"aws_api/elastic_load_balancing.html#create_load_balancer_policy"},{"doc":"aws_api/elastic_load_balancing","title":"delete_load_balancer","content":"pub fn delete_load_balancer(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing.delete_load_balancer\naws_api/elastic_load_balancing delete_load_balancer","url":"aws_api/elastic_load_balancing.html#delete_load_balancer"},{"doc":"aws_api/elastic_load_balancing","title":"delete_load_balancer_listeners","content":"pub fn delete_load_balancer_listeners(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing.delete_load_balancer_listeners\naws_api/elastic_load_balancing delete_load_balancer_listeners","url":"aws_api/elastic_load_balancing.html#delete_load_balancer_listeners"},{"doc":"aws_api/elastic_load_balancing","title":"delete_load_balancer_policy","content":"pub fn delete_load_balancer_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing.delete_load_balancer_policy\naws_api/elastic_load_balancing delete_load_balancer_policy","url":"aws_api/elastic_load_balancing.html#delete_load_balancer_policy"},{"doc":"aws_api/elastic_load_balancing","title":"deregister_instances_from_load_balancer","content":"pub fn deregister_instances_from_load_balancer(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing.deregister_instances_from_load_balancer\naws_api/elastic_load_balancing deregister_instances_from_load_balancer","url":"aws_api/elastic_load_balancing.html#deregister_instances_from_load_balancer"},{"doc":"aws_api/elastic_load_balancing","title":"describe_account_limits","content":"pub fn describe_account_limits(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing.describe_account_limits\naws_api/elastic_load_balancing describe_account_limits","url":"aws_api/elastic_load_balancing.html#describe_account_limits"},{"doc":"aws_api/elastic_load_balancing","title":"describe_instance_health","content":"pub fn describe_instance_health(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing.describe_instance_health\naws_api/elastic_load_balancing describe_instance_health","url":"aws_api/elastic_load_balancing.html#describe_instance_health"},{"doc":"aws_api/elastic_load_balancing","title":"describe_load_balancer_attributes","content":"pub fn describe_load_balancer_attributes(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing.describe_load_balancer_attributes\naws_api/elastic_load_balancing describe_load_balancer_attributes","url":"aws_api/elastic_load_balancing.html#describe_load_balancer_attributes"},{"doc":"aws_api/elastic_load_balancing","title":"describe_load_balancer_policies","content":"pub fn describe_load_balancer_policies(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing.describe_load_balancer_policies\naws_api/elastic_load_balancing describe_load_balancer_policies","url":"aws_api/elastic_load_balancing.html#describe_load_balancer_policies"},{"doc":"aws_api/elastic_load_balancing","title":"describe_load_balancer_policy_types","content":"pub fn describe_load_balancer_policy_types(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing.describe_load_balancer_policy_types\naws_api/elastic_load_balancing describe_load_balancer_policy_types","url":"aws_api/elastic_load_balancing.html#describe_load_balancer_policy_types"},{"doc":"aws_api/elastic_load_balancing","title":"describe_load_balancers","content":"pub fn describe_load_balancers(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing.describe_load_balancers\naws_api/elastic_load_balancing describe_load_balancers","url":"aws_api/elastic_load_balancing.html#describe_load_balancers"},{"doc":"aws_api/elastic_load_balancing","title":"describe_tags","content":"pub fn describe_tags(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing.describe_tags\naws_api/elastic_load_balancing describe_tags","url":"aws_api/elastic_load_balancing.html#describe_tags"},{"doc":"aws_api/elastic_load_balancing","title":"detach_load_balancer_from_subnets","content":"pub fn detach_load_balancer_from_subnets(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing.detach_load_balancer_from_subnets\naws_api/elastic_load_balancing detach_load_balancer_from_subnets","url":"aws_api/elastic_load_balancing.html#detach_load_balancer_from_subnets"},{"doc":"aws_api/elastic_load_balancing","title":"disable_availability_zones_for_load_balancer","content":"pub fn disable_availability_zones_for_load_balancer(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing.disable_availability_zones_for_load_balancer\naws_api/elastic_load_balancing disable_availability_zones_for_load_balancer","url":"aws_api/elastic_load_balancing.html#disable_availability_zones_for_load_balancer"},{"doc":"aws_api/elastic_load_balancing","title":"enable_availability_zones_for_load_balancer","content":"pub fn enable_availability_zones_for_load_balancer(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing.enable_availability_zones_for_load_balancer\naws_api/elastic_load_balancing enable_availability_zones_for_load_balancer","url":"aws_api/elastic_load_balancing.html#enable_availability_zones_for_load_balancer"},{"doc":"aws_api/elastic_load_balancing","title":"modify_load_balancer_attributes","content":"pub fn modify_load_balancer_attributes(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing.modify_load_balancer_attributes\naws_api/elastic_load_balancing modify_load_balancer_attributes","url":"aws_api/elastic_load_balancing.html#modify_load_balancer_attributes"},{"doc":"aws_api/elastic_load_balancing","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/elastic_load_balancing.new\naws_api/elastic_load_balancing new","url":"aws_api/elastic_load_balancing.html#new"},{"doc":"aws_api/elastic_load_balancing","title":"register_instances_with_load_balancer","content":"pub fn register_instances_with_load_balancer(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing.register_instances_with_load_balancer\naws_api/elastic_load_balancing register_instances_with_load_balancer","url":"aws_api/elastic_load_balancing.html#register_instances_with_load_balancer"},{"doc":"aws_api/elastic_load_balancing","title":"remove_tags","content":"pub fn remove_tags(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing.remove_tags\naws_api/elastic_load_balancing remove_tags","url":"aws_api/elastic_load_balancing.html#remove_tags"},{"doc":"aws_api/elastic_load_balancing","title":"set_load_balancer_listener_ssl_certificate","content":"pub fn set_load_balancer_listener_ssl_certificate(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing.set_load_balancer_listener_ssl_certificate\naws_api/elastic_load_balancing set_load_balancer_listener_ssl_certificate","url":"aws_api/elastic_load_balancing.html#set_load_balancer_listener_ssl_certificate"},{"doc":"aws_api/elastic_load_balancing","title":"set_load_balancer_policies_for_backend_server","content":"pub fn set_load_balancer_policies_for_backend_server(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing.set_load_balancer_policies_for_backend_server\naws_api/elastic_load_balancing set_load_balancer_policies_for_backend_server","url":"aws_api/elastic_load_balancing.html#set_load_balancer_policies_for_backend_server"},{"doc":"aws_api/elastic_load_balancing","title":"set_load_balancer_policies_of_listener","content":"pub fn set_load_balancer_policies_of_listener(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing.set_load_balancer_policies_of_listener\naws_api/elastic_load_balancing set_load_balancer_policies_of_listener","url":"aws_api/elastic_load_balancing.html#set_load_balancer_policies_of_listener"},{"doc":"aws_api/elastic_load_balancing","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/elastic_load_balancing.with_custom_endpoint\naws_api/elastic_load_balancing with_custom_endpoint","url":"aws_api/elastic_load_balancing.html#with_custom_endpoint"},{"doc":"aws_api/elastic_load_balancing","title":"aws_api/elastic_load_balancing","content":"","url":"aws_api/elastic_load_balancing.html"},{"doc":"aws_api/elastic_load_balancing_v2","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/elastic_load_balancing_v2.Client\naws_api/elastic_load_balancing_v2 Client","url":"aws_api/elastic_load_balancing_v2.html#Client"},{"doc":"aws_api/elastic_load_balancing_v2","title":"add_listener_certificates","content":"pub fn add_listener_certificates(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing_v2.add_listener_certificates\naws_api/elastic_load_balancing_v2 add_listener_certificates","url":"aws_api/elastic_load_balancing_v2.html#add_listener_certificates"},{"doc":"aws_api/elastic_load_balancing_v2","title":"add_tags","content":"pub fn add_tags(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing_v2.add_tags\naws_api/elastic_load_balancing_v2 add_tags","url":"aws_api/elastic_load_balancing_v2.html#add_tags"},{"doc":"aws_api/elastic_load_balancing_v2","title":"add_trust_store_revocations","content":"pub fn add_trust_store_revocations(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing_v2.add_trust_store_revocations\naws_api/elastic_load_balancing_v2 add_trust_store_revocations","url":"aws_api/elastic_load_balancing_v2.html#add_trust_store_revocations"},{"doc":"aws_api/elastic_load_balancing_v2","title":"create_listener","content":"pub fn create_listener(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing_v2.create_listener\naws_api/elastic_load_balancing_v2 create_listener","url":"aws_api/elastic_load_balancing_v2.html#create_listener"},{"doc":"aws_api/elastic_load_balancing_v2","title":"create_load_balancer","content":"pub fn create_load_balancer(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing_v2.create_load_balancer\naws_api/elastic_load_balancing_v2 create_load_balancer","url":"aws_api/elastic_load_balancing_v2.html#create_load_balancer"},{"doc":"aws_api/elastic_load_balancing_v2","title":"create_rule","content":"pub fn create_rule(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing_v2.create_rule\naws_api/elastic_load_balancing_v2 create_rule","url":"aws_api/elastic_load_balancing_v2.html#create_rule"},{"doc":"aws_api/elastic_load_balancing_v2","title":"create_target_group","content":"pub fn create_target_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing_v2.create_target_group\naws_api/elastic_load_balancing_v2 create_target_group","url":"aws_api/elastic_load_balancing_v2.html#create_target_group"},{"doc":"aws_api/elastic_load_balancing_v2","title":"create_trust_store","content":"pub fn create_trust_store(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing_v2.create_trust_store\naws_api/elastic_load_balancing_v2 create_trust_store","url":"aws_api/elastic_load_balancing_v2.html#create_trust_store"},{"doc":"aws_api/elastic_load_balancing_v2","title":"delete_listener","content":"pub fn delete_listener(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing_v2.delete_listener\naws_api/elastic_load_balancing_v2 delete_listener","url":"aws_api/elastic_load_balancing_v2.html#delete_listener"},{"doc":"aws_api/elastic_load_balancing_v2","title":"delete_load_balancer","content":"pub fn delete_load_balancer(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing_v2.delete_load_balancer\naws_api/elastic_load_balancing_v2 delete_load_balancer","url":"aws_api/elastic_load_balancing_v2.html#delete_load_balancer"},{"doc":"aws_api/elastic_load_balancing_v2","title":"delete_rule","content":"pub fn delete_rule(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing_v2.delete_rule\naws_api/elastic_load_balancing_v2 delete_rule","url":"aws_api/elastic_load_balancing_v2.html#delete_rule"},{"doc":"aws_api/elastic_load_balancing_v2","title":"delete_shared_trust_store_association","content":"pub fn delete_shared_trust_store_association(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing_v2.delete_shared_trust_store_association\naws_api/elastic_load_balancing_v2 delete_shared_trust_store_association","url":"aws_api/elastic_load_balancing_v2.html#delete_shared_trust_store_association"},{"doc":"aws_api/elastic_load_balancing_v2","title":"delete_target_group","content":"pub fn delete_target_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing_v2.delete_target_group\naws_api/elastic_load_balancing_v2 delete_target_group","url":"aws_api/elastic_load_balancing_v2.html#delete_target_group"},{"doc":"aws_api/elastic_load_balancing_v2","title":"delete_trust_store","content":"pub fn delete_trust_store(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing_v2.delete_trust_store\naws_api/elastic_load_balancing_v2 delete_trust_store","url":"aws_api/elastic_load_balancing_v2.html#delete_trust_store"},{"doc":"aws_api/elastic_load_balancing_v2","title":"deregister_targets","content":"pub fn deregister_targets(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing_v2.deregister_targets\naws_api/elastic_load_balancing_v2 deregister_targets","url":"aws_api/elastic_load_balancing_v2.html#deregister_targets"},{"doc":"aws_api/elastic_load_balancing_v2","title":"describe_account_limits","content":"pub fn describe_account_limits(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing_v2.describe_account_limits\naws_api/elastic_load_balancing_v2 describe_account_limits","url":"aws_api/elastic_load_balancing_v2.html#describe_account_limits"},{"doc":"aws_api/elastic_load_balancing_v2","title":"describe_listener_certificates","content":"pub fn describe_listener_certificates(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing_v2.describe_listener_certificates\naws_api/elastic_load_balancing_v2 describe_listener_certificates","url":"aws_api/elastic_load_balancing_v2.html#describe_listener_certificates"},{"doc":"aws_api/elastic_load_balancing_v2","title":"describe_listeners","content":"pub fn describe_listeners(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing_v2.describe_listeners\naws_api/elastic_load_balancing_v2 describe_listeners","url":"aws_api/elastic_load_balancing_v2.html#describe_listeners"},{"doc":"aws_api/elastic_load_balancing_v2","title":"describe_load_balancer_attributes","content":"pub fn describe_load_balancer_attributes(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing_v2.describe_load_balancer_attributes\naws_api/elastic_load_balancing_v2 describe_load_balancer_attributes","url":"aws_api/elastic_load_balancing_v2.html#describe_load_balancer_attributes"},{"doc":"aws_api/elastic_load_balancing_v2","title":"describe_load_balancers","content":"pub fn describe_load_balancers(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing_v2.describe_load_balancers\naws_api/elastic_load_balancing_v2 describe_load_balancers","url":"aws_api/elastic_load_balancing_v2.html#describe_load_balancers"},{"doc":"aws_api/elastic_load_balancing_v2","title":"describe_rules","content":"pub fn describe_rules(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing_v2.describe_rules\naws_api/elastic_load_balancing_v2 describe_rules","url":"aws_api/elastic_load_balancing_v2.html#describe_rules"},{"doc":"aws_api/elastic_load_balancing_v2","title":"describe_ssl_policies","content":"pub fn describe_ssl_policies(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing_v2.describe_ssl_policies\naws_api/elastic_load_balancing_v2 describe_ssl_policies","url":"aws_api/elastic_load_balancing_v2.html#describe_ssl_policies"},{"doc":"aws_api/elastic_load_balancing_v2","title":"describe_tags","content":"pub fn describe_tags(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing_v2.describe_tags\naws_api/elastic_load_balancing_v2 describe_tags","url":"aws_api/elastic_load_balancing_v2.html#describe_tags"},{"doc":"aws_api/elastic_load_balancing_v2","title":"describe_target_group_attributes","content":"pub fn describe_target_group_attributes(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing_v2.describe_target_group_attributes\naws_api/elastic_load_balancing_v2 describe_target_group_attributes","url":"aws_api/elastic_load_balancing_v2.html#describe_target_group_attributes"},{"doc":"aws_api/elastic_load_balancing_v2","title":"describe_target_groups","content":"pub fn describe_target_groups(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing_v2.describe_target_groups\naws_api/elastic_load_balancing_v2 describe_target_groups","url":"aws_api/elastic_load_balancing_v2.html#describe_target_groups"},{"doc":"aws_api/elastic_load_balancing_v2","title":"describe_target_health","content":"pub fn describe_target_health(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing_v2.describe_target_health\naws_api/elastic_load_balancing_v2 describe_target_health","url":"aws_api/elastic_load_balancing_v2.html#describe_target_health"},{"doc":"aws_api/elastic_load_balancing_v2","title":"describe_trust_store_associations","content":"pub fn describe_trust_store_associations(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing_v2.describe_trust_store_associations\naws_api/elastic_load_balancing_v2 describe_trust_store_associations","url":"aws_api/elastic_load_balancing_v2.html#describe_trust_store_associations"},{"doc":"aws_api/elastic_load_balancing_v2","title":"describe_trust_store_revocations","content":"pub fn describe_trust_store_revocations(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing_v2.describe_trust_store_revocations\naws_api/elastic_load_balancing_v2 describe_trust_store_revocations","url":"aws_api/elastic_load_balancing_v2.html#describe_trust_store_revocations"},{"doc":"aws_api/elastic_load_balancing_v2","title":"describe_trust_stores","content":"pub fn describe_trust_stores(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing_v2.describe_trust_stores\naws_api/elastic_load_balancing_v2 describe_trust_stores","url":"aws_api/elastic_load_balancing_v2.html#describe_trust_stores"},{"doc":"aws_api/elastic_load_balancing_v2","title":"get_resource_policy","content":"pub fn get_resource_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing_v2.get_resource_policy\naws_api/elastic_load_balancing_v2 get_resource_policy","url":"aws_api/elastic_load_balancing_v2.html#get_resource_policy"},{"doc":"aws_api/elastic_load_balancing_v2","title":"get_trust_store_ca_certificates_bundle","content":"pub fn get_trust_store_ca_certificates_bundle(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing_v2.get_trust_store_ca_certificates_bundle\naws_api/elastic_load_balancing_v2 get_trust_store_ca_certificates_bundle","url":"aws_api/elastic_load_balancing_v2.html#get_trust_store_ca_certificates_bundle"},{"doc":"aws_api/elastic_load_balancing_v2","title":"get_trust_store_revocation_content","content":"pub fn get_trust_store_revocation_content(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing_v2.get_trust_store_revocation_content\naws_api/elastic_load_balancing_v2 get_trust_store_revocation_content","url":"aws_api/elastic_load_balancing_v2.html#get_trust_store_revocation_content"},{"doc":"aws_api/elastic_load_balancing_v2","title":"modify_listener","content":"pub fn modify_listener(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing_v2.modify_listener\naws_api/elastic_load_balancing_v2 modify_listener","url":"aws_api/elastic_load_balancing_v2.html#modify_listener"},{"doc":"aws_api/elastic_load_balancing_v2","title":"modify_load_balancer_attributes","content":"pub fn modify_load_balancer_attributes(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing_v2.modify_load_balancer_attributes\naws_api/elastic_load_balancing_v2 modify_load_balancer_attributes","url":"aws_api/elastic_load_balancing_v2.html#modify_load_balancer_attributes"},{"doc":"aws_api/elastic_load_balancing_v2","title":"modify_rule","content":"pub fn modify_rule(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing_v2.modify_rule\naws_api/elastic_load_balancing_v2 modify_rule","url":"aws_api/elastic_load_balancing_v2.html#modify_rule"},{"doc":"aws_api/elastic_load_balancing_v2","title":"modify_target_group","content":"pub fn modify_target_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing_v2.modify_target_group\naws_api/elastic_load_balancing_v2 modify_target_group","url":"aws_api/elastic_load_balancing_v2.html#modify_target_group"},{"doc":"aws_api/elastic_load_balancing_v2","title":"modify_target_group_attributes","content":"pub fn modify_target_group_attributes(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing_v2.modify_target_group_attributes\naws_api/elastic_load_balancing_v2 modify_target_group_attributes","url":"aws_api/elastic_load_balancing_v2.html#modify_target_group_attributes"},{"doc":"aws_api/elastic_load_balancing_v2","title":"modify_trust_store","content":"pub fn modify_trust_store(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing_v2.modify_trust_store\naws_api/elastic_load_balancing_v2 modify_trust_store","url":"aws_api/elastic_load_balancing_v2.html#modify_trust_store"},{"doc":"aws_api/elastic_load_balancing_v2","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/elastic_load_balancing_v2.new\naws_api/elastic_load_balancing_v2 new","url":"aws_api/elastic_load_balancing_v2.html#new"},{"doc":"aws_api/elastic_load_balancing_v2","title":"register_targets","content":"pub fn register_targets(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing_v2.register_targets\naws_api/elastic_load_balancing_v2 register_targets","url":"aws_api/elastic_load_balancing_v2.html#register_targets"},{"doc":"aws_api/elastic_load_balancing_v2","title":"remove_listener_certificates","content":"pub fn remove_listener_certificates(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing_v2.remove_listener_certificates\naws_api/elastic_load_balancing_v2 remove_listener_certificates","url":"aws_api/elastic_load_balancing_v2.html#remove_listener_certificates"},{"doc":"aws_api/elastic_load_balancing_v2","title":"remove_tags","content":"pub fn remove_tags(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing_v2.remove_tags\naws_api/elastic_load_balancing_v2 remove_tags","url":"aws_api/elastic_load_balancing_v2.html#remove_tags"},{"doc":"aws_api/elastic_load_balancing_v2","title":"remove_trust_store_revocations","content":"pub fn remove_trust_store_revocations(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing_v2.remove_trust_store_revocations\naws_api/elastic_load_balancing_v2 remove_trust_store_revocations","url":"aws_api/elastic_load_balancing_v2.html#remove_trust_store_revocations"},{"doc":"aws_api/elastic_load_balancing_v2","title":"set_ip_address_type","content":"pub fn set_ip_address_type(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing_v2.set_ip_address_type\naws_api/elastic_load_balancing_v2 set_ip_address_type","url":"aws_api/elastic_load_balancing_v2.html#set_ip_address_type"},{"doc":"aws_api/elastic_load_balancing_v2","title":"set_rule_priorities","content":"pub fn set_rule_priorities(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing_v2.set_rule_priorities\naws_api/elastic_load_balancing_v2 set_rule_priorities","url":"aws_api/elastic_load_balancing_v2.html#set_rule_priorities"},{"doc":"aws_api/elastic_load_balancing_v2","title":"set_security_groups","content":"pub fn set_security_groups(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing_v2.set_security_groups\naws_api/elastic_load_balancing_v2 set_security_groups","url":"aws_api/elastic_load_balancing_v2.html#set_security_groups"},{"doc":"aws_api/elastic_load_balancing_v2","title":"set_subnets","content":"pub fn set_subnets(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_load_balancing_v2.set_subnets\naws_api/elastic_load_balancing_v2 set_subnets","url":"aws_api/elastic_load_balancing_v2.html#set_subnets"},{"doc":"aws_api/elastic_load_balancing_v2","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/elastic_load_balancing_v2.with_custom_endpoint\naws_api/elastic_load_balancing_v2 with_custom_endpoint","url":"aws_api/elastic_load_balancing_v2.html#with_custom_endpoint"},{"doc":"aws_api/elastic_load_balancing_v2","title":"aws_api/elastic_load_balancing_v2","content":"","url":"aws_api/elastic_load_balancing_v2.html"},{"doc":"aws_api/elastic_transcoder","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/elastic_transcoder.Client\naws_api/elastic_transcoder Client","url":"aws_api/elastic_transcoder.html#Client"},{"doc":"aws_api/elastic_transcoder","title":"cancel_job","content":"pub fn cancel_job(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_transcoder.cancel_job\naws_api/elastic_transcoder cancel_job","url":"aws_api/elastic_transcoder.html#cancel_job"},{"doc":"aws_api/elastic_transcoder","title":"create_job","content":"pub fn create_job(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_transcoder.create_job\naws_api/elastic_transcoder create_job","url":"aws_api/elastic_transcoder.html#create_job"},{"doc":"aws_api/elastic_transcoder","title":"create_pipeline","content":"pub fn create_pipeline(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_transcoder.create_pipeline\naws_api/elastic_transcoder create_pipeline","url":"aws_api/elastic_transcoder.html#create_pipeline"},{"doc":"aws_api/elastic_transcoder","title":"create_preset","content":"pub fn create_preset(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_transcoder.create_preset\naws_api/elastic_transcoder create_preset","url":"aws_api/elastic_transcoder.html#create_preset"},{"doc":"aws_api/elastic_transcoder","title":"delete_pipeline","content":"pub fn delete_pipeline(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_transcoder.delete_pipeline\naws_api/elastic_transcoder delete_pipeline","url":"aws_api/elastic_transcoder.html#delete_pipeline"},{"doc":"aws_api/elastic_transcoder","title":"delete_preset","content":"pub fn delete_preset(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_transcoder.delete_preset\naws_api/elastic_transcoder delete_preset","url":"aws_api/elastic_transcoder.html#delete_preset"},{"doc":"aws_api/elastic_transcoder","title":"list_jobs_by_pipeline","content":"pub fn list_jobs_by_pipeline(\n  client: Client,\n  pipeline_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_transcoder.list_jobs_by_pipeline\naws_api/elastic_transcoder list_jobs_by_pipeline","url":"aws_api/elastic_transcoder.html#list_jobs_by_pipeline"},{"doc":"aws_api/elastic_transcoder","title":"list_jobs_by_status","content":"pub fn list_jobs_by_status(\n  client: Client,\n  status: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_transcoder.list_jobs_by_status\naws_api/elastic_transcoder list_jobs_by_status","url":"aws_api/elastic_transcoder.html#list_jobs_by_status"},{"doc":"aws_api/elastic_transcoder","title":"list_pipelines","content":"pub fn list_pipelines(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_transcoder.list_pipelines\naws_api/elastic_transcoder list_pipelines","url":"aws_api/elastic_transcoder.html#list_pipelines"},{"doc":"aws_api/elastic_transcoder","title":"list_presets","content":"pub fn list_presets(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_transcoder.list_presets\naws_api/elastic_transcoder list_presets","url":"aws_api/elastic_transcoder.html#list_presets"},{"doc":"aws_api/elastic_transcoder","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/elastic_transcoder.new\naws_api/elastic_transcoder new","url":"aws_api/elastic_transcoder.html#new"},{"doc":"aws_api/elastic_transcoder","title":"read_job","content":"pub fn read_job(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_transcoder.read_job\naws_api/elastic_transcoder read_job","url":"aws_api/elastic_transcoder.html#read_job"},{"doc":"aws_api/elastic_transcoder","title":"read_pipeline","content":"pub fn read_pipeline(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_transcoder.read_pipeline\naws_api/elastic_transcoder read_pipeline","url":"aws_api/elastic_transcoder.html#read_pipeline"},{"doc":"aws_api/elastic_transcoder","title":"read_preset","content":"pub fn read_preset(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_transcoder.read_preset\naws_api/elastic_transcoder read_preset","url":"aws_api/elastic_transcoder.html#read_preset"},{"doc":"aws_api/elastic_transcoder","title":"test_role","content":"pub fn test_role(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_transcoder.test_role\naws_api/elastic_transcoder test_role","url":"aws_api/elastic_transcoder.html#test_role"},{"doc":"aws_api/elastic_transcoder","title":"update_pipeline","content":"pub fn update_pipeline(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_transcoder.update_pipeline\naws_api/elastic_transcoder update_pipeline","url":"aws_api/elastic_transcoder.html#update_pipeline"},{"doc":"aws_api/elastic_transcoder","title":"update_pipeline_notifications","content":"pub fn update_pipeline_notifications(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_transcoder.update_pipeline_notifications\naws_api/elastic_transcoder update_pipeline_notifications","url":"aws_api/elastic_transcoder.html#update_pipeline_notifications"},{"doc":"aws_api/elastic_transcoder","title":"update_pipeline_status","content":"pub fn update_pipeline_status(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elastic_transcoder.update_pipeline_status\naws_api/elastic_transcoder update_pipeline_status","url":"aws_api/elastic_transcoder.html#update_pipeline_status"},{"doc":"aws_api/elastic_transcoder","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/elastic_transcoder.with_custom_endpoint\naws_api/elastic_transcoder with_custom_endpoint","url":"aws_api/elastic_transcoder.html#with_custom_endpoint"},{"doc":"aws_api/elastic_transcoder","title":"aws_api/elastic_transcoder","content":"","url":"aws_api/elastic_transcoder.html"},{"doc":"aws_api/elasticache","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/elasticache.Client\naws_api/elasticache Client","url":"aws_api/elasticache.html#Client"},{"doc":"aws_api/elasticache","title":"add_tags_to_resource","content":"pub fn add_tags_to_resource(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.add_tags_to_resource\naws_api/elasticache add_tags_to_resource","url":"aws_api/elasticache.html#add_tags_to_resource"},{"doc":"aws_api/elasticache","title":"authorize_cache_security_group_ingress","content":"pub fn authorize_cache_security_group_ingress(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.authorize_cache_security_group_ingress\naws_api/elasticache authorize_cache_security_group_ingress","url":"aws_api/elasticache.html#authorize_cache_security_group_ingress"},{"doc":"aws_api/elasticache","title":"batch_apply_update_action","content":"pub fn batch_apply_update_action(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.batch_apply_update_action\naws_api/elasticache batch_apply_update_action","url":"aws_api/elasticache.html#batch_apply_update_action"},{"doc":"aws_api/elasticache","title":"batch_stop_update_action","content":"pub fn batch_stop_update_action(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.batch_stop_update_action\naws_api/elasticache batch_stop_update_action","url":"aws_api/elasticache.html#batch_stop_update_action"},{"doc":"aws_api/elasticache","title":"complete_migration","content":"pub fn complete_migration(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.complete_migration\naws_api/elasticache complete_migration","url":"aws_api/elasticache.html#complete_migration"},{"doc":"aws_api/elasticache","title":"copy_serverless_cache_snapshot","content":"pub fn copy_serverless_cache_snapshot(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.copy_serverless_cache_snapshot\naws_api/elasticache copy_serverless_cache_snapshot","url":"aws_api/elasticache.html#copy_serverless_cache_snapshot"},{"doc":"aws_api/elasticache","title":"copy_snapshot","content":"pub fn copy_snapshot(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.copy_snapshot\naws_api/elasticache copy_snapshot","url":"aws_api/elasticache.html#copy_snapshot"},{"doc":"aws_api/elasticache","title":"create_cache_cluster","content":"pub fn create_cache_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.create_cache_cluster\naws_api/elasticache create_cache_cluster","url":"aws_api/elasticache.html#create_cache_cluster"},{"doc":"aws_api/elasticache","title":"create_cache_parameter_group","content":"pub fn create_cache_parameter_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.create_cache_parameter_group\naws_api/elasticache create_cache_parameter_group","url":"aws_api/elasticache.html#create_cache_parameter_group"},{"doc":"aws_api/elasticache","title":"create_cache_security_group","content":"pub fn create_cache_security_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.create_cache_security_group\naws_api/elasticache create_cache_security_group","url":"aws_api/elasticache.html#create_cache_security_group"},{"doc":"aws_api/elasticache","title":"create_cache_subnet_group","content":"pub fn create_cache_subnet_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.create_cache_subnet_group\naws_api/elasticache create_cache_subnet_group","url":"aws_api/elasticache.html#create_cache_subnet_group"},{"doc":"aws_api/elasticache","title":"create_global_replication_group","content":"pub fn create_global_replication_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.create_global_replication_group\naws_api/elasticache create_global_replication_group","url":"aws_api/elasticache.html#create_global_replication_group"},{"doc":"aws_api/elasticache","title":"create_replication_group","content":"pub fn create_replication_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.create_replication_group\naws_api/elasticache create_replication_group","url":"aws_api/elasticache.html#create_replication_group"},{"doc":"aws_api/elasticache","title":"create_serverless_cache","content":"pub fn create_serverless_cache(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.create_serverless_cache\naws_api/elasticache create_serverless_cache","url":"aws_api/elasticache.html#create_serverless_cache"},{"doc":"aws_api/elasticache","title":"create_serverless_cache_snapshot","content":"pub fn create_serverless_cache_snapshot(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.create_serverless_cache_snapshot\naws_api/elasticache create_serverless_cache_snapshot","url":"aws_api/elasticache.html#create_serverless_cache_snapshot"},{"doc":"aws_api/elasticache","title":"create_snapshot","content":"pub fn create_snapshot(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.create_snapshot\naws_api/elasticache create_snapshot","url":"aws_api/elasticache.html#create_snapshot"},{"doc":"aws_api/elasticache","title":"create_user","content":"pub fn create_user(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.create_user\naws_api/elasticache create_user","url":"aws_api/elasticache.html#create_user"},{"doc":"aws_api/elasticache","title":"create_user_group","content":"pub fn create_user_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.create_user_group\naws_api/elasticache create_user_group","url":"aws_api/elasticache.html#create_user_group"},{"doc":"aws_api/elasticache","title":"decrease_node_groups_in_global_replication_group","content":"pub fn decrease_node_groups_in_global_replication_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.decrease_node_groups_in_global_replication_group\naws_api/elasticache decrease_node_groups_in_global_replication_group","url":"aws_api/elasticache.html#decrease_node_groups_in_global_replication_group"},{"doc":"aws_api/elasticache","title":"decrease_replica_count","content":"pub fn decrease_replica_count(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.decrease_replica_count\naws_api/elasticache decrease_replica_count","url":"aws_api/elasticache.html#decrease_replica_count"},{"doc":"aws_api/elasticache","title":"delete_cache_cluster","content":"pub fn delete_cache_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.delete_cache_cluster\naws_api/elasticache delete_cache_cluster","url":"aws_api/elasticache.html#delete_cache_cluster"},{"doc":"aws_api/elasticache","title":"delete_cache_parameter_group","content":"pub fn delete_cache_parameter_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.delete_cache_parameter_group\naws_api/elasticache delete_cache_parameter_group","url":"aws_api/elasticache.html#delete_cache_parameter_group"},{"doc":"aws_api/elasticache","title":"delete_cache_security_group","content":"pub fn delete_cache_security_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.delete_cache_security_group\naws_api/elasticache delete_cache_security_group","url":"aws_api/elasticache.html#delete_cache_security_group"},{"doc":"aws_api/elasticache","title":"delete_cache_subnet_group","content":"pub fn delete_cache_subnet_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.delete_cache_subnet_group\naws_api/elasticache delete_cache_subnet_group","url":"aws_api/elasticache.html#delete_cache_subnet_group"},{"doc":"aws_api/elasticache","title":"delete_global_replication_group","content":"pub fn delete_global_replication_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.delete_global_replication_group\naws_api/elasticache delete_global_replication_group","url":"aws_api/elasticache.html#delete_global_replication_group"},{"doc":"aws_api/elasticache","title":"delete_replication_group","content":"pub fn delete_replication_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.delete_replication_group\naws_api/elasticache delete_replication_group","url":"aws_api/elasticache.html#delete_replication_group"},{"doc":"aws_api/elasticache","title":"delete_serverless_cache","content":"pub fn delete_serverless_cache(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.delete_serverless_cache\naws_api/elasticache delete_serverless_cache","url":"aws_api/elasticache.html#delete_serverless_cache"},{"doc":"aws_api/elasticache","title":"delete_serverless_cache_snapshot","content":"pub fn delete_serverless_cache_snapshot(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.delete_serverless_cache_snapshot\naws_api/elasticache delete_serverless_cache_snapshot","url":"aws_api/elasticache.html#delete_serverless_cache_snapshot"},{"doc":"aws_api/elasticache","title":"delete_snapshot","content":"pub fn delete_snapshot(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.delete_snapshot\naws_api/elasticache delete_snapshot","url":"aws_api/elasticache.html#delete_snapshot"},{"doc":"aws_api/elasticache","title":"delete_user","content":"pub fn delete_user(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.delete_user\naws_api/elasticache delete_user","url":"aws_api/elasticache.html#delete_user"},{"doc":"aws_api/elasticache","title":"delete_user_group","content":"pub fn delete_user_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.delete_user_group\naws_api/elasticache delete_user_group","url":"aws_api/elasticache.html#delete_user_group"},{"doc":"aws_api/elasticache","title":"describe_cache_clusters","content":"pub fn describe_cache_clusters(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.describe_cache_clusters\naws_api/elasticache describe_cache_clusters","url":"aws_api/elasticache.html#describe_cache_clusters"},{"doc":"aws_api/elasticache","title":"describe_cache_engine_versions","content":"pub fn describe_cache_engine_versions(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.describe_cache_engine_versions\naws_api/elasticache describe_cache_engine_versions","url":"aws_api/elasticache.html#describe_cache_engine_versions"},{"doc":"aws_api/elasticache","title":"describe_cache_parameter_groups","content":"pub fn describe_cache_parameter_groups(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.describe_cache_parameter_groups\naws_api/elasticache describe_cache_parameter_groups","url":"aws_api/elasticache.html#describe_cache_parameter_groups"},{"doc":"aws_api/elasticache","title":"describe_cache_parameters","content":"pub fn describe_cache_parameters(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.describe_cache_parameters\naws_api/elasticache describe_cache_parameters","url":"aws_api/elasticache.html#describe_cache_parameters"},{"doc":"aws_api/elasticache","title":"describe_cache_security_groups","content":"pub fn describe_cache_security_groups(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.describe_cache_security_groups\naws_api/elasticache describe_cache_security_groups","url":"aws_api/elasticache.html#describe_cache_security_groups"},{"doc":"aws_api/elasticache","title":"describe_cache_subnet_groups","content":"pub fn describe_cache_subnet_groups(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.describe_cache_subnet_groups\naws_api/elasticache describe_cache_subnet_groups","url":"aws_api/elasticache.html#describe_cache_subnet_groups"},{"doc":"aws_api/elasticache","title":"describe_engine_default_parameters","content":"pub fn describe_engine_default_parameters(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.describe_engine_default_parameters\naws_api/elasticache describe_engine_default_parameters","url":"aws_api/elasticache.html#describe_engine_default_parameters"},{"doc":"aws_api/elasticache","title":"describe_events","content":"pub fn describe_events(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.describe_events\naws_api/elasticache describe_events","url":"aws_api/elasticache.html#describe_events"},{"doc":"aws_api/elasticache","title":"describe_global_replication_groups","content":"pub fn describe_global_replication_groups(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.describe_global_replication_groups\naws_api/elasticache describe_global_replication_groups","url":"aws_api/elasticache.html#describe_global_replication_groups"},{"doc":"aws_api/elasticache","title":"describe_replication_groups","content":"pub fn describe_replication_groups(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.describe_replication_groups\naws_api/elasticache describe_replication_groups","url":"aws_api/elasticache.html#describe_replication_groups"},{"doc":"aws_api/elasticache","title":"describe_reserved_cache_nodes","content":"pub fn describe_reserved_cache_nodes(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.describe_reserved_cache_nodes\naws_api/elasticache describe_reserved_cache_nodes","url":"aws_api/elasticache.html#describe_reserved_cache_nodes"},{"doc":"aws_api/elasticache","title":"describe_reserved_cache_nodes_offerings","content":"pub fn describe_reserved_cache_nodes_offerings(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.describe_reserved_cache_nodes_offerings\naws_api/elasticache describe_reserved_cache_nodes_offerings","url":"aws_api/elasticache.html#describe_reserved_cache_nodes_offerings"},{"doc":"aws_api/elasticache","title":"describe_serverless_cache_snapshots","content":"pub fn describe_serverless_cache_snapshots(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.describe_serverless_cache_snapshots\naws_api/elasticache describe_serverless_cache_snapshots","url":"aws_api/elasticache.html#describe_serverless_cache_snapshots"},{"doc":"aws_api/elasticache","title":"describe_serverless_caches","content":"pub fn describe_serverless_caches(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.describe_serverless_caches\naws_api/elasticache describe_serverless_caches","url":"aws_api/elasticache.html#describe_serverless_caches"},{"doc":"aws_api/elasticache","title":"describe_service_updates","content":"pub fn describe_service_updates(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.describe_service_updates\naws_api/elasticache describe_service_updates","url":"aws_api/elasticache.html#describe_service_updates"},{"doc":"aws_api/elasticache","title":"describe_snapshots","content":"pub fn describe_snapshots(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.describe_snapshots\naws_api/elasticache describe_snapshots","url":"aws_api/elasticache.html#describe_snapshots"},{"doc":"aws_api/elasticache","title":"describe_update_actions","content":"pub fn describe_update_actions(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.describe_update_actions\naws_api/elasticache describe_update_actions","url":"aws_api/elasticache.html#describe_update_actions"},{"doc":"aws_api/elasticache","title":"describe_user_groups","content":"pub fn describe_user_groups(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.describe_user_groups\naws_api/elasticache describe_user_groups","url":"aws_api/elasticache.html#describe_user_groups"},{"doc":"aws_api/elasticache","title":"describe_users","content":"pub fn describe_users(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.describe_users\naws_api/elasticache describe_users","url":"aws_api/elasticache.html#describe_users"},{"doc":"aws_api/elasticache","title":"disassociate_global_replication_group","content":"pub fn disassociate_global_replication_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.disassociate_global_replication_group\naws_api/elasticache disassociate_global_replication_group","url":"aws_api/elasticache.html#disassociate_global_replication_group"},{"doc":"aws_api/elasticache","title":"export_serverless_cache_snapshot","content":"pub fn export_serverless_cache_snapshot(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.export_serverless_cache_snapshot\naws_api/elasticache export_serverless_cache_snapshot","url":"aws_api/elasticache.html#export_serverless_cache_snapshot"},{"doc":"aws_api/elasticache","title":"failover_global_replication_group","content":"pub fn failover_global_replication_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.failover_global_replication_group\naws_api/elasticache failover_global_replication_group","url":"aws_api/elasticache.html#failover_global_replication_group"},{"doc":"aws_api/elasticache","title":"increase_node_groups_in_global_replication_group","content":"pub fn increase_node_groups_in_global_replication_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.increase_node_groups_in_global_replication_group\naws_api/elasticache increase_node_groups_in_global_replication_group","url":"aws_api/elasticache.html#increase_node_groups_in_global_replication_group"},{"doc":"aws_api/elasticache","title":"increase_replica_count","content":"pub fn increase_replica_count(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.increase_replica_count\naws_api/elasticache increase_replica_count","url":"aws_api/elasticache.html#increase_replica_count"},{"doc":"aws_api/elasticache","title":"list_allowed_node_type_modifications","content":"pub fn list_allowed_node_type_modifications(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.list_allowed_node_type_modifications\naws_api/elasticache list_allowed_node_type_modifications","url":"aws_api/elasticache.html#list_allowed_node_type_modifications"},{"doc":"aws_api/elasticache","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.list_tags_for_resource\naws_api/elasticache list_tags_for_resource","url":"aws_api/elasticache.html#list_tags_for_resource"},{"doc":"aws_api/elasticache","title":"modify_cache_cluster","content":"pub fn modify_cache_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.modify_cache_cluster\naws_api/elasticache modify_cache_cluster","url":"aws_api/elasticache.html#modify_cache_cluster"},{"doc":"aws_api/elasticache","title":"modify_cache_parameter_group","content":"pub fn modify_cache_parameter_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.modify_cache_parameter_group\naws_api/elasticache modify_cache_parameter_group","url":"aws_api/elasticache.html#modify_cache_parameter_group"},{"doc":"aws_api/elasticache","title":"modify_cache_subnet_group","content":"pub fn modify_cache_subnet_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.modify_cache_subnet_group\naws_api/elasticache modify_cache_subnet_group","url":"aws_api/elasticache.html#modify_cache_subnet_group"},{"doc":"aws_api/elasticache","title":"modify_global_replication_group","content":"pub fn modify_global_replication_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.modify_global_replication_group\naws_api/elasticache modify_global_replication_group","url":"aws_api/elasticache.html#modify_global_replication_group"},{"doc":"aws_api/elasticache","title":"modify_replication_group","content":"pub fn modify_replication_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.modify_replication_group\naws_api/elasticache modify_replication_group","url":"aws_api/elasticache.html#modify_replication_group"},{"doc":"aws_api/elasticache","title":"modify_replication_group_shard_configuration","content":"pub fn modify_replication_group_shard_configuration(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.modify_replication_group_shard_configuration\naws_api/elasticache modify_replication_group_shard_configuration","url":"aws_api/elasticache.html#modify_replication_group_shard_configuration"},{"doc":"aws_api/elasticache","title":"modify_serverless_cache","content":"pub fn modify_serverless_cache(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.modify_serverless_cache\naws_api/elasticache modify_serverless_cache","url":"aws_api/elasticache.html#modify_serverless_cache"},{"doc":"aws_api/elasticache","title":"modify_user","content":"pub fn modify_user(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.modify_user\naws_api/elasticache modify_user","url":"aws_api/elasticache.html#modify_user"},{"doc":"aws_api/elasticache","title":"modify_user_group","content":"pub fn modify_user_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.modify_user_group\naws_api/elasticache modify_user_group","url":"aws_api/elasticache.html#modify_user_group"},{"doc":"aws_api/elasticache","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/elasticache.new\naws_api/elasticache new","url":"aws_api/elasticache.html#new"},{"doc":"aws_api/elasticache","title":"purchase_reserved_cache_nodes_offering","content":"pub fn purchase_reserved_cache_nodes_offering(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.purchase_reserved_cache_nodes_offering\naws_api/elasticache purchase_reserved_cache_nodes_offering","url":"aws_api/elasticache.html#purchase_reserved_cache_nodes_offering"},{"doc":"aws_api/elasticache","title":"rebalance_slots_in_global_replication_group","content":"pub fn rebalance_slots_in_global_replication_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.rebalance_slots_in_global_replication_group\naws_api/elasticache rebalance_slots_in_global_replication_group","url":"aws_api/elasticache.html#rebalance_slots_in_global_replication_group"},{"doc":"aws_api/elasticache","title":"reboot_cache_cluster","content":"pub fn reboot_cache_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.reboot_cache_cluster\naws_api/elasticache reboot_cache_cluster","url":"aws_api/elasticache.html#reboot_cache_cluster"},{"doc":"aws_api/elasticache","title":"remove_tags_from_resource","content":"pub fn remove_tags_from_resource(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.remove_tags_from_resource\naws_api/elasticache remove_tags_from_resource","url":"aws_api/elasticache.html#remove_tags_from_resource"},{"doc":"aws_api/elasticache","title":"reset_cache_parameter_group","content":"pub fn reset_cache_parameter_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.reset_cache_parameter_group\naws_api/elasticache reset_cache_parameter_group","url":"aws_api/elasticache.html#reset_cache_parameter_group"},{"doc":"aws_api/elasticache","title":"revoke_cache_security_group_ingress","content":"pub fn revoke_cache_security_group_ingress(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.revoke_cache_security_group_ingress\naws_api/elasticache revoke_cache_security_group_ingress","url":"aws_api/elasticache.html#revoke_cache_security_group_ingress"},{"doc":"aws_api/elasticache","title":"start_migration","content":"pub fn start_migration(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.start_migration\naws_api/elasticache start_migration","url":"aws_api/elasticache.html#start_migration"},{"doc":"aws_api/elasticache","title":"test_failover","content":"pub fn test_failover(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.test_failover\naws_api/elasticache test_failover","url":"aws_api/elasticache.html#test_failover"},{"doc":"aws_api/elasticache","title":"test_migration","content":"pub fn test_migration(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticache.test_migration\naws_api/elasticache test_migration","url":"aws_api/elasticache.html#test_migration"},{"doc":"aws_api/elasticache","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/elasticache.with_custom_endpoint\naws_api/elasticache with_custom_endpoint","url":"aws_api/elasticache.html#with_custom_endpoint"},{"doc":"aws_api/elasticache","title":"aws_api/elasticache","content":"","url":"aws_api/elasticache.html"},{"doc":"aws_api/elasticsearch_service","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/elasticsearch_service.Client\naws_api/elasticsearch_service Client","url":"aws_api/elasticsearch_service.html#Client"},{"doc":"aws_api/elasticsearch_service","title":"accept_inbound_cross_cluster_search_connection","content":"pub fn accept_inbound_cross_cluster_search_connection(\n  client: Client,\n  cross_cluster_search_connection_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.accept_inbound_cross_cluster_search_connection\naws_api/elasticsearch_service accept_inbound_cross_cluster_search_connection","url":"aws_api/elasticsearch_service.html#accept_inbound_cross_cluster_search_connection"},{"doc":"aws_api/elasticsearch_service","title":"add_tags","content":"pub fn add_tags(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.add_tags\naws_api/elasticsearch_service add_tags","url":"aws_api/elasticsearch_service.html#add_tags"},{"doc":"aws_api/elasticsearch_service","title":"associate_package","content":"pub fn associate_package(\n  client: Client,\n  package_id: String,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.associate_package\naws_api/elasticsearch_service associate_package","url":"aws_api/elasticsearch_service.html#associate_package"},{"doc":"aws_api/elasticsearch_service","title":"authorize_vpc_endpoint_access","content":"pub fn authorize_vpc_endpoint_access(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.authorize_vpc_endpoint_access\naws_api/elasticsearch_service authorize_vpc_endpoint_access","url":"aws_api/elasticsearch_service.html#authorize_vpc_endpoint_access"},{"doc":"aws_api/elasticsearch_service","title":"cancel_domain_config_change","content":"pub fn cancel_domain_config_change(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.cancel_domain_config_change\naws_api/elasticsearch_service cancel_domain_config_change","url":"aws_api/elasticsearch_service.html#cancel_domain_config_change"},{"doc":"aws_api/elasticsearch_service","title":"cancel_elasticsearch_service_software_update","content":"pub fn cancel_elasticsearch_service_software_update(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.cancel_elasticsearch_service_software_update\naws_api/elasticsearch_service cancel_elasticsearch_service_software_update","url":"aws_api/elasticsearch_service.html#cancel_elasticsearch_service_software_update"},{"doc":"aws_api/elasticsearch_service","title":"create_elasticsearch_domain","content":"pub fn create_elasticsearch_domain(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.create_elasticsearch_domain\naws_api/elasticsearch_service create_elasticsearch_domain","url":"aws_api/elasticsearch_service.html#create_elasticsearch_domain"},{"doc":"aws_api/elasticsearch_service","title":"create_outbound_cross_cluster_search_connection","content":"pub fn create_outbound_cross_cluster_search_connection(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.create_outbound_cross_cluster_search_connection\naws_api/elasticsearch_service create_outbound_cross_cluster_search_connection","url":"aws_api/elasticsearch_service.html#create_outbound_cross_cluster_search_connection"},{"doc":"aws_api/elasticsearch_service","title":"create_package","content":"pub fn create_package(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.create_package\naws_api/elasticsearch_service create_package","url":"aws_api/elasticsearch_service.html#create_package"},{"doc":"aws_api/elasticsearch_service","title":"create_vpc_endpoint","content":"pub fn create_vpc_endpoint(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.create_vpc_endpoint\naws_api/elasticsearch_service create_vpc_endpoint","url":"aws_api/elasticsearch_service.html#create_vpc_endpoint"},{"doc":"aws_api/elasticsearch_service","title":"delete_elasticsearch_domain","content":"pub fn delete_elasticsearch_domain(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.delete_elasticsearch_domain\naws_api/elasticsearch_service delete_elasticsearch_domain","url":"aws_api/elasticsearch_service.html#delete_elasticsearch_domain"},{"doc":"aws_api/elasticsearch_service","title":"delete_elasticsearch_service_role","content":"pub fn delete_elasticsearch_service_role(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.delete_elasticsearch_service_role\naws_api/elasticsearch_service delete_elasticsearch_service_role","url":"aws_api/elasticsearch_service.html#delete_elasticsearch_service_role"},{"doc":"aws_api/elasticsearch_service","title":"delete_inbound_cross_cluster_search_connection","content":"pub fn delete_inbound_cross_cluster_search_connection(\n  client: Client,\n  cross_cluster_search_connection_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.delete_inbound_cross_cluster_search_connection\naws_api/elasticsearch_service delete_inbound_cross_cluster_search_connection","url":"aws_api/elasticsearch_service.html#delete_inbound_cross_cluster_search_connection"},{"doc":"aws_api/elasticsearch_service","title":"delete_outbound_cross_cluster_search_connection","content":"pub fn delete_outbound_cross_cluster_search_connection(\n  client: Client,\n  cross_cluster_search_connection_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.delete_outbound_cross_cluster_search_connection\naws_api/elasticsearch_service delete_outbound_cross_cluster_search_connection","url":"aws_api/elasticsearch_service.html#delete_outbound_cross_cluster_search_connection"},{"doc":"aws_api/elasticsearch_service","title":"delete_package","content":"pub fn delete_package(\n  client: Client,\n  package_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.delete_package\naws_api/elasticsearch_service delete_package","url":"aws_api/elasticsearch_service.html#delete_package"},{"doc":"aws_api/elasticsearch_service","title":"delete_vpc_endpoint","content":"pub fn delete_vpc_endpoint(\n  client: Client,\n  vpc_endpoint_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.delete_vpc_endpoint\naws_api/elasticsearch_service delete_vpc_endpoint","url":"aws_api/elasticsearch_service.html#delete_vpc_endpoint"},{"doc":"aws_api/elasticsearch_service","title":"describe_domain_auto_tunes","content":"pub fn describe_domain_auto_tunes(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.describe_domain_auto_tunes\naws_api/elasticsearch_service describe_domain_auto_tunes","url":"aws_api/elasticsearch_service.html#describe_domain_auto_tunes"},{"doc":"aws_api/elasticsearch_service","title":"describe_domain_change_progress","content":"pub fn describe_domain_change_progress(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.describe_domain_change_progress\naws_api/elasticsearch_service describe_domain_change_progress","url":"aws_api/elasticsearch_service.html#describe_domain_change_progress"},{"doc":"aws_api/elasticsearch_service","title":"describe_elasticsearch_domain","content":"pub fn describe_elasticsearch_domain(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.describe_elasticsearch_domain\naws_api/elasticsearch_service describe_elasticsearch_domain","url":"aws_api/elasticsearch_service.html#describe_elasticsearch_domain"},{"doc":"aws_api/elasticsearch_service","title":"describe_elasticsearch_domain_config","content":"pub fn describe_elasticsearch_domain_config(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.describe_elasticsearch_domain_config\naws_api/elasticsearch_service describe_elasticsearch_domain_config","url":"aws_api/elasticsearch_service.html#describe_elasticsearch_domain_config"},{"doc":"aws_api/elasticsearch_service","title":"describe_elasticsearch_domains","content":"pub fn describe_elasticsearch_domains(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.describe_elasticsearch_domains\naws_api/elasticsearch_service describe_elasticsearch_domains","url":"aws_api/elasticsearch_service.html#describe_elasticsearch_domains"},{"doc":"aws_api/elasticsearch_service","title":"describe_elasticsearch_instance_type_limits","content":"pub fn describe_elasticsearch_instance_type_limits(\n  client: Client,\n  elasticsearch_version: String,\n  instance_type: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.describe_elasticsearch_instance_type_limits\naws_api/elasticsearch_service describe_elasticsearch_instance_type_limits","url":"aws_api/elasticsearch_service.html#describe_elasticsearch_instance_type_limits"},{"doc":"aws_api/elasticsearch_service","title":"describe_inbound_cross_cluster_search_connections","content":"pub fn describe_inbound_cross_cluster_search_connections(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.describe_inbound_cross_cluster_search_connections\naws_api/elasticsearch_service describe_inbound_cross_cluster_search_connections","url":"aws_api/elasticsearch_service.html#describe_inbound_cross_cluster_search_connections"},{"doc":"aws_api/elasticsearch_service","title":"describe_outbound_cross_cluster_search_connections","content":"pub fn describe_outbound_cross_cluster_search_connections(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.describe_outbound_cross_cluster_search_connections\naws_api/elasticsearch_service describe_outbound_cross_cluster_search_connections","url":"aws_api/elasticsearch_service.html#describe_outbound_cross_cluster_search_connections"},{"doc":"aws_api/elasticsearch_service","title":"describe_packages","content":"pub fn describe_packages(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.describe_packages\naws_api/elasticsearch_service describe_packages","url":"aws_api/elasticsearch_service.html#describe_packages"},{"doc":"aws_api/elasticsearch_service","title":"describe_reserved_elasticsearch_instance_offerings","content":"pub fn describe_reserved_elasticsearch_instance_offerings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.describe_reserved_elasticsearch_instance_offerings\naws_api/elasticsearch_service describe_reserved_elasticsearch_instance_offerings","url":"aws_api/elasticsearch_service.html#describe_reserved_elasticsearch_instance_offerings"},{"doc":"aws_api/elasticsearch_service","title":"describe_reserved_elasticsearch_instances","content":"pub fn describe_reserved_elasticsearch_instances(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.describe_reserved_elasticsearch_instances\naws_api/elasticsearch_service describe_reserved_elasticsearch_instances","url":"aws_api/elasticsearch_service.html#describe_reserved_elasticsearch_instances"},{"doc":"aws_api/elasticsearch_service","title":"describe_vpc_endpoints","content":"pub fn describe_vpc_endpoints(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.describe_vpc_endpoints\naws_api/elasticsearch_service describe_vpc_endpoints","url":"aws_api/elasticsearch_service.html#describe_vpc_endpoints"},{"doc":"aws_api/elasticsearch_service","title":"dissociate_package","content":"pub fn dissociate_package(\n  client: Client,\n  package_id: String,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.dissociate_package\naws_api/elasticsearch_service dissociate_package","url":"aws_api/elasticsearch_service.html#dissociate_package"},{"doc":"aws_api/elasticsearch_service","title":"get_compatible_elasticsearch_versions","content":"pub fn get_compatible_elasticsearch_versions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.get_compatible_elasticsearch_versions\naws_api/elasticsearch_service get_compatible_elasticsearch_versions","url":"aws_api/elasticsearch_service.html#get_compatible_elasticsearch_versions"},{"doc":"aws_api/elasticsearch_service","title":"get_package_version_history","content":"pub fn get_package_version_history(\n  client: Client,\n  package_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.get_package_version_history\naws_api/elasticsearch_service get_package_version_history","url":"aws_api/elasticsearch_service.html#get_package_version_history"},{"doc":"aws_api/elasticsearch_service","title":"get_upgrade_history","content":"pub fn get_upgrade_history(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.get_upgrade_history\naws_api/elasticsearch_service get_upgrade_history","url":"aws_api/elasticsearch_service.html#get_upgrade_history"},{"doc":"aws_api/elasticsearch_service","title":"get_upgrade_status","content":"pub fn get_upgrade_status(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.get_upgrade_status\naws_api/elasticsearch_service get_upgrade_status","url":"aws_api/elasticsearch_service.html#get_upgrade_status"},{"doc":"aws_api/elasticsearch_service","title":"list_domain_names","content":"pub fn list_domain_names(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.list_domain_names\naws_api/elasticsearch_service list_domain_names","url":"aws_api/elasticsearch_service.html#list_domain_names"},{"doc":"aws_api/elasticsearch_service","title":"list_domains_for_package","content":"pub fn list_domains_for_package(\n  client: Client,\n  package_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.list_domains_for_package\naws_api/elasticsearch_service list_domains_for_package","url":"aws_api/elasticsearch_service.html#list_domains_for_package"},{"doc":"aws_api/elasticsearch_service","title":"list_elasticsearch_instance_types","content":"pub fn list_elasticsearch_instance_types(\n  client: Client,\n  elasticsearch_version: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.list_elasticsearch_instance_types\naws_api/elasticsearch_service list_elasticsearch_instance_types","url":"aws_api/elasticsearch_service.html#list_elasticsearch_instance_types"},{"doc":"aws_api/elasticsearch_service","title":"list_elasticsearch_versions","content":"pub fn list_elasticsearch_versions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.list_elasticsearch_versions\naws_api/elasticsearch_service list_elasticsearch_versions","url":"aws_api/elasticsearch_service.html#list_elasticsearch_versions"},{"doc":"aws_api/elasticsearch_service","title":"list_packages_for_domain","content":"pub fn list_packages_for_domain(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.list_packages_for_domain\naws_api/elasticsearch_service list_packages_for_domain","url":"aws_api/elasticsearch_service.html#list_packages_for_domain"},{"doc":"aws_api/elasticsearch_service","title":"list_tags","content":"pub fn list_tags(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.list_tags\naws_api/elasticsearch_service list_tags","url":"aws_api/elasticsearch_service.html#list_tags"},{"doc":"aws_api/elasticsearch_service","title":"list_vpc_endpoint_access","content":"pub fn list_vpc_endpoint_access(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.list_vpc_endpoint_access\naws_api/elasticsearch_service list_vpc_endpoint_access","url":"aws_api/elasticsearch_service.html#list_vpc_endpoint_access"},{"doc":"aws_api/elasticsearch_service","title":"list_vpc_endpoints","content":"pub fn list_vpc_endpoints(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.list_vpc_endpoints\naws_api/elasticsearch_service list_vpc_endpoints","url":"aws_api/elasticsearch_service.html#list_vpc_endpoints"},{"doc":"aws_api/elasticsearch_service","title":"list_vpc_endpoints_for_domain","content":"pub fn list_vpc_endpoints_for_domain(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.list_vpc_endpoints_for_domain\naws_api/elasticsearch_service list_vpc_endpoints_for_domain","url":"aws_api/elasticsearch_service.html#list_vpc_endpoints_for_domain"},{"doc":"aws_api/elasticsearch_service","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/elasticsearch_service.new\naws_api/elasticsearch_service new","url":"aws_api/elasticsearch_service.html#new"},{"doc":"aws_api/elasticsearch_service","title":"purchase_reserved_elasticsearch_instance_offering","content":"pub fn purchase_reserved_elasticsearch_instance_offering(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.purchase_reserved_elasticsearch_instance_offering\naws_api/elasticsearch_service purchase_reserved_elasticsearch_instance_offering","url":"aws_api/elasticsearch_service.html#purchase_reserved_elasticsearch_instance_offering"},{"doc":"aws_api/elasticsearch_service","title":"reject_inbound_cross_cluster_search_connection","content":"pub fn reject_inbound_cross_cluster_search_connection(\n  client: Client,\n  cross_cluster_search_connection_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.reject_inbound_cross_cluster_search_connection\naws_api/elasticsearch_service reject_inbound_cross_cluster_search_connection","url":"aws_api/elasticsearch_service.html#reject_inbound_cross_cluster_search_connection"},{"doc":"aws_api/elasticsearch_service","title":"remove_tags","content":"pub fn remove_tags(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.remove_tags\naws_api/elasticsearch_service remove_tags","url":"aws_api/elasticsearch_service.html#remove_tags"},{"doc":"aws_api/elasticsearch_service","title":"revoke_vpc_endpoint_access","content":"pub fn revoke_vpc_endpoint_access(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.revoke_vpc_endpoint_access\naws_api/elasticsearch_service revoke_vpc_endpoint_access","url":"aws_api/elasticsearch_service.html#revoke_vpc_endpoint_access"},{"doc":"aws_api/elasticsearch_service","title":"start_elasticsearch_service_software_update","content":"pub fn start_elasticsearch_service_software_update(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.start_elasticsearch_service_software_update\naws_api/elasticsearch_service start_elasticsearch_service_software_update","url":"aws_api/elasticsearch_service.html#start_elasticsearch_service_software_update"},{"doc":"aws_api/elasticsearch_service","title":"update_elasticsearch_domain_config","content":"pub fn update_elasticsearch_domain_config(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.update_elasticsearch_domain_config\naws_api/elasticsearch_service update_elasticsearch_domain_config","url":"aws_api/elasticsearch_service.html#update_elasticsearch_domain_config"},{"doc":"aws_api/elasticsearch_service","title":"update_package","content":"pub fn update_package(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.update_package\naws_api/elasticsearch_service update_package","url":"aws_api/elasticsearch_service.html#update_package"},{"doc":"aws_api/elasticsearch_service","title":"update_vpc_endpoint","content":"pub fn update_vpc_endpoint(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.update_vpc_endpoint\naws_api/elasticsearch_service update_vpc_endpoint","url":"aws_api/elasticsearch_service.html#update_vpc_endpoint"},{"doc":"aws_api/elasticsearch_service","title":"upgrade_elasticsearch_domain","content":"pub fn upgrade_elasticsearch_domain(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/elasticsearch_service.upgrade_elasticsearch_domain\naws_api/elasticsearch_service upgrade_elasticsearch_domain","url":"aws_api/elasticsearch_service.html#upgrade_elasticsearch_domain"},{"doc":"aws_api/elasticsearch_service","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/elasticsearch_service.with_custom_endpoint\naws_api/elasticsearch_service with_custom_endpoint","url":"aws_api/elasticsearch_service.html#with_custom_endpoint"},{"doc":"aws_api/elasticsearch_service","title":"aws_api/elasticsearch_service","content":"","url":"aws_api/elasticsearch_service.html"},{"doc":"aws_api/emr","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/emr.Client\naws_api/emr Client","url":"aws_api/emr.html#Client"},{"doc":"aws_api/emr","title":"add_instance_fleet","content":"pub fn add_instance_fleet(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.add_instance_fleet\naws_api/emr add_instance_fleet","url":"aws_api/emr.html#add_instance_fleet"},{"doc":"aws_api/emr","title":"add_instance_groups","content":"pub fn add_instance_groups(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.add_instance_groups\naws_api/emr add_instance_groups","url":"aws_api/emr.html#add_instance_groups"},{"doc":"aws_api/emr","title":"add_job_flow_steps","content":"pub fn add_job_flow_steps(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.add_job_flow_steps\naws_api/emr add_job_flow_steps","url":"aws_api/emr.html#add_job_flow_steps"},{"doc":"aws_api/emr","title":"add_tags","content":"pub fn add_tags(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.add_tags\naws_api/emr add_tags","url":"aws_api/emr.html#add_tags"},{"doc":"aws_api/emr","title":"cancel_steps","content":"pub fn cancel_steps(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.cancel_steps\naws_api/emr cancel_steps","url":"aws_api/emr.html#cancel_steps"},{"doc":"aws_api/emr","title":"create_security_configuration","content":"pub fn create_security_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.create_security_configuration\naws_api/emr create_security_configuration","url":"aws_api/emr.html#create_security_configuration"},{"doc":"aws_api/emr","title":"create_studio","content":"pub fn create_studio(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.create_studio\naws_api/emr create_studio","url":"aws_api/emr.html#create_studio"},{"doc":"aws_api/emr","title":"create_studio_session_mapping","content":"pub fn create_studio_session_mapping(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.create_studio_session_mapping\naws_api/emr create_studio_session_mapping","url":"aws_api/emr.html#create_studio_session_mapping"},{"doc":"aws_api/emr","title":"delete_security_configuration","content":"pub fn delete_security_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.delete_security_configuration\naws_api/emr delete_security_configuration","url":"aws_api/emr.html#delete_security_configuration"},{"doc":"aws_api/emr","title":"delete_studio","content":"pub fn delete_studio(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.delete_studio\naws_api/emr delete_studio","url":"aws_api/emr.html#delete_studio"},{"doc":"aws_api/emr","title":"delete_studio_session_mapping","content":"pub fn delete_studio_session_mapping(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.delete_studio_session_mapping\naws_api/emr delete_studio_session_mapping","url":"aws_api/emr.html#delete_studio_session_mapping"},{"doc":"aws_api/emr","title":"describe_cluster","content":"pub fn describe_cluster(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.describe_cluster\naws_api/emr describe_cluster","url":"aws_api/emr.html#describe_cluster"},{"doc":"aws_api/emr","title":"describe_job_flows","content":"pub fn describe_job_flows(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.describe_job_flows\naws_api/emr describe_job_flows","url":"aws_api/emr.html#describe_job_flows"},{"doc":"aws_api/emr","title":"describe_notebook_execution","content":"pub fn describe_notebook_execution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.describe_notebook_execution\naws_api/emr describe_notebook_execution","url":"aws_api/emr.html#describe_notebook_execution"},{"doc":"aws_api/emr","title":"describe_release_label","content":"pub fn describe_release_label(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.describe_release_label\naws_api/emr describe_release_label","url":"aws_api/emr.html#describe_release_label"},{"doc":"aws_api/emr","title":"describe_security_configuration","content":"pub fn describe_security_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.describe_security_configuration\naws_api/emr describe_security_configuration","url":"aws_api/emr.html#describe_security_configuration"},{"doc":"aws_api/emr","title":"describe_step","content":"pub fn describe_step(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.describe_step\naws_api/emr describe_step","url":"aws_api/emr.html#describe_step"},{"doc":"aws_api/emr","title":"describe_studio","content":"pub fn describe_studio(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.describe_studio\naws_api/emr describe_studio","url":"aws_api/emr.html#describe_studio"},{"doc":"aws_api/emr","title":"get_auto_termination_policy","content":"pub fn get_auto_termination_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.get_auto_termination_policy\naws_api/emr get_auto_termination_policy","url":"aws_api/emr.html#get_auto_termination_policy"},{"doc":"aws_api/emr","title":"get_block_public_access_configuration","content":"pub fn get_block_public_access_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.get_block_public_access_configuration\naws_api/emr get_block_public_access_configuration","url":"aws_api/emr.html#get_block_public_access_configuration"},{"doc":"aws_api/emr","title":"get_cluster_session_credentials","content":"pub fn get_cluster_session_credentials(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.get_cluster_session_credentials\naws_api/emr get_cluster_session_credentials","url":"aws_api/emr.html#get_cluster_session_credentials"},{"doc":"aws_api/emr","title":"get_managed_scaling_policy","content":"pub fn get_managed_scaling_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.get_managed_scaling_policy\naws_api/emr get_managed_scaling_policy","url":"aws_api/emr.html#get_managed_scaling_policy"},{"doc":"aws_api/emr","title":"get_studio_session_mapping","content":"pub fn get_studio_session_mapping(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.get_studio_session_mapping\naws_api/emr get_studio_session_mapping","url":"aws_api/emr.html#get_studio_session_mapping"},{"doc":"aws_api/emr","title":"list_bootstrap_actions","content":"pub fn list_bootstrap_actions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.list_bootstrap_actions\naws_api/emr list_bootstrap_actions","url":"aws_api/emr.html#list_bootstrap_actions"},{"doc":"aws_api/emr","title":"list_clusters","content":"pub fn list_clusters(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.list_clusters\naws_api/emr list_clusters","url":"aws_api/emr.html#list_clusters"},{"doc":"aws_api/emr","title":"list_instance_fleets","content":"pub fn list_instance_fleets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.list_instance_fleets\naws_api/emr list_instance_fleets","url":"aws_api/emr.html#list_instance_fleets"},{"doc":"aws_api/emr","title":"list_instance_groups","content":"pub fn list_instance_groups(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.list_instance_groups\naws_api/emr list_instance_groups","url":"aws_api/emr.html#list_instance_groups"},{"doc":"aws_api/emr","title":"list_instances","content":"pub fn list_instances(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.list_instances\naws_api/emr list_instances","url":"aws_api/emr.html#list_instances"},{"doc":"aws_api/emr","title":"list_notebook_executions","content":"pub fn list_notebook_executions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.list_notebook_executions\naws_api/emr list_notebook_executions","url":"aws_api/emr.html#list_notebook_executions"},{"doc":"aws_api/emr","title":"list_release_labels","content":"pub fn list_release_labels(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.list_release_labels\naws_api/emr list_release_labels","url":"aws_api/emr.html#list_release_labels"},{"doc":"aws_api/emr","title":"list_security_configurations","content":"pub fn list_security_configurations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.list_security_configurations\naws_api/emr list_security_configurations","url":"aws_api/emr.html#list_security_configurations"},{"doc":"aws_api/emr","title":"list_steps","content":"pub fn list_steps(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.list_steps\naws_api/emr list_steps","url":"aws_api/emr.html#list_steps"},{"doc":"aws_api/emr","title":"list_studio_session_mappings","content":"pub fn list_studio_session_mappings(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.list_studio_session_mappings\naws_api/emr list_studio_session_mappings","url":"aws_api/emr.html#list_studio_session_mappings"},{"doc":"aws_api/emr","title":"list_studios","content":"pub fn list_studios(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.list_studios\naws_api/emr list_studios","url":"aws_api/emr.html#list_studios"},{"doc":"aws_api/emr","title":"list_supported_instance_types","content":"pub fn list_supported_instance_types(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.list_supported_instance_types\naws_api/emr list_supported_instance_types","url":"aws_api/emr.html#list_supported_instance_types"},{"doc":"aws_api/emr","title":"modify_cluster","content":"pub fn modify_cluster(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.modify_cluster\naws_api/emr modify_cluster","url":"aws_api/emr.html#modify_cluster"},{"doc":"aws_api/emr","title":"modify_instance_fleet","content":"pub fn modify_instance_fleet(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.modify_instance_fleet\naws_api/emr modify_instance_fleet","url":"aws_api/emr.html#modify_instance_fleet"},{"doc":"aws_api/emr","title":"modify_instance_groups","content":"pub fn modify_instance_groups(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.modify_instance_groups\naws_api/emr modify_instance_groups","url":"aws_api/emr.html#modify_instance_groups"},{"doc":"aws_api/emr","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/emr.new\naws_api/emr new","url":"aws_api/emr.html#new"},{"doc":"aws_api/emr","title":"put_auto_scaling_policy","content":"pub fn put_auto_scaling_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.put_auto_scaling_policy\naws_api/emr put_auto_scaling_policy","url":"aws_api/emr.html#put_auto_scaling_policy"},{"doc":"aws_api/emr","title":"put_auto_termination_policy","content":"pub fn put_auto_termination_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.put_auto_termination_policy\naws_api/emr put_auto_termination_policy","url":"aws_api/emr.html#put_auto_termination_policy"},{"doc":"aws_api/emr","title":"put_block_public_access_configuration","content":"pub fn put_block_public_access_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.put_block_public_access_configuration\naws_api/emr put_block_public_access_configuration","url":"aws_api/emr.html#put_block_public_access_configuration"},{"doc":"aws_api/emr","title":"put_managed_scaling_policy","content":"pub fn put_managed_scaling_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.put_managed_scaling_policy\naws_api/emr put_managed_scaling_policy","url":"aws_api/emr.html#put_managed_scaling_policy"},{"doc":"aws_api/emr","title":"remove_auto_scaling_policy","content":"pub fn remove_auto_scaling_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.remove_auto_scaling_policy\naws_api/emr remove_auto_scaling_policy","url":"aws_api/emr.html#remove_auto_scaling_policy"},{"doc":"aws_api/emr","title":"remove_auto_termination_policy","content":"pub fn remove_auto_termination_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.remove_auto_termination_policy\naws_api/emr remove_auto_termination_policy","url":"aws_api/emr.html#remove_auto_termination_policy"},{"doc":"aws_api/emr","title":"remove_managed_scaling_policy","content":"pub fn remove_managed_scaling_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.remove_managed_scaling_policy\naws_api/emr remove_managed_scaling_policy","url":"aws_api/emr.html#remove_managed_scaling_policy"},{"doc":"aws_api/emr","title":"remove_tags","content":"pub fn remove_tags(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.remove_tags\naws_api/emr remove_tags","url":"aws_api/emr.html#remove_tags"},{"doc":"aws_api/emr","title":"run_job_flow","content":"pub fn run_job_flow(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.run_job_flow\naws_api/emr run_job_flow","url":"aws_api/emr.html#run_job_flow"},{"doc":"aws_api/emr","title":"set_keep_job_flow_alive_when_no_steps","content":"pub fn set_keep_job_flow_alive_when_no_steps(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.set_keep_job_flow_alive_when_no_steps\naws_api/emr set_keep_job_flow_alive_when_no_steps","url":"aws_api/emr.html#set_keep_job_flow_alive_when_no_steps"},{"doc":"aws_api/emr","title":"set_termination_protection","content":"pub fn set_termination_protection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.set_termination_protection\naws_api/emr set_termination_protection","url":"aws_api/emr.html#set_termination_protection"},{"doc":"aws_api/emr","title":"set_unhealthy_node_replacement","content":"pub fn set_unhealthy_node_replacement(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.set_unhealthy_node_replacement\naws_api/emr set_unhealthy_node_replacement","url":"aws_api/emr.html#set_unhealthy_node_replacement"},{"doc":"aws_api/emr","title":"set_visible_to_all_users","content":"pub fn set_visible_to_all_users(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.set_visible_to_all_users\naws_api/emr set_visible_to_all_users","url":"aws_api/emr.html#set_visible_to_all_users"},{"doc":"aws_api/emr","title":"start_notebook_execution","content":"pub fn start_notebook_execution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.start_notebook_execution\naws_api/emr start_notebook_execution","url":"aws_api/emr.html#start_notebook_execution"},{"doc":"aws_api/emr","title":"stop_notebook_execution","content":"pub fn stop_notebook_execution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.stop_notebook_execution\naws_api/emr stop_notebook_execution","url":"aws_api/emr.html#stop_notebook_execution"},{"doc":"aws_api/emr","title":"terminate_job_flows","content":"pub fn terminate_job_flows(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.terminate_job_flows\naws_api/emr terminate_job_flows","url":"aws_api/emr.html#terminate_job_flows"},{"doc":"aws_api/emr","title":"update_studio","content":"pub fn update_studio(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.update_studio\naws_api/emr update_studio","url":"aws_api/emr.html#update_studio"},{"doc":"aws_api/emr","title":"update_studio_session_mapping","content":"pub fn update_studio_session_mapping(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr.update_studio_session_mapping\naws_api/emr update_studio_session_mapping","url":"aws_api/emr.html#update_studio_session_mapping"},{"doc":"aws_api/emr","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/emr.with_custom_endpoint\naws_api/emr with_custom_endpoint","url":"aws_api/emr.html#with_custom_endpoint"},{"doc":"aws_api/emr","title":"aws_api/emr","content":"","url":"aws_api/emr.html"},{"doc":"aws_api/emr_containers","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/emr_containers.Client\naws_api/emr_containers Client","url":"aws_api/emr_containers.html#Client"},{"doc":"aws_api/emr_containers","title":"cancel_job_run","content":"pub fn cancel_job_run(\n  client: Client,\n  virtual_cluster_id: String,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr_containers.cancel_job_run\naws_api/emr_containers cancel_job_run","url":"aws_api/emr_containers.html#cancel_job_run"},{"doc":"aws_api/emr_containers","title":"create_job_template","content":"pub fn create_job_template(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr_containers.create_job_template\naws_api/emr_containers create_job_template","url":"aws_api/emr_containers.html#create_job_template"},{"doc":"aws_api/emr_containers","title":"create_managed_endpoint","content":"pub fn create_managed_endpoint(\n  client: Client,\n  virtual_cluster_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr_containers.create_managed_endpoint\naws_api/emr_containers create_managed_endpoint","url":"aws_api/emr_containers.html#create_managed_endpoint"},{"doc":"aws_api/emr_containers","title":"create_security_configuration","content":"pub fn create_security_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr_containers.create_security_configuration\naws_api/emr_containers create_security_configuration","url":"aws_api/emr_containers.html#create_security_configuration"},{"doc":"aws_api/emr_containers","title":"create_virtual_cluster","content":"pub fn create_virtual_cluster(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr_containers.create_virtual_cluster\naws_api/emr_containers create_virtual_cluster","url":"aws_api/emr_containers.html#create_virtual_cluster"},{"doc":"aws_api/emr_containers","title":"delete_job_template","content":"pub fn delete_job_template(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr_containers.delete_job_template\naws_api/emr_containers delete_job_template","url":"aws_api/emr_containers.html#delete_job_template"},{"doc":"aws_api/emr_containers","title":"delete_managed_endpoint","content":"pub fn delete_managed_endpoint(\n  client: Client,\n  virtual_cluster_id: String,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr_containers.delete_managed_endpoint\naws_api/emr_containers delete_managed_endpoint","url":"aws_api/emr_containers.html#delete_managed_endpoint"},{"doc":"aws_api/emr_containers","title":"delete_virtual_cluster","content":"pub fn delete_virtual_cluster(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr_containers.delete_virtual_cluster\naws_api/emr_containers delete_virtual_cluster","url":"aws_api/emr_containers.html#delete_virtual_cluster"},{"doc":"aws_api/emr_containers","title":"describe_job_run","content":"pub fn describe_job_run(\n  client: Client,\n  virtual_cluster_id: String,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr_containers.describe_job_run\naws_api/emr_containers describe_job_run","url":"aws_api/emr_containers.html#describe_job_run"},{"doc":"aws_api/emr_containers","title":"describe_job_template","content":"pub fn describe_job_template(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr_containers.describe_job_template\naws_api/emr_containers describe_job_template","url":"aws_api/emr_containers.html#describe_job_template"},{"doc":"aws_api/emr_containers","title":"describe_managed_endpoint","content":"pub fn describe_managed_endpoint(\n  client: Client,\n  virtual_cluster_id: String,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr_containers.describe_managed_endpoint\naws_api/emr_containers describe_managed_endpoint","url":"aws_api/emr_containers.html#describe_managed_endpoint"},{"doc":"aws_api/emr_containers","title":"describe_security_configuration","content":"pub fn describe_security_configuration(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr_containers.describe_security_configuration\naws_api/emr_containers describe_security_configuration","url":"aws_api/emr_containers.html#describe_security_configuration"},{"doc":"aws_api/emr_containers","title":"describe_virtual_cluster","content":"pub fn describe_virtual_cluster(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr_containers.describe_virtual_cluster\naws_api/emr_containers describe_virtual_cluster","url":"aws_api/emr_containers.html#describe_virtual_cluster"},{"doc":"aws_api/emr_containers","title":"get_managed_endpoint_session_credentials","content":"pub fn get_managed_endpoint_session_credentials(\n  client: Client,\n  virtual_cluster_identifier: String,\n  endpoint_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr_containers.get_managed_endpoint_session_credentials\naws_api/emr_containers get_managed_endpoint_session_credentials","url":"aws_api/emr_containers.html#get_managed_endpoint_session_credentials"},{"doc":"aws_api/emr_containers","title":"list_job_runs","content":"pub fn list_job_runs(\n  client: Client,\n  virtual_cluster_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr_containers.list_job_runs\naws_api/emr_containers list_job_runs","url":"aws_api/emr_containers.html#list_job_runs"},{"doc":"aws_api/emr_containers","title":"list_job_templates","content":"pub fn list_job_templates(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr_containers.list_job_templates\naws_api/emr_containers list_job_templates","url":"aws_api/emr_containers.html#list_job_templates"},{"doc":"aws_api/emr_containers","title":"list_managed_endpoints","content":"pub fn list_managed_endpoints(\n  client: Client,\n  virtual_cluster_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr_containers.list_managed_endpoints\naws_api/emr_containers list_managed_endpoints","url":"aws_api/emr_containers.html#list_managed_endpoints"},{"doc":"aws_api/emr_containers","title":"list_security_configurations","content":"pub fn list_security_configurations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr_containers.list_security_configurations\naws_api/emr_containers list_security_configurations","url":"aws_api/emr_containers.html#list_security_configurations"},{"doc":"aws_api/emr_containers","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr_containers.list_tags_for_resource\naws_api/emr_containers list_tags_for_resource","url":"aws_api/emr_containers.html#list_tags_for_resource"},{"doc":"aws_api/emr_containers","title":"list_virtual_clusters","content":"pub fn list_virtual_clusters(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr_containers.list_virtual_clusters\naws_api/emr_containers list_virtual_clusters","url":"aws_api/emr_containers.html#list_virtual_clusters"},{"doc":"aws_api/emr_containers","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/emr_containers.new\naws_api/emr_containers new","url":"aws_api/emr_containers.html#new"},{"doc":"aws_api/emr_containers","title":"start_job_run","content":"pub fn start_job_run(\n  client: Client,\n  virtual_cluster_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr_containers.start_job_run\naws_api/emr_containers start_job_run","url":"aws_api/emr_containers.html#start_job_run"},{"doc":"aws_api/emr_containers","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr_containers.tag_resource\naws_api/emr_containers tag_resource","url":"aws_api/emr_containers.html#tag_resource"},{"doc":"aws_api/emr_containers","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr_containers.untag_resource\naws_api/emr_containers untag_resource","url":"aws_api/emr_containers.html#untag_resource"},{"doc":"aws_api/emr_containers","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/emr_containers.with_custom_endpoint\naws_api/emr_containers with_custom_endpoint","url":"aws_api/emr_containers.html#with_custom_endpoint"},{"doc":"aws_api/emr_containers","title":"aws_api/emr_containers","content":"","url":"aws_api/emr_containers.html"},{"doc":"aws_api/emr_serverless","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/emr_serverless.Client\naws_api/emr_serverless Client","url":"aws_api/emr_serverless.html#Client"},{"doc":"aws_api/emr_serverless","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr_serverless.list_tags_for_resource\naws_api/emr_serverless list_tags_for_resource","url":"aws_api/emr_serverless.html#list_tags_for_resource"},{"doc":"aws_api/emr_serverless","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/emr_serverless.new\naws_api/emr_serverless new","url":"aws_api/emr_serverless.html#new"},{"doc":"aws_api/emr_serverless","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr_serverless.tag_resource\naws_api/emr_serverless tag_resource","url":"aws_api/emr_serverless.html#tag_resource"},{"doc":"aws_api/emr_serverless","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/emr_serverless.untag_resource\naws_api/emr_serverless untag_resource","url":"aws_api/emr_serverless.html#untag_resource"},{"doc":"aws_api/emr_serverless","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/emr_serverless.with_custom_endpoint\naws_api/emr_serverless with_custom_endpoint","url":"aws_api/emr_serverless.html#with_custom_endpoint"},{"doc":"aws_api/emr_serverless","title":"aws_api/emr_serverless","content":"","url":"aws_api/emr_serverless.html"},{"doc":"aws_api/eventbridge","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/eventbridge.Client\naws_api/eventbridge Client","url":"aws_api/eventbridge.html#Client"},{"doc":"aws_api/eventbridge","title":"activate_event_source","content":"pub fn activate_event_source(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.activate_event_source\naws_api/eventbridge activate_event_source","url":"aws_api/eventbridge.html#activate_event_source"},{"doc":"aws_api/eventbridge","title":"cancel_replay","content":"pub fn cancel_replay(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.cancel_replay\naws_api/eventbridge cancel_replay","url":"aws_api/eventbridge.html#cancel_replay"},{"doc":"aws_api/eventbridge","title":"create_api_destination","content":"pub fn create_api_destination(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.create_api_destination\naws_api/eventbridge create_api_destination","url":"aws_api/eventbridge.html#create_api_destination"},{"doc":"aws_api/eventbridge","title":"create_archive","content":"pub fn create_archive(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.create_archive\naws_api/eventbridge create_archive","url":"aws_api/eventbridge.html#create_archive"},{"doc":"aws_api/eventbridge","title":"create_connection","content":"pub fn create_connection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.create_connection\naws_api/eventbridge create_connection","url":"aws_api/eventbridge.html#create_connection"},{"doc":"aws_api/eventbridge","title":"create_endpoint","content":"pub fn create_endpoint(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.create_endpoint\naws_api/eventbridge create_endpoint","url":"aws_api/eventbridge.html#create_endpoint"},{"doc":"aws_api/eventbridge","title":"create_event_bus","content":"pub fn create_event_bus(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.create_event_bus\naws_api/eventbridge create_event_bus","url":"aws_api/eventbridge.html#create_event_bus"},{"doc":"aws_api/eventbridge","title":"create_partner_event_source","content":"pub fn create_partner_event_source(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.create_partner_event_source\naws_api/eventbridge create_partner_event_source","url":"aws_api/eventbridge.html#create_partner_event_source"},{"doc":"aws_api/eventbridge","title":"deactivate_event_source","content":"pub fn deactivate_event_source(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.deactivate_event_source\naws_api/eventbridge deactivate_event_source","url":"aws_api/eventbridge.html#deactivate_event_source"},{"doc":"aws_api/eventbridge","title":"deauthorize_connection","content":"pub fn deauthorize_connection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.deauthorize_connection\naws_api/eventbridge deauthorize_connection","url":"aws_api/eventbridge.html#deauthorize_connection"},{"doc":"aws_api/eventbridge","title":"delete_api_destination","content":"pub fn delete_api_destination(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.delete_api_destination\naws_api/eventbridge delete_api_destination","url":"aws_api/eventbridge.html#delete_api_destination"},{"doc":"aws_api/eventbridge","title":"delete_archive","content":"pub fn delete_archive(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.delete_archive\naws_api/eventbridge delete_archive","url":"aws_api/eventbridge.html#delete_archive"},{"doc":"aws_api/eventbridge","title":"delete_connection","content":"pub fn delete_connection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.delete_connection\naws_api/eventbridge delete_connection","url":"aws_api/eventbridge.html#delete_connection"},{"doc":"aws_api/eventbridge","title":"delete_endpoint","content":"pub fn delete_endpoint(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.delete_endpoint\naws_api/eventbridge delete_endpoint","url":"aws_api/eventbridge.html#delete_endpoint"},{"doc":"aws_api/eventbridge","title":"delete_event_bus","content":"pub fn delete_event_bus(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.delete_event_bus\naws_api/eventbridge delete_event_bus","url":"aws_api/eventbridge.html#delete_event_bus"},{"doc":"aws_api/eventbridge","title":"delete_partner_event_source","content":"pub fn delete_partner_event_source(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.delete_partner_event_source\naws_api/eventbridge delete_partner_event_source","url":"aws_api/eventbridge.html#delete_partner_event_source"},{"doc":"aws_api/eventbridge","title":"delete_rule","content":"pub fn delete_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.delete_rule\naws_api/eventbridge delete_rule","url":"aws_api/eventbridge.html#delete_rule"},{"doc":"aws_api/eventbridge","title":"describe_api_destination","content":"pub fn describe_api_destination(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.describe_api_destination\naws_api/eventbridge describe_api_destination","url":"aws_api/eventbridge.html#describe_api_destination"},{"doc":"aws_api/eventbridge","title":"describe_archive","content":"pub fn describe_archive(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.describe_archive\naws_api/eventbridge describe_archive","url":"aws_api/eventbridge.html#describe_archive"},{"doc":"aws_api/eventbridge","title":"describe_connection","content":"pub fn describe_connection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.describe_connection\naws_api/eventbridge describe_connection","url":"aws_api/eventbridge.html#describe_connection"},{"doc":"aws_api/eventbridge","title":"describe_endpoint","content":"pub fn describe_endpoint(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.describe_endpoint\naws_api/eventbridge describe_endpoint","url":"aws_api/eventbridge.html#describe_endpoint"},{"doc":"aws_api/eventbridge","title":"describe_event_bus","content":"pub fn describe_event_bus(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.describe_event_bus\naws_api/eventbridge describe_event_bus","url":"aws_api/eventbridge.html#describe_event_bus"},{"doc":"aws_api/eventbridge","title":"describe_event_source","content":"pub fn describe_event_source(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.describe_event_source\naws_api/eventbridge describe_event_source","url":"aws_api/eventbridge.html#describe_event_source"},{"doc":"aws_api/eventbridge","title":"describe_partner_event_source","content":"pub fn describe_partner_event_source(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.describe_partner_event_source\naws_api/eventbridge describe_partner_event_source","url":"aws_api/eventbridge.html#describe_partner_event_source"},{"doc":"aws_api/eventbridge","title":"describe_replay","content":"pub fn describe_replay(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.describe_replay\naws_api/eventbridge describe_replay","url":"aws_api/eventbridge.html#describe_replay"},{"doc":"aws_api/eventbridge","title":"describe_rule","content":"pub fn describe_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.describe_rule\naws_api/eventbridge describe_rule","url":"aws_api/eventbridge.html#describe_rule"},{"doc":"aws_api/eventbridge","title":"disable_rule","content":"pub fn disable_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.disable_rule\naws_api/eventbridge disable_rule","url":"aws_api/eventbridge.html#disable_rule"},{"doc":"aws_api/eventbridge","title":"enable_rule","content":"pub fn enable_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.enable_rule\naws_api/eventbridge enable_rule","url":"aws_api/eventbridge.html#enable_rule"},{"doc":"aws_api/eventbridge","title":"list_api_destinations","content":"pub fn list_api_destinations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.list_api_destinations\naws_api/eventbridge list_api_destinations","url":"aws_api/eventbridge.html#list_api_destinations"},{"doc":"aws_api/eventbridge","title":"list_archives","content":"pub fn list_archives(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.list_archives\naws_api/eventbridge list_archives","url":"aws_api/eventbridge.html#list_archives"},{"doc":"aws_api/eventbridge","title":"list_connections","content":"pub fn list_connections(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.list_connections\naws_api/eventbridge list_connections","url":"aws_api/eventbridge.html#list_connections"},{"doc":"aws_api/eventbridge","title":"list_endpoints","content":"pub fn list_endpoints(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.list_endpoints\naws_api/eventbridge list_endpoints","url":"aws_api/eventbridge.html#list_endpoints"},{"doc":"aws_api/eventbridge","title":"list_event_buses","content":"pub fn list_event_buses(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.list_event_buses\naws_api/eventbridge list_event_buses","url":"aws_api/eventbridge.html#list_event_buses"},{"doc":"aws_api/eventbridge","title":"list_event_sources","content":"pub fn list_event_sources(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.list_event_sources\naws_api/eventbridge list_event_sources","url":"aws_api/eventbridge.html#list_event_sources"},{"doc":"aws_api/eventbridge","title":"list_partner_event_source_accounts","content":"pub fn list_partner_event_source_accounts(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.list_partner_event_source_accounts\naws_api/eventbridge list_partner_event_source_accounts","url":"aws_api/eventbridge.html#list_partner_event_source_accounts"},{"doc":"aws_api/eventbridge","title":"list_partner_event_sources","content":"pub fn list_partner_event_sources(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.list_partner_event_sources\naws_api/eventbridge list_partner_event_sources","url":"aws_api/eventbridge.html#list_partner_event_sources"},{"doc":"aws_api/eventbridge","title":"list_replays","content":"pub fn list_replays(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.list_replays\naws_api/eventbridge list_replays","url":"aws_api/eventbridge.html#list_replays"},{"doc":"aws_api/eventbridge","title":"list_rule_names_by_target","content":"pub fn list_rule_names_by_target(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.list_rule_names_by_target\naws_api/eventbridge list_rule_names_by_target","url":"aws_api/eventbridge.html#list_rule_names_by_target"},{"doc":"aws_api/eventbridge","title":"list_rules","content":"pub fn list_rules(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.list_rules\naws_api/eventbridge list_rules","url":"aws_api/eventbridge.html#list_rules"},{"doc":"aws_api/eventbridge","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.list_tags_for_resource\naws_api/eventbridge list_tags_for_resource","url":"aws_api/eventbridge.html#list_tags_for_resource"},{"doc":"aws_api/eventbridge","title":"list_targets_by_rule","content":"pub fn list_targets_by_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.list_targets_by_rule\naws_api/eventbridge list_targets_by_rule","url":"aws_api/eventbridge.html#list_targets_by_rule"},{"doc":"aws_api/eventbridge","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/eventbridge.new\naws_api/eventbridge new","url":"aws_api/eventbridge.html#new"},{"doc":"aws_api/eventbridge","title":"put_events","content":"pub fn put_events(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.put_events\naws_api/eventbridge put_events","url":"aws_api/eventbridge.html#put_events"},{"doc":"aws_api/eventbridge","title":"put_partner_events","content":"pub fn put_partner_events(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.put_partner_events\naws_api/eventbridge put_partner_events","url":"aws_api/eventbridge.html#put_partner_events"},{"doc":"aws_api/eventbridge","title":"put_permission","content":"pub fn put_permission(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.put_permission\naws_api/eventbridge put_permission","url":"aws_api/eventbridge.html#put_permission"},{"doc":"aws_api/eventbridge","title":"put_rule","content":"pub fn put_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.put_rule\naws_api/eventbridge put_rule","url":"aws_api/eventbridge.html#put_rule"},{"doc":"aws_api/eventbridge","title":"put_targets","content":"pub fn put_targets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.put_targets\naws_api/eventbridge put_targets","url":"aws_api/eventbridge.html#put_targets"},{"doc":"aws_api/eventbridge","title":"remove_permission","content":"pub fn remove_permission(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.remove_permission\naws_api/eventbridge remove_permission","url":"aws_api/eventbridge.html#remove_permission"},{"doc":"aws_api/eventbridge","title":"remove_targets","content":"pub fn remove_targets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.remove_targets\naws_api/eventbridge remove_targets","url":"aws_api/eventbridge.html#remove_targets"},{"doc":"aws_api/eventbridge","title":"start_replay","content":"pub fn start_replay(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.start_replay\naws_api/eventbridge start_replay","url":"aws_api/eventbridge.html#start_replay"},{"doc":"aws_api/eventbridge","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.tag_resource\naws_api/eventbridge tag_resource","url":"aws_api/eventbridge.html#tag_resource"},{"doc":"aws_api/eventbridge","title":"test_event_pattern","content":"pub fn test_event_pattern(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.test_event_pattern\naws_api/eventbridge test_event_pattern","url":"aws_api/eventbridge.html#test_event_pattern"},{"doc":"aws_api/eventbridge","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.untag_resource\naws_api/eventbridge untag_resource","url":"aws_api/eventbridge.html#untag_resource"},{"doc":"aws_api/eventbridge","title":"update_api_destination","content":"pub fn update_api_destination(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.update_api_destination\naws_api/eventbridge update_api_destination","url":"aws_api/eventbridge.html#update_api_destination"},{"doc":"aws_api/eventbridge","title":"update_archive","content":"pub fn update_archive(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.update_archive\naws_api/eventbridge update_archive","url":"aws_api/eventbridge.html#update_archive"},{"doc":"aws_api/eventbridge","title":"update_connection","content":"pub fn update_connection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.update_connection\naws_api/eventbridge update_connection","url":"aws_api/eventbridge.html#update_connection"},{"doc":"aws_api/eventbridge","title":"update_endpoint","content":"pub fn update_endpoint(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.update_endpoint\naws_api/eventbridge update_endpoint","url":"aws_api/eventbridge.html#update_endpoint"},{"doc":"aws_api/eventbridge","title":"update_event_bus","content":"pub fn update_event_bus(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/eventbridge.update_event_bus\naws_api/eventbridge update_event_bus","url":"aws_api/eventbridge.html#update_event_bus"},{"doc":"aws_api/eventbridge","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/eventbridge.with_custom_endpoint\naws_api/eventbridge with_custom_endpoint","url":"aws_api/eventbridge.html#with_custom_endpoint"},{"doc":"aws_api/eventbridge","title":"aws_api/eventbridge","content":"","url":"aws_api/eventbridge.html"},{"doc":"aws_api/evidently","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/evidently.Client\naws_api/evidently Client","url":"aws_api/evidently.html#Client"},{"doc":"aws_api/evidently","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/evidently.list_tags_for_resource\naws_api/evidently list_tags_for_resource","url":"aws_api/evidently.html#list_tags_for_resource"},{"doc":"aws_api/evidently","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/evidently.new\naws_api/evidently new","url":"aws_api/evidently.html#new"},{"doc":"aws_api/evidently","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/evidently.tag_resource\naws_api/evidently tag_resource","url":"aws_api/evidently.html#tag_resource"},{"doc":"aws_api/evidently","title":"test_segment_pattern","content":"pub fn test_segment_pattern(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/evidently.test_segment_pattern\naws_api/evidently test_segment_pattern","url":"aws_api/evidently.html#test_segment_pattern"},{"doc":"aws_api/evidently","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/evidently.untag_resource\naws_api/evidently untag_resource","url":"aws_api/evidently.html#untag_resource"},{"doc":"aws_api/evidently","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/evidently.with_custom_endpoint\naws_api/evidently with_custom_endpoint","url":"aws_api/evidently.html#with_custom_endpoint"},{"doc":"aws_api/evidently","title":"aws_api/evidently","content":"","url":"aws_api/evidently.html"},{"doc":"aws_api/finspace","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/finspace.Client\naws_api/finspace Client","url":"aws_api/finspace.html#Client"},{"doc":"aws_api/finspace","title":"create_environment","content":"pub fn create_environment(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace.create_environment\naws_api/finspace create_environment","url":"aws_api/finspace.html#create_environment"},{"doc":"aws_api/finspace","title":"create_kx_changeset","content":"pub fn create_kx_changeset(\n  client: Client,\n  environment_id: String,\n  database_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace.create_kx_changeset\naws_api/finspace create_kx_changeset","url":"aws_api/finspace.html#create_kx_changeset"},{"doc":"aws_api/finspace","title":"create_kx_cluster","content":"pub fn create_kx_cluster(\n  client: Client,\n  environment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace.create_kx_cluster\naws_api/finspace create_kx_cluster","url":"aws_api/finspace.html#create_kx_cluster"},{"doc":"aws_api/finspace","title":"create_kx_database","content":"pub fn create_kx_database(\n  client: Client,\n  environment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace.create_kx_database\naws_api/finspace create_kx_database","url":"aws_api/finspace.html#create_kx_database"},{"doc":"aws_api/finspace","title":"create_kx_dataview","content":"pub fn create_kx_dataview(\n  client: Client,\n  environment_id: String,\n  database_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace.create_kx_dataview\naws_api/finspace create_kx_dataview","url":"aws_api/finspace.html#create_kx_dataview"},{"doc":"aws_api/finspace","title":"create_kx_environment","content":"pub fn create_kx_environment(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace.create_kx_environment\naws_api/finspace create_kx_environment","url":"aws_api/finspace.html#create_kx_environment"},{"doc":"aws_api/finspace","title":"create_kx_scaling_group","content":"pub fn create_kx_scaling_group(\n  client: Client,\n  environment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace.create_kx_scaling_group\naws_api/finspace create_kx_scaling_group","url":"aws_api/finspace.html#create_kx_scaling_group"},{"doc":"aws_api/finspace","title":"create_kx_user","content":"pub fn create_kx_user(\n  client: Client,\n  environment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace.create_kx_user\naws_api/finspace create_kx_user","url":"aws_api/finspace.html#create_kx_user"},{"doc":"aws_api/finspace","title":"create_kx_volume","content":"pub fn create_kx_volume(\n  client: Client,\n  environment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace.create_kx_volume\naws_api/finspace create_kx_volume","url":"aws_api/finspace.html#create_kx_volume"},{"doc":"aws_api/finspace","title":"delete_environment","content":"pub fn delete_environment(\n  client: Client,\n  environment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace.delete_environment\naws_api/finspace delete_environment","url":"aws_api/finspace.html#delete_environment"},{"doc":"aws_api/finspace","title":"delete_kx_cluster","content":"pub fn delete_kx_cluster(\n  client: Client,\n  environment_id: String,\n  cluster_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace.delete_kx_cluster\naws_api/finspace delete_kx_cluster","url":"aws_api/finspace.html#delete_kx_cluster"},{"doc":"aws_api/finspace","title":"delete_kx_cluster_node","content":"pub fn delete_kx_cluster_node(\n  client: Client,\n  environment_id: String,\n  cluster_name: String,\n  node_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace.delete_kx_cluster_node\naws_api/finspace delete_kx_cluster_node","url":"aws_api/finspace.html#delete_kx_cluster_node"},{"doc":"aws_api/finspace","title":"delete_kx_database","content":"pub fn delete_kx_database(\n  client: Client,\n  environment_id: String,\n  database_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace.delete_kx_database\naws_api/finspace delete_kx_database","url":"aws_api/finspace.html#delete_kx_database"},{"doc":"aws_api/finspace","title":"delete_kx_dataview","content":"pub fn delete_kx_dataview(\n  client: Client,\n  environment_id: String,\n  database_name: String,\n  dataview_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace.delete_kx_dataview\naws_api/finspace delete_kx_dataview","url":"aws_api/finspace.html#delete_kx_dataview"},{"doc":"aws_api/finspace","title":"delete_kx_environment","content":"pub fn delete_kx_environment(\n  client: Client,\n  environment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace.delete_kx_environment\naws_api/finspace delete_kx_environment","url":"aws_api/finspace.html#delete_kx_environment"},{"doc":"aws_api/finspace","title":"delete_kx_scaling_group","content":"pub fn delete_kx_scaling_group(\n  client: Client,\n  environment_id: String,\n  scaling_group_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace.delete_kx_scaling_group\naws_api/finspace delete_kx_scaling_group","url":"aws_api/finspace.html#delete_kx_scaling_group"},{"doc":"aws_api/finspace","title":"delete_kx_user","content":"pub fn delete_kx_user(\n  client: Client,\n  environment_id: String,\n  user_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace.delete_kx_user\naws_api/finspace delete_kx_user","url":"aws_api/finspace.html#delete_kx_user"},{"doc":"aws_api/finspace","title":"delete_kx_volume","content":"pub fn delete_kx_volume(\n  client: Client,\n  environment_id: String,\n  volume_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace.delete_kx_volume\naws_api/finspace delete_kx_volume","url":"aws_api/finspace.html#delete_kx_volume"},{"doc":"aws_api/finspace","title":"get_environment","content":"pub fn get_environment(\n  client: Client,\n  environment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace.get_environment\naws_api/finspace get_environment","url":"aws_api/finspace.html#get_environment"},{"doc":"aws_api/finspace","title":"get_kx_changeset","content":"pub fn get_kx_changeset(\n  client: Client,\n  environment_id: String,\n  database_name: String,\n  changeset_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace.get_kx_changeset\naws_api/finspace get_kx_changeset","url":"aws_api/finspace.html#get_kx_changeset"},{"doc":"aws_api/finspace","title":"get_kx_cluster","content":"pub fn get_kx_cluster(\n  client: Client,\n  environment_id: String,\n  cluster_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace.get_kx_cluster\naws_api/finspace get_kx_cluster","url":"aws_api/finspace.html#get_kx_cluster"},{"doc":"aws_api/finspace","title":"get_kx_connection_string","content":"pub fn get_kx_connection_string(\n  client: Client,\n  environment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace.get_kx_connection_string\naws_api/finspace get_kx_connection_string","url":"aws_api/finspace.html#get_kx_connection_string"},{"doc":"aws_api/finspace","title":"get_kx_database","content":"pub fn get_kx_database(\n  client: Client,\n  environment_id: String,\n  database_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace.get_kx_database\naws_api/finspace get_kx_database","url":"aws_api/finspace.html#get_kx_database"},{"doc":"aws_api/finspace","title":"get_kx_dataview","content":"pub fn get_kx_dataview(\n  client: Client,\n  environment_id: String,\n  database_name: String,\n  dataview_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace.get_kx_dataview\naws_api/finspace get_kx_dataview","url":"aws_api/finspace.html#get_kx_dataview"},{"doc":"aws_api/finspace","title":"get_kx_environment","content":"pub fn get_kx_environment(\n  client: Client,\n  environment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace.get_kx_environment\naws_api/finspace get_kx_environment","url":"aws_api/finspace.html#get_kx_environment"},{"doc":"aws_api/finspace","title":"get_kx_scaling_group","content":"pub fn get_kx_scaling_group(\n  client: Client,\n  environment_id: String,\n  scaling_group_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace.get_kx_scaling_group\naws_api/finspace get_kx_scaling_group","url":"aws_api/finspace.html#get_kx_scaling_group"},{"doc":"aws_api/finspace","title":"get_kx_user","content":"pub fn get_kx_user(\n  client: Client,\n  environment_id: String,\n  user_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace.get_kx_user\naws_api/finspace get_kx_user","url":"aws_api/finspace.html#get_kx_user"},{"doc":"aws_api/finspace","title":"get_kx_volume","content":"pub fn get_kx_volume(\n  client: Client,\n  environment_id: String,\n  volume_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace.get_kx_volume\naws_api/finspace get_kx_volume","url":"aws_api/finspace.html#get_kx_volume"},{"doc":"aws_api/finspace","title":"list_environments","content":"pub fn list_environments(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace.list_environments\naws_api/finspace list_environments","url":"aws_api/finspace.html#list_environments"},{"doc":"aws_api/finspace","title":"list_kx_changesets","content":"pub fn list_kx_changesets(\n  client: Client,\n  environment_id: String,\n  database_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace.list_kx_changesets\naws_api/finspace list_kx_changesets","url":"aws_api/finspace.html#list_kx_changesets"},{"doc":"aws_api/finspace","title":"list_kx_cluster_nodes","content":"pub fn list_kx_cluster_nodes(\n  client: Client,\n  environment_id: String,\n  cluster_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace.list_kx_cluster_nodes\naws_api/finspace list_kx_cluster_nodes","url":"aws_api/finspace.html#list_kx_cluster_nodes"},{"doc":"aws_api/finspace","title":"list_kx_clusters","content":"pub fn list_kx_clusters(\n  client: Client,\n  environment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace.list_kx_clusters\naws_api/finspace list_kx_clusters","url":"aws_api/finspace.html#list_kx_clusters"},{"doc":"aws_api/finspace","title":"list_kx_databases","content":"pub fn list_kx_databases(\n  client: Client,\n  environment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace.list_kx_databases\naws_api/finspace list_kx_databases","url":"aws_api/finspace.html#list_kx_databases"},{"doc":"aws_api/finspace","title":"list_kx_dataviews","content":"pub fn list_kx_dataviews(\n  client: Client,\n  environment_id: String,\n  database_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace.list_kx_dataviews\naws_api/finspace list_kx_dataviews","url":"aws_api/finspace.html#list_kx_dataviews"},{"doc":"aws_api/finspace","title":"list_kx_environments","content":"pub fn list_kx_environments(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace.list_kx_environments\naws_api/finspace list_kx_environments","url":"aws_api/finspace.html#list_kx_environments"},{"doc":"aws_api/finspace","title":"list_kx_scaling_groups","content":"pub fn list_kx_scaling_groups(\n  client: Client,\n  environment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace.list_kx_scaling_groups\naws_api/finspace list_kx_scaling_groups","url":"aws_api/finspace.html#list_kx_scaling_groups"},{"doc":"aws_api/finspace","title":"list_kx_users","content":"pub fn list_kx_users(\n  client: Client,\n  environment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace.list_kx_users\naws_api/finspace list_kx_users","url":"aws_api/finspace.html#list_kx_users"},{"doc":"aws_api/finspace","title":"list_kx_volumes","content":"pub fn list_kx_volumes(\n  client: Client,\n  environment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace.list_kx_volumes\naws_api/finspace list_kx_volumes","url":"aws_api/finspace.html#list_kx_volumes"},{"doc":"aws_api/finspace","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace.list_tags_for_resource\naws_api/finspace list_tags_for_resource","url":"aws_api/finspace.html#list_tags_for_resource"},{"doc":"aws_api/finspace","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/finspace.new\naws_api/finspace new","url":"aws_api/finspace.html#new"},{"doc":"aws_api/finspace","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace.tag_resource\naws_api/finspace tag_resource","url":"aws_api/finspace.html#tag_resource"},{"doc":"aws_api/finspace","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace.untag_resource\naws_api/finspace untag_resource","url":"aws_api/finspace.html#untag_resource"},{"doc":"aws_api/finspace","title":"update_environment","content":"pub fn update_environment(\n  client: Client,\n  environment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace.update_environment\naws_api/finspace update_environment","url":"aws_api/finspace.html#update_environment"},{"doc":"aws_api/finspace","title":"update_kx_cluster_code_configuration","content":"pub fn update_kx_cluster_code_configuration(\n  client: Client,\n  environment_id: String,\n  cluster_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace.update_kx_cluster_code_configuration\naws_api/finspace update_kx_cluster_code_configuration","url":"aws_api/finspace.html#update_kx_cluster_code_configuration"},{"doc":"aws_api/finspace","title":"update_kx_cluster_databases","content":"pub fn update_kx_cluster_databases(\n  client: Client,\n  environment_id: String,\n  cluster_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace.update_kx_cluster_databases\naws_api/finspace update_kx_cluster_databases","url":"aws_api/finspace.html#update_kx_cluster_databases"},{"doc":"aws_api/finspace","title":"update_kx_database","content":"pub fn update_kx_database(\n  client: Client,\n  environment_id: String,\n  database_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace.update_kx_database\naws_api/finspace update_kx_database","url":"aws_api/finspace.html#update_kx_database"},{"doc":"aws_api/finspace","title":"update_kx_dataview","content":"pub fn update_kx_dataview(\n  client: Client,\n  environment_id: String,\n  database_name: String,\n  dataview_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace.update_kx_dataview\naws_api/finspace update_kx_dataview","url":"aws_api/finspace.html#update_kx_dataview"},{"doc":"aws_api/finspace","title":"update_kx_environment","content":"pub fn update_kx_environment(\n  client: Client,\n  environment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace.update_kx_environment\naws_api/finspace update_kx_environment","url":"aws_api/finspace.html#update_kx_environment"},{"doc":"aws_api/finspace","title":"update_kx_environment_network","content":"pub fn update_kx_environment_network(\n  client: Client,\n  environment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace.update_kx_environment_network\naws_api/finspace update_kx_environment_network","url":"aws_api/finspace.html#update_kx_environment_network"},{"doc":"aws_api/finspace","title":"update_kx_user","content":"pub fn update_kx_user(\n  client: Client,\n  environment_id: String,\n  user_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace.update_kx_user\naws_api/finspace update_kx_user","url":"aws_api/finspace.html#update_kx_user"},{"doc":"aws_api/finspace","title":"update_kx_volume","content":"pub fn update_kx_volume(\n  client: Client,\n  environment_id: String,\n  volume_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace.update_kx_volume\naws_api/finspace update_kx_volume","url":"aws_api/finspace.html#update_kx_volume"},{"doc":"aws_api/finspace","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/finspace.with_custom_endpoint\naws_api/finspace with_custom_endpoint","url":"aws_api/finspace.html#with_custom_endpoint"},{"doc":"aws_api/finspace","title":"aws_api/finspace","content":"","url":"aws_api/finspace.html"},{"doc":"aws_api/finspace_data","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/finspace_data.Client\naws_api/finspace_data Client","url":"aws_api/finspace_data.html#Client"},{"doc":"aws_api/finspace_data","title":"associate_user_to_permission_group","content":"pub fn associate_user_to_permission_group(\n  client: Client,\n  permission_group_id: String,\n  user_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace_data.associate_user_to_permission_group\naws_api/finspace_data associate_user_to_permission_group","url":"aws_api/finspace_data.html#associate_user_to_permission_group"},{"doc":"aws_api/finspace_data","title":"create_changeset","content":"pub fn create_changeset(\n  client: Client,\n  dataset_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace_data.create_changeset\naws_api/finspace_data create_changeset","url":"aws_api/finspace_data.html#create_changeset"},{"doc":"aws_api/finspace_data","title":"create_data_view","content":"pub fn create_data_view(\n  client: Client,\n  dataset_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace_data.create_data_view\naws_api/finspace_data create_data_view","url":"aws_api/finspace_data.html#create_data_view"},{"doc":"aws_api/finspace_data","title":"create_dataset","content":"pub fn create_dataset(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace_data.create_dataset\naws_api/finspace_data create_dataset","url":"aws_api/finspace_data.html#create_dataset"},{"doc":"aws_api/finspace_data","title":"create_permission_group","content":"pub fn create_permission_group(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace_data.create_permission_group\naws_api/finspace_data create_permission_group","url":"aws_api/finspace_data.html#create_permission_group"},{"doc":"aws_api/finspace_data","title":"create_user","content":"pub fn create_user(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace_data.create_user\naws_api/finspace_data create_user","url":"aws_api/finspace_data.html#create_user"},{"doc":"aws_api/finspace_data","title":"delete_dataset","content":"pub fn delete_dataset(\n  client: Client,\n  dataset_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace_data.delete_dataset\naws_api/finspace_data delete_dataset","url":"aws_api/finspace_data.html#delete_dataset"},{"doc":"aws_api/finspace_data","title":"delete_permission_group","content":"pub fn delete_permission_group(\n  client: Client,\n  permission_group_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace_data.delete_permission_group\naws_api/finspace_data delete_permission_group","url":"aws_api/finspace_data.html#delete_permission_group"},{"doc":"aws_api/finspace_data","title":"disable_user","content":"pub fn disable_user(\n  client: Client,\n  user_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace_data.disable_user\naws_api/finspace_data disable_user","url":"aws_api/finspace_data.html#disable_user"},{"doc":"aws_api/finspace_data","title":"disassociate_user_from_permission_group","content":"pub fn disassociate_user_from_permission_group(\n  client: Client,\n  permission_group_id: String,\n  user_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace_data.disassociate_user_from_permission_group\naws_api/finspace_data disassociate_user_from_permission_group","url":"aws_api/finspace_data.html#disassociate_user_from_permission_group"},{"doc":"aws_api/finspace_data","title":"enable_user","content":"pub fn enable_user(\n  client: Client,\n  user_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace_data.enable_user\naws_api/finspace_data enable_user","url":"aws_api/finspace_data.html#enable_user"},{"doc":"aws_api/finspace_data","title":"get_changeset","content":"pub fn get_changeset(\n  client: Client,\n  dataset_id: String,\n  changeset_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace_data.get_changeset\naws_api/finspace_data get_changeset","url":"aws_api/finspace_data.html#get_changeset"},{"doc":"aws_api/finspace_data","title":"get_data_view","content":"pub fn get_data_view(\n  client: Client,\n  dataset_id: String,\n  data_view_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace_data.get_data_view\naws_api/finspace_data get_data_view","url":"aws_api/finspace_data.html#get_data_view"},{"doc":"aws_api/finspace_data","title":"get_dataset","content":"pub fn get_dataset(\n  client: Client,\n  dataset_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace_data.get_dataset\naws_api/finspace_data get_dataset","url":"aws_api/finspace_data.html#get_dataset"},{"doc":"aws_api/finspace_data","title":"get_external_data_view_access_details","content":"pub fn get_external_data_view_access_details(\n  client: Client,\n  dataset_id: String,\n  data_view_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace_data.get_external_data_view_access_details\naws_api/finspace_data get_external_data_view_access_details","url":"aws_api/finspace_data.html#get_external_data_view_access_details"},{"doc":"aws_api/finspace_data","title":"get_permission_group","content":"pub fn get_permission_group(\n  client: Client,\n  permission_group_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace_data.get_permission_group\naws_api/finspace_data get_permission_group","url":"aws_api/finspace_data.html#get_permission_group"},{"doc":"aws_api/finspace_data","title":"get_programmatic_access_credentials","content":"pub fn get_programmatic_access_credentials(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace_data.get_programmatic_access_credentials\naws_api/finspace_data get_programmatic_access_credentials","url":"aws_api/finspace_data.html#get_programmatic_access_credentials"},{"doc":"aws_api/finspace_data","title":"get_user","content":"pub fn get_user(\n  client: Client,\n  user_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace_data.get_user\naws_api/finspace_data get_user","url":"aws_api/finspace_data.html#get_user"},{"doc":"aws_api/finspace_data","title":"get_working_location","content":"pub fn get_working_location(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace_data.get_working_location\naws_api/finspace_data get_working_location","url":"aws_api/finspace_data.html#get_working_location"},{"doc":"aws_api/finspace_data","title":"list_changesets","content":"pub fn list_changesets(\n  client: Client,\n  dataset_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace_data.list_changesets\naws_api/finspace_data list_changesets","url":"aws_api/finspace_data.html#list_changesets"},{"doc":"aws_api/finspace_data","title":"list_data_views","content":"pub fn list_data_views(\n  client: Client,\n  dataset_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace_data.list_data_views\naws_api/finspace_data list_data_views","url":"aws_api/finspace_data.html#list_data_views"},{"doc":"aws_api/finspace_data","title":"list_datasets","content":"pub fn list_datasets(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace_data.list_datasets\naws_api/finspace_data list_datasets","url":"aws_api/finspace_data.html#list_datasets"},{"doc":"aws_api/finspace_data","title":"list_permission_groups","content":"pub fn list_permission_groups(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace_data.list_permission_groups\naws_api/finspace_data list_permission_groups","url":"aws_api/finspace_data.html#list_permission_groups"},{"doc":"aws_api/finspace_data","title":"list_permission_groups_by_user","content":"pub fn list_permission_groups_by_user(\n  client: Client,\n  user_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace_data.list_permission_groups_by_user\naws_api/finspace_data list_permission_groups_by_user","url":"aws_api/finspace_data.html#list_permission_groups_by_user"},{"doc":"aws_api/finspace_data","title":"list_users","content":"pub fn list_users(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace_data.list_users\naws_api/finspace_data list_users","url":"aws_api/finspace_data.html#list_users"},{"doc":"aws_api/finspace_data","title":"list_users_by_permission_group","content":"pub fn list_users_by_permission_group(\n  client: Client,\n  permission_group_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace_data.list_users_by_permission_group\naws_api/finspace_data list_users_by_permission_group","url":"aws_api/finspace_data.html#list_users_by_permission_group"},{"doc":"aws_api/finspace_data","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/finspace_data.new\naws_api/finspace_data new","url":"aws_api/finspace_data.html#new"},{"doc":"aws_api/finspace_data","title":"reset_user_password","content":"pub fn reset_user_password(\n  client: Client,\n  user_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace_data.reset_user_password\naws_api/finspace_data reset_user_password","url":"aws_api/finspace_data.html#reset_user_password"},{"doc":"aws_api/finspace_data","title":"update_changeset","content":"pub fn update_changeset(\n  client: Client,\n  dataset_id: String,\n  changeset_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace_data.update_changeset\naws_api/finspace_data update_changeset","url":"aws_api/finspace_data.html#update_changeset"},{"doc":"aws_api/finspace_data","title":"update_dataset","content":"pub fn update_dataset(\n  client: Client,\n  dataset_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace_data.update_dataset\naws_api/finspace_data update_dataset","url":"aws_api/finspace_data.html#update_dataset"},{"doc":"aws_api/finspace_data","title":"update_permission_group","content":"pub fn update_permission_group(\n  client: Client,\n  permission_group_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace_data.update_permission_group\naws_api/finspace_data update_permission_group","url":"aws_api/finspace_data.html#update_permission_group"},{"doc":"aws_api/finspace_data","title":"update_user","content":"pub fn update_user(\n  client: Client,\n  user_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/finspace_data.update_user\naws_api/finspace_data update_user","url":"aws_api/finspace_data.html#update_user"},{"doc":"aws_api/finspace_data","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/finspace_data.with_custom_endpoint\naws_api/finspace_data with_custom_endpoint","url":"aws_api/finspace_data.html#with_custom_endpoint"},{"doc":"aws_api/finspace_data","title":"aws_api/finspace_data","content":"","url":"aws_api/finspace_data.html"},{"doc":"aws_api/firehose","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/firehose.Client\naws_api/firehose Client","url":"aws_api/firehose.html#Client"},{"doc":"aws_api/firehose","title":"create_delivery_stream","content":"pub fn create_delivery_stream(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/firehose.create_delivery_stream\naws_api/firehose create_delivery_stream","url":"aws_api/firehose.html#create_delivery_stream"},{"doc":"aws_api/firehose","title":"delete_delivery_stream","content":"pub fn delete_delivery_stream(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/firehose.delete_delivery_stream\naws_api/firehose delete_delivery_stream","url":"aws_api/firehose.html#delete_delivery_stream"},{"doc":"aws_api/firehose","title":"describe_delivery_stream","content":"pub fn describe_delivery_stream(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/firehose.describe_delivery_stream\naws_api/firehose describe_delivery_stream","url":"aws_api/firehose.html#describe_delivery_stream"},{"doc":"aws_api/firehose","title":"list_delivery_streams","content":"pub fn list_delivery_streams(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/firehose.list_delivery_streams\naws_api/firehose list_delivery_streams","url":"aws_api/firehose.html#list_delivery_streams"},{"doc":"aws_api/firehose","title":"list_tags_for_delivery_stream","content":"pub fn list_tags_for_delivery_stream(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/firehose.list_tags_for_delivery_stream\naws_api/firehose list_tags_for_delivery_stream","url":"aws_api/firehose.html#list_tags_for_delivery_stream"},{"doc":"aws_api/firehose","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/firehose.new\naws_api/firehose new","url":"aws_api/firehose.html#new"},{"doc":"aws_api/firehose","title":"put_record","content":"pub fn put_record(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/firehose.put_record\naws_api/firehose put_record","url":"aws_api/firehose.html#put_record"},{"doc":"aws_api/firehose","title":"put_record_batch","content":"pub fn put_record_batch(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/firehose.put_record_batch\naws_api/firehose put_record_batch","url":"aws_api/firehose.html#put_record_batch"},{"doc":"aws_api/firehose","title":"start_delivery_stream_encryption","content":"pub fn start_delivery_stream_encryption(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/firehose.start_delivery_stream_encryption\naws_api/firehose start_delivery_stream_encryption","url":"aws_api/firehose.html#start_delivery_stream_encryption"},{"doc":"aws_api/firehose","title":"stop_delivery_stream_encryption","content":"pub fn stop_delivery_stream_encryption(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/firehose.stop_delivery_stream_encryption\naws_api/firehose stop_delivery_stream_encryption","url":"aws_api/firehose.html#stop_delivery_stream_encryption"},{"doc":"aws_api/firehose","title":"tag_delivery_stream","content":"pub fn tag_delivery_stream(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/firehose.tag_delivery_stream\naws_api/firehose tag_delivery_stream","url":"aws_api/firehose.html#tag_delivery_stream"},{"doc":"aws_api/firehose","title":"untag_delivery_stream","content":"pub fn untag_delivery_stream(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/firehose.untag_delivery_stream\naws_api/firehose untag_delivery_stream","url":"aws_api/firehose.html#untag_delivery_stream"},{"doc":"aws_api/firehose","title":"update_destination","content":"pub fn update_destination(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/firehose.update_destination\naws_api/firehose update_destination","url":"aws_api/firehose.html#update_destination"},{"doc":"aws_api/firehose","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/firehose.with_custom_endpoint\naws_api/firehose with_custom_endpoint","url":"aws_api/firehose.html#with_custom_endpoint"},{"doc":"aws_api/firehose","title":"aws_api/firehose","content":"","url":"aws_api/firehose.html"},{"doc":"aws_api/fms","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/fms.Client\naws_api/fms Client","url":"aws_api/fms.html#Client"},{"doc":"aws_api/fms","title":"associate_admin_account","content":"pub fn associate_admin_account(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fms.associate_admin_account\naws_api/fms associate_admin_account","url":"aws_api/fms.html#associate_admin_account"},{"doc":"aws_api/fms","title":"associate_third_party_firewall","content":"pub fn associate_third_party_firewall(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fms.associate_third_party_firewall\naws_api/fms associate_third_party_firewall","url":"aws_api/fms.html#associate_third_party_firewall"},{"doc":"aws_api/fms","title":"batch_associate_resource","content":"pub fn batch_associate_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fms.batch_associate_resource\naws_api/fms batch_associate_resource","url":"aws_api/fms.html#batch_associate_resource"},{"doc":"aws_api/fms","title":"batch_disassociate_resource","content":"pub fn batch_disassociate_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fms.batch_disassociate_resource\naws_api/fms batch_disassociate_resource","url":"aws_api/fms.html#batch_disassociate_resource"},{"doc":"aws_api/fms","title":"delete_apps_list","content":"pub fn delete_apps_list(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fms.delete_apps_list\naws_api/fms delete_apps_list","url":"aws_api/fms.html#delete_apps_list"},{"doc":"aws_api/fms","title":"delete_notification_channel","content":"pub fn delete_notification_channel(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fms.delete_notification_channel\naws_api/fms delete_notification_channel","url":"aws_api/fms.html#delete_notification_channel"},{"doc":"aws_api/fms","title":"delete_policy","content":"pub fn delete_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fms.delete_policy\naws_api/fms delete_policy","url":"aws_api/fms.html#delete_policy"},{"doc":"aws_api/fms","title":"delete_protocols_list","content":"pub fn delete_protocols_list(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fms.delete_protocols_list\naws_api/fms delete_protocols_list","url":"aws_api/fms.html#delete_protocols_list"},{"doc":"aws_api/fms","title":"delete_resource_set","content":"pub fn delete_resource_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fms.delete_resource_set\naws_api/fms delete_resource_set","url":"aws_api/fms.html#delete_resource_set"},{"doc":"aws_api/fms","title":"disassociate_admin_account","content":"pub fn disassociate_admin_account(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fms.disassociate_admin_account\naws_api/fms disassociate_admin_account","url":"aws_api/fms.html#disassociate_admin_account"},{"doc":"aws_api/fms","title":"disassociate_third_party_firewall","content":"pub fn disassociate_third_party_firewall(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fms.disassociate_third_party_firewall\naws_api/fms disassociate_third_party_firewall","url":"aws_api/fms.html#disassociate_third_party_firewall"},{"doc":"aws_api/fms","title":"get_admin_account","content":"pub fn get_admin_account(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fms.get_admin_account\naws_api/fms get_admin_account","url":"aws_api/fms.html#get_admin_account"},{"doc":"aws_api/fms","title":"get_admin_scope","content":"pub fn get_admin_scope(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fms.get_admin_scope\naws_api/fms get_admin_scope","url":"aws_api/fms.html#get_admin_scope"},{"doc":"aws_api/fms","title":"get_apps_list","content":"pub fn get_apps_list(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fms.get_apps_list\naws_api/fms get_apps_list","url":"aws_api/fms.html#get_apps_list"},{"doc":"aws_api/fms","title":"get_compliance_detail","content":"pub fn get_compliance_detail(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fms.get_compliance_detail\naws_api/fms get_compliance_detail","url":"aws_api/fms.html#get_compliance_detail"},{"doc":"aws_api/fms","title":"get_notification_channel","content":"pub fn get_notification_channel(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fms.get_notification_channel\naws_api/fms get_notification_channel","url":"aws_api/fms.html#get_notification_channel"},{"doc":"aws_api/fms","title":"get_policy","content":"pub fn get_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fms.get_policy\naws_api/fms get_policy","url":"aws_api/fms.html#get_policy"},{"doc":"aws_api/fms","title":"get_protection_status","content":"pub fn get_protection_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fms.get_protection_status\naws_api/fms get_protection_status","url":"aws_api/fms.html#get_protection_status"},{"doc":"aws_api/fms","title":"get_protocols_list","content":"pub fn get_protocols_list(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fms.get_protocols_list\naws_api/fms get_protocols_list","url":"aws_api/fms.html#get_protocols_list"},{"doc":"aws_api/fms","title":"get_resource_set","content":"pub fn get_resource_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fms.get_resource_set\naws_api/fms get_resource_set","url":"aws_api/fms.html#get_resource_set"},{"doc":"aws_api/fms","title":"get_third_party_firewall_association_status","content":"pub fn get_third_party_firewall_association_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fms.get_third_party_firewall_association_status\naws_api/fms get_third_party_firewall_association_status","url":"aws_api/fms.html#get_third_party_firewall_association_status"},{"doc":"aws_api/fms","title":"get_violation_details","content":"pub fn get_violation_details(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fms.get_violation_details\naws_api/fms get_violation_details","url":"aws_api/fms.html#get_violation_details"},{"doc":"aws_api/fms","title":"list_admin_accounts_for_organization","content":"pub fn list_admin_accounts_for_organization(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fms.list_admin_accounts_for_organization\naws_api/fms list_admin_accounts_for_organization","url":"aws_api/fms.html#list_admin_accounts_for_organization"},{"doc":"aws_api/fms","title":"list_admins_managing_account","content":"pub fn list_admins_managing_account(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fms.list_admins_managing_account\naws_api/fms list_admins_managing_account","url":"aws_api/fms.html#list_admins_managing_account"},{"doc":"aws_api/fms","title":"list_apps_lists","content":"pub fn list_apps_lists(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fms.list_apps_lists\naws_api/fms list_apps_lists","url":"aws_api/fms.html#list_apps_lists"},{"doc":"aws_api/fms","title":"list_compliance_status","content":"pub fn list_compliance_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fms.list_compliance_status\naws_api/fms list_compliance_status","url":"aws_api/fms.html#list_compliance_status"},{"doc":"aws_api/fms","title":"list_discovered_resources","content":"pub fn list_discovered_resources(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fms.list_discovered_resources\naws_api/fms list_discovered_resources","url":"aws_api/fms.html#list_discovered_resources"},{"doc":"aws_api/fms","title":"list_member_accounts","content":"pub fn list_member_accounts(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fms.list_member_accounts\naws_api/fms list_member_accounts","url":"aws_api/fms.html#list_member_accounts"},{"doc":"aws_api/fms","title":"list_policies","content":"pub fn list_policies(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fms.list_policies\naws_api/fms list_policies","url":"aws_api/fms.html#list_policies"},{"doc":"aws_api/fms","title":"list_protocols_lists","content":"pub fn list_protocols_lists(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fms.list_protocols_lists\naws_api/fms list_protocols_lists","url":"aws_api/fms.html#list_protocols_lists"},{"doc":"aws_api/fms","title":"list_resource_set_resources","content":"pub fn list_resource_set_resources(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fms.list_resource_set_resources\naws_api/fms list_resource_set_resources","url":"aws_api/fms.html#list_resource_set_resources"},{"doc":"aws_api/fms","title":"list_resource_sets","content":"pub fn list_resource_sets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fms.list_resource_sets\naws_api/fms list_resource_sets","url":"aws_api/fms.html#list_resource_sets"},{"doc":"aws_api/fms","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fms.list_tags_for_resource\naws_api/fms list_tags_for_resource","url":"aws_api/fms.html#list_tags_for_resource"},{"doc":"aws_api/fms","title":"list_third_party_firewall_firewall_policies","content":"pub fn list_third_party_firewall_firewall_policies(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fms.list_third_party_firewall_firewall_policies\naws_api/fms list_third_party_firewall_firewall_policies","url":"aws_api/fms.html#list_third_party_firewall_firewall_policies"},{"doc":"aws_api/fms","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/fms.new\naws_api/fms new","url":"aws_api/fms.html#new"},{"doc":"aws_api/fms","title":"put_admin_account","content":"pub fn put_admin_account(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fms.put_admin_account\naws_api/fms put_admin_account","url":"aws_api/fms.html#put_admin_account"},{"doc":"aws_api/fms","title":"put_apps_list","content":"pub fn put_apps_list(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fms.put_apps_list\naws_api/fms put_apps_list","url":"aws_api/fms.html#put_apps_list"},{"doc":"aws_api/fms","title":"put_notification_channel","content":"pub fn put_notification_channel(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fms.put_notification_channel\naws_api/fms put_notification_channel","url":"aws_api/fms.html#put_notification_channel"},{"doc":"aws_api/fms","title":"put_policy","content":"pub fn put_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fms.put_policy\naws_api/fms put_policy","url":"aws_api/fms.html#put_policy"},{"doc":"aws_api/fms","title":"put_protocols_list","content":"pub fn put_protocols_list(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fms.put_protocols_list\naws_api/fms put_protocols_list","url":"aws_api/fms.html#put_protocols_list"},{"doc":"aws_api/fms","title":"put_resource_set","content":"pub fn put_resource_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fms.put_resource_set\naws_api/fms put_resource_set","url":"aws_api/fms.html#put_resource_set"},{"doc":"aws_api/fms","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fms.tag_resource\naws_api/fms tag_resource","url":"aws_api/fms.html#tag_resource"},{"doc":"aws_api/fms","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fms.untag_resource\naws_api/fms untag_resource","url":"aws_api/fms.html#untag_resource"},{"doc":"aws_api/fms","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/fms.with_custom_endpoint\naws_api/fms with_custom_endpoint","url":"aws_api/fms.html#with_custom_endpoint"},{"doc":"aws_api/fms","title":"aws_api/fms","content":"","url":"aws_api/fms.html"},{"doc":"aws_api/forecast","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/forecast.Client\naws_api/forecast Client","url":"aws_api/forecast.html#Client"},{"doc":"aws_api/forecast","title":"create_auto_predictor","content":"pub fn create_auto_predictor(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.create_auto_predictor\naws_api/forecast create_auto_predictor","url":"aws_api/forecast.html#create_auto_predictor"},{"doc":"aws_api/forecast","title":"create_dataset","content":"pub fn create_dataset(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.create_dataset\naws_api/forecast create_dataset","url":"aws_api/forecast.html#create_dataset"},{"doc":"aws_api/forecast","title":"create_dataset_group","content":"pub fn create_dataset_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.create_dataset_group\naws_api/forecast create_dataset_group","url":"aws_api/forecast.html#create_dataset_group"},{"doc":"aws_api/forecast","title":"create_dataset_import_job","content":"pub fn create_dataset_import_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.create_dataset_import_job\naws_api/forecast create_dataset_import_job","url":"aws_api/forecast.html#create_dataset_import_job"},{"doc":"aws_api/forecast","title":"create_explainability","content":"pub fn create_explainability(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.create_explainability\naws_api/forecast create_explainability","url":"aws_api/forecast.html#create_explainability"},{"doc":"aws_api/forecast","title":"create_explainability_export","content":"pub fn create_explainability_export(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.create_explainability_export\naws_api/forecast create_explainability_export","url":"aws_api/forecast.html#create_explainability_export"},{"doc":"aws_api/forecast","title":"create_forecast","content":"pub fn create_forecast(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.create_forecast\naws_api/forecast create_forecast","url":"aws_api/forecast.html#create_forecast"},{"doc":"aws_api/forecast","title":"create_forecast_export_job","content":"pub fn create_forecast_export_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.create_forecast_export_job\naws_api/forecast create_forecast_export_job","url":"aws_api/forecast.html#create_forecast_export_job"},{"doc":"aws_api/forecast","title":"create_monitor","content":"pub fn create_monitor(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.create_monitor\naws_api/forecast create_monitor","url":"aws_api/forecast.html#create_monitor"},{"doc":"aws_api/forecast","title":"create_predictor","content":"pub fn create_predictor(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.create_predictor\naws_api/forecast create_predictor","url":"aws_api/forecast.html#create_predictor"},{"doc":"aws_api/forecast","title":"create_predictor_backtest_export_job","content":"pub fn create_predictor_backtest_export_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.create_predictor_backtest_export_job\naws_api/forecast create_predictor_backtest_export_job","url":"aws_api/forecast.html#create_predictor_backtest_export_job"},{"doc":"aws_api/forecast","title":"create_what_if_analysis","content":"pub fn create_what_if_analysis(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.create_what_if_analysis\naws_api/forecast create_what_if_analysis","url":"aws_api/forecast.html#create_what_if_analysis"},{"doc":"aws_api/forecast","title":"create_what_if_forecast","content":"pub fn create_what_if_forecast(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.create_what_if_forecast\naws_api/forecast create_what_if_forecast","url":"aws_api/forecast.html#create_what_if_forecast"},{"doc":"aws_api/forecast","title":"create_what_if_forecast_export","content":"pub fn create_what_if_forecast_export(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.create_what_if_forecast_export\naws_api/forecast create_what_if_forecast_export","url":"aws_api/forecast.html#create_what_if_forecast_export"},{"doc":"aws_api/forecast","title":"delete_dataset","content":"pub fn delete_dataset(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.delete_dataset\naws_api/forecast delete_dataset","url":"aws_api/forecast.html#delete_dataset"},{"doc":"aws_api/forecast","title":"delete_dataset_group","content":"pub fn delete_dataset_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.delete_dataset_group\naws_api/forecast delete_dataset_group","url":"aws_api/forecast.html#delete_dataset_group"},{"doc":"aws_api/forecast","title":"delete_dataset_import_job","content":"pub fn delete_dataset_import_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.delete_dataset_import_job\naws_api/forecast delete_dataset_import_job","url":"aws_api/forecast.html#delete_dataset_import_job"},{"doc":"aws_api/forecast","title":"delete_explainability","content":"pub fn delete_explainability(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.delete_explainability\naws_api/forecast delete_explainability","url":"aws_api/forecast.html#delete_explainability"},{"doc":"aws_api/forecast","title":"delete_explainability_export","content":"pub fn delete_explainability_export(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.delete_explainability_export\naws_api/forecast delete_explainability_export","url":"aws_api/forecast.html#delete_explainability_export"},{"doc":"aws_api/forecast","title":"delete_forecast","content":"pub fn delete_forecast(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.delete_forecast\naws_api/forecast delete_forecast","url":"aws_api/forecast.html#delete_forecast"},{"doc":"aws_api/forecast","title":"delete_forecast_export_job","content":"pub fn delete_forecast_export_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.delete_forecast_export_job\naws_api/forecast delete_forecast_export_job","url":"aws_api/forecast.html#delete_forecast_export_job"},{"doc":"aws_api/forecast","title":"delete_monitor","content":"pub fn delete_monitor(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.delete_monitor\naws_api/forecast delete_monitor","url":"aws_api/forecast.html#delete_monitor"},{"doc":"aws_api/forecast","title":"delete_predictor","content":"pub fn delete_predictor(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.delete_predictor\naws_api/forecast delete_predictor","url":"aws_api/forecast.html#delete_predictor"},{"doc":"aws_api/forecast","title":"delete_predictor_backtest_export_job","content":"pub fn delete_predictor_backtest_export_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.delete_predictor_backtest_export_job\naws_api/forecast delete_predictor_backtest_export_job","url":"aws_api/forecast.html#delete_predictor_backtest_export_job"},{"doc":"aws_api/forecast","title":"delete_resource_tree","content":"pub fn delete_resource_tree(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.delete_resource_tree\naws_api/forecast delete_resource_tree","url":"aws_api/forecast.html#delete_resource_tree"},{"doc":"aws_api/forecast","title":"delete_what_if_analysis","content":"pub fn delete_what_if_analysis(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.delete_what_if_analysis\naws_api/forecast delete_what_if_analysis","url":"aws_api/forecast.html#delete_what_if_analysis"},{"doc":"aws_api/forecast","title":"delete_what_if_forecast","content":"pub fn delete_what_if_forecast(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.delete_what_if_forecast\naws_api/forecast delete_what_if_forecast","url":"aws_api/forecast.html#delete_what_if_forecast"},{"doc":"aws_api/forecast","title":"delete_what_if_forecast_export","content":"pub fn delete_what_if_forecast_export(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.delete_what_if_forecast_export\naws_api/forecast delete_what_if_forecast_export","url":"aws_api/forecast.html#delete_what_if_forecast_export"},{"doc":"aws_api/forecast","title":"describe_auto_predictor","content":"pub fn describe_auto_predictor(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.describe_auto_predictor\naws_api/forecast describe_auto_predictor","url":"aws_api/forecast.html#describe_auto_predictor"},{"doc":"aws_api/forecast","title":"describe_dataset","content":"pub fn describe_dataset(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.describe_dataset\naws_api/forecast describe_dataset","url":"aws_api/forecast.html#describe_dataset"},{"doc":"aws_api/forecast","title":"describe_dataset_group","content":"pub fn describe_dataset_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.describe_dataset_group\naws_api/forecast describe_dataset_group","url":"aws_api/forecast.html#describe_dataset_group"},{"doc":"aws_api/forecast","title":"describe_dataset_import_job","content":"pub fn describe_dataset_import_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.describe_dataset_import_job\naws_api/forecast describe_dataset_import_job","url":"aws_api/forecast.html#describe_dataset_import_job"},{"doc":"aws_api/forecast","title":"describe_explainability","content":"pub fn describe_explainability(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.describe_explainability\naws_api/forecast describe_explainability","url":"aws_api/forecast.html#describe_explainability"},{"doc":"aws_api/forecast","title":"describe_explainability_export","content":"pub fn describe_explainability_export(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.describe_explainability_export\naws_api/forecast describe_explainability_export","url":"aws_api/forecast.html#describe_explainability_export"},{"doc":"aws_api/forecast","title":"describe_forecast","content":"pub fn describe_forecast(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.describe_forecast\naws_api/forecast describe_forecast","url":"aws_api/forecast.html#describe_forecast"},{"doc":"aws_api/forecast","title":"describe_forecast_export_job","content":"pub fn describe_forecast_export_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.describe_forecast_export_job\naws_api/forecast describe_forecast_export_job","url":"aws_api/forecast.html#describe_forecast_export_job"},{"doc":"aws_api/forecast","title":"describe_monitor","content":"pub fn describe_monitor(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.describe_monitor\naws_api/forecast describe_monitor","url":"aws_api/forecast.html#describe_monitor"},{"doc":"aws_api/forecast","title":"describe_predictor","content":"pub fn describe_predictor(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.describe_predictor\naws_api/forecast describe_predictor","url":"aws_api/forecast.html#describe_predictor"},{"doc":"aws_api/forecast","title":"describe_predictor_backtest_export_job","content":"pub fn describe_predictor_backtest_export_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.describe_predictor_backtest_export_job\naws_api/forecast describe_predictor_backtest_export_job","url":"aws_api/forecast.html#describe_predictor_backtest_export_job"},{"doc":"aws_api/forecast","title":"describe_what_if_analysis","content":"pub fn describe_what_if_analysis(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.describe_what_if_analysis\naws_api/forecast describe_what_if_analysis","url":"aws_api/forecast.html#describe_what_if_analysis"},{"doc":"aws_api/forecast","title":"describe_what_if_forecast","content":"pub fn describe_what_if_forecast(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.describe_what_if_forecast\naws_api/forecast describe_what_if_forecast","url":"aws_api/forecast.html#describe_what_if_forecast"},{"doc":"aws_api/forecast","title":"describe_what_if_forecast_export","content":"pub fn describe_what_if_forecast_export(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.describe_what_if_forecast_export\naws_api/forecast describe_what_if_forecast_export","url":"aws_api/forecast.html#describe_what_if_forecast_export"},{"doc":"aws_api/forecast","title":"get_accuracy_metrics","content":"pub fn get_accuracy_metrics(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.get_accuracy_metrics\naws_api/forecast get_accuracy_metrics","url":"aws_api/forecast.html#get_accuracy_metrics"},{"doc":"aws_api/forecast","title":"list_dataset_groups","content":"pub fn list_dataset_groups(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.list_dataset_groups\naws_api/forecast list_dataset_groups","url":"aws_api/forecast.html#list_dataset_groups"},{"doc":"aws_api/forecast","title":"list_dataset_import_jobs","content":"pub fn list_dataset_import_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.list_dataset_import_jobs\naws_api/forecast list_dataset_import_jobs","url":"aws_api/forecast.html#list_dataset_import_jobs"},{"doc":"aws_api/forecast","title":"list_datasets","content":"pub fn list_datasets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.list_datasets\naws_api/forecast list_datasets","url":"aws_api/forecast.html#list_datasets"},{"doc":"aws_api/forecast","title":"list_explainabilities","content":"pub fn list_explainabilities(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.list_explainabilities\naws_api/forecast list_explainabilities","url":"aws_api/forecast.html#list_explainabilities"},{"doc":"aws_api/forecast","title":"list_explainability_exports","content":"pub fn list_explainability_exports(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.list_explainability_exports\naws_api/forecast list_explainability_exports","url":"aws_api/forecast.html#list_explainability_exports"},{"doc":"aws_api/forecast","title":"list_forecast_export_jobs","content":"pub fn list_forecast_export_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.list_forecast_export_jobs\naws_api/forecast list_forecast_export_jobs","url":"aws_api/forecast.html#list_forecast_export_jobs"},{"doc":"aws_api/forecast","title":"list_forecasts","content":"pub fn list_forecasts(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.list_forecasts\naws_api/forecast list_forecasts","url":"aws_api/forecast.html#list_forecasts"},{"doc":"aws_api/forecast","title":"list_monitor_evaluations","content":"pub fn list_monitor_evaluations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.list_monitor_evaluations\naws_api/forecast list_monitor_evaluations","url":"aws_api/forecast.html#list_monitor_evaluations"},{"doc":"aws_api/forecast","title":"list_monitors","content":"pub fn list_monitors(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.list_monitors\naws_api/forecast list_monitors","url":"aws_api/forecast.html#list_monitors"},{"doc":"aws_api/forecast","title":"list_predictor_backtest_export_jobs","content":"pub fn list_predictor_backtest_export_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.list_predictor_backtest_export_jobs\naws_api/forecast list_predictor_backtest_export_jobs","url":"aws_api/forecast.html#list_predictor_backtest_export_jobs"},{"doc":"aws_api/forecast","title":"list_predictors","content":"pub fn list_predictors(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.list_predictors\naws_api/forecast list_predictors","url":"aws_api/forecast.html#list_predictors"},{"doc":"aws_api/forecast","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.list_tags_for_resource\naws_api/forecast list_tags_for_resource","url":"aws_api/forecast.html#list_tags_for_resource"},{"doc":"aws_api/forecast","title":"list_what_if_analyses","content":"pub fn list_what_if_analyses(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.list_what_if_analyses\naws_api/forecast list_what_if_analyses","url":"aws_api/forecast.html#list_what_if_analyses"},{"doc":"aws_api/forecast","title":"list_what_if_forecast_exports","content":"pub fn list_what_if_forecast_exports(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.list_what_if_forecast_exports\naws_api/forecast list_what_if_forecast_exports","url":"aws_api/forecast.html#list_what_if_forecast_exports"},{"doc":"aws_api/forecast","title":"list_what_if_forecasts","content":"pub fn list_what_if_forecasts(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.list_what_if_forecasts\naws_api/forecast list_what_if_forecasts","url":"aws_api/forecast.html#list_what_if_forecasts"},{"doc":"aws_api/forecast","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/forecast.new\naws_api/forecast new","url":"aws_api/forecast.html#new"},{"doc":"aws_api/forecast","title":"resume_resource","content":"pub fn resume_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.resume_resource\naws_api/forecast resume_resource","url":"aws_api/forecast.html#resume_resource"},{"doc":"aws_api/forecast","title":"stop_resource","content":"pub fn stop_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.stop_resource\naws_api/forecast stop_resource","url":"aws_api/forecast.html#stop_resource"},{"doc":"aws_api/forecast","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.tag_resource\naws_api/forecast tag_resource","url":"aws_api/forecast.html#tag_resource"},{"doc":"aws_api/forecast","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.untag_resource\naws_api/forecast untag_resource","url":"aws_api/forecast.html#untag_resource"},{"doc":"aws_api/forecast","title":"update_dataset_group","content":"pub fn update_dataset_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecast.update_dataset_group\naws_api/forecast update_dataset_group","url":"aws_api/forecast.html#update_dataset_group"},{"doc":"aws_api/forecast","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/forecast.with_custom_endpoint\naws_api/forecast with_custom_endpoint","url":"aws_api/forecast.html#with_custom_endpoint"},{"doc":"aws_api/forecast","title":"aws_api/forecast","content":"","url":"aws_api/forecast.html"},{"doc":"aws_api/forecastquery","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/forecastquery.Client\naws_api/forecastquery Client","url":"aws_api/forecastquery.html#Client"},{"doc":"aws_api/forecastquery","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/forecastquery.new\naws_api/forecastquery new","url":"aws_api/forecastquery.html#new"},{"doc":"aws_api/forecastquery","title":"query_forecast","content":"pub fn query_forecast(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecastquery.query_forecast\naws_api/forecastquery query_forecast","url":"aws_api/forecastquery.html#query_forecast"},{"doc":"aws_api/forecastquery","title":"query_what_if_forecast","content":"pub fn query_what_if_forecast(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/forecastquery.query_what_if_forecast\naws_api/forecastquery query_what_if_forecast","url":"aws_api/forecastquery.html#query_what_if_forecast"},{"doc":"aws_api/forecastquery","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/forecastquery.with_custom_endpoint\naws_api/forecastquery with_custom_endpoint","url":"aws_api/forecastquery.html#with_custom_endpoint"},{"doc":"aws_api/forecastquery","title":"aws_api/forecastquery","content":"","url":"aws_api/forecastquery.html"},{"doc":"aws_api/frauddetector","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/frauddetector.Client\naws_api/frauddetector Client","url":"aws_api/frauddetector.html#Client"},{"doc":"aws_api/frauddetector","title":"batch_create_variable","content":"pub fn batch_create_variable(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.batch_create_variable\naws_api/frauddetector batch_create_variable","url":"aws_api/frauddetector.html#batch_create_variable"},{"doc":"aws_api/frauddetector","title":"batch_get_variable","content":"pub fn batch_get_variable(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.batch_get_variable\naws_api/frauddetector batch_get_variable","url":"aws_api/frauddetector.html#batch_get_variable"},{"doc":"aws_api/frauddetector","title":"cancel_batch_import_job","content":"pub fn cancel_batch_import_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.cancel_batch_import_job\naws_api/frauddetector cancel_batch_import_job","url":"aws_api/frauddetector.html#cancel_batch_import_job"},{"doc":"aws_api/frauddetector","title":"cancel_batch_prediction_job","content":"pub fn cancel_batch_prediction_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.cancel_batch_prediction_job\naws_api/frauddetector cancel_batch_prediction_job","url":"aws_api/frauddetector.html#cancel_batch_prediction_job"},{"doc":"aws_api/frauddetector","title":"create_batch_import_job","content":"pub fn create_batch_import_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.create_batch_import_job\naws_api/frauddetector create_batch_import_job","url":"aws_api/frauddetector.html#create_batch_import_job"},{"doc":"aws_api/frauddetector","title":"create_batch_prediction_job","content":"pub fn create_batch_prediction_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.create_batch_prediction_job\naws_api/frauddetector create_batch_prediction_job","url":"aws_api/frauddetector.html#create_batch_prediction_job"},{"doc":"aws_api/frauddetector","title":"create_detector_version","content":"pub fn create_detector_version(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.create_detector_version\naws_api/frauddetector create_detector_version","url":"aws_api/frauddetector.html#create_detector_version"},{"doc":"aws_api/frauddetector","title":"create_list","content":"pub fn create_list(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.create_list\naws_api/frauddetector create_list","url":"aws_api/frauddetector.html#create_list"},{"doc":"aws_api/frauddetector","title":"create_model","content":"pub fn create_model(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.create_model\naws_api/frauddetector create_model","url":"aws_api/frauddetector.html#create_model"},{"doc":"aws_api/frauddetector","title":"create_model_version","content":"pub fn create_model_version(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.create_model_version\naws_api/frauddetector create_model_version","url":"aws_api/frauddetector.html#create_model_version"},{"doc":"aws_api/frauddetector","title":"create_rule","content":"pub fn create_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.create_rule\naws_api/frauddetector create_rule","url":"aws_api/frauddetector.html#create_rule"},{"doc":"aws_api/frauddetector","title":"create_variable","content":"pub fn create_variable(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.create_variable\naws_api/frauddetector create_variable","url":"aws_api/frauddetector.html#create_variable"},{"doc":"aws_api/frauddetector","title":"delete_batch_import_job","content":"pub fn delete_batch_import_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.delete_batch_import_job\naws_api/frauddetector delete_batch_import_job","url":"aws_api/frauddetector.html#delete_batch_import_job"},{"doc":"aws_api/frauddetector","title":"delete_batch_prediction_job","content":"pub fn delete_batch_prediction_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.delete_batch_prediction_job\naws_api/frauddetector delete_batch_prediction_job","url":"aws_api/frauddetector.html#delete_batch_prediction_job"},{"doc":"aws_api/frauddetector","title":"delete_detector","content":"pub fn delete_detector(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.delete_detector\naws_api/frauddetector delete_detector","url":"aws_api/frauddetector.html#delete_detector"},{"doc":"aws_api/frauddetector","title":"delete_detector_version","content":"pub fn delete_detector_version(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.delete_detector_version\naws_api/frauddetector delete_detector_version","url":"aws_api/frauddetector.html#delete_detector_version"},{"doc":"aws_api/frauddetector","title":"delete_entity_type","content":"pub fn delete_entity_type(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.delete_entity_type\naws_api/frauddetector delete_entity_type","url":"aws_api/frauddetector.html#delete_entity_type"},{"doc":"aws_api/frauddetector","title":"delete_event","content":"pub fn delete_event(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.delete_event\naws_api/frauddetector delete_event","url":"aws_api/frauddetector.html#delete_event"},{"doc":"aws_api/frauddetector","title":"delete_event_type","content":"pub fn delete_event_type(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.delete_event_type\naws_api/frauddetector delete_event_type","url":"aws_api/frauddetector.html#delete_event_type"},{"doc":"aws_api/frauddetector","title":"delete_events_by_event_type","content":"pub fn delete_events_by_event_type(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.delete_events_by_event_type\naws_api/frauddetector delete_events_by_event_type","url":"aws_api/frauddetector.html#delete_events_by_event_type"},{"doc":"aws_api/frauddetector","title":"delete_external_model","content":"pub fn delete_external_model(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.delete_external_model\naws_api/frauddetector delete_external_model","url":"aws_api/frauddetector.html#delete_external_model"},{"doc":"aws_api/frauddetector","title":"delete_label","content":"pub fn delete_label(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.delete_label\naws_api/frauddetector delete_label","url":"aws_api/frauddetector.html#delete_label"},{"doc":"aws_api/frauddetector","title":"delete_list","content":"pub fn delete_list(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.delete_list\naws_api/frauddetector delete_list","url":"aws_api/frauddetector.html#delete_list"},{"doc":"aws_api/frauddetector","title":"delete_model","content":"pub fn delete_model(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.delete_model\naws_api/frauddetector delete_model","url":"aws_api/frauddetector.html#delete_model"},{"doc":"aws_api/frauddetector","title":"delete_model_version","content":"pub fn delete_model_version(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.delete_model_version\naws_api/frauddetector delete_model_version","url":"aws_api/frauddetector.html#delete_model_version"},{"doc":"aws_api/frauddetector","title":"delete_outcome","content":"pub fn delete_outcome(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.delete_outcome\naws_api/frauddetector delete_outcome","url":"aws_api/frauddetector.html#delete_outcome"},{"doc":"aws_api/frauddetector","title":"delete_rule","content":"pub fn delete_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.delete_rule\naws_api/frauddetector delete_rule","url":"aws_api/frauddetector.html#delete_rule"},{"doc":"aws_api/frauddetector","title":"delete_variable","content":"pub fn delete_variable(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.delete_variable\naws_api/frauddetector delete_variable","url":"aws_api/frauddetector.html#delete_variable"},{"doc":"aws_api/frauddetector","title":"describe_detector","content":"pub fn describe_detector(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.describe_detector\naws_api/frauddetector describe_detector","url":"aws_api/frauddetector.html#describe_detector"},{"doc":"aws_api/frauddetector","title":"describe_model_versions","content":"pub fn describe_model_versions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.describe_model_versions\naws_api/frauddetector describe_model_versions","url":"aws_api/frauddetector.html#describe_model_versions"},{"doc":"aws_api/frauddetector","title":"get_batch_import_jobs","content":"pub fn get_batch_import_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.get_batch_import_jobs\naws_api/frauddetector get_batch_import_jobs","url":"aws_api/frauddetector.html#get_batch_import_jobs"},{"doc":"aws_api/frauddetector","title":"get_batch_prediction_jobs","content":"pub fn get_batch_prediction_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.get_batch_prediction_jobs\naws_api/frauddetector get_batch_prediction_jobs","url":"aws_api/frauddetector.html#get_batch_prediction_jobs"},{"doc":"aws_api/frauddetector","title":"get_delete_events_by_event_type_status","content":"pub fn get_delete_events_by_event_type_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.get_delete_events_by_event_type_status\naws_api/frauddetector get_delete_events_by_event_type_status","url":"aws_api/frauddetector.html#get_delete_events_by_event_type_status"},{"doc":"aws_api/frauddetector","title":"get_detector_version","content":"pub fn get_detector_version(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.get_detector_version\naws_api/frauddetector get_detector_version","url":"aws_api/frauddetector.html#get_detector_version"},{"doc":"aws_api/frauddetector","title":"get_detectors","content":"pub fn get_detectors(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.get_detectors\naws_api/frauddetector get_detectors","url":"aws_api/frauddetector.html#get_detectors"},{"doc":"aws_api/frauddetector","title":"get_entity_types","content":"pub fn get_entity_types(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.get_entity_types\naws_api/frauddetector get_entity_types","url":"aws_api/frauddetector.html#get_entity_types"},{"doc":"aws_api/frauddetector","title":"get_event","content":"pub fn get_event(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.get_event\naws_api/frauddetector get_event","url":"aws_api/frauddetector.html#get_event"},{"doc":"aws_api/frauddetector","title":"get_event_prediction","content":"pub fn get_event_prediction(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.get_event_prediction\naws_api/frauddetector get_event_prediction","url":"aws_api/frauddetector.html#get_event_prediction"},{"doc":"aws_api/frauddetector","title":"get_event_prediction_metadata","content":"pub fn get_event_prediction_metadata(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.get_event_prediction_metadata\naws_api/frauddetector get_event_prediction_metadata","url":"aws_api/frauddetector.html#get_event_prediction_metadata"},{"doc":"aws_api/frauddetector","title":"get_event_types","content":"pub fn get_event_types(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.get_event_types\naws_api/frauddetector get_event_types","url":"aws_api/frauddetector.html#get_event_types"},{"doc":"aws_api/frauddetector","title":"get_external_models","content":"pub fn get_external_models(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.get_external_models\naws_api/frauddetector get_external_models","url":"aws_api/frauddetector.html#get_external_models"},{"doc":"aws_api/frauddetector","title":"get_kms_encryption_key","content":"pub fn get_kms_encryption_key(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.get_kms_encryption_key\naws_api/frauddetector get_kms_encryption_key","url":"aws_api/frauddetector.html#get_kms_encryption_key"},{"doc":"aws_api/frauddetector","title":"get_labels","content":"pub fn get_labels(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.get_labels\naws_api/frauddetector get_labels","url":"aws_api/frauddetector.html#get_labels"},{"doc":"aws_api/frauddetector","title":"get_list_elements","content":"pub fn get_list_elements(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.get_list_elements\naws_api/frauddetector get_list_elements","url":"aws_api/frauddetector.html#get_list_elements"},{"doc":"aws_api/frauddetector","title":"get_lists_metadata","content":"pub fn get_lists_metadata(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.get_lists_metadata\naws_api/frauddetector get_lists_metadata","url":"aws_api/frauddetector.html#get_lists_metadata"},{"doc":"aws_api/frauddetector","title":"get_model_version","content":"pub fn get_model_version(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.get_model_version\naws_api/frauddetector get_model_version","url":"aws_api/frauddetector.html#get_model_version"},{"doc":"aws_api/frauddetector","title":"get_models","content":"pub fn get_models(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.get_models\naws_api/frauddetector get_models","url":"aws_api/frauddetector.html#get_models"},{"doc":"aws_api/frauddetector","title":"get_outcomes","content":"pub fn get_outcomes(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.get_outcomes\naws_api/frauddetector get_outcomes","url":"aws_api/frauddetector.html#get_outcomes"},{"doc":"aws_api/frauddetector","title":"get_rules","content":"pub fn get_rules(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.get_rules\naws_api/frauddetector get_rules","url":"aws_api/frauddetector.html#get_rules"},{"doc":"aws_api/frauddetector","title":"get_variables","content":"pub fn get_variables(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.get_variables\naws_api/frauddetector get_variables","url":"aws_api/frauddetector.html#get_variables"},{"doc":"aws_api/frauddetector","title":"list_event_predictions","content":"pub fn list_event_predictions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.list_event_predictions\naws_api/frauddetector list_event_predictions","url":"aws_api/frauddetector.html#list_event_predictions"},{"doc":"aws_api/frauddetector","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.list_tags_for_resource\naws_api/frauddetector list_tags_for_resource","url":"aws_api/frauddetector.html#list_tags_for_resource"},{"doc":"aws_api/frauddetector","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/frauddetector.new\naws_api/frauddetector new","url":"aws_api/frauddetector.html#new"},{"doc":"aws_api/frauddetector","title":"put_detector","content":"pub fn put_detector(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.put_detector\naws_api/frauddetector put_detector","url":"aws_api/frauddetector.html#put_detector"},{"doc":"aws_api/frauddetector","title":"put_entity_type","content":"pub fn put_entity_type(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.put_entity_type\naws_api/frauddetector put_entity_type","url":"aws_api/frauddetector.html#put_entity_type"},{"doc":"aws_api/frauddetector","title":"put_event_type","content":"pub fn put_event_type(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.put_event_type\naws_api/frauddetector put_event_type","url":"aws_api/frauddetector.html#put_event_type"},{"doc":"aws_api/frauddetector","title":"put_external_model","content":"pub fn put_external_model(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.put_external_model\naws_api/frauddetector put_external_model","url":"aws_api/frauddetector.html#put_external_model"},{"doc":"aws_api/frauddetector","title":"put_kms_encryption_key","content":"pub fn put_kms_encryption_key(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.put_kms_encryption_key\naws_api/frauddetector put_kms_encryption_key","url":"aws_api/frauddetector.html#put_kms_encryption_key"},{"doc":"aws_api/frauddetector","title":"put_label","content":"pub fn put_label(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.put_label\naws_api/frauddetector put_label","url":"aws_api/frauddetector.html#put_label"},{"doc":"aws_api/frauddetector","title":"put_outcome","content":"pub fn put_outcome(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.put_outcome\naws_api/frauddetector put_outcome","url":"aws_api/frauddetector.html#put_outcome"},{"doc":"aws_api/frauddetector","title":"send_event","content":"pub fn send_event(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.send_event\naws_api/frauddetector send_event","url":"aws_api/frauddetector.html#send_event"},{"doc":"aws_api/frauddetector","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.tag_resource\naws_api/frauddetector tag_resource","url":"aws_api/frauddetector.html#tag_resource"},{"doc":"aws_api/frauddetector","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.untag_resource\naws_api/frauddetector untag_resource","url":"aws_api/frauddetector.html#untag_resource"},{"doc":"aws_api/frauddetector","title":"update_detector_version","content":"pub fn update_detector_version(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.update_detector_version\naws_api/frauddetector update_detector_version","url":"aws_api/frauddetector.html#update_detector_version"},{"doc":"aws_api/frauddetector","title":"update_detector_version_metadata","content":"pub fn update_detector_version_metadata(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.update_detector_version_metadata\naws_api/frauddetector update_detector_version_metadata","url":"aws_api/frauddetector.html#update_detector_version_metadata"},{"doc":"aws_api/frauddetector","title":"update_detector_version_status","content":"pub fn update_detector_version_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.update_detector_version_status\naws_api/frauddetector update_detector_version_status","url":"aws_api/frauddetector.html#update_detector_version_status"},{"doc":"aws_api/frauddetector","title":"update_event_label","content":"pub fn update_event_label(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.update_event_label\naws_api/frauddetector update_event_label","url":"aws_api/frauddetector.html#update_event_label"},{"doc":"aws_api/frauddetector","title":"update_list","content":"pub fn update_list(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.update_list\naws_api/frauddetector update_list","url":"aws_api/frauddetector.html#update_list"},{"doc":"aws_api/frauddetector","title":"update_model","content":"pub fn update_model(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.update_model\naws_api/frauddetector update_model","url":"aws_api/frauddetector.html#update_model"},{"doc":"aws_api/frauddetector","title":"update_model_version","content":"pub fn update_model_version(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.update_model_version\naws_api/frauddetector update_model_version","url":"aws_api/frauddetector.html#update_model_version"},{"doc":"aws_api/frauddetector","title":"update_model_version_status","content":"pub fn update_model_version_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.update_model_version_status\naws_api/frauddetector update_model_version_status","url":"aws_api/frauddetector.html#update_model_version_status"},{"doc":"aws_api/frauddetector","title":"update_rule_metadata","content":"pub fn update_rule_metadata(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.update_rule_metadata\naws_api/frauddetector update_rule_metadata","url":"aws_api/frauddetector.html#update_rule_metadata"},{"doc":"aws_api/frauddetector","title":"update_rule_version","content":"pub fn update_rule_version(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.update_rule_version\naws_api/frauddetector update_rule_version","url":"aws_api/frauddetector.html#update_rule_version"},{"doc":"aws_api/frauddetector","title":"update_variable","content":"pub fn update_variable(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/frauddetector.update_variable\naws_api/frauddetector update_variable","url":"aws_api/frauddetector.html#update_variable"},{"doc":"aws_api/frauddetector","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/frauddetector.with_custom_endpoint\naws_api/frauddetector with_custom_endpoint","url":"aws_api/frauddetector.html#with_custom_endpoint"},{"doc":"aws_api/frauddetector","title":"aws_api/frauddetector","content":"","url":"aws_api/frauddetector.html"},{"doc":"aws_api/fsx","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/fsx.Client\naws_api/fsx Client","url":"aws_api/fsx.html#Client"},{"doc":"aws_api/fsx","title":"associate_file_system_aliases","content":"pub fn associate_file_system_aliases(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fsx.associate_file_system_aliases\naws_api/fsx associate_file_system_aliases","url":"aws_api/fsx.html#associate_file_system_aliases"},{"doc":"aws_api/fsx","title":"cancel_data_repository_task","content":"pub fn cancel_data_repository_task(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fsx.cancel_data_repository_task\naws_api/fsx cancel_data_repository_task","url":"aws_api/fsx.html#cancel_data_repository_task"},{"doc":"aws_api/fsx","title":"copy_backup","content":"pub fn copy_backup(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fsx.copy_backup\naws_api/fsx copy_backup","url":"aws_api/fsx.html#copy_backup"},{"doc":"aws_api/fsx","title":"copy_snapshot_and_update_volume","content":"pub fn copy_snapshot_and_update_volume(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fsx.copy_snapshot_and_update_volume\naws_api/fsx copy_snapshot_and_update_volume","url":"aws_api/fsx.html#copy_snapshot_and_update_volume"},{"doc":"aws_api/fsx","title":"create_backup","content":"pub fn create_backup(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fsx.create_backup\naws_api/fsx create_backup","url":"aws_api/fsx.html#create_backup"},{"doc":"aws_api/fsx","title":"create_data_repository_association","content":"pub fn create_data_repository_association(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fsx.create_data_repository_association\naws_api/fsx create_data_repository_association","url":"aws_api/fsx.html#create_data_repository_association"},{"doc":"aws_api/fsx","title":"create_data_repository_task","content":"pub fn create_data_repository_task(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fsx.create_data_repository_task\naws_api/fsx create_data_repository_task","url":"aws_api/fsx.html#create_data_repository_task"},{"doc":"aws_api/fsx","title":"create_file_cache","content":"pub fn create_file_cache(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fsx.create_file_cache\naws_api/fsx create_file_cache","url":"aws_api/fsx.html#create_file_cache"},{"doc":"aws_api/fsx","title":"create_file_system","content":"pub fn create_file_system(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fsx.create_file_system\naws_api/fsx create_file_system","url":"aws_api/fsx.html#create_file_system"},{"doc":"aws_api/fsx","title":"create_file_system_from_backup","content":"pub fn create_file_system_from_backup(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fsx.create_file_system_from_backup\naws_api/fsx create_file_system_from_backup","url":"aws_api/fsx.html#create_file_system_from_backup"},{"doc":"aws_api/fsx","title":"create_snapshot","content":"pub fn create_snapshot(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fsx.create_snapshot\naws_api/fsx create_snapshot","url":"aws_api/fsx.html#create_snapshot"},{"doc":"aws_api/fsx","title":"create_storage_virtual_machine","content":"pub fn create_storage_virtual_machine(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fsx.create_storage_virtual_machine\naws_api/fsx create_storage_virtual_machine","url":"aws_api/fsx.html#create_storage_virtual_machine"},{"doc":"aws_api/fsx","title":"create_volume","content":"pub fn create_volume(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fsx.create_volume\naws_api/fsx create_volume","url":"aws_api/fsx.html#create_volume"},{"doc":"aws_api/fsx","title":"create_volume_from_backup","content":"pub fn create_volume_from_backup(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fsx.create_volume_from_backup\naws_api/fsx create_volume_from_backup","url":"aws_api/fsx.html#create_volume_from_backup"},{"doc":"aws_api/fsx","title":"delete_backup","content":"pub fn delete_backup(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fsx.delete_backup\naws_api/fsx delete_backup","url":"aws_api/fsx.html#delete_backup"},{"doc":"aws_api/fsx","title":"delete_data_repository_association","content":"pub fn delete_data_repository_association(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fsx.delete_data_repository_association\naws_api/fsx delete_data_repository_association","url":"aws_api/fsx.html#delete_data_repository_association"},{"doc":"aws_api/fsx","title":"delete_file_cache","content":"pub fn delete_file_cache(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fsx.delete_file_cache\naws_api/fsx delete_file_cache","url":"aws_api/fsx.html#delete_file_cache"},{"doc":"aws_api/fsx","title":"delete_file_system","content":"pub fn delete_file_system(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fsx.delete_file_system\naws_api/fsx delete_file_system","url":"aws_api/fsx.html#delete_file_system"},{"doc":"aws_api/fsx","title":"delete_snapshot","content":"pub fn delete_snapshot(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fsx.delete_snapshot\naws_api/fsx delete_snapshot","url":"aws_api/fsx.html#delete_snapshot"},{"doc":"aws_api/fsx","title":"delete_storage_virtual_machine","content":"pub fn delete_storage_virtual_machine(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fsx.delete_storage_virtual_machine\naws_api/fsx delete_storage_virtual_machine","url":"aws_api/fsx.html#delete_storage_virtual_machine"},{"doc":"aws_api/fsx","title":"delete_volume","content":"pub fn delete_volume(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fsx.delete_volume\naws_api/fsx delete_volume","url":"aws_api/fsx.html#delete_volume"},{"doc":"aws_api/fsx","title":"describe_backups","content":"pub fn describe_backups(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fsx.describe_backups\naws_api/fsx describe_backups","url":"aws_api/fsx.html#describe_backups"},{"doc":"aws_api/fsx","title":"describe_data_repository_associations","content":"pub fn describe_data_repository_associations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fsx.describe_data_repository_associations\naws_api/fsx describe_data_repository_associations","url":"aws_api/fsx.html#describe_data_repository_associations"},{"doc":"aws_api/fsx","title":"describe_data_repository_tasks","content":"pub fn describe_data_repository_tasks(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fsx.describe_data_repository_tasks\naws_api/fsx describe_data_repository_tasks","url":"aws_api/fsx.html#describe_data_repository_tasks"},{"doc":"aws_api/fsx","title":"describe_file_caches","content":"pub fn describe_file_caches(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fsx.describe_file_caches\naws_api/fsx describe_file_caches","url":"aws_api/fsx.html#describe_file_caches"},{"doc":"aws_api/fsx","title":"describe_file_system_aliases","content":"pub fn describe_file_system_aliases(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fsx.describe_file_system_aliases\naws_api/fsx describe_file_system_aliases","url":"aws_api/fsx.html#describe_file_system_aliases"},{"doc":"aws_api/fsx","title":"describe_file_systems","content":"pub fn describe_file_systems(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fsx.describe_file_systems\naws_api/fsx describe_file_systems","url":"aws_api/fsx.html#describe_file_systems"},{"doc":"aws_api/fsx","title":"describe_shared_vpc_configuration","content":"pub fn describe_shared_vpc_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fsx.describe_shared_vpc_configuration\naws_api/fsx describe_shared_vpc_configuration","url":"aws_api/fsx.html#describe_shared_vpc_configuration"},{"doc":"aws_api/fsx","title":"describe_snapshots","content":"pub fn describe_snapshots(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fsx.describe_snapshots\naws_api/fsx describe_snapshots","url":"aws_api/fsx.html#describe_snapshots"},{"doc":"aws_api/fsx","title":"describe_storage_virtual_machines","content":"pub fn describe_storage_virtual_machines(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fsx.describe_storage_virtual_machines\naws_api/fsx describe_storage_virtual_machines","url":"aws_api/fsx.html#describe_storage_virtual_machines"},{"doc":"aws_api/fsx","title":"describe_volumes","content":"pub fn describe_volumes(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fsx.describe_volumes\naws_api/fsx describe_volumes","url":"aws_api/fsx.html#describe_volumes"},{"doc":"aws_api/fsx","title":"disassociate_file_system_aliases","content":"pub fn disassociate_file_system_aliases(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fsx.disassociate_file_system_aliases\naws_api/fsx disassociate_file_system_aliases","url":"aws_api/fsx.html#disassociate_file_system_aliases"},{"doc":"aws_api/fsx","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fsx.list_tags_for_resource\naws_api/fsx list_tags_for_resource","url":"aws_api/fsx.html#list_tags_for_resource"},{"doc":"aws_api/fsx","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/fsx.new\naws_api/fsx new","url":"aws_api/fsx.html#new"},{"doc":"aws_api/fsx","title":"release_file_system_nfs_v3_locks","content":"pub fn release_file_system_nfs_v3_locks(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fsx.release_file_system_nfs_v3_locks\naws_api/fsx release_file_system_nfs_v3_locks","url":"aws_api/fsx.html#release_file_system_nfs_v3_locks"},{"doc":"aws_api/fsx","title":"restore_volume_from_snapshot","content":"pub fn restore_volume_from_snapshot(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fsx.restore_volume_from_snapshot\naws_api/fsx restore_volume_from_snapshot","url":"aws_api/fsx.html#restore_volume_from_snapshot"},{"doc":"aws_api/fsx","title":"start_misconfigured_state_recovery","content":"pub fn start_misconfigured_state_recovery(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fsx.start_misconfigured_state_recovery\naws_api/fsx start_misconfigured_state_recovery","url":"aws_api/fsx.html#start_misconfigured_state_recovery"},{"doc":"aws_api/fsx","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fsx.tag_resource\naws_api/fsx tag_resource","url":"aws_api/fsx.html#tag_resource"},{"doc":"aws_api/fsx","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fsx.untag_resource\naws_api/fsx untag_resource","url":"aws_api/fsx.html#untag_resource"},{"doc":"aws_api/fsx","title":"update_data_repository_association","content":"pub fn update_data_repository_association(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fsx.update_data_repository_association\naws_api/fsx update_data_repository_association","url":"aws_api/fsx.html#update_data_repository_association"},{"doc":"aws_api/fsx","title":"update_file_cache","content":"pub fn update_file_cache(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fsx.update_file_cache\naws_api/fsx update_file_cache","url":"aws_api/fsx.html#update_file_cache"},{"doc":"aws_api/fsx","title":"update_file_system","content":"pub fn update_file_system(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fsx.update_file_system\naws_api/fsx update_file_system","url":"aws_api/fsx.html#update_file_system"},{"doc":"aws_api/fsx","title":"update_shared_vpc_configuration","content":"pub fn update_shared_vpc_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fsx.update_shared_vpc_configuration\naws_api/fsx update_shared_vpc_configuration","url":"aws_api/fsx.html#update_shared_vpc_configuration"},{"doc":"aws_api/fsx","title":"update_snapshot","content":"pub fn update_snapshot(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fsx.update_snapshot\naws_api/fsx update_snapshot","url":"aws_api/fsx.html#update_snapshot"},{"doc":"aws_api/fsx","title":"update_storage_virtual_machine","content":"pub fn update_storage_virtual_machine(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fsx.update_storage_virtual_machine\naws_api/fsx update_storage_virtual_machine","url":"aws_api/fsx.html#update_storage_virtual_machine"},{"doc":"aws_api/fsx","title":"update_volume","content":"pub fn update_volume(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/fsx.update_volume\naws_api/fsx update_volume","url":"aws_api/fsx.html#update_volume"},{"doc":"aws_api/fsx","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/fsx.with_custom_endpoint\naws_api/fsx with_custom_endpoint","url":"aws_api/fsx.html#with_custom_endpoint"},{"doc":"aws_api/fsx","title":"aws_api/fsx","content":"","url":"aws_api/fsx.html"},{"doc":"aws_api/gamelift","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/gamelift.Client\naws_api/gamelift Client","url":"aws_api/gamelift.html#Client"},{"doc":"aws_api/gamelift","title":"accept_match","content":"pub fn accept_match(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.accept_match\naws_api/gamelift accept_match","url":"aws_api/gamelift.html#accept_match"},{"doc":"aws_api/gamelift","title":"claim_game_server","content":"pub fn claim_game_server(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.claim_game_server\naws_api/gamelift claim_game_server","url":"aws_api/gamelift.html#claim_game_server"},{"doc":"aws_api/gamelift","title":"create_alias","content":"pub fn create_alias(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.create_alias\naws_api/gamelift create_alias","url":"aws_api/gamelift.html#create_alias"},{"doc":"aws_api/gamelift","title":"create_build","content":"pub fn create_build(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.create_build\naws_api/gamelift create_build","url":"aws_api/gamelift.html#create_build"},{"doc":"aws_api/gamelift","title":"create_container_group_definition","content":"pub fn create_container_group_definition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.create_container_group_definition\naws_api/gamelift create_container_group_definition","url":"aws_api/gamelift.html#create_container_group_definition"},{"doc":"aws_api/gamelift","title":"create_fleet","content":"pub fn create_fleet(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.create_fleet\naws_api/gamelift create_fleet","url":"aws_api/gamelift.html#create_fleet"},{"doc":"aws_api/gamelift","title":"create_fleet_locations","content":"pub fn create_fleet_locations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.create_fleet_locations\naws_api/gamelift create_fleet_locations","url":"aws_api/gamelift.html#create_fleet_locations"},{"doc":"aws_api/gamelift","title":"create_game_server_group","content":"pub fn create_game_server_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.create_game_server_group\naws_api/gamelift create_game_server_group","url":"aws_api/gamelift.html#create_game_server_group"},{"doc":"aws_api/gamelift","title":"create_game_session","content":"pub fn create_game_session(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.create_game_session\naws_api/gamelift create_game_session","url":"aws_api/gamelift.html#create_game_session"},{"doc":"aws_api/gamelift","title":"create_game_session_queue","content":"pub fn create_game_session_queue(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.create_game_session_queue\naws_api/gamelift create_game_session_queue","url":"aws_api/gamelift.html#create_game_session_queue"},{"doc":"aws_api/gamelift","title":"create_location","content":"pub fn create_location(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.create_location\naws_api/gamelift create_location","url":"aws_api/gamelift.html#create_location"},{"doc":"aws_api/gamelift","title":"create_matchmaking_configuration","content":"pub fn create_matchmaking_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.create_matchmaking_configuration\naws_api/gamelift create_matchmaking_configuration","url":"aws_api/gamelift.html#create_matchmaking_configuration"},{"doc":"aws_api/gamelift","title":"create_matchmaking_rule_set","content":"pub fn create_matchmaking_rule_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.create_matchmaking_rule_set\naws_api/gamelift create_matchmaking_rule_set","url":"aws_api/gamelift.html#create_matchmaking_rule_set"},{"doc":"aws_api/gamelift","title":"create_player_session","content":"pub fn create_player_session(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.create_player_session\naws_api/gamelift create_player_session","url":"aws_api/gamelift.html#create_player_session"},{"doc":"aws_api/gamelift","title":"create_player_sessions","content":"pub fn create_player_sessions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.create_player_sessions\naws_api/gamelift create_player_sessions","url":"aws_api/gamelift.html#create_player_sessions"},{"doc":"aws_api/gamelift","title":"create_script","content":"pub fn create_script(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.create_script\naws_api/gamelift create_script","url":"aws_api/gamelift.html#create_script"},{"doc":"aws_api/gamelift","title":"create_vpc_peering_authorization","content":"pub fn create_vpc_peering_authorization(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.create_vpc_peering_authorization\naws_api/gamelift create_vpc_peering_authorization","url":"aws_api/gamelift.html#create_vpc_peering_authorization"},{"doc":"aws_api/gamelift","title":"create_vpc_peering_connection","content":"pub fn create_vpc_peering_connection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.create_vpc_peering_connection\naws_api/gamelift create_vpc_peering_connection","url":"aws_api/gamelift.html#create_vpc_peering_connection"},{"doc":"aws_api/gamelift","title":"delete_alias","content":"pub fn delete_alias(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.delete_alias\naws_api/gamelift delete_alias","url":"aws_api/gamelift.html#delete_alias"},{"doc":"aws_api/gamelift","title":"delete_build","content":"pub fn delete_build(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.delete_build\naws_api/gamelift delete_build","url":"aws_api/gamelift.html#delete_build"},{"doc":"aws_api/gamelift","title":"delete_container_group_definition","content":"pub fn delete_container_group_definition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.delete_container_group_definition\naws_api/gamelift delete_container_group_definition","url":"aws_api/gamelift.html#delete_container_group_definition"},{"doc":"aws_api/gamelift","title":"delete_fleet","content":"pub fn delete_fleet(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.delete_fleet\naws_api/gamelift delete_fleet","url":"aws_api/gamelift.html#delete_fleet"},{"doc":"aws_api/gamelift","title":"delete_fleet_locations","content":"pub fn delete_fleet_locations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.delete_fleet_locations\naws_api/gamelift delete_fleet_locations","url":"aws_api/gamelift.html#delete_fleet_locations"},{"doc":"aws_api/gamelift","title":"delete_game_server_group","content":"pub fn delete_game_server_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.delete_game_server_group\naws_api/gamelift delete_game_server_group","url":"aws_api/gamelift.html#delete_game_server_group"},{"doc":"aws_api/gamelift","title":"delete_game_session_queue","content":"pub fn delete_game_session_queue(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.delete_game_session_queue\naws_api/gamelift delete_game_session_queue","url":"aws_api/gamelift.html#delete_game_session_queue"},{"doc":"aws_api/gamelift","title":"delete_location","content":"pub fn delete_location(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.delete_location\naws_api/gamelift delete_location","url":"aws_api/gamelift.html#delete_location"},{"doc":"aws_api/gamelift","title":"delete_matchmaking_configuration","content":"pub fn delete_matchmaking_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.delete_matchmaking_configuration\naws_api/gamelift delete_matchmaking_configuration","url":"aws_api/gamelift.html#delete_matchmaking_configuration"},{"doc":"aws_api/gamelift","title":"delete_matchmaking_rule_set","content":"pub fn delete_matchmaking_rule_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.delete_matchmaking_rule_set\naws_api/gamelift delete_matchmaking_rule_set","url":"aws_api/gamelift.html#delete_matchmaking_rule_set"},{"doc":"aws_api/gamelift","title":"delete_scaling_policy","content":"pub fn delete_scaling_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.delete_scaling_policy\naws_api/gamelift delete_scaling_policy","url":"aws_api/gamelift.html#delete_scaling_policy"},{"doc":"aws_api/gamelift","title":"delete_script","content":"pub fn delete_script(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.delete_script\naws_api/gamelift delete_script","url":"aws_api/gamelift.html#delete_script"},{"doc":"aws_api/gamelift","title":"delete_vpc_peering_authorization","content":"pub fn delete_vpc_peering_authorization(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.delete_vpc_peering_authorization\naws_api/gamelift delete_vpc_peering_authorization","url":"aws_api/gamelift.html#delete_vpc_peering_authorization"},{"doc":"aws_api/gamelift","title":"delete_vpc_peering_connection","content":"pub fn delete_vpc_peering_connection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.delete_vpc_peering_connection\naws_api/gamelift delete_vpc_peering_connection","url":"aws_api/gamelift.html#delete_vpc_peering_connection"},{"doc":"aws_api/gamelift","title":"deregister_compute","content":"pub fn deregister_compute(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.deregister_compute\naws_api/gamelift deregister_compute","url":"aws_api/gamelift.html#deregister_compute"},{"doc":"aws_api/gamelift","title":"deregister_game_server","content":"pub fn deregister_game_server(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.deregister_game_server\naws_api/gamelift deregister_game_server","url":"aws_api/gamelift.html#deregister_game_server"},{"doc":"aws_api/gamelift","title":"describe_alias","content":"pub fn describe_alias(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.describe_alias\naws_api/gamelift describe_alias","url":"aws_api/gamelift.html#describe_alias"},{"doc":"aws_api/gamelift","title":"describe_build","content":"pub fn describe_build(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.describe_build\naws_api/gamelift describe_build","url":"aws_api/gamelift.html#describe_build"},{"doc":"aws_api/gamelift","title":"describe_compute","content":"pub fn describe_compute(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.describe_compute\naws_api/gamelift describe_compute","url":"aws_api/gamelift.html#describe_compute"},{"doc":"aws_api/gamelift","title":"describe_container_group_definition","content":"pub fn describe_container_group_definition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.describe_container_group_definition\naws_api/gamelift describe_container_group_definition","url":"aws_api/gamelift.html#describe_container_group_definition"},{"doc":"aws_api/gamelift","title":"describe_ec2_instance_limits","content":"pub fn describe_ec2_instance_limits(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.describe_ec2_instance_limits\naws_api/gamelift describe_ec2_instance_limits","url":"aws_api/gamelift.html#describe_ec2_instance_limits"},{"doc":"aws_api/gamelift","title":"describe_fleet_attributes","content":"pub fn describe_fleet_attributes(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.describe_fleet_attributes\naws_api/gamelift describe_fleet_attributes","url":"aws_api/gamelift.html#describe_fleet_attributes"},{"doc":"aws_api/gamelift","title":"describe_fleet_capacity","content":"pub fn describe_fleet_capacity(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.describe_fleet_capacity\naws_api/gamelift describe_fleet_capacity","url":"aws_api/gamelift.html#describe_fleet_capacity"},{"doc":"aws_api/gamelift","title":"describe_fleet_events","content":"pub fn describe_fleet_events(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.describe_fleet_events\naws_api/gamelift describe_fleet_events","url":"aws_api/gamelift.html#describe_fleet_events"},{"doc":"aws_api/gamelift","title":"describe_fleet_location_attributes","content":"pub fn describe_fleet_location_attributes(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.describe_fleet_location_attributes\naws_api/gamelift describe_fleet_location_attributes","url":"aws_api/gamelift.html#describe_fleet_location_attributes"},{"doc":"aws_api/gamelift","title":"describe_fleet_location_capacity","content":"pub fn describe_fleet_location_capacity(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.describe_fleet_location_capacity\naws_api/gamelift describe_fleet_location_capacity","url":"aws_api/gamelift.html#describe_fleet_location_capacity"},{"doc":"aws_api/gamelift","title":"describe_fleet_location_utilization","content":"pub fn describe_fleet_location_utilization(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.describe_fleet_location_utilization\naws_api/gamelift describe_fleet_location_utilization","url":"aws_api/gamelift.html#describe_fleet_location_utilization"},{"doc":"aws_api/gamelift","title":"describe_fleet_port_settings","content":"pub fn describe_fleet_port_settings(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.describe_fleet_port_settings\naws_api/gamelift describe_fleet_port_settings","url":"aws_api/gamelift.html#describe_fleet_port_settings"},{"doc":"aws_api/gamelift","title":"describe_fleet_utilization","content":"pub fn describe_fleet_utilization(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.describe_fleet_utilization\naws_api/gamelift describe_fleet_utilization","url":"aws_api/gamelift.html#describe_fleet_utilization"},{"doc":"aws_api/gamelift","title":"describe_game_server","content":"pub fn describe_game_server(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.describe_game_server\naws_api/gamelift describe_game_server","url":"aws_api/gamelift.html#describe_game_server"},{"doc":"aws_api/gamelift","title":"describe_game_server_group","content":"pub fn describe_game_server_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.describe_game_server_group\naws_api/gamelift describe_game_server_group","url":"aws_api/gamelift.html#describe_game_server_group"},{"doc":"aws_api/gamelift","title":"describe_game_server_instances","content":"pub fn describe_game_server_instances(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.describe_game_server_instances\naws_api/gamelift describe_game_server_instances","url":"aws_api/gamelift.html#describe_game_server_instances"},{"doc":"aws_api/gamelift","title":"describe_game_session_details","content":"pub fn describe_game_session_details(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.describe_game_session_details\naws_api/gamelift describe_game_session_details","url":"aws_api/gamelift.html#describe_game_session_details"},{"doc":"aws_api/gamelift","title":"describe_game_session_placement","content":"pub fn describe_game_session_placement(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.describe_game_session_placement\naws_api/gamelift describe_game_session_placement","url":"aws_api/gamelift.html#describe_game_session_placement"},{"doc":"aws_api/gamelift","title":"describe_game_session_queues","content":"pub fn describe_game_session_queues(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.describe_game_session_queues\naws_api/gamelift describe_game_session_queues","url":"aws_api/gamelift.html#describe_game_session_queues"},{"doc":"aws_api/gamelift","title":"describe_game_sessions","content":"pub fn describe_game_sessions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.describe_game_sessions\naws_api/gamelift describe_game_sessions","url":"aws_api/gamelift.html#describe_game_sessions"},{"doc":"aws_api/gamelift","title":"describe_instances","content":"pub fn describe_instances(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.describe_instances\naws_api/gamelift describe_instances","url":"aws_api/gamelift.html#describe_instances"},{"doc":"aws_api/gamelift","title":"describe_matchmaking","content":"pub fn describe_matchmaking(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.describe_matchmaking\naws_api/gamelift describe_matchmaking","url":"aws_api/gamelift.html#describe_matchmaking"},{"doc":"aws_api/gamelift","title":"describe_matchmaking_configurations","content":"pub fn describe_matchmaking_configurations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.describe_matchmaking_configurations\naws_api/gamelift describe_matchmaking_configurations","url":"aws_api/gamelift.html#describe_matchmaking_configurations"},{"doc":"aws_api/gamelift","title":"describe_matchmaking_rule_sets","content":"pub fn describe_matchmaking_rule_sets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.describe_matchmaking_rule_sets\naws_api/gamelift describe_matchmaking_rule_sets","url":"aws_api/gamelift.html#describe_matchmaking_rule_sets"},{"doc":"aws_api/gamelift","title":"describe_player_sessions","content":"pub fn describe_player_sessions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.describe_player_sessions\naws_api/gamelift describe_player_sessions","url":"aws_api/gamelift.html#describe_player_sessions"},{"doc":"aws_api/gamelift","title":"describe_runtime_configuration","content":"pub fn describe_runtime_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.describe_runtime_configuration\naws_api/gamelift describe_runtime_configuration","url":"aws_api/gamelift.html#describe_runtime_configuration"},{"doc":"aws_api/gamelift","title":"describe_scaling_policies","content":"pub fn describe_scaling_policies(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.describe_scaling_policies\naws_api/gamelift describe_scaling_policies","url":"aws_api/gamelift.html#describe_scaling_policies"},{"doc":"aws_api/gamelift","title":"describe_script","content":"pub fn describe_script(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.describe_script\naws_api/gamelift describe_script","url":"aws_api/gamelift.html#describe_script"},{"doc":"aws_api/gamelift","title":"describe_vpc_peering_authorizations","content":"pub fn describe_vpc_peering_authorizations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.describe_vpc_peering_authorizations\naws_api/gamelift describe_vpc_peering_authorizations","url":"aws_api/gamelift.html#describe_vpc_peering_authorizations"},{"doc":"aws_api/gamelift","title":"describe_vpc_peering_connections","content":"pub fn describe_vpc_peering_connections(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.describe_vpc_peering_connections\naws_api/gamelift describe_vpc_peering_connections","url":"aws_api/gamelift.html#describe_vpc_peering_connections"},{"doc":"aws_api/gamelift","title":"get_compute_access","content":"pub fn get_compute_access(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.get_compute_access\naws_api/gamelift get_compute_access","url":"aws_api/gamelift.html#get_compute_access"},{"doc":"aws_api/gamelift","title":"get_compute_auth_token","content":"pub fn get_compute_auth_token(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.get_compute_auth_token\naws_api/gamelift get_compute_auth_token","url":"aws_api/gamelift.html#get_compute_auth_token"},{"doc":"aws_api/gamelift","title":"get_game_session_log_url","content":"pub fn get_game_session_log_url(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.get_game_session_log_url\naws_api/gamelift get_game_session_log_url","url":"aws_api/gamelift.html#get_game_session_log_url"},{"doc":"aws_api/gamelift","title":"get_instance_access","content":"pub fn get_instance_access(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.get_instance_access\naws_api/gamelift get_instance_access","url":"aws_api/gamelift.html#get_instance_access"},{"doc":"aws_api/gamelift","title":"list_aliases","content":"pub fn list_aliases(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.list_aliases\naws_api/gamelift list_aliases","url":"aws_api/gamelift.html#list_aliases"},{"doc":"aws_api/gamelift","title":"list_builds","content":"pub fn list_builds(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.list_builds\naws_api/gamelift list_builds","url":"aws_api/gamelift.html#list_builds"},{"doc":"aws_api/gamelift","title":"list_compute","content":"pub fn list_compute(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.list_compute\naws_api/gamelift list_compute","url":"aws_api/gamelift.html#list_compute"},{"doc":"aws_api/gamelift","title":"list_container_group_definitions","content":"pub fn list_container_group_definitions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.list_container_group_definitions\naws_api/gamelift list_container_group_definitions","url":"aws_api/gamelift.html#list_container_group_definitions"},{"doc":"aws_api/gamelift","title":"list_fleets","content":"pub fn list_fleets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.list_fleets\naws_api/gamelift list_fleets","url":"aws_api/gamelift.html#list_fleets"},{"doc":"aws_api/gamelift","title":"list_game_server_groups","content":"pub fn list_game_server_groups(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.list_game_server_groups\naws_api/gamelift list_game_server_groups","url":"aws_api/gamelift.html#list_game_server_groups"},{"doc":"aws_api/gamelift","title":"list_game_servers","content":"pub fn list_game_servers(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.list_game_servers\naws_api/gamelift list_game_servers","url":"aws_api/gamelift.html#list_game_servers"},{"doc":"aws_api/gamelift","title":"list_locations","content":"pub fn list_locations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.list_locations\naws_api/gamelift list_locations","url":"aws_api/gamelift.html#list_locations"},{"doc":"aws_api/gamelift","title":"list_scripts","content":"pub fn list_scripts(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.list_scripts\naws_api/gamelift list_scripts","url":"aws_api/gamelift.html#list_scripts"},{"doc":"aws_api/gamelift","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.list_tags_for_resource\naws_api/gamelift list_tags_for_resource","url":"aws_api/gamelift.html#list_tags_for_resource"},{"doc":"aws_api/gamelift","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/gamelift.new\naws_api/gamelift new","url":"aws_api/gamelift.html#new"},{"doc":"aws_api/gamelift","title":"put_scaling_policy","content":"pub fn put_scaling_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.put_scaling_policy\naws_api/gamelift put_scaling_policy","url":"aws_api/gamelift.html#put_scaling_policy"},{"doc":"aws_api/gamelift","title":"register_compute","content":"pub fn register_compute(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.register_compute\naws_api/gamelift register_compute","url":"aws_api/gamelift.html#register_compute"},{"doc":"aws_api/gamelift","title":"register_game_server","content":"pub fn register_game_server(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.register_game_server\naws_api/gamelift register_game_server","url":"aws_api/gamelift.html#register_game_server"},{"doc":"aws_api/gamelift","title":"request_upload_credentials","content":"pub fn request_upload_credentials(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.request_upload_credentials\naws_api/gamelift request_upload_credentials","url":"aws_api/gamelift.html#request_upload_credentials"},{"doc":"aws_api/gamelift","title":"resolve_alias","content":"pub fn resolve_alias(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.resolve_alias\naws_api/gamelift resolve_alias","url":"aws_api/gamelift.html#resolve_alias"},{"doc":"aws_api/gamelift","title":"resume_game_server_group","content":"pub fn resume_game_server_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.resume_game_server_group\naws_api/gamelift resume_game_server_group","url":"aws_api/gamelift.html#resume_game_server_group"},{"doc":"aws_api/gamelift","title":"search_game_sessions","content":"pub fn search_game_sessions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.search_game_sessions\naws_api/gamelift search_game_sessions","url":"aws_api/gamelift.html#search_game_sessions"},{"doc":"aws_api/gamelift","title":"start_fleet_actions","content":"pub fn start_fleet_actions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.start_fleet_actions\naws_api/gamelift start_fleet_actions","url":"aws_api/gamelift.html#start_fleet_actions"},{"doc":"aws_api/gamelift","title":"start_game_session_placement","content":"pub fn start_game_session_placement(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.start_game_session_placement\naws_api/gamelift start_game_session_placement","url":"aws_api/gamelift.html#start_game_session_placement"},{"doc":"aws_api/gamelift","title":"start_match_backfill","content":"pub fn start_match_backfill(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.start_match_backfill\naws_api/gamelift start_match_backfill","url":"aws_api/gamelift.html#start_match_backfill"},{"doc":"aws_api/gamelift","title":"start_matchmaking","content":"pub fn start_matchmaking(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.start_matchmaking\naws_api/gamelift start_matchmaking","url":"aws_api/gamelift.html#start_matchmaking"},{"doc":"aws_api/gamelift","title":"stop_fleet_actions","content":"pub fn stop_fleet_actions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.stop_fleet_actions\naws_api/gamelift stop_fleet_actions","url":"aws_api/gamelift.html#stop_fleet_actions"},{"doc":"aws_api/gamelift","title":"stop_game_session_placement","content":"pub fn stop_game_session_placement(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.stop_game_session_placement\naws_api/gamelift stop_game_session_placement","url":"aws_api/gamelift.html#stop_game_session_placement"},{"doc":"aws_api/gamelift","title":"stop_matchmaking","content":"pub fn stop_matchmaking(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.stop_matchmaking\naws_api/gamelift stop_matchmaking","url":"aws_api/gamelift.html#stop_matchmaking"},{"doc":"aws_api/gamelift","title":"suspend_game_server_group","content":"pub fn suspend_game_server_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.suspend_game_server_group\naws_api/gamelift suspend_game_server_group","url":"aws_api/gamelift.html#suspend_game_server_group"},{"doc":"aws_api/gamelift","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.tag_resource\naws_api/gamelift tag_resource","url":"aws_api/gamelift.html#tag_resource"},{"doc":"aws_api/gamelift","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.untag_resource\naws_api/gamelift untag_resource","url":"aws_api/gamelift.html#untag_resource"},{"doc":"aws_api/gamelift","title":"update_alias","content":"pub fn update_alias(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.update_alias\naws_api/gamelift update_alias","url":"aws_api/gamelift.html#update_alias"},{"doc":"aws_api/gamelift","title":"update_build","content":"pub fn update_build(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.update_build\naws_api/gamelift update_build","url":"aws_api/gamelift.html#update_build"},{"doc":"aws_api/gamelift","title":"update_fleet_attributes","content":"pub fn update_fleet_attributes(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.update_fleet_attributes\naws_api/gamelift update_fleet_attributes","url":"aws_api/gamelift.html#update_fleet_attributes"},{"doc":"aws_api/gamelift","title":"update_fleet_capacity","content":"pub fn update_fleet_capacity(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.update_fleet_capacity\naws_api/gamelift update_fleet_capacity","url":"aws_api/gamelift.html#update_fleet_capacity"},{"doc":"aws_api/gamelift","title":"update_fleet_port_settings","content":"pub fn update_fleet_port_settings(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.update_fleet_port_settings\naws_api/gamelift update_fleet_port_settings","url":"aws_api/gamelift.html#update_fleet_port_settings"},{"doc":"aws_api/gamelift","title":"update_game_server","content":"pub fn update_game_server(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.update_game_server\naws_api/gamelift update_game_server","url":"aws_api/gamelift.html#update_game_server"},{"doc":"aws_api/gamelift","title":"update_game_server_group","content":"pub fn update_game_server_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.update_game_server_group\naws_api/gamelift update_game_server_group","url":"aws_api/gamelift.html#update_game_server_group"},{"doc":"aws_api/gamelift","title":"update_game_session","content":"pub fn update_game_session(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.update_game_session\naws_api/gamelift update_game_session","url":"aws_api/gamelift.html#update_game_session"},{"doc":"aws_api/gamelift","title":"update_game_session_queue","content":"pub fn update_game_session_queue(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.update_game_session_queue\naws_api/gamelift update_game_session_queue","url":"aws_api/gamelift.html#update_game_session_queue"},{"doc":"aws_api/gamelift","title":"update_matchmaking_configuration","content":"pub fn update_matchmaking_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.update_matchmaking_configuration\naws_api/gamelift update_matchmaking_configuration","url":"aws_api/gamelift.html#update_matchmaking_configuration"},{"doc":"aws_api/gamelift","title":"update_runtime_configuration","content":"pub fn update_runtime_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.update_runtime_configuration\naws_api/gamelift update_runtime_configuration","url":"aws_api/gamelift.html#update_runtime_configuration"},{"doc":"aws_api/gamelift","title":"update_script","content":"pub fn update_script(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.update_script\naws_api/gamelift update_script","url":"aws_api/gamelift.html#update_script"},{"doc":"aws_api/gamelift","title":"validate_matchmaking_rule_set","content":"pub fn validate_matchmaking_rule_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/gamelift.validate_matchmaking_rule_set\naws_api/gamelift validate_matchmaking_rule_set","url":"aws_api/gamelift.html#validate_matchmaking_rule_set"},{"doc":"aws_api/gamelift","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/gamelift.with_custom_endpoint\naws_api/gamelift with_custom_endpoint","url":"aws_api/gamelift.html#with_custom_endpoint"},{"doc":"aws_api/gamelift","title":"aws_api/gamelift","content":"","url":"aws_api/gamelift.html"},{"doc":"aws_api/glacier","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/glacier.Client\naws_api/glacier Client","url":"aws_api/glacier.html#Client"},{"doc":"aws_api/glacier","title":"abort_multipart_upload","content":"pub fn abort_multipart_upload(\n  client: Client,\n  account_id: String,\n  vault_name: String,\n  upload_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glacier.abort_multipart_upload\naws_api/glacier abort_multipart_upload","url":"aws_api/glacier.html#abort_multipart_upload"},{"doc":"aws_api/glacier","title":"abort_vault_lock","content":"pub fn abort_vault_lock(\n  client: Client,\n  account_id: String,\n  vault_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glacier.abort_vault_lock\naws_api/glacier abort_vault_lock","url":"aws_api/glacier.html#abort_vault_lock"},{"doc":"aws_api/glacier","title":"add_tags_to_vault","content":"pub fn add_tags_to_vault(\n  client: Client,\n  account_id: String,\n  vault_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glacier.add_tags_to_vault\naws_api/glacier add_tags_to_vault","url":"aws_api/glacier.html#add_tags_to_vault"},{"doc":"aws_api/glacier","title":"complete_multipart_upload","content":"pub fn complete_multipart_upload(\n  client: Client,\n  account_id: String,\n  vault_name: String,\n  upload_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glacier.complete_multipart_upload\naws_api/glacier complete_multipart_upload","url":"aws_api/glacier.html#complete_multipart_upload"},{"doc":"aws_api/glacier","title":"complete_vault_lock","content":"pub fn complete_vault_lock(\n  client: Client,\n  account_id: String,\n  vault_name: String,\n  lock_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glacier.complete_vault_lock\naws_api/glacier complete_vault_lock","url":"aws_api/glacier.html#complete_vault_lock"},{"doc":"aws_api/glacier","title":"create_vault","content":"pub fn create_vault(\n  client: Client,\n  account_id: String,\n  vault_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glacier.create_vault\naws_api/glacier create_vault","url":"aws_api/glacier.html#create_vault"},{"doc":"aws_api/glacier","title":"delete_archive","content":"pub fn delete_archive(\n  client: Client,\n  account_id: String,\n  vault_name: String,\n  archive_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glacier.delete_archive\naws_api/glacier delete_archive","url":"aws_api/glacier.html#delete_archive"},{"doc":"aws_api/glacier","title":"delete_vault","content":"pub fn delete_vault(\n  client: Client,\n  account_id: String,\n  vault_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glacier.delete_vault\naws_api/glacier delete_vault","url":"aws_api/glacier.html#delete_vault"},{"doc":"aws_api/glacier","title":"delete_vault_access_policy","content":"pub fn delete_vault_access_policy(\n  client: Client,\n  account_id: String,\n  vault_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glacier.delete_vault_access_policy\naws_api/glacier delete_vault_access_policy","url":"aws_api/glacier.html#delete_vault_access_policy"},{"doc":"aws_api/glacier","title":"delete_vault_notifications","content":"pub fn delete_vault_notifications(\n  client: Client,\n  account_id: String,\n  vault_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glacier.delete_vault_notifications\naws_api/glacier delete_vault_notifications","url":"aws_api/glacier.html#delete_vault_notifications"},{"doc":"aws_api/glacier","title":"describe_job","content":"pub fn describe_job(\n  client: Client,\n  account_id: String,\n  vault_name: String,\n  job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glacier.describe_job\naws_api/glacier describe_job","url":"aws_api/glacier.html#describe_job"},{"doc":"aws_api/glacier","title":"describe_vault","content":"pub fn describe_vault(\n  client: Client,\n  account_id: String,\n  vault_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glacier.describe_vault\naws_api/glacier describe_vault","url":"aws_api/glacier.html#describe_vault"},{"doc":"aws_api/glacier","title":"get_data_retrieval_policy","content":"pub fn get_data_retrieval_policy(\n  client: Client,\n  account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glacier.get_data_retrieval_policy\naws_api/glacier get_data_retrieval_policy","url":"aws_api/glacier.html#get_data_retrieval_policy"},{"doc":"aws_api/glacier","title":"get_job_output","content":"pub fn get_job_output(\n  client: Client,\n  account_id: String,\n  vault_name: String,\n  job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glacier.get_job_output\naws_api/glacier get_job_output","url":"aws_api/glacier.html#get_job_output"},{"doc":"aws_api/glacier","title":"get_vault_access_policy","content":"pub fn get_vault_access_policy(\n  client: Client,\n  account_id: String,\n  vault_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glacier.get_vault_access_policy\naws_api/glacier get_vault_access_policy","url":"aws_api/glacier.html#get_vault_access_policy"},{"doc":"aws_api/glacier","title":"get_vault_lock","content":"pub fn get_vault_lock(\n  client: Client,\n  account_id: String,\n  vault_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glacier.get_vault_lock\naws_api/glacier get_vault_lock","url":"aws_api/glacier.html#get_vault_lock"},{"doc":"aws_api/glacier","title":"get_vault_notifications","content":"pub fn get_vault_notifications(\n  client: Client,\n  account_id: String,\n  vault_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glacier.get_vault_notifications\naws_api/glacier get_vault_notifications","url":"aws_api/glacier.html#get_vault_notifications"},{"doc":"aws_api/glacier","title":"initiate_job","content":"pub fn initiate_job(\n  client: Client,\n  account_id: String,\n  vault_name: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glacier.initiate_job\naws_api/glacier initiate_job","url":"aws_api/glacier.html#initiate_job"},{"doc":"aws_api/glacier","title":"initiate_multipart_upload","content":"pub fn initiate_multipart_upload(\n  client: Client,\n  account_id: String,\n  vault_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glacier.initiate_multipart_upload\naws_api/glacier initiate_multipart_upload","url":"aws_api/glacier.html#initiate_multipart_upload"},{"doc":"aws_api/glacier","title":"initiate_vault_lock","content":"pub fn initiate_vault_lock(\n  client: Client,\n  account_id: String,\n  vault_name: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glacier.initiate_vault_lock\naws_api/glacier initiate_vault_lock","url":"aws_api/glacier.html#initiate_vault_lock"},{"doc":"aws_api/glacier","title":"list_jobs","content":"pub fn list_jobs(\n  client: Client,\n  account_id: String,\n  vault_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glacier.list_jobs\naws_api/glacier list_jobs","url":"aws_api/glacier.html#list_jobs"},{"doc":"aws_api/glacier","title":"list_multipart_uploads","content":"pub fn list_multipart_uploads(\n  client: Client,\n  account_id: String,\n  vault_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glacier.list_multipart_uploads\naws_api/glacier list_multipart_uploads","url":"aws_api/glacier.html#list_multipart_uploads"},{"doc":"aws_api/glacier","title":"list_parts","content":"pub fn list_parts(\n  client: Client,\n  account_id: String,\n  vault_name: String,\n  upload_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glacier.list_parts\naws_api/glacier list_parts","url":"aws_api/glacier.html#list_parts"},{"doc":"aws_api/glacier","title":"list_provisioned_capacity","content":"pub fn list_provisioned_capacity(\n  client: Client,\n  account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glacier.list_provisioned_capacity\naws_api/glacier list_provisioned_capacity","url":"aws_api/glacier.html#list_provisioned_capacity"},{"doc":"aws_api/glacier","title":"list_tags_for_vault","content":"pub fn list_tags_for_vault(\n  client: Client,\n  account_id: String,\n  vault_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glacier.list_tags_for_vault\naws_api/glacier list_tags_for_vault","url":"aws_api/glacier.html#list_tags_for_vault"},{"doc":"aws_api/glacier","title":"list_vaults","content":"pub fn list_vaults(\n  client: Client,\n  account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glacier.list_vaults\naws_api/glacier list_vaults","url":"aws_api/glacier.html#list_vaults"},{"doc":"aws_api/glacier","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/glacier.new\naws_api/glacier new","url":"aws_api/glacier.html#new"},{"doc":"aws_api/glacier","title":"purchase_provisioned_capacity","content":"pub fn purchase_provisioned_capacity(\n  client: Client,\n  account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glacier.purchase_provisioned_capacity\naws_api/glacier purchase_provisioned_capacity","url":"aws_api/glacier.html#purchase_provisioned_capacity"},{"doc":"aws_api/glacier","title":"remove_tags_from_vault","content":"pub fn remove_tags_from_vault(\n  client: Client,\n  account_id: String,\n  vault_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glacier.remove_tags_from_vault\naws_api/glacier remove_tags_from_vault","url":"aws_api/glacier.html#remove_tags_from_vault"},{"doc":"aws_api/glacier","title":"set_data_retrieval_policy","content":"pub fn set_data_retrieval_policy(\n  client: Client,\n  account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glacier.set_data_retrieval_policy\naws_api/glacier set_data_retrieval_policy","url":"aws_api/glacier.html#set_data_retrieval_policy"},{"doc":"aws_api/glacier","title":"set_vault_access_policy","content":"pub fn set_vault_access_policy(\n  client: Client,\n  account_id: String,\n  vault_name: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glacier.set_vault_access_policy\naws_api/glacier set_vault_access_policy","url":"aws_api/glacier.html#set_vault_access_policy"},{"doc":"aws_api/glacier","title":"set_vault_notifications","content":"pub fn set_vault_notifications(\n  client: Client,\n  account_id: String,\n  vault_name: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glacier.set_vault_notifications\naws_api/glacier set_vault_notifications","url":"aws_api/glacier.html#set_vault_notifications"},{"doc":"aws_api/glacier","title":"upload_archive","content":"pub fn upload_archive(\n  client: Client,\n  account_id: String,\n  vault_name: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glacier.upload_archive\naws_api/glacier upload_archive","url":"aws_api/glacier.html#upload_archive"},{"doc":"aws_api/glacier","title":"upload_multipart_part","content":"pub fn upload_multipart_part(\n  client: Client,\n  account_id: String,\n  vault_name: String,\n  upload_id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glacier.upload_multipart_part\naws_api/glacier upload_multipart_part","url":"aws_api/glacier.html#upload_multipart_part"},{"doc":"aws_api/glacier","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/glacier.with_custom_endpoint\naws_api/glacier with_custom_endpoint","url":"aws_api/glacier.html#with_custom_endpoint"},{"doc":"aws_api/glacier","title":"aws_api/glacier","content":"","url":"aws_api/glacier.html"},{"doc":"aws_api/global_accelerator","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/global_accelerator.Client\naws_api/global_accelerator Client","url":"aws_api/global_accelerator.html#Client"},{"doc":"aws_api/global_accelerator","title":"add_custom_routing_endpoints","content":"pub fn add_custom_routing_endpoints(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.add_custom_routing_endpoints\naws_api/global_accelerator add_custom_routing_endpoints","url":"aws_api/global_accelerator.html#add_custom_routing_endpoints"},{"doc":"aws_api/global_accelerator","title":"add_endpoints","content":"pub fn add_endpoints(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.add_endpoints\naws_api/global_accelerator add_endpoints","url":"aws_api/global_accelerator.html#add_endpoints"},{"doc":"aws_api/global_accelerator","title":"advertise_byoip_cidr","content":"pub fn advertise_byoip_cidr(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.advertise_byoip_cidr\naws_api/global_accelerator advertise_byoip_cidr","url":"aws_api/global_accelerator.html#advertise_byoip_cidr"},{"doc":"aws_api/global_accelerator","title":"allow_custom_routing_traffic","content":"pub fn allow_custom_routing_traffic(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.allow_custom_routing_traffic\naws_api/global_accelerator allow_custom_routing_traffic","url":"aws_api/global_accelerator.html#allow_custom_routing_traffic"},{"doc":"aws_api/global_accelerator","title":"create_accelerator","content":"pub fn create_accelerator(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.create_accelerator\naws_api/global_accelerator create_accelerator","url":"aws_api/global_accelerator.html#create_accelerator"},{"doc":"aws_api/global_accelerator","title":"create_cross_account_attachment","content":"pub fn create_cross_account_attachment(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.create_cross_account_attachment\naws_api/global_accelerator create_cross_account_attachment","url":"aws_api/global_accelerator.html#create_cross_account_attachment"},{"doc":"aws_api/global_accelerator","title":"create_custom_routing_accelerator","content":"pub fn create_custom_routing_accelerator(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.create_custom_routing_accelerator\naws_api/global_accelerator create_custom_routing_accelerator","url":"aws_api/global_accelerator.html#create_custom_routing_accelerator"},{"doc":"aws_api/global_accelerator","title":"create_custom_routing_endpoint_group","content":"pub fn create_custom_routing_endpoint_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.create_custom_routing_endpoint_group\naws_api/global_accelerator create_custom_routing_endpoint_group","url":"aws_api/global_accelerator.html#create_custom_routing_endpoint_group"},{"doc":"aws_api/global_accelerator","title":"create_custom_routing_listener","content":"pub fn create_custom_routing_listener(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.create_custom_routing_listener\naws_api/global_accelerator create_custom_routing_listener","url":"aws_api/global_accelerator.html#create_custom_routing_listener"},{"doc":"aws_api/global_accelerator","title":"create_endpoint_group","content":"pub fn create_endpoint_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.create_endpoint_group\naws_api/global_accelerator create_endpoint_group","url":"aws_api/global_accelerator.html#create_endpoint_group"},{"doc":"aws_api/global_accelerator","title":"create_listener","content":"pub fn create_listener(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.create_listener\naws_api/global_accelerator create_listener","url":"aws_api/global_accelerator.html#create_listener"},{"doc":"aws_api/global_accelerator","title":"delete_accelerator","content":"pub fn delete_accelerator(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.delete_accelerator\naws_api/global_accelerator delete_accelerator","url":"aws_api/global_accelerator.html#delete_accelerator"},{"doc":"aws_api/global_accelerator","title":"delete_cross_account_attachment","content":"pub fn delete_cross_account_attachment(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.delete_cross_account_attachment\naws_api/global_accelerator delete_cross_account_attachment","url":"aws_api/global_accelerator.html#delete_cross_account_attachment"},{"doc":"aws_api/global_accelerator","title":"delete_custom_routing_accelerator","content":"pub fn delete_custom_routing_accelerator(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.delete_custom_routing_accelerator\naws_api/global_accelerator delete_custom_routing_accelerator","url":"aws_api/global_accelerator.html#delete_custom_routing_accelerator"},{"doc":"aws_api/global_accelerator","title":"delete_custom_routing_endpoint_group","content":"pub fn delete_custom_routing_endpoint_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.delete_custom_routing_endpoint_group\naws_api/global_accelerator delete_custom_routing_endpoint_group","url":"aws_api/global_accelerator.html#delete_custom_routing_endpoint_group"},{"doc":"aws_api/global_accelerator","title":"delete_custom_routing_listener","content":"pub fn delete_custom_routing_listener(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.delete_custom_routing_listener\naws_api/global_accelerator delete_custom_routing_listener","url":"aws_api/global_accelerator.html#delete_custom_routing_listener"},{"doc":"aws_api/global_accelerator","title":"delete_endpoint_group","content":"pub fn delete_endpoint_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.delete_endpoint_group\naws_api/global_accelerator delete_endpoint_group","url":"aws_api/global_accelerator.html#delete_endpoint_group"},{"doc":"aws_api/global_accelerator","title":"delete_listener","content":"pub fn delete_listener(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.delete_listener\naws_api/global_accelerator delete_listener","url":"aws_api/global_accelerator.html#delete_listener"},{"doc":"aws_api/global_accelerator","title":"deny_custom_routing_traffic","content":"pub fn deny_custom_routing_traffic(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.deny_custom_routing_traffic\naws_api/global_accelerator deny_custom_routing_traffic","url":"aws_api/global_accelerator.html#deny_custom_routing_traffic"},{"doc":"aws_api/global_accelerator","title":"deprovision_byoip_cidr","content":"pub fn deprovision_byoip_cidr(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.deprovision_byoip_cidr\naws_api/global_accelerator deprovision_byoip_cidr","url":"aws_api/global_accelerator.html#deprovision_byoip_cidr"},{"doc":"aws_api/global_accelerator","title":"describe_accelerator","content":"pub fn describe_accelerator(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.describe_accelerator\naws_api/global_accelerator describe_accelerator","url":"aws_api/global_accelerator.html#describe_accelerator"},{"doc":"aws_api/global_accelerator","title":"describe_accelerator_attributes","content":"pub fn describe_accelerator_attributes(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.describe_accelerator_attributes\naws_api/global_accelerator describe_accelerator_attributes","url":"aws_api/global_accelerator.html#describe_accelerator_attributes"},{"doc":"aws_api/global_accelerator","title":"describe_cross_account_attachment","content":"pub fn describe_cross_account_attachment(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.describe_cross_account_attachment\naws_api/global_accelerator describe_cross_account_attachment","url":"aws_api/global_accelerator.html#describe_cross_account_attachment"},{"doc":"aws_api/global_accelerator","title":"describe_custom_routing_accelerator","content":"pub fn describe_custom_routing_accelerator(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.describe_custom_routing_accelerator\naws_api/global_accelerator describe_custom_routing_accelerator","url":"aws_api/global_accelerator.html#describe_custom_routing_accelerator"},{"doc":"aws_api/global_accelerator","title":"describe_custom_routing_accelerator_attributes","content":"pub fn describe_custom_routing_accelerator_attributes(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.describe_custom_routing_accelerator_attributes\naws_api/global_accelerator describe_custom_routing_accelerator_attributes","url":"aws_api/global_accelerator.html#describe_custom_routing_accelerator_attributes"},{"doc":"aws_api/global_accelerator","title":"describe_custom_routing_endpoint_group","content":"pub fn describe_custom_routing_endpoint_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.describe_custom_routing_endpoint_group\naws_api/global_accelerator describe_custom_routing_endpoint_group","url":"aws_api/global_accelerator.html#describe_custom_routing_endpoint_group"},{"doc":"aws_api/global_accelerator","title":"describe_custom_routing_listener","content":"pub fn describe_custom_routing_listener(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.describe_custom_routing_listener\naws_api/global_accelerator describe_custom_routing_listener","url":"aws_api/global_accelerator.html#describe_custom_routing_listener"},{"doc":"aws_api/global_accelerator","title":"describe_endpoint_group","content":"pub fn describe_endpoint_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.describe_endpoint_group\naws_api/global_accelerator describe_endpoint_group","url":"aws_api/global_accelerator.html#describe_endpoint_group"},{"doc":"aws_api/global_accelerator","title":"describe_listener","content":"pub fn describe_listener(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.describe_listener\naws_api/global_accelerator describe_listener","url":"aws_api/global_accelerator.html#describe_listener"},{"doc":"aws_api/global_accelerator","title":"list_accelerators","content":"pub fn list_accelerators(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.list_accelerators\naws_api/global_accelerator list_accelerators","url":"aws_api/global_accelerator.html#list_accelerators"},{"doc":"aws_api/global_accelerator","title":"list_byoip_cidrs","content":"pub fn list_byoip_cidrs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.list_byoip_cidrs\naws_api/global_accelerator list_byoip_cidrs","url":"aws_api/global_accelerator.html#list_byoip_cidrs"},{"doc":"aws_api/global_accelerator","title":"list_cross_account_attachments","content":"pub fn list_cross_account_attachments(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.list_cross_account_attachments\naws_api/global_accelerator list_cross_account_attachments","url":"aws_api/global_accelerator.html#list_cross_account_attachments"},{"doc":"aws_api/global_accelerator","title":"list_cross_account_resource_accounts","content":"pub fn list_cross_account_resource_accounts(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.list_cross_account_resource_accounts\naws_api/global_accelerator list_cross_account_resource_accounts","url":"aws_api/global_accelerator.html#list_cross_account_resource_accounts"},{"doc":"aws_api/global_accelerator","title":"list_cross_account_resources","content":"pub fn list_cross_account_resources(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.list_cross_account_resources\naws_api/global_accelerator list_cross_account_resources","url":"aws_api/global_accelerator.html#list_cross_account_resources"},{"doc":"aws_api/global_accelerator","title":"list_custom_routing_accelerators","content":"pub fn list_custom_routing_accelerators(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.list_custom_routing_accelerators\naws_api/global_accelerator list_custom_routing_accelerators","url":"aws_api/global_accelerator.html#list_custom_routing_accelerators"},{"doc":"aws_api/global_accelerator","title":"list_custom_routing_endpoint_groups","content":"pub fn list_custom_routing_endpoint_groups(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.list_custom_routing_endpoint_groups\naws_api/global_accelerator list_custom_routing_endpoint_groups","url":"aws_api/global_accelerator.html#list_custom_routing_endpoint_groups"},{"doc":"aws_api/global_accelerator","title":"list_custom_routing_listeners","content":"pub fn list_custom_routing_listeners(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.list_custom_routing_listeners\naws_api/global_accelerator list_custom_routing_listeners","url":"aws_api/global_accelerator.html#list_custom_routing_listeners"},{"doc":"aws_api/global_accelerator","title":"list_custom_routing_port_mappings","content":"pub fn list_custom_routing_port_mappings(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.list_custom_routing_port_mappings\naws_api/global_accelerator list_custom_routing_port_mappings","url":"aws_api/global_accelerator.html#list_custom_routing_port_mappings"},{"doc":"aws_api/global_accelerator","title":"list_custom_routing_port_mappings_by_destination","content":"pub fn list_custom_routing_port_mappings_by_destination(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.list_custom_routing_port_mappings_by_destination\naws_api/global_accelerator list_custom_routing_port_mappings_by_destination","url":"aws_api/global_accelerator.html#list_custom_routing_port_mappings_by_destination"},{"doc":"aws_api/global_accelerator","title":"list_endpoint_groups","content":"pub fn list_endpoint_groups(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.list_endpoint_groups\naws_api/global_accelerator list_endpoint_groups","url":"aws_api/global_accelerator.html#list_endpoint_groups"},{"doc":"aws_api/global_accelerator","title":"list_listeners","content":"pub fn list_listeners(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.list_listeners\naws_api/global_accelerator list_listeners","url":"aws_api/global_accelerator.html#list_listeners"},{"doc":"aws_api/global_accelerator","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.list_tags_for_resource\naws_api/global_accelerator list_tags_for_resource","url":"aws_api/global_accelerator.html#list_tags_for_resource"},{"doc":"aws_api/global_accelerator","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/global_accelerator.new\naws_api/global_accelerator new","url":"aws_api/global_accelerator.html#new"},{"doc":"aws_api/global_accelerator","title":"provision_byoip_cidr","content":"pub fn provision_byoip_cidr(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.provision_byoip_cidr\naws_api/global_accelerator provision_byoip_cidr","url":"aws_api/global_accelerator.html#provision_byoip_cidr"},{"doc":"aws_api/global_accelerator","title":"remove_custom_routing_endpoints","content":"pub fn remove_custom_routing_endpoints(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.remove_custom_routing_endpoints\naws_api/global_accelerator remove_custom_routing_endpoints","url":"aws_api/global_accelerator.html#remove_custom_routing_endpoints"},{"doc":"aws_api/global_accelerator","title":"remove_endpoints","content":"pub fn remove_endpoints(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.remove_endpoints\naws_api/global_accelerator remove_endpoints","url":"aws_api/global_accelerator.html#remove_endpoints"},{"doc":"aws_api/global_accelerator","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.tag_resource\naws_api/global_accelerator tag_resource","url":"aws_api/global_accelerator.html#tag_resource"},{"doc":"aws_api/global_accelerator","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.untag_resource\naws_api/global_accelerator untag_resource","url":"aws_api/global_accelerator.html#untag_resource"},{"doc":"aws_api/global_accelerator","title":"update_accelerator","content":"pub fn update_accelerator(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.update_accelerator\naws_api/global_accelerator update_accelerator","url":"aws_api/global_accelerator.html#update_accelerator"},{"doc":"aws_api/global_accelerator","title":"update_accelerator_attributes","content":"pub fn update_accelerator_attributes(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.update_accelerator_attributes\naws_api/global_accelerator update_accelerator_attributes","url":"aws_api/global_accelerator.html#update_accelerator_attributes"},{"doc":"aws_api/global_accelerator","title":"update_cross_account_attachment","content":"pub fn update_cross_account_attachment(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.update_cross_account_attachment\naws_api/global_accelerator update_cross_account_attachment","url":"aws_api/global_accelerator.html#update_cross_account_attachment"},{"doc":"aws_api/global_accelerator","title":"update_custom_routing_accelerator","content":"pub fn update_custom_routing_accelerator(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.update_custom_routing_accelerator\naws_api/global_accelerator update_custom_routing_accelerator","url":"aws_api/global_accelerator.html#update_custom_routing_accelerator"},{"doc":"aws_api/global_accelerator","title":"update_custom_routing_accelerator_attributes","content":"pub fn update_custom_routing_accelerator_attributes(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.update_custom_routing_accelerator_attributes\naws_api/global_accelerator update_custom_routing_accelerator_attributes","url":"aws_api/global_accelerator.html#update_custom_routing_accelerator_attributes"},{"doc":"aws_api/global_accelerator","title":"update_custom_routing_listener","content":"pub fn update_custom_routing_listener(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.update_custom_routing_listener\naws_api/global_accelerator update_custom_routing_listener","url":"aws_api/global_accelerator.html#update_custom_routing_listener"},{"doc":"aws_api/global_accelerator","title":"update_endpoint_group","content":"pub fn update_endpoint_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.update_endpoint_group\naws_api/global_accelerator update_endpoint_group","url":"aws_api/global_accelerator.html#update_endpoint_group"},{"doc":"aws_api/global_accelerator","title":"update_listener","content":"pub fn update_listener(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.update_listener\naws_api/global_accelerator update_listener","url":"aws_api/global_accelerator.html#update_listener"},{"doc":"aws_api/global_accelerator","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/global_accelerator.with_custom_endpoint\naws_api/global_accelerator with_custom_endpoint","url":"aws_api/global_accelerator.html#with_custom_endpoint"},{"doc":"aws_api/global_accelerator","title":"withdraw_byoip_cidr","content":"pub fn withdraw_byoip_cidr(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/global_accelerator.withdraw_byoip_cidr\naws_api/global_accelerator withdraw_byoip_cidr","url":"aws_api/global_accelerator.html#withdraw_byoip_cidr"},{"doc":"aws_api/global_accelerator","title":"aws_api/global_accelerator","content":"","url":"aws_api/global_accelerator.html"},{"doc":"aws_api/glue","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/glue.Client\naws_api/glue Client","url":"aws_api/glue.html#Client"},{"doc":"aws_api/glue","title":"batch_create_partition","content":"pub fn batch_create_partition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.batch_create_partition\naws_api/glue batch_create_partition","url":"aws_api/glue.html#batch_create_partition"},{"doc":"aws_api/glue","title":"batch_delete_connection","content":"pub fn batch_delete_connection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.batch_delete_connection\naws_api/glue batch_delete_connection","url":"aws_api/glue.html#batch_delete_connection"},{"doc":"aws_api/glue","title":"batch_delete_partition","content":"pub fn batch_delete_partition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.batch_delete_partition\naws_api/glue batch_delete_partition","url":"aws_api/glue.html#batch_delete_partition"},{"doc":"aws_api/glue","title":"batch_delete_table","content":"pub fn batch_delete_table(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.batch_delete_table\naws_api/glue batch_delete_table","url":"aws_api/glue.html#batch_delete_table"},{"doc":"aws_api/glue","title":"batch_delete_table_version","content":"pub fn batch_delete_table_version(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.batch_delete_table_version\naws_api/glue batch_delete_table_version","url":"aws_api/glue.html#batch_delete_table_version"},{"doc":"aws_api/glue","title":"batch_get_blueprints","content":"pub fn batch_get_blueprints(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.batch_get_blueprints\naws_api/glue batch_get_blueprints","url":"aws_api/glue.html#batch_get_blueprints"},{"doc":"aws_api/glue","title":"batch_get_crawlers","content":"pub fn batch_get_crawlers(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.batch_get_crawlers\naws_api/glue batch_get_crawlers","url":"aws_api/glue.html#batch_get_crawlers"},{"doc":"aws_api/glue","title":"batch_get_custom_entity_types","content":"pub fn batch_get_custom_entity_types(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.batch_get_custom_entity_types\naws_api/glue batch_get_custom_entity_types","url":"aws_api/glue.html#batch_get_custom_entity_types"},{"doc":"aws_api/glue","title":"batch_get_data_quality_result","content":"pub fn batch_get_data_quality_result(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.batch_get_data_quality_result\naws_api/glue batch_get_data_quality_result","url":"aws_api/glue.html#batch_get_data_quality_result"},{"doc":"aws_api/glue","title":"batch_get_dev_endpoints","content":"pub fn batch_get_dev_endpoints(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.batch_get_dev_endpoints\naws_api/glue batch_get_dev_endpoints","url":"aws_api/glue.html#batch_get_dev_endpoints"},{"doc":"aws_api/glue","title":"batch_get_jobs","content":"pub fn batch_get_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.batch_get_jobs\naws_api/glue batch_get_jobs","url":"aws_api/glue.html#batch_get_jobs"},{"doc":"aws_api/glue","title":"batch_get_partition","content":"pub fn batch_get_partition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.batch_get_partition\naws_api/glue batch_get_partition","url":"aws_api/glue.html#batch_get_partition"},{"doc":"aws_api/glue","title":"batch_get_table_optimizer","content":"pub fn batch_get_table_optimizer(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.batch_get_table_optimizer\naws_api/glue batch_get_table_optimizer","url":"aws_api/glue.html#batch_get_table_optimizer"},{"doc":"aws_api/glue","title":"batch_get_triggers","content":"pub fn batch_get_triggers(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.batch_get_triggers\naws_api/glue batch_get_triggers","url":"aws_api/glue.html#batch_get_triggers"},{"doc":"aws_api/glue","title":"batch_get_workflows","content":"pub fn batch_get_workflows(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.batch_get_workflows\naws_api/glue batch_get_workflows","url":"aws_api/glue.html#batch_get_workflows"},{"doc":"aws_api/glue","title":"batch_put_data_quality_statistic_annotation","content":"pub fn batch_put_data_quality_statistic_annotation(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.batch_put_data_quality_statistic_annotation\naws_api/glue batch_put_data_quality_statistic_annotation","url":"aws_api/glue.html#batch_put_data_quality_statistic_annotation"},{"doc":"aws_api/glue","title":"batch_stop_job_run","content":"pub fn batch_stop_job_run(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.batch_stop_job_run\naws_api/glue batch_stop_job_run","url":"aws_api/glue.html#batch_stop_job_run"},{"doc":"aws_api/glue","title":"batch_update_partition","content":"pub fn batch_update_partition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.batch_update_partition\naws_api/glue batch_update_partition","url":"aws_api/glue.html#batch_update_partition"},{"doc":"aws_api/glue","title":"cancel_data_quality_rule_recommendation_run","content":"pub fn cancel_data_quality_rule_recommendation_run(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.cancel_data_quality_rule_recommendation_run\naws_api/glue cancel_data_quality_rule_recommendation_run","url":"aws_api/glue.html#cancel_data_quality_rule_recommendation_run"},{"doc":"aws_api/glue","title":"cancel_data_quality_ruleset_evaluation_run","content":"pub fn cancel_data_quality_ruleset_evaluation_run(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.cancel_data_quality_ruleset_evaluation_run\naws_api/glue cancel_data_quality_ruleset_evaluation_run","url":"aws_api/glue.html#cancel_data_quality_ruleset_evaluation_run"},{"doc":"aws_api/glue","title":"cancel_ml_task_run","content":"pub fn cancel_ml_task_run(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.cancel_ml_task_run\naws_api/glue cancel_ml_task_run","url":"aws_api/glue.html#cancel_ml_task_run"},{"doc":"aws_api/glue","title":"cancel_statement","content":"pub fn cancel_statement(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.cancel_statement\naws_api/glue cancel_statement","url":"aws_api/glue.html#cancel_statement"},{"doc":"aws_api/glue","title":"check_schema_version_validity","content":"pub fn check_schema_version_validity(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.check_schema_version_validity\naws_api/glue check_schema_version_validity","url":"aws_api/glue.html#check_schema_version_validity"},{"doc":"aws_api/glue","title":"create_blueprint","content":"pub fn create_blueprint(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.create_blueprint\naws_api/glue create_blueprint","url":"aws_api/glue.html#create_blueprint"},{"doc":"aws_api/glue","title":"create_classifier","content":"pub fn create_classifier(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.create_classifier\naws_api/glue create_classifier","url":"aws_api/glue.html#create_classifier"},{"doc":"aws_api/glue","title":"create_connection","content":"pub fn create_connection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.create_connection\naws_api/glue create_connection","url":"aws_api/glue.html#create_connection"},{"doc":"aws_api/glue","title":"create_crawler","content":"pub fn create_crawler(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.create_crawler\naws_api/glue create_crawler","url":"aws_api/glue.html#create_crawler"},{"doc":"aws_api/glue","title":"create_custom_entity_type","content":"pub fn create_custom_entity_type(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.create_custom_entity_type\naws_api/glue create_custom_entity_type","url":"aws_api/glue.html#create_custom_entity_type"},{"doc":"aws_api/glue","title":"create_data_quality_ruleset","content":"pub fn create_data_quality_ruleset(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.create_data_quality_ruleset\naws_api/glue create_data_quality_ruleset","url":"aws_api/glue.html#create_data_quality_ruleset"},{"doc":"aws_api/glue","title":"create_database","content":"pub fn create_database(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.create_database\naws_api/glue create_database","url":"aws_api/glue.html#create_database"},{"doc":"aws_api/glue","title":"create_dev_endpoint","content":"pub fn create_dev_endpoint(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.create_dev_endpoint\naws_api/glue create_dev_endpoint","url":"aws_api/glue.html#create_dev_endpoint"},{"doc":"aws_api/glue","title":"create_job","content":"pub fn create_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.create_job\naws_api/glue create_job","url":"aws_api/glue.html#create_job"},{"doc":"aws_api/glue","title":"create_ml_transform","content":"pub fn create_ml_transform(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.create_ml_transform\naws_api/glue create_ml_transform","url":"aws_api/glue.html#create_ml_transform"},{"doc":"aws_api/glue","title":"create_partition","content":"pub fn create_partition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.create_partition\naws_api/glue create_partition","url":"aws_api/glue.html#create_partition"},{"doc":"aws_api/glue","title":"create_partition_index","content":"pub fn create_partition_index(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.create_partition_index\naws_api/glue create_partition_index","url":"aws_api/glue.html#create_partition_index"},{"doc":"aws_api/glue","title":"create_registry","content":"pub fn create_registry(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.create_registry\naws_api/glue create_registry","url":"aws_api/glue.html#create_registry"},{"doc":"aws_api/glue","title":"create_schema","content":"pub fn create_schema(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.create_schema\naws_api/glue create_schema","url":"aws_api/glue.html#create_schema"},{"doc":"aws_api/glue","title":"create_script","content":"pub fn create_script(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.create_script\naws_api/glue create_script","url":"aws_api/glue.html#create_script"},{"doc":"aws_api/glue","title":"create_security_configuration","content":"pub fn create_security_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.create_security_configuration\naws_api/glue create_security_configuration","url":"aws_api/glue.html#create_security_configuration"},{"doc":"aws_api/glue","title":"create_session","content":"pub fn create_session(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.create_session\naws_api/glue create_session","url":"aws_api/glue.html#create_session"},{"doc":"aws_api/glue","title":"create_table","content":"pub fn create_table(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.create_table\naws_api/glue create_table","url":"aws_api/glue.html#create_table"},{"doc":"aws_api/glue","title":"create_table_optimizer","content":"pub fn create_table_optimizer(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.create_table_optimizer\naws_api/glue create_table_optimizer","url":"aws_api/glue.html#create_table_optimizer"},{"doc":"aws_api/glue","title":"create_trigger","content":"pub fn create_trigger(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.create_trigger\naws_api/glue create_trigger","url":"aws_api/glue.html#create_trigger"},{"doc":"aws_api/glue","title":"create_usage_profile","content":"pub fn create_usage_profile(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.create_usage_profile\naws_api/glue create_usage_profile","url":"aws_api/glue.html#create_usage_profile"},{"doc":"aws_api/glue","title":"create_user_defined_function","content":"pub fn create_user_defined_function(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.create_user_defined_function\naws_api/glue create_user_defined_function","url":"aws_api/glue.html#create_user_defined_function"},{"doc":"aws_api/glue","title":"create_workflow","content":"pub fn create_workflow(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.create_workflow\naws_api/glue create_workflow","url":"aws_api/glue.html#create_workflow"},{"doc":"aws_api/glue","title":"delete_blueprint","content":"pub fn delete_blueprint(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.delete_blueprint\naws_api/glue delete_blueprint","url":"aws_api/glue.html#delete_blueprint"},{"doc":"aws_api/glue","title":"delete_classifier","content":"pub fn delete_classifier(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.delete_classifier\naws_api/glue delete_classifier","url":"aws_api/glue.html#delete_classifier"},{"doc":"aws_api/glue","title":"delete_column_statistics_for_partition","content":"pub fn delete_column_statistics_for_partition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.delete_column_statistics_for_partition\naws_api/glue delete_column_statistics_for_partition","url":"aws_api/glue.html#delete_column_statistics_for_partition"},{"doc":"aws_api/glue","title":"delete_column_statistics_for_table","content":"pub fn delete_column_statistics_for_table(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.delete_column_statistics_for_table\naws_api/glue delete_column_statistics_for_table","url":"aws_api/glue.html#delete_column_statistics_for_table"},{"doc":"aws_api/glue","title":"delete_connection","content":"pub fn delete_connection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.delete_connection\naws_api/glue delete_connection","url":"aws_api/glue.html#delete_connection"},{"doc":"aws_api/glue","title":"delete_crawler","content":"pub fn delete_crawler(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.delete_crawler\naws_api/glue delete_crawler","url":"aws_api/glue.html#delete_crawler"},{"doc":"aws_api/glue","title":"delete_custom_entity_type","content":"pub fn delete_custom_entity_type(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.delete_custom_entity_type\naws_api/glue delete_custom_entity_type","url":"aws_api/glue.html#delete_custom_entity_type"},{"doc":"aws_api/glue","title":"delete_data_quality_ruleset","content":"pub fn delete_data_quality_ruleset(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.delete_data_quality_ruleset\naws_api/glue delete_data_quality_ruleset","url":"aws_api/glue.html#delete_data_quality_ruleset"},{"doc":"aws_api/glue","title":"delete_database","content":"pub fn delete_database(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.delete_database\naws_api/glue delete_database","url":"aws_api/glue.html#delete_database"},{"doc":"aws_api/glue","title":"delete_dev_endpoint","content":"pub fn delete_dev_endpoint(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.delete_dev_endpoint\naws_api/glue delete_dev_endpoint","url":"aws_api/glue.html#delete_dev_endpoint"},{"doc":"aws_api/glue","title":"delete_job","content":"pub fn delete_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.delete_job\naws_api/glue delete_job","url":"aws_api/glue.html#delete_job"},{"doc":"aws_api/glue","title":"delete_ml_transform","content":"pub fn delete_ml_transform(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.delete_ml_transform\naws_api/glue delete_ml_transform","url":"aws_api/glue.html#delete_ml_transform"},{"doc":"aws_api/glue","title":"delete_partition","content":"pub fn delete_partition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.delete_partition\naws_api/glue delete_partition","url":"aws_api/glue.html#delete_partition"},{"doc":"aws_api/glue","title":"delete_partition_index","content":"pub fn delete_partition_index(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.delete_partition_index\naws_api/glue delete_partition_index","url":"aws_api/glue.html#delete_partition_index"},{"doc":"aws_api/glue","title":"delete_registry","content":"pub fn delete_registry(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.delete_registry\naws_api/glue delete_registry","url":"aws_api/glue.html#delete_registry"},{"doc":"aws_api/glue","title":"delete_resource_policy","content":"pub fn delete_resource_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.delete_resource_policy\naws_api/glue delete_resource_policy","url":"aws_api/glue.html#delete_resource_policy"},{"doc":"aws_api/glue","title":"delete_schema","content":"pub fn delete_schema(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.delete_schema\naws_api/glue delete_schema","url":"aws_api/glue.html#delete_schema"},{"doc":"aws_api/glue","title":"delete_schema_versions","content":"pub fn delete_schema_versions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.delete_schema_versions\naws_api/glue delete_schema_versions","url":"aws_api/glue.html#delete_schema_versions"},{"doc":"aws_api/glue","title":"delete_security_configuration","content":"pub fn delete_security_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.delete_security_configuration\naws_api/glue delete_security_configuration","url":"aws_api/glue.html#delete_security_configuration"},{"doc":"aws_api/glue","title":"delete_session","content":"pub fn delete_session(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.delete_session\naws_api/glue delete_session","url":"aws_api/glue.html#delete_session"},{"doc":"aws_api/glue","title":"delete_table","content":"pub fn delete_table(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.delete_table\naws_api/glue delete_table","url":"aws_api/glue.html#delete_table"},{"doc":"aws_api/glue","title":"delete_table_optimizer","content":"pub fn delete_table_optimizer(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.delete_table_optimizer\naws_api/glue delete_table_optimizer","url":"aws_api/glue.html#delete_table_optimizer"},{"doc":"aws_api/glue","title":"delete_table_version","content":"pub fn delete_table_version(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.delete_table_version\naws_api/glue delete_table_version","url":"aws_api/glue.html#delete_table_version"},{"doc":"aws_api/glue","title":"delete_trigger","content":"pub fn delete_trigger(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.delete_trigger\naws_api/glue delete_trigger","url":"aws_api/glue.html#delete_trigger"},{"doc":"aws_api/glue","title":"delete_usage_profile","content":"pub fn delete_usage_profile(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.delete_usage_profile\naws_api/glue delete_usage_profile","url":"aws_api/glue.html#delete_usage_profile"},{"doc":"aws_api/glue","title":"delete_user_defined_function","content":"pub fn delete_user_defined_function(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.delete_user_defined_function\naws_api/glue delete_user_defined_function","url":"aws_api/glue.html#delete_user_defined_function"},{"doc":"aws_api/glue","title":"delete_workflow","content":"pub fn delete_workflow(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.delete_workflow\naws_api/glue delete_workflow","url":"aws_api/glue.html#delete_workflow"},{"doc":"aws_api/glue","title":"get_blueprint","content":"pub fn get_blueprint(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_blueprint\naws_api/glue get_blueprint","url":"aws_api/glue.html#get_blueprint"},{"doc":"aws_api/glue","title":"get_blueprint_run","content":"pub fn get_blueprint_run(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_blueprint_run\naws_api/glue get_blueprint_run","url":"aws_api/glue.html#get_blueprint_run"},{"doc":"aws_api/glue","title":"get_blueprint_runs","content":"pub fn get_blueprint_runs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_blueprint_runs\naws_api/glue get_blueprint_runs","url":"aws_api/glue.html#get_blueprint_runs"},{"doc":"aws_api/glue","title":"get_catalog_import_status","content":"pub fn get_catalog_import_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_catalog_import_status\naws_api/glue get_catalog_import_status","url":"aws_api/glue.html#get_catalog_import_status"},{"doc":"aws_api/glue","title":"get_classifier","content":"pub fn get_classifier(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_classifier\naws_api/glue get_classifier","url":"aws_api/glue.html#get_classifier"},{"doc":"aws_api/glue","title":"get_classifiers","content":"pub fn get_classifiers(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_classifiers\naws_api/glue get_classifiers","url":"aws_api/glue.html#get_classifiers"},{"doc":"aws_api/glue","title":"get_column_statistics_for_partition","content":"pub fn get_column_statistics_for_partition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_column_statistics_for_partition\naws_api/glue get_column_statistics_for_partition","url":"aws_api/glue.html#get_column_statistics_for_partition"},{"doc":"aws_api/glue","title":"get_column_statistics_for_table","content":"pub fn get_column_statistics_for_table(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_column_statistics_for_table\naws_api/glue get_column_statistics_for_table","url":"aws_api/glue.html#get_column_statistics_for_table"},{"doc":"aws_api/glue","title":"get_column_statistics_task_run","content":"pub fn get_column_statistics_task_run(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_column_statistics_task_run\naws_api/glue get_column_statistics_task_run","url":"aws_api/glue.html#get_column_statistics_task_run"},{"doc":"aws_api/glue","title":"get_column_statistics_task_runs","content":"pub fn get_column_statistics_task_runs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_column_statistics_task_runs\naws_api/glue get_column_statistics_task_runs","url":"aws_api/glue.html#get_column_statistics_task_runs"},{"doc":"aws_api/glue","title":"get_connection","content":"pub fn get_connection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_connection\naws_api/glue get_connection","url":"aws_api/glue.html#get_connection"},{"doc":"aws_api/glue","title":"get_connections","content":"pub fn get_connections(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_connections\naws_api/glue get_connections","url":"aws_api/glue.html#get_connections"},{"doc":"aws_api/glue","title":"get_crawler","content":"pub fn get_crawler(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_crawler\naws_api/glue get_crawler","url":"aws_api/glue.html#get_crawler"},{"doc":"aws_api/glue","title":"get_crawler_metrics","content":"pub fn get_crawler_metrics(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_crawler_metrics\naws_api/glue get_crawler_metrics","url":"aws_api/glue.html#get_crawler_metrics"},{"doc":"aws_api/glue","title":"get_crawlers","content":"pub fn get_crawlers(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_crawlers\naws_api/glue get_crawlers","url":"aws_api/glue.html#get_crawlers"},{"doc":"aws_api/glue","title":"get_custom_entity_type","content":"pub fn get_custom_entity_type(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_custom_entity_type\naws_api/glue get_custom_entity_type","url":"aws_api/glue.html#get_custom_entity_type"},{"doc":"aws_api/glue","title":"get_data_catalog_encryption_settings","content":"pub fn get_data_catalog_encryption_settings(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_data_catalog_encryption_settings\naws_api/glue get_data_catalog_encryption_settings","url":"aws_api/glue.html#get_data_catalog_encryption_settings"},{"doc":"aws_api/glue","title":"get_data_quality_model","content":"pub fn get_data_quality_model(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_data_quality_model\naws_api/glue get_data_quality_model","url":"aws_api/glue.html#get_data_quality_model"},{"doc":"aws_api/glue","title":"get_data_quality_model_result","content":"pub fn get_data_quality_model_result(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_data_quality_model_result\naws_api/glue get_data_quality_model_result","url":"aws_api/glue.html#get_data_quality_model_result"},{"doc":"aws_api/glue","title":"get_data_quality_result","content":"pub fn get_data_quality_result(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_data_quality_result\naws_api/glue get_data_quality_result","url":"aws_api/glue.html#get_data_quality_result"},{"doc":"aws_api/glue","title":"get_data_quality_rule_recommendation_run","content":"pub fn get_data_quality_rule_recommendation_run(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_data_quality_rule_recommendation_run\naws_api/glue get_data_quality_rule_recommendation_run","url":"aws_api/glue.html#get_data_quality_rule_recommendation_run"},{"doc":"aws_api/glue","title":"get_data_quality_ruleset","content":"pub fn get_data_quality_ruleset(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_data_quality_ruleset\naws_api/glue get_data_quality_ruleset","url":"aws_api/glue.html#get_data_quality_ruleset"},{"doc":"aws_api/glue","title":"get_data_quality_ruleset_evaluation_run","content":"pub fn get_data_quality_ruleset_evaluation_run(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_data_quality_ruleset_evaluation_run\naws_api/glue get_data_quality_ruleset_evaluation_run","url":"aws_api/glue.html#get_data_quality_ruleset_evaluation_run"},{"doc":"aws_api/glue","title":"get_database","content":"pub fn get_database(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_database\naws_api/glue get_database","url":"aws_api/glue.html#get_database"},{"doc":"aws_api/glue","title":"get_databases","content":"pub fn get_databases(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_databases\naws_api/glue get_databases","url":"aws_api/glue.html#get_databases"},{"doc":"aws_api/glue","title":"get_dataflow_graph","content":"pub fn get_dataflow_graph(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_dataflow_graph\naws_api/glue get_dataflow_graph","url":"aws_api/glue.html#get_dataflow_graph"},{"doc":"aws_api/glue","title":"get_dev_endpoint","content":"pub fn get_dev_endpoint(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_dev_endpoint\naws_api/glue get_dev_endpoint","url":"aws_api/glue.html#get_dev_endpoint"},{"doc":"aws_api/glue","title":"get_dev_endpoints","content":"pub fn get_dev_endpoints(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_dev_endpoints\naws_api/glue get_dev_endpoints","url":"aws_api/glue.html#get_dev_endpoints"},{"doc":"aws_api/glue","title":"get_job","content":"pub fn get_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_job\naws_api/glue get_job","url":"aws_api/glue.html#get_job"},{"doc":"aws_api/glue","title":"get_job_bookmark","content":"pub fn get_job_bookmark(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_job_bookmark\naws_api/glue get_job_bookmark","url":"aws_api/glue.html#get_job_bookmark"},{"doc":"aws_api/glue","title":"get_job_run","content":"pub fn get_job_run(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_job_run\naws_api/glue get_job_run","url":"aws_api/glue.html#get_job_run"},{"doc":"aws_api/glue","title":"get_job_runs","content":"pub fn get_job_runs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_job_runs\naws_api/glue get_job_runs","url":"aws_api/glue.html#get_job_runs"},{"doc":"aws_api/glue","title":"get_jobs","content":"pub fn get_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_jobs\naws_api/glue get_jobs","url":"aws_api/glue.html#get_jobs"},{"doc":"aws_api/glue","title":"get_mapping","content":"pub fn get_mapping(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_mapping\naws_api/glue get_mapping","url":"aws_api/glue.html#get_mapping"},{"doc":"aws_api/glue","title":"get_ml_task_run","content":"pub fn get_ml_task_run(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_ml_task_run\naws_api/glue get_ml_task_run","url":"aws_api/glue.html#get_ml_task_run"},{"doc":"aws_api/glue","title":"get_ml_task_runs","content":"pub fn get_ml_task_runs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_ml_task_runs\naws_api/glue get_ml_task_runs","url":"aws_api/glue.html#get_ml_task_runs"},{"doc":"aws_api/glue","title":"get_ml_transform","content":"pub fn get_ml_transform(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_ml_transform\naws_api/glue get_ml_transform","url":"aws_api/glue.html#get_ml_transform"},{"doc":"aws_api/glue","title":"get_ml_transforms","content":"pub fn get_ml_transforms(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_ml_transforms\naws_api/glue get_ml_transforms","url":"aws_api/glue.html#get_ml_transforms"},{"doc":"aws_api/glue","title":"get_partition","content":"pub fn get_partition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_partition\naws_api/glue get_partition","url":"aws_api/glue.html#get_partition"},{"doc":"aws_api/glue","title":"get_partition_indexes","content":"pub fn get_partition_indexes(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_partition_indexes\naws_api/glue get_partition_indexes","url":"aws_api/glue.html#get_partition_indexes"},{"doc":"aws_api/glue","title":"get_partitions","content":"pub fn get_partitions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_partitions\naws_api/glue get_partitions","url":"aws_api/glue.html#get_partitions"},{"doc":"aws_api/glue","title":"get_plan","content":"pub fn get_plan(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_plan\naws_api/glue get_plan","url":"aws_api/glue.html#get_plan"},{"doc":"aws_api/glue","title":"get_registry","content":"pub fn get_registry(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_registry\naws_api/glue get_registry","url":"aws_api/glue.html#get_registry"},{"doc":"aws_api/glue","title":"get_resource_policies","content":"pub fn get_resource_policies(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_resource_policies\naws_api/glue get_resource_policies","url":"aws_api/glue.html#get_resource_policies"},{"doc":"aws_api/glue","title":"get_resource_policy","content":"pub fn get_resource_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_resource_policy\naws_api/glue get_resource_policy","url":"aws_api/glue.html#get_resource_policy"},{"doc":"aws_api/glue","title":"get_schema","content":"pub fn get_schema(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_schema\naws_api/glue get_schema","url":"aws_api/glue.html#get_schema"},{"doc":"aws_api/glue","title":"get_schema_by_definition","content":"pub fn get_schema_by_definition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_schema_by_definition\naws_api/glue get_schema_by_definition","url":"aws_api/glue.html#get_schema_by_definition"},{"doc":"aws_api/glue","title":"get_schema_version","content":"pub fn get_schema_version(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_schema_version\naws_api/glue get_schema_version","url":"aws_api/glue.html#get_schema_version"},{"doc":"aws_api/glue","title":"get_schema_versions_diff","content":"pub fn get_schema_versions_diff(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_schema_versions_diff\naws_api/glue get_schema_versions_diff","url":"aws_api/glue.html#get_schema_versions_diff"},{"doc":"aws_api/glue","title":"get_security_configuration","content":"pub fn get_security_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_security_configuration\naws_api/glue get_security_configuration","url":"aws_api/glue.html#get_security_configuration"},{"doc":"aws_api/glue","title":"get_security_configurations","content":"pub fn get_security_configurations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_security_configurations\naws_api/glue get_security_configurations","url":"aws_api/glue.html#get_security_configurations"},{"doc":"aws_api/glue","title":"get_session","content":"pub fn get_session(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_session\naws_api/glue get_session","url":"aws_api/glue.html#get_session"},{"doc":"aws_api/glue","title":"get_statement","content":"pub fn get_statement(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_statement\naws_api/glue get_statement","url":"aws_api/glue.html#get_statement"},{"doc":"aws_api/glue","title":"get_table","content":"pub fn get_table(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_table\naws_api/glue get_table","url":"aws_api/glue.html#get_table"},{"doc":"aws_api/glue","title":"get_table_optimizer","content":"pub fn get_table_optimizer(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_table_optimizer\naws_api/glue get_table_optimizer","url":"aws_api/glue.html#get_table_optimizer"},{"doc":"aws_api/glue","title":"get_table_version","content":"pub fn get_table_version(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_table_version\naws_api/glue get_table_version","url":"aws_api/glue.html#get_table_version"},{"doc":"aws_api/glue","title":"get_table_versions","content":"pub fn get_table_versions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_table_versions\naws_api/glue get_table_versions","url":"aws_api/glue.html#get_table_versions"},{"doc":"aws_api/glue","title":"get_tables","content":"pub fn get_tables(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_tables\naws_api/glue get_tables","url":"aws_api/glue.html#get_tables"},{"doc":"aws_api/glue","title":"get_tags","content":"pub fn get_tags(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_tags\naws_api/glue get_tags","url":"aws_api/glue.html#get_tags"},{"doc":"aws_api/glue","title":"get_trigger","content":"pub fn get_trigger(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_trigger\naws_api/glue get_trigger","url":"aws_api/glue.html#get_trigger"},{"doc":"aws_api/glue","title":"get_triggers","content":"pub fn get_triggers(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_triggers\naws_api/glue get_triggers","url":"aws_api/glue.html#get_triggers"},{"doc":"aws_api/glue","title":"get_unfiltered_partition_metadata","content":"pub fn get_unfiltered_partition_metadata(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_unfiltered_partition_metadata\naws_api/glue get_unfiltered_partition_metadata","url":"aws_api/glue.html#get_unfiltered_partition_metadata"},{"doc":"aws_api/glue","title":"get_unfiltered_partitions_metadata","content":"pub fn get_unfiltered_partitions_metadata(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_unfiltered_partitions_metadata\naws_api/glue get_unfiltered_partitions_metadata","url":"aws_api/glue.html#get_unfiltered_partitions_metadata"},{"doc":"aws_api/glue","title":"get_unfiltered_table_metadata","content":"pub fn get_unfiltered_table_metadata(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_unfiltered_table_metadata\naws_api/glue get_unfiltered_table_metadata","url":"aws_api/glue.html#get_unfiltered_table_metadata"},{"doc":"aws_api/glue","title":"get_usage_profile","content":"pub fn get_usage_profile(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_usage_profile\naws_api/glue get_usage_profile","url":"aws_api/glue.html#get_usage_profile"},{"doc":"aws_api/glue","title":"get_user_defined_function","content":"pub fn get_user_defined_function(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_user_defined_function\naws_api/glue get_user_defined_function","url":"aws_api/glue.html#get_user_defined_function"},{"doc":"aws_api/glue","title":"get_user_defined_functions","content":"pub fn get_user_defined_functions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_user_defined_functions\naws_api/glue get_user_defined_functions","url":"aws_api/glue.html#get_user_defined_functions"},{"doc":"aws_api/glue","title":"get_workflow","content":"pub fn get_workflow(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_workflow\naws_api/glue get_workflow","url":"aws_api/glue.html#get_workflow"},{"doc":"aws_api/glue","title":"get_workflow_run","content":"pub fn get_workflow_run(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_workflow_run\naws_api/glue get_workflow_run","url":"aws_api/glue.html#get_workflow_run"},{"doc":"aws_api/glue","title":"get_workflow_run_properties","content":"pub fn get_workflow_run_properties(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_workflow_run_properties\naws_api/glue get_workflow_run_properties","url":"aws_api/glue.html#get_workflow_run_properties"},{"doc":"aws_api/glue","title":"get_workflow_runs","content":"pub fn get_workflow_runs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.get_workflow_runs\naws_api/glue get_workflow_runs","url":"aws_api/glue.html#get_workflow_runs"},{"doc":"aws_api/glue","title":"import_catalog_to_glue","content":"pub fn import_catalog_to_glue(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.import_catalog_to_glue\naws_api/glue import_catalog_to_glue","url":"aws_api/glue.html#import_catalog_to_glue"},{"doc":"aws_api/glue","title":"list_blueprints","content":"pub fn list_blueprints(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.list_blueprints\naws_api/glue list_blueprints","url":"aws_api/glue.html#list_blueprints"},{"doc":"aws_api/glue","title":"list_column_statistics_task_runs","content":"pub fn list_column_statistics_task_runs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.list_column_statistics_task_runs\naws_api/glue list_column_statistics_task_runs","url":"aws_api/glue.html#list_column_statistics_task_runs"},{"doc":"aws_api/glue","title":"list_crawlers","content":"pub fn list_crawlers(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.list_crawlers\naws_api/glue list_crawlers","url":"aws_api/glue.html#list_crawlers"},{"doc":"aws_api/glue","title":"list_crawls","content":"pub fn list_crawls(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.list_crawls\naws_api/glue list_crawls","url":"aws_api/glue.html#list_crawls"},{"doc":"aws_api/glue","title":"list_custom_entity_types","content":"pub fn list_custom_entity_types(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.list_custom_entity_types\naws_api/glue list_custom_entity_types","url":"aws_api/glue.html#list_custom_entity_types"},{"doc":"aws_api/glue","title":"list_data_quality_results","content":"pub fn list_data_quality_results(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.list_data_quality_results\naws_api/glue list_data_quality_results","url":"aws_api/glue.html#list_data_quality_results"},{"doc":"aws_api/glue","title":"list_data_quality_rule_recommendation_runs","content":"pub fn list_data_quality_rule_recommendation_runs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.list_data_quality_rule_recommendation_runs\naws_api/glue list_data_quality_rule_recommendation_runs","url":"aws_api/glue.html#list_data_quality_rule_recommendation_runs"},{"doc":"aws_api/glue","title":"list_data_quality_ruleset_evaluation_runs","content":"pub fn list_data_quality_ruleset_evaluation_runs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.list_data_quality_ruleset_evaluation_runs\naws_api/glue list_data_quality_ruleset_evaluation_runs","url":"aws_api/glue.html#list_data_quality_ruleset_evaluation_runs"},{"doc":"aws_api/glue","title":"list_data_quality_rulesets","content":"pub fn list_data_quality_rulesets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.list_data_quality_rulesets\naws_api/glue list_data_quality_rulesets","url":"aws_api/glue.html#list_data_quality_rulesets"},{"doc":"aws_api/glue","title":"list_data_quality_statistic_annotations","content":"pub fn list_data_quality_statistic_annotations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.list_data_quality_statistic_annotations\naws_api/glue list_data_quality_statistic_annotations","url":"aws_api/glue.html#list_data_quality_statistic_annotations"},{"doc":"aws_api/glue","title":"list_data_quality_statistics","content":"pub fn list_data_quality_statistics(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.list_data_quality_statistics\naws_api/glue list_data_quality_statistics","url":"aws_api/glue.html#list_data_quality_statistics"},{"doc":"aws_api/glue","title":"list_dev_endpoints","content":"pub fn list_dev_endpoints(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.list_dev_endpoints\naws_api/glue list_dev_endpoints","url":"aws_api/glue.html#list_dev_endpoints"},{"doc":"aws_api/glue","title":"list_jobs","content":"pub fn list_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.list_jobs\naws_api/glue list_jobs","url":"aws_api/glue.html#list_jobs"},{"doc":"aws_api/glue","title":"list_ml_transforms","content":"pub fn list_ml_transforms(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.list_ml_transforms\naws_api/glue list_ml_transforms","url":"aws_api/glue.html#list_ml_transforms"},{"doc":"aws_api/glue","title":"list_registries","content":"pub fn list_registries(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.list_registries\naws_api/glue list_registries","url":"aws_api/glue.html#list_registries"},{"doc":"aws_api/glue","title":"list_schema_versions","content":"pub fn list_schema_versions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.list_schema_versions\naws_api/glue list_schema_versions","url":"aws_api/glue.html#list_schema_versions"},{"doc":"aws_api/glue","title":"list_schemas","content":"pub fn list_schemas(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.list_schemas\naws_api/glue list_schemas","url":"aws_api/glue.html#list_schemas"},{"doc":"aws_api/glue","title":"list_sessions","content":"pub fn list_sessions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.list_sessions\naws_api/glue list_sessions","url":"aws_api/glue.html#list_sessions"},{"doc":"aws_api/glue","title":"list_statements","content":"pub fn list_statements(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.list_statements\naws_api/glue list_statements","url":"aws_api/glue.html#list_statements"},{"doc":"aws_api/glue","title":"list_table_optimizer_runs","content":"pub fn list_table_optimizer_runs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.list_table_optimizer_runs\naws_api/glue list_table_optimizer_runs","url":"aws_api/glue.html#list_table_optimizer_runs"},{"doc":"aws_api/glue","title":"list_triggers","content":"pub fn list_triggers(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.list_triggers\naws_api/glue list_triggers","url":"aws_api/glue.html#list_triggers"},{"doc":"aws_api/glue","title":"list_usage_profiles","content":"pub fn list_usage_profiles(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.list_usage_profiles\naws_api/glue list_usage_profiles","url":"aws_api/glue.html#list_usage_profiles"},{"doc":"aws_api/glue","title":"list_workflows","content":"pub fn list_workflows(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.list_workflows\naws_api/glue list_workflows","url":"aws_api/glue.html#list_workflows"},{"doc":"aws_api/glue","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/glue.new\naws_api/glue new","url":"aws_api/glue.html#new"},{"doc":"aws_api/glue","title":"put_data_catalog_encryption_settings","content":"pub fn put_data_catalog_encryption_settings(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.put_data_catalog_encryption_settings\naws_api/glue put_data_catalog_encryption_settings","url":"aws_api/glue.html#put_data_catalog_encryption_settings"},{"doc":"aws_api/glue","title":"put_data_quality_profile_annotation","content":"pub fn put_data_quality_profile_annotation(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.put_data_quality_profile_annotation\naws_api/glue put_data_quality_profile_annotation","url":"aws_api/glue.html#put_data_quality_profile_annotation"},{"doc":"aws_api/glue","title":"put_resource_policy","content":"pub fn put_resource_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.put_resource_policy\naws_api/glue put_resource_policy","url":"aws_api/glue.html#put_resource_policy"},{"doc":"aws_api/glue","title":"put_schema_version_metadata","content":"pub fn put_schema_version_metadata(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.put_schema_version_metadata\naws_api/glue put_schema_version_metadata","url":"aws_api/glue.html#put_schema_version_metadata"},{"doc":"aws_api/glue","title":"put_workflow_run_properties","content":"pub fn put_workflow_run_properties(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.put_workflow_run_properties\naws_api/glue put_workflow_run_properties","url":"aws_api/glue.html#put_workflow_run_properties"},{"doc":"aws_api/glue","title":"query_schema_version_metadata","content":"pub fn query_schema_version_metadata(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.query_schema_version_metadata\naws_api/glue query_schema_version_metadata","url":"aws_api/glue.html#query_schema_version_metadata"},{"doc":"aws_api/glue","title":"register_schema_version","content":"pub fn register_schema_version(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.register_schema_version\naws_api/glue register_schema_version","url":"aws_api/glue.html#register_schema_version"},{"doc":"aws_api/glue","title":"remove_schema_version_metadata","content":"pub fn remove_schema_version_metadata(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.remove_schema_version_metadata\naws_api/glue remove_schema_version_metadata","url":"aws_api/glue.html#remove_schema_version_metadata"},{"doc":"aws_api/glue","title":"reset_job_bookmark","content":"pub fn reset_job_bookmark(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.reset_job_bookmark\naws_api/glue reset_job_bookmark","url":"aws_api/glue.html#reset_job_bookmark"},{"doc":"aws_api/glue","title":"resume_workflow_run","content":"pub fn resume_workflow_run(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.resume_workflow_run\naws_api/glue resume_workflow_run","url":"aws_api/glue.html#resume_workflow_run"},{"doc":"aws_api/glue","title":"run_statement","content":"pub fn run_statement(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.run_statement\naws_api/glue run_statement","url":"aws_api/glue.html#run_statement"},{"doc":"aws_api/glue","title":"search_tables","content":"pub fn search_tables(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.search_tables\naws_api/glue search_tables","url":"aws_api/glue.html#search_tables"},{"doc":"aws_api/glue","title":"start_blueprint_run","content":"pub fn start_blueprint_run(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.start_blueprint_run\naws_api/glue start_blueprint_run","url":"aws_api/glue.html#start_blueprint_run"},{"doc":"aws_api/glue","title":"start_column_statistics_task_run","content":"pub fn start_column_statistics_task_run(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.start_column_statistics_task_run\naws_api/glue start_column_statistics_task_run","url":"aws_api/glue.html#start_column_statistics_task_run"},{"doc":"aws_api/glue","title":"start_crawler","content":"pub fn start_crawler(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.start_crawler\naws_api/glue start_crawler","url":"aws_api/glue.html#start_crawler"},{"doc":"aws_api/glue","title":"start_crawler_schedule","content":"pub fn start_crawler_schedule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.start_crawler_schedule\naws_api/glue start_crawler_schedule","url":"aws_api/glue.html#start_crawler_schedule"},{"doc":"aws_api/glue","title":"start_data_quality_rule_recommendation_run","content":"pub fn start_data_quality_rule_recommendation_run(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.start_data_quality_rule_recommendation_run\naws_api/glue start_data_quality_rule_recommendation_run","url":"aws_api/glue.html#start_data_quality_rule_recommendation_run"},{"doc":"aws_api/glue","title":"start_data_quality_ruleset_evaluation_run","content":"pub fn start_data_quality_ruleset_evaluation_run(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.start_data_quality_ruleset_evaluation_run\naws_api/glue start_data_quality_ruleset_evaluation_run","url":"aws_api/glue.html#start_data_quality_ruleset_evaluation_run"},{"doc":"aws_api/glue","title":"start_export_labels_task_run","content":"pub fn start_export_labels_task_run(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.start_export_labels_task_run\naws_api/glue start_export_labels_task_run","url":"aws_api/glue.html#start_export_labels_task_run"},{"doc":"aws_api/glue","title":"start_import_labels_task_run","content":"pub fn start_import_labels_task_run(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.start_import_labels_task_run\naws_api/glue start_import_labels_task_run","url":"aws_api/glue.html#start_import_labels_task_run"},{"doc":"aws_api/glue","title":"start_job_run","content":"pub fn start_job_run(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.start_job_run\naws_api/glue start_job_run","url":"aws_api/glue.html#start_job_run"},{"doc":"aws_api/glue","title":"start_ml_evaluation_task_run","content":"pub fn start_ml_evaluation_task_run(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.start_ml_evaluation_task_run\naws_api/glue start_ml_evaluation_task_run","url":"aws_api/glue.html#start_ml_evaluation_task_run"},{"doc":"aws_api/glue","title":"start_ml_labeling_set_generation_task_run","content":"pub fn start_ml_labeling_set_generation_task_run(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.start_ml_labeling_set_generation_task_run\naws_api/glue start_ml_labeling_set_generation_task_run","url":"aws_api/glue.html#start_ml_labeling_set_generation_task_run"},{"doc":"aws_api/glue","title":"start_trigger","content":"pub fn start_trigger(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.start_trigger\naws_api/glue start_trigger","url":"aws_api/glue.html#start_trigger"},{"doc":"aws_api/glue","title":"start_workflow_run","content":"pub fn start_workflow_run(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.start_workflow_run\naws_api/glue start_workflow_run","url":"aws_api/glue.html#start_workflow_run"},{"doc":"aws_api/glue","title":"stop_column_statistics_task_run","content":"pub fn stop_column_statistics_task_run(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.stop_column_statistics_task_run\naws_api/glue stop_column_statistics_task_run","url":"aws_api/glue.html#stop_column_statistics_task_run"},{"doc":"aws_api/glue","title":"stop_crawler","content":"pub fn stop_crawler(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.stop_crawler\naws_api/glue stop_crawler","url":"aws_api/glue.html#stop_crawler"},{"doc":"aws_api/glue","title":"stop_crawler_schedule","content":"pub fn stop_crawler_schedule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.stop_crawler_schedule\naws_api/glue stop_crawler_schedule","url":"aws_api/glue.html#stop_crawler_schedule"},{"doc":"aws_api/glue","title":"stop_session","content":"pub fn stop_session(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.stop_session\naws_api/glue stop_session","url":"aws_api/glue.html#stop_session"},{"doc":"aws_api/glue","title":"stop_trigger","content":"pub fn stop_trigger(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.stop_trigger\naws_api/glue stop_trigger","url":"aws_api/glue.html#stop_trigger"},{"doc":"aws_api/glue","title":"stop_workflow_run","content":"pub fn stop_workflow_run(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.stop_workflow_run\naws_api/glue stop_workflow_run","url":"aws_api/glue.html#stop_workflow_run"},{"doc":"aws_api/glue","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.tag_resource\naws_api/glue tag_resource","url":"aws_api/glue.html#tag_resource"},{"doc":"aws_api/glue","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.untag_resource\naws_api/glue untag_resource","url":"aws_api/glue.html#untag_resource"},{"doc":"aws_api/glue","title":"update_blueprint","content":"pub fn update_blueprint(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.update_blueprint\naws_api/glue update_blueprint","url":"aws_api/glue.html#update_blueprint"},{"doc":"aws_api/glue","title":"update_classifier","content":"pub fn update_classifier(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.update_classifier\naws_api/glue update_classifier","url":"aws_api/glue.html#update_classifier"},{"doc":"aws_api/glue","title":"update_column_statistics_for_partition","content":"pub fn update_column_statistics_for_partition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.update_column_statistics_for_partition\naws_api/glue update_column_statistics_for_partition","url":"aws_api/glue.html#update_column_statistics_for_partition"},{"doc":"aws_api/glue","title":"update_column_statistics_for_table","content":"pub fn update_column_statistics_for_table(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.update_column_statistics_for_table\naws_api/glue update_column_statistics_for_table","url":"aws_api/glue.html#update_column_statistics_for_table"},{"doc":"aws_api/glue","title":"update_connection","content":"pub fn update_connection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.update_connection\naws_api/glue update_connection","url":"aws_api/glue.html#update_connection"},{"doc":"aws_api/glue","title":"update_crawler","content":"pub fn update_crawler(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.update_crawler\naws_api/glue update_crawler","url":"aws_api/glue.html#update_crawler"},{"doc":"aws_api/glue","title":"update_crawler_schedule","content":"pub fn update_crawler_schedule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.update_crawler_schedule\naws_api/glue update_crawler_schedule","url":"aws_api/glue.html#update_crawler_schedule"},{"doc":"aws_api/glue","title":"update_data_quality_ruleset","content":"pub fn update_data_quality_ruleset(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.update_data_quality_ruleset\naws_api/glue update_data_quality_ruleset","url":"aws_api/glue.html#update_data_quality_ruleset"},{"doc":"aws_api/glue","title":"update_database","content":"pub fn update_database(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.update_database\naws_api/glue update_database","url":"aws_api/glue.html#update_database"},{"doc":"aws_api/glue","title":"update_dev_endpoint","content":"pub fn update_dev_endpoint(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.update_dev_endpoint\naws_api/glue update_dev_endpoint","url":"aws_api/glue.html#update_dev_endpoint"},{"doc":"aws_api/glue","title":"update_job","content":"pub fn update_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.update_job\naws_api/glue update_job","url":"aws_api/glue.html#update_job"},{"doc":"aws_api/glue","title":"update_job_from_source_control","content":"pub fn update_job_from_source_control(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.update_job_from_source_control\naws_api/glue update_job_from_source_control","url":"aws_api/glue.html#update_job_from_source_control"},{"doc":"aws_api/glue","title":"update_ml_transform","content":"pub fn update_ml_transform(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.update_ml_transform\naws_api/glue update_ml_transform","url":"aws_api/glue.html#update_ml_transform"},{"doc":"aws_api/glue","title":"update_partition","content":"pub fn update_partition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.update_partition\naws_api/glue update_partition","url":"aws_api/glue.html#update_partition"},{"doc":"aws_api/glue","title":"update_registry","content":"pub fn update_registry(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.update_registry\naws_api/glue update_registry","url":"aws_api/glue.html#update_registry"},{"doc":"aws_api/glue","title":"update_schema","content":"pub fn update_schema(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.update_schema\naws_api/glue update_schema","url":"aws_api/glue.html#update_schema"},{"doc":"aws_api/glue","title":"update_source_control_from_job","content":"pub fn update_source_control_from_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.update_source_control_from_job\naws_api/glue update_source_control_from_job","url":"aws_api/glue.html#update_source_control_from_job"},{"doc":"aws_api/glue","title":"update_table","content":"pub fn update_table(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.update_table\naws_api/glue update_table","url":"aws_api/glue.html#update_table"},{"doc":"aws_api/glue","title":"update_table_optimizer","content":"pub fn update_table_optimizer(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.update_table_optimizer\naws_api/glue update_table_optimizer","url":"aws_api/glue.html#update_table_optimizer"},{"doc":"aws_api/glue","title":"update_trigger","content":"pub fn update_trigger(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.update_trigger\naws_api/glue update_trigger","url":"aws_api/glue.html#update_trigger"},{"doc":"aws_api/glue","title":"update_usage_profile","content":"pub fn update_usage_profile(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.update_usage_profile\naws_api/glue update_usage_profile","url":"aws_api/glue.html#update_usage_profile"},{"doc":"aws_api/glue","title":"update_user_defined_function","content":"pub fn update_user_defined_function(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.update_user_defined_function\naws_api/glue update_user_defined_function","url":"aws_api/glue.html#update_user_defined_function"},{"doc":"aws_api/glue","title":"update_workflow","content":"pub fn update_workflow(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/glue.update_workflow\naws_api/glue update_workflow","url":"aws_api/glue.html#update_workflow"},{"doc":"aws_api/glue","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/glue.with_custom_endpoint\naws_api/glue with_custom_endpoint","url":"aws_api/glue.html#with_custom_endpoint"},{"doc":"aws_api/glue","title":"aws_api/glue","content":"","url":"aws_api/glue.html"},{"doc":"aws_api/grafana","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/grafana.Client\naws_api/grafana Client","url":"aws_api/grafana.html#Client"},{"doc":"aws_api/grafana","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/grafana.list_tags_for_resource\naws_api/grafana list_tags_for_resource","url":"aws_api/grafana.html#list_tags_for_resource"},{"doc":"aws_api/grafana","title":"list_versions","content":"pub fn list_versions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/grafana.list_versions\naws_api/grafana list_versions","url":"aws_api/grafana.html#list_versions"},{"doc":"aws_api/grafana","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/grafana.new\naws_api/grafana new","url":"aws_api/grafana.html#new"},{"doc":"aws_api/grafana","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/grafana.tag_resource\naws_api/grafana tag_resource","url":"aws_api/grafana.html#tag_resource"},{"doc":"aws_api/grafana","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/grafana.untag_resource\naws_api/grafana untag_resource","url":"aws_api/grafana.html#untag_resource"},{"doc":"aws_api/grafana","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/grafana.with_custom_endpoint\naws_api/grafana with_custom_endpoint","url":"aws_api/grafana.html#with_custom_endpoint"},{"doc":"aws_api/grafana","title":"aws_api/grafana","content":"","url":"aws_api/grafana.html"},{"doc":"aws_api/greengrass","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/greengrass.Client\naws_api/greengrass Client","url":"aws_api/greengrass.html#Client"},{"doc":"aws_api/greengrass","title":"associate_role_to_group","content":"pub fn associate_role_to_group(\n  client: Client,\n  group_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.associate_role_to_group\naws_api/greengrass associate_role_to_group","url":"aws_api/greengrass.html#associate_role_to_group"},{"doc":"aws_api/greengrass","title":"associate_service_role_to_account","content":"pub fn associate_service_role_to_account(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.associate_service_role_to_account\naws_api/greengrass associate_service_role_to_account","url":"aws_api/greengrass.html#associate_service_role_to_account"},{"doc":"aws_api/greengrass","title":"create_connector_definition","content":"pub fn create_connector_definition(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.create_connector_definition\naws_api/greengrass create_connector_definition","url":"aws_api/greengrass.html#create_connector_definition"},{"doc":"aws_api/greengrass","title":"create_connector_definition_version","content":"pub fn create_connector_definition_version(\n  client: Client,\n  connector_definition_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.create_connector_definition_version\naws_api/greengrass create_connector_definition_version","url":"aws_api/greengrass.html#create_connector_definition_version"},{"doc":"aws_api/greengrass","title":"create_core_definition","content":"pub fn create_core_definition(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.create_core_definition\naws_api/greengrass create_core_definition","url":"aws_api/greengrass.html#create_core_definition"},{"doc":"aws_api/greengrass","title":"create_core_definition_version","content":"pub fn create_core_definition_version(\n  client: Client,\n  core_definition_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.create_core_definition_version\naws_api/greengrass create_core_definition_version","url":"aws_api/greengrass.html#create_core_definition_version"},{"doc":"aws_api/greengrass","title":"create_deployment","content":"pub fn create_deployment(\n  client: Client,\n  group_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.create_deployment\naws_api/greengrass create_deployment","url":"aws_api/greengrass.html#create_deployment"},{"doc":"aws_api/greengrass","title":"create_device_definition","content":"pub fn create_device_definition(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.create_device_definition\naws_api/greengrass create_device_definition","url":"aws_api/greengrass.html#create_device_definition"},{"doc":"aws_api/greengrass","title":"create_device_definition_version","content":"pub fn create_device_definition_version(\n  client: Client,\n  device_definition_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.create_device_definition_version\naws_api/greengrass create_device_definition_version","url":"aws_api/greengrass.html#create_device_definition_version"},{"doc":"aws_api/greengrass","title":"create_function_definition","content":"pub fn create_function_definition(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.create_function_definition\naws_api/greengrass create_function_definition","url":"aws_api/greengrass.html#create_function_definition"},{"doc":"aws_api/greengrass","title":"create_function_definition_version","content":"pub fn create_function_definition_version(\n  client: Client,\n  function_definition_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.create_function_definition_version\naws_api/greengrass create_function_definition_version","url":"aws_api/greengrass.html#create_function_definition_version"},{"doc":"aws_api/greengrass","title":"create_group","content":"pub fn create_group(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.create_group\naws_api/greengrass create_group","url":"aws_api/greengrass.html#create_group"},{"doc":"aws_api/greengrass","title":"create_group_certificate_authority","content":"pub fn create_group_certificate_authority(\n  client: Client,\n  group_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.create_group_certificate_authority\naws_api/greengrass create_group_certificate_authority","url":"aws_api/greengrass.html#create_group_certificate_authority"},{"doc":"aws_api/greengrass","title":"create_group_version","content":"pub fn create_group_version(\n  client: Client,\n  group_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.create_group_version\naws_api/greengrass create_group_version","url":"aws_api/greengrass.html#create_group_version"},{"doc":"aws_api/greengrass","title":"create_logger_definition","content":"pub fn create_logger_definition(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.create_logger_definition\naws_api/greengrass create_logger_definition","url":"aws_api/greengrass.html#create_logger_definition"},{"doc":"aws_api/greengrass","title":"create_logger_definition_version","content":"pub fn create_logger_definition_version(\n  client: Client,\n  logger_definition_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.create_logger_definition_version\naws_api/greengrass create_logger_definition_version","url":"aws_api/greengrass.html#create_logger_definition_version"},{"doc":"aws_api/greengrass","title":"create_resource_definition","content":"pub fn create_resource_definition(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.create_resource_definition\naws_api/greengrass create_resource_definition","url":"aws_api/greengrass.html#create_resource_definition"},{"doc":"aws_api/greengrass","title":"create_resource_definition_version","content":"pub fn create_resource_definition_version(\n  client: Client,\n  resource_definition_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.create_resource_definition_version\naws_api/greengrass create_resource_definition_version","url":"aws_api/greengrass.html#create_resource_definition_version"},{"doc":"aws_api/greengrass","title":"create_software_update_job","content":"pub fn create_software_update_job(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.create_software_update_job\naws_api/greengrass create_software_update_job","url":"aws_api/greengrass.html#create_software_update_job"},{"doc":"aws_api/greengrass","title":"create_subscription_definition","content":"pub fn create_subscription_definition(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.create_subscription_definition\naws_api/greengrass create_subscription_definition","url":"aws_api/greengrass.html#create_subscription_definition"},{"doc":"aws_api/greengrass","title":"create_subscription_definition_version","content":"pub fn create_subscription_definition_version(\n  client: Client,\n  subscription_definition_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.create_subscription_definition_version\naws_api/greengrass create_subscription_definition_version","url":"aws_api/greengrass.html#create_subscription_definition_version"},{"doc":"aws_api/greengrass","title":"delete_connector_definition","content":"pub fn delete_connector_definition(\n  client: Client,\n  connector_definition_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.delete_connector_definition\naws_api/greengrass delete_connector_definition","url":"aws_api/greengrass.html#delete_connector_definition"},{"doc":"aws_api/greengrass","title":"delete_core_definition","content":"pub fn delete_core_definition(\n  client: Client,\n  core_definition_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.delete_core_definition\naws_api/greengrass delete_core_definition","url":"aws_api/greengrass.html#delete_core_definition"},{"doc":"aws_api/greengrass","title":"delete_device_definition","content":"pub fn delete_device_definition(\n  client: Client,\n  device_definition_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.delete_device_definition\naws_api/greengrass delete_device_definition","url":"aws_api/greengrass.html#delete_device_definition"},{"doc":"aws_api/greengrass","title":"delete_function_definition","content":"pub fn delete_function_definition(\n  client: Client,\n  function_definition_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.delete_function_definition\naws_api/greengrass delete_function_definition","url":"aws_api/greengrass.html#delete_function_definition"},{"doc":"aws_api/greengrass","title":"delete_group","content":"pub fn delete_group(\n  client: Client,\n  group_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.delete_group\naws_api/greengrass delete_group","url":"aws_api/greengrass.html#delete_group"},{"doc":"aws_api/greengrass","title":"delete_logger_definition","content":"pub fn delete_logger_definition(\n  client: Client,\n  logger_definition_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.delete_logger_definition\naws_api/greengrass delete_logger_definition","url":"aws_api/greengrass.html#delete_logger_definition"},{"doc":"aws_api/greengrass","title":"delete_resource_definition","content":"pub fn delete_resource_definition(\n  client: Client,\n  resource_definition_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.delete_resource_definition\naws_api/greengrass delete_resource_definition","url":"aws_api/greengrass.html#delete_resource_definition"},{"doc":"aws_api/greengrass","title":"delete_subscription_definition","content":"pub fn delete_subscription_definition(\n  client: Client,\n  subscription_definition_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.delete_subscription_definition\naws_api/greengrass delete_subscription_definition","url":"aws_api/greengrass.html#delete_subscription_definition"},{"doc":"aws_api/greengrass","title":"disassociate_role_from_group","content":"pub fn disassociate_role_from_group(\n  client: Client,\n  group_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.disassociate_role_from_group\naws_api/greengrass disassociate_role_from_group","url":"aws_api/greengrass.html#disassociate_role_from_group"},{"doc":"aws_api/greengrass","title":"disassociate_service_role_from_account","content":"pub fn disassociate_service_role_from_account(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.disassociate_service_role_from_account\naws_api/greengrass disassociate_service_role_from_account","url":"aws_api/greengrass.html#disassociate_service_role_from_account"},{"doc":"aws_api/greengrass","title":"get_associated_role","content":"pub fn get_associated_role(\n  client: Client,\n  group_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.get_associated_role\naws_api/greengrass get_associated_role","url":"aws_api/greengrass.html#get_associated_role"},{"doc":"aws_api/greengrass","title":"get_bulk_deployment_status","content":"pub fn get_bulk_deployment_status(\n  client: Client,\n  bulk_deployment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.get_bulk_deployment_status\naws_api/greengrass get_bulk_deployment_status","url":"aws_api/greengrass.html#get_bulk_deployment_status"},{"doc":"aws_api/greengrass","title":"get_connectivity_info","content":"pub fn get_connectivity_info(\n  client: Client,\n  thing_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.get_connectivity_info\naws_api/greengrass get_connectivity_info","url":"aws_api/greengrass.html#get_connectivity_info"},{"doc":"aws_api/greengrass","title":"get_connector_definition","content":"pub fn get_connector_definition(\n  client: Client,\n  connector_definition_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.get_connector_definition\naws_api/greengrass get_connector_definition","url":"aws_api/greengrass.html#get_connector_definition"},{"doc":"aws_api/greengrass","title":"get_connector_definition_version","content":"pub fn get_connector_definition_version(\n  client: Client,\n  connector_definition_id: String,\n  connector_definition_version_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.get_connector_definition_version\naws_api/greengrass get_connector_definition_version","url":"aws_api/greengrass.html#get_connector_definition_version"},{"doc":"aws_api/greengrass","title":"get_core_definition","content":"pub fn get_core_definition(\n  client: Client,\n  core_definition_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.get_core_definition\naws_api/greengrass get_core_definition","url":"aws_api/greengrass.html#get_core_definition"},{"doc":"aws_api/greengrass","title":"get_core_definition_version","content":"pub fn get_core_definition_version(\n  client: Client,\n  core_definition_id: String,\n  core_definition_version_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.get_core_definition_version\naws_api/greengrass get_core_definition_version","url":"aws_api/greengrass.html#get_core_definition_version"},{"doc":"aws_api/greengrass","title":"get_deployment_status","content":"pub fn get_deployment_status(\n  client: Client,\n  group_id: String,\n  deployment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.get_deployment_status\naws_api/greengrass get_deployment_status","url":"aws_api/greengrass.html#get_deployment_status"},{"doc":"aws_api/greengrass","title":"get_device_definition","content":"pub fn get_device_definition(\n  client: Client,\n  device_definition_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.get_device_definition\naws_api/greengrass get_device_definition","url":"aws_api/greengrass.html#get_device_definition"},{"doc":"aws_api/greengrass","title":"get_device_definition_version","content":"pub fn get_device_definition_version(\n  client: Client,\n  device_definition_id: String,\n  device_definition_version_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.get_device_definition_version\naws_api/greengrass get_device_definition_version","url":"aws_api/greengrass.html#get_device_definition_version"},{"doc":"aws_api/greengrass","title":"get_function_definition","content":"pub fn get_function_definition(\n  client: Client,\n  function_definition_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.get_function_definition\naws_api/greengrass get_function_definition","url":"aws_api/greengrass.html#get_function_definition"},{"doc":"aws_api/greengrass","title":"get_function_definition_version","content":"pub fn get_function_definition_version(\n  client: Client,\n  function_definition_id: String,\n  function_definition_version_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.get_function_definition_version\naws_api/greengrass get_function_definition_version","url":"aws_api/greengrass.html#get_function_definition_version"},{"doc":"aws_api/greengrass","title":"get_group","content":"pub fn get_group(\n  client: Client,\n  group_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.get_group\naws_api/greengrass get_group","url":"aws_api/greengrass.html#get_group"},{"doc":"aws_api/greengrass","title":"get_group_certificate_authority","content":"pub fn get_group_certificate_authority(\n  client: Client,\n  group_id: String,\n  certificate_authority_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.get_group_certificate_authority\naws_api/greengrass get_group_certificate_authority","url":"aws_api/greengrass.html#get_group_certificate_authority"},{"doc":"aws_api/greengrass","title":"get_group_certificate_configuration","content":"pub fn get_group_certificate_configuration(\n  client: Client,\n  group_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.get_group_certificate_configuration\naws_api/greengrass get_group_certificate_configuration","url":"aws_api/greengrass.html#get_group_certificate_configuration"},{"doc":"aws_api/greengrass","title":"get_group_version","content":"pub fn get_group_version(\n  client: Client,\n  group_id: String,\n  group_version_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.get_group_version\naws_api/greengrass get_group_version","url":"aws_api/greengrass.html#get_group_version"},{"doc":"aws_api/greengrass","title":"get_logger_definition","content":"pub fn get_logger_definition(\n  client: Client,\n  logger_definition_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.get_logger_definition\naws_api/greengrass get_logger_definition","url":"aws_api/greengrass.html#get_logger_definition"},{"doc":"aws_api/greengrass","title":"get_logger_definition_version","content":"pub fn get_logger_definition_version(\n  client: Client,\n  logger_definition_id: String,\n  logger_definition_version_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.get_logger_definition_version\naws_api/greengrass get_logger_definition_version","url":"aws_api/greengrass.html#get_logger_definition_version"},{"doc":"aws_api/greengrass","title":"get_resource_definition","content":"pub fn get_resource_definition(\n  client: Client,\n  resource_definition_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.get_resource_definition\naws_api/greengrass get_resource_definition","url":"aws_api/greengrass.html#get_resource_definition"},{"doc":"aws_api/greengrass","title":"get_resource_definition_version","content":"pub fn get_resource_definition_version(\n  client: Client,\n  resource_definition_id: String,\n  resource_definition_version_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.get_resource_definition_version\naws_api/greengrass get_resource_definition_version","url":"aws_api/greengrass.html#get_resource_definition_version"},{"doc":"aws_api/greengrass","title":"get_service_role_for_account","content":"pub fn get_service_role_for_account(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.get_service_role_for_account\naws_api/greengrass get_service_role_for_account","url":"aws_api/greengrass.html#get_service_role_for_account"},{"doc":"aws_api/greengrass","title":"get_subscription_definition","content":"pub fn get_subscription_definition(\n  client: Client,\n  subscription_definition_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.get_subscription_definition\naws_api/greengrass get_subscription_definition","url":"aws_api/greengrass.html#get_subscription_definition"},{"doc":"aws_api/greengrass","title":"get_subscription_definition_version","content":"pub fn get_subscription_definition_version(\n  client: Client,\n  subscription_definition_id: String,\n  subscription_definition_version_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.get_subscription_definition_version\naws_api/greengrass get_subscription_definition_version","url":"aws_api/greengrass.html#get_subscription_definition_version"},{"doc":"aws_api/greengrass","title":"get_thing_runtime_configuration","content":"pub fn get_thing_runtime_configuration(\n  client: Client,\n  thing_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.get_thing_runtime_configuration\naws_api/greengrass get_thing_runtime_configuration","url":"aws_api/greengrass.html#get_thing_runtime_configuration"},{"doc":"aws_api/greengrass","title":"list_bulk_deployment_detailed_reports","content":"pub fn list_bulk_deployment_detailed_reports(\n  client: Client,\n  bulk_deployment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.list_bulk_deployment_detailed_reports\naws_api/greengrass list_bulk_deployment_detailed_reports","url":"aws_api/greengrass.html#list_bulk_deployment_detailed_reports"},{"doc":"aws_api/greengrass","title":"list_bulk_deployments","content":"pub fn list_bulk_deployments(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.list_bulk_deployments\naws_api/greengrass list_bulk_deployments","url":"aws_api/greengrass.html#list_bulk_deployments"},{"doc":"aws_api/greengrass","title":"list_connector_definition_versions","content":"pub fn list_connector_definition_versions(\n  client: Client,\n  connector_definition_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.list_connector_definition_versions\naws_api/greengrass list_connector_definition_versions","url":"aws_api/greengrass.html#list_connector_definition_versions"},{"doc":"aws_api/greengrass","title":"list_connector_definitions","content":"pub fn list_connector_definitions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.list_connector_definitions\naws_api/greengrass list_connector_definitions","url":"aws_api/greengrass.html#list_connector_definitions"},{"doc":"aws_api/greengrass","title":"list_core_definition_versions","content":"pub fn list_core_definition_versions(\n  client: Client,\n  core_definition_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.list_core_definition_versions\naws_api/greengrass list_core_definition_versions","url":"aws_api/greengrass.html#list_core_definition_versions"},{"doc":"aws_api/greengrass","title":"list_core_definitions","content":"pub fn list_core_definitions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.list_core_definitions\naws_api/greengrass list_core_definitions","url":"aws_api/greengrass.html#list_core_definitions"},{"doc":"aws_api/greengrass","title":"list_deployments","content":"pub fn list_deployments(\n  client: Client,\n  group_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.list_deployments\naws_api/greengrass list_deployments","url":"aws_api/greengrass.html#list_deployments"},{"doc":"aws_api/greengrass","title":"list_device_definition_versions","content":"pub fn list_device_definition_versions(\n  client: Client,\n  device_definition_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.list_device_definition_versions\naws_api/greengrass list_device_definition_versions","url":"aws_api/greengrass.html#list_device_definition_versions"},{"doc":"aws_api/greengrass","title":"list_device_definitions","content":"pub fn list_device_definitions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.list_device_definitions\naws_api/greengrass list_device_definitions","url":"aws_api/greengrass.html#list_device_definitions"},{"doc":"aws_api/greengrass","title":"list_function_definition_versions","content":"pub fn list_function_definition_versions(\n  client: Client,\n  function_definition_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.list_function_definition_versions\naws_api/greengrass list_function_definition_versions","url":"aws_api/greengrass.html#list_function_definition_versions"},{"doc":"aws_api/greengrass","title":"list_function_definitions","content":"pub fn list_function_definitions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.list_function_definitions\naws_api/greengrass list_function_definitions","url":"aws_api/greengrass.html#list_function_definitions"},{"doc":"aws_api/greengrass","title":"list_group_certificate_authorities","content":"pub fn list_group_certificate_authorities(\n  client: Client,\n  group_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.list_group_certificate_authorities\naws_api/greengrass list_group_certificate_authorities","url":"aws_api/greengrass.html#list_group_certificate_authorities"},{"doc":"aws_api/greengrass","title":"list_group_versions","content":"pub fn list_group_versions(\n  client: Client,\n  group_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.list_group_versions\naws_api/greengrass list_group_versions","url":"aws_api/greengrass.html#list_group_versions"},{"doc":"aws_api/greengrass","title":"list_groups","content":"pub fn list_groups(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.list_groups\naws_api/greengrass list_groups","url":"aws_api/greengrass.html#list_groups"},{"doc":"aws_api/greengrass","title":"list_logger_definition_versions","content":"pub fn list_logger_definition_versions(\n  client: Client,\n  logger_definition_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.list_logger_definition_versions\naws_api/greengrass list_logger_definition_versions","url":"aws_api/greengrass.html#list_logger_definition_versions"},{"doc":"aws_api/greengrass","title":"list_logger_definitions","content":"pub fn list_logger_definitions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.list_logger_definitions\naws_api/greengrass list_logger_definitions","url":"aws_api/greengrass.html#list_logger_definitions"},{"doc":"aws_api/greengrass","title":"list_resource_definition_versions","content":"pub fn list_resource_definition_versions(\n  client: Client,\n  resource_definition_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.list_resource_definition_versions\naws_api/greengrass list_resource_definition_versions","url":"aws_api/greengrass.html#list_resource_definition_versions"},{"doc":"aws_api/greengrass","title":"list_resource_definitions","content":"pub fn list_resource_definitions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.list_resource_definitions\naws_api/greengrass list_resource_definitions","url":"aws_api/greengrass.html#list_resource_definitions"},{"doc":"aws_api/greengrass","title":"list_subscription_definition_versions","content":"pub fn list_subscription_definition_versions(\n  client: Client,\n  subscription_definition_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.list_subscription_definition_versions\naws_api/greengrass list_subscription_definition_versions","url":"aws_api/greengrass.html#list_subscription_definition_versions"},{"doc":"aws_api/greengrass","title":"list_subscription_definitions","content":"pub fn list_subscription_definitions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.list_subscription_definitions\naws_api/greengrass list_subscription_definitions","url":"aws_api/greengrass.html#list_subscription_definitions"},{"doc":"aws_api/greengrass","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.list_tags_for_resource\naws_api/greengrass list_tags_for_resource","url":"aws_api/greengrass.html#list_tags_for_resource"},{"doc":"aws_api/greengrass","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/greengrass.new\naws_api/greengrass new","url":"aws_api/greengrass.html#new"},{"doc":"aws_api/greengrass","title":"reset_deployments","content":"pub fn reset_deployments(\n  client: Client,\n  group_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.reset_deployments\naws_api/greengrass reset_deployments","url":"aws_api/greengrass.html#reset_deployments"},{"doc":"aws_api/greengrass","title":"start_bulk_deployment","content":"pub fn start_bulk_deployment(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.start_bulk_deployment\naws_api/greengrass start_bulk_deployment","url":"aws_api/greengrass.html#start_bulk_deployment"},{"doc":"aws_api/greengrass","title":"stop_bulk_deployment","content":"pub fn stop_bulk_deployment(\n  client: Client,\n  bulk_deployment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.stop_bulk_deployment\naws_api/greengrass stop_bulk_deployment","url":"aws_api/greengrass.html#stop_bulk_deployment"},{"doc":"aws_api/greengrass","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.tag_resource\naws_api/greengrass tag_resource","url":"aws_api/greengrass.html#tag_resource"},{"doc":"aws_api/greengrass","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.untag_resource\naws_api/greengrass untag_resource","url":"aws_api/greengrass.html#untag_resource"},{"doc":"aws_api/greengrass","title":"update_connectivity_info","content":"pub fn update_connectivity_info(\n  client: Client,\n  thing_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.update_connectivity_info\naws_api/greengrass update_connectivity_info","url":"aws_api/greengrass.html#update_connectivity_info"},{"doc":"aws_api/greengrass","title":"update_connector_definition","content":"pub fn update_connector_definition(\n  client: Client,\n  connector_definition_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.update_connector_definition\naws_api/greengrass update_connector_definition","url":"aws_api/greengrass.html#update_connector_definition"},{"doc":"aws_api/greengrass","title":"update_core_definition","content":"pub fn update_core_definition(\n  client: Client,\n  core_definition_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.update_core_definition\naws_api/greengrass update_core_definition","url":"aws_api/greengrass.html#update_core_definition"},{"doc":"aws_api/greengrass","title":"update_device_definition","content":"pub fn update_device_definition(\n  client: Client,\n  device_definition_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.update_device_definition\naws_api/greengrass update_device_definition","url":"aws_api/greengrass.html#update_device_definition"},{"doc":"aws_api/greengrass","title":"update_function_definition","content":"pub fn update_function_definition(\n  client: Client,\n  function_definition_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.update_function_definition\naws_api/greengrass update_function_definition","url":"aws_api/greengrass.html#update_function_definition"},{"doc":"aws_api/greengrass","title":"update_group","content":"pub fn update_group(\n  client: Client,\n  group_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.update_group\naws_api/greengrass update_group","url":"aws_api/greengrass.html#update_group"},{"doc":"aws_api/greengrass","title":"update_group_certificate_configuration","content":"pub fn update_group_certificate_configuration(\n  client: Client,\n  group_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.update_group_certificate_configuration\naws_api/greengrass update_group_certificate_configuration","url":"aws_api/greengrass.html#update_group_certificate_configuration"},{"doc":"aws_api/greengrass","title":"update_logger_definition","content":"pub fn update_logger_definition(\n  client: Client,\n  logger_definition_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.update_logger_definition\naws_api/greengrass update_logger_definition","url":"aws_api/greengrass.html#update_logger_definition"},{"doc":"aws_api/greengrass","title":"update_resource_definition","content":"pub fn update_resource_definition(\n  client: Client,\n  resource_definition_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.update_resource_definition\naws_api/greengrass update_resource_definition","url":"aws_api/greengrass.html#update_resource_definition"},{"doc":"aws_api/greengrass","title":"update_subscription_definition","content":"pub fn update_subscription_definition(\n  client: Client,\n  subscription_definition_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.update_subscription_definition\naws_api/greengrass update_subscription_definition","url":"aws_api/greengrass.html#update_subscription_definition"},{"doc":"aws_api/greengrass","title":"update_thing_runtime_configuration","content":"pub fn update_thing_runtime_configuration(\n  client: Client,\n  thing_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrass.update_thing_runtime_configuration\naws_api/greengrass update_thing_runtime_configuration","url":"aws_api/greengrass.html#update_thing_runtime_configuration"},{"doc":"aws_api/greengrass","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/greengrass.with_custom_endpoint\naws_api/greengrass with_custom_endpoint","url":"aws_api/greengrass.html#with_custom_endpoint"},{"doc":"aws_api/greengrass","title":"aws_api/greengrass","content":"","url":"aws_api/greengrass.html"},{"doc":"aws_api/greengrassv2","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/greengrassv2.Client\naws_api/greengrassv2 Client","url":"aws_api/greengrassv2.html#Client"},{"doc":"aws_api/greengrassv2","title":"associate_service_role_to_account","content":"pub fn associate_service_role_to_account(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrassv2.associate_service_role_to_account\naws_api/greengrassv2 associate_service_role_to_account","url":"aws_api/greengrassv2.html#associate_service_role_to_account"},{"doc":"aws_api/greengrassv2","title":"batch_associate_client_device_with_core_device","content":"pub fn batch_associate_client_device_with_core_device(\n  client: Client,\n  core_device_thing_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrassv2.batch_associate_client_device_with_core_device\naws_api/greengrassv2 batch_associate_client_device_with_core_device","url":"aws_api/greengrassv2.html#batch_associate_client_device_with_core_device"},{"doc":"aws_api/greengrassv2","title":"batch_disassociate_client_device_from_core_device","content":"pub fn batch_disassociate_client_device_from_core_device(\n  client: Client,\n  core_device_thing_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrassv2.batch_disassociate_client_device_from_core_device\naws_api/greengrassv2 batch_disassociate_client_device_from_core_device","url":"aws_api/greengrassv2.html#batch_disassociate_client_device_from_core_device"},{"doc":"aws_api/greengrassv2","title":"cancel_deployment","content":"pub fn cancel_deployment(\n  client: Client,\n  deployment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrassv2.cancel_deployment\naws_api/greengrassv2 cancel_deployment","url":"aws_api/greengrassv2.html#cancel_deployment"},{"doc":"aws_api/greengrassv2","title":"create_component_version","content":"pub fn create_component_version(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrassv2.create_component_version\naws_api/greengrassv2 create_component_version","url":"aws_api/greengrassv2.html#create_component_version"},{"doc":"aws_api/greengrassv2","title":"create_deployment","content":"pub fn create_deployment(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrassv2.create_deployment\naws_api/greengrassv2 create_deployment","url":"aws_api/greengrassv2.html#create_deployment"},{"doc":"aws_api/greengrassv2","title":"delete_component","content":"pub fn delete_component(\n  client: Client,\n  arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrassv2.delete_component\naws_api/greengrassv2 delete_component","url":"aws_api/greengrassv2.html#delete_component"},{"doc":"aws_api/greengrassv2","title":"delete_core_device","content":"pub fn delete_core_device(\n  client: Client,\n  core_device_thing_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrassv2.delete_core_device\naws_api/greengrassv2 delete_core_device","url":"aws_api/greengrassv2.html#delete_core_device"},{"doc":"aws_api/greengrassv2","title":"delete_deployment","content":"pub fn delete_deployment(\n  client: Client,\n  deployment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrassv2.delete_deployment\naws_api/greengrassv2 delete_deployment","url":"aws_api/greengrassv2.html#delete_deployment"},{"doc":"aws_api/greengrassv2","title":"describe_component","content":"pub fn describe_component(\n  client: Client,\n  arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrassv2.describe_component\naws_api/greengrassv2 describe_component","url":"aws_api/greengrassv2.html#describe_component"},{"doc":"aws_api/greengrassv2","title":"disassociate_service_role_from_account","content":"pub fn disassociate_service_role_from_account(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrassv2.disassociate_service_role_from_account\naws_api/greengrassv2 disassociate_service_role_from_account","url":"aws_api/greengrassv2.html#disassociate_service_role_from_account"},{"doc":"aws_api/greengrassv2","title":"get_component","content":"pub fn get_component(\n  client: Client,\n  arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrassv2.get_component\naws_api/greengrassv2 get_component","url":"aws_api/greengrassv2.html#get_component"},{"doc":"aws_api/greengrassv2","title":"get_component_version_artifact","content":"pub fn get_component_version_artifact(\n  client: Client,\n  arn: String,\n  artifact_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrassv2.get_component_version_artifact\naws_api/greengrassv2 get_component_version_artifact","url":"aws_api/greengrassv2.html#get_component_version_artifact"},{"doc":"aws_api/greengrassv2","title":"get_connectivity_info","content":"pub fn get_connectivity_info(\n  client: Client,\n  thing_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrassv2.get_connectivity_info\naws_api/greengrassv2 get_connectivity_info","url":"aws_api/greengrassv2.html#get_connectivity_info"},{"doc":"aws_api/greengrassv2","title":"get_core_device","content":"pub fn get_core_device(\n  client: Client,\n  core_device_thing_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrassv2.get_core_device\naws_api/greengrassv2 get_core_device","url":"aws_api/greengrassv2.html#get_core_device"},{"doc":"aws_api/greengrassv2","title":"get_deployment","content":"pub fn get_deployment(\n  client: Client,\n  deployment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrassv2.get_deployment\naws_api/greengrassv2 get_deployment","url":"aws_api/greengrassv2.html#get_deployment"},{"doc":"aws_api/greengrassv2","title":"get_service_role_for_account","content":"pub fn get_service_role_for_account(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrassv2.get_service_role_for_account\naws_api/greengrassv2 get_service_role_for_account","url":"aws_api/greengrassv2.html#get_service_role_for_account"},{"doc":"aws_api/greengrassv2","title":"list_client_devices_associated_with_core_device","content":"pub fn list_client_devices_associated_with_core_device(\n  client: Client,\n  core_device_thing_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrassv2.list_client_devices_associated_with_core_device\naws_api/greengrassv2 list_client_devices_associated_with_core_device","url":"aws_api/greengrassv2.html#list_client_devices_associated_with_core_device"},{"doc":"aws_api/greengrassv2","title":"list_component_versions","content":"pub fn list_component_versions(\n  client: Client,\n  arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrassv2.list_component_versions\naws_api/greengrassv2 list_component_versions","url":"aws_api/greengrassv2.html#list_component_versions"},{"doc":"aws_api/greengrassv2","title":"list_components","content":"pub fn list_components(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrassv2.list_components\naws_api/greengrassv2 list_components","url":"aws_api/greengrassv2.html#list_components"},{"doc":"aws_api/greengrassv2","title":"list_core_devices","content":"pub fn list_core_devices(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrassv2.list_core_devices\naws_api/greengrassv2 list_core_devices","url":"aws_api/greengrassv2.html#list_core_devices"},{"doc":"aws_api/greengrassv2","title":"list_deployments","content":"pub fn list_deployments(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrassv2.list_deployments\naws_api/greengrassv2 list_deployments","url":"aws_api/greengrassv2.html#list_deployments"},{"doc":"aws_api/greengrassv2","title":"list_effective_deployments","content":"pub fn list_effective_deployments(\n  client: Client,\n  core_device_thing_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrassv2.list_effective_deployments\naws_api/greengrassv2 list_effective_deployments","url":"aws_api/greengrassv2.html#list_effective_deployments"},{"doc":"aws_api/greengrassv2","title":"list_installed_components","content":"pub fn list_installed_components(\n  client: Client,\n  core_device_thing_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrassv2.list_installed_components\naws_api/greengrassv2 list_installed_components","url":"aws_api/greengrassv2.html#list_installed_components"},{"doc":"aws_api/greengrassv2","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrassv2.list_tags_for_resource\naws_api/greengrassv2 list_tags_for_resource","url":"aws_api/greengrassv2.html#list_tags_for_resource"},{"doc":"aws_api/greengrassv2","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/greengrassv2.new\naws_api/greengrassv2 new","url":"aws_api/greengrassv2.html#new"},{"doc":"aws_api/greengrassv2","title":"resolve_component_candidates","content":"pub fn resolve_component_candidates(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrassv2.resolve_component_candidates\naws_api/greengrassv2 resolve_component_candidates","url":"aws_api/greengrassv2.html#resolve_component_candidates"},{"doc":"aws_api/greengrassv2","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrassv2.tag_resource\naws_api/greengrassv2 tag_resource","url":"aws_api/greengrassv2.html#tag_resource"},{"doc":"aws_api/greengrassv2","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrassv2.untag_resource\naws_api/greengrassv2 untag_resource","url":"aws_api/greengrassv2.html#untag_resource"},{"doc":"aws_api/greengrassv2","title":"update_connectivity_info","content":"pub fn update_connectivity_info(\n  client: Client,\n  thing_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/greengrassv2.update_connectivity_info\naws_api/greengrassv2 update_connectivity_info","url":"aws_api/greengrassv2.html#update_connectivity_info"},{"doc":"aws_api/greengrassv2","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/greengrassv2.with_custom_endpoint\naws_api/greengrassv2 with_custom_endpoint","url":"aws_api/greengrassv2.html#with_custom_endpoint"},{"doc":"aws_api/greengrassv2","title":"aws_api/greengrassv2","content":"","url":"aws_api/greengrassv2.html"},{"doc":"aws_api/groundstation","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/groundstation.Client\naws_api/groundstation Client","url":"aws_api/groundstation.html#Client"},{"doc":"aws_api/groundstation","title":"get_minute_usage","content":"pub fn get_minute_usage(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/groundstation.get_minute_usage\naws_api/groundstation get_minute_usage","url":"aws_api/groundstation.html#get_minute_usage"},{"doc":"aws_api/groundstation","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/groundstation.list_tags_for_resource\naws_api/groundstation list_tags_for_resource","url":"aws_api/groundstation.html#list_tags_for_resource"},{"doc":"aws_api/groundstation","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/groundstation.new\naws_api/groundstation new","url":"aws_api/groundstation.html#new"},{"doc":"aws_api/groundstation","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/groundstation.tag_resource\naws_api/groundstation tag_resource","url":"aws_api/groundstation.html#tag_resource"},{"doc":"aws_api/groundstation","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/groundstation.untag_resource\naws_api/groundstation untag_resource","url":"aws_api/groundstation.html#untag_resource"},{"doc":"aws_api/groundstation","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/groundstation.with_custom_endpoint\naws_api/groundstation with_custom_endpoint","url":"aws_api/groundstation.html#with_custom_endpoint"},{"doc":"aws_api/groundstation","title":"aws_api/groundstation","content":"","url":"aws_api/groundstation.html"},{"doc":"aws_api/guardduty","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/guardduty.Client\naws_api/guardduty Client","url":"aws_api/guardduty.html#Client"},{"doc":"aws_api/guardduty","title":"accept_administrator_invitation","content":"pub fn accept_administrator_invitation(\n  client: Client,\n  detector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.accept_administrator_invitation\naws_api/guardduty accept_administrator_invitation","url":"aws_api/guardduty.html#accept_administrator_invitation"},{"doc":"aws_api/guardduty","title":"accept_invitation","content":"pub fn accept_invitation(\n  client: Client,\n  detector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.accept_invitation\naws_api/guardduty accept_invitation","url":"aws_api/guardduty.html#accept_invitation"},{"doc":"aws_api/guardduty","title":"archive_findings","content":"pub fn archive_findings(\n  client: Client,\n  detector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.archive_findings\naws_api/guardduty archive_findings","url":"aws_api/guardduty.html#archive_findings"},{"doc":"aws_api/guardduty","title":"create_detector","content":"pub fn create_detector(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.create_detector\naws_api/guardduty create_detector","url":"aws_api/guardduty.html#create_detector"},{"doc":"aws_api/guardduty","title":"create_filter","content":"pub fn create_filter(\n  client: Client,\n  detector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.create_filter\naws_api/guardduty create_filter","url":"aws_api/guardduty.html#create_filter"},{"doc":"aws_api/guardduty","title":"create_ip_set","content":"pub fn create_ip_set(\n  client: Client,\n  detector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.create_ip_set\naws_api/guardduty create_ip_set","url":"aws_api/guardduty.html#create_ip_set"},{"doc":"aws_api/guardduty","title":"create_malware_protection_plan","content":"pub fn create_malware_protection_plan(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.create_malware_protection_plan\naws_api/guardduty create_malware_protection_plan","url":"aws_api/guardduty.html#create_malware_protection_plan"},{"doc":"aws_api/guardduty","title":"create_members","content":"pub fn create_members(\n  client: Client,\n  detector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.create_members\naws_api/guardduty create_members","url":"aws_api/guardduty.html#create_members"},{"doc":"aws_api/guardduty","title":"create_publishing_destination","content":"pub fn create_publishing_destination(\n  client: Client,\n  detector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.create_publishing_destination\naws_api/guardduty create_publishing_destination","url":"aws_api/guardduty.html#create_publishing_destination"},{"doc":"aws_api/guardduty","title":"create_sample_findings","content":"pub fn create_sample_findings(\n  client: Client,\n  detector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.create_sample_findings\naws_api/guardduty create_sample_findings","url":"aws_api/guardduty.html#create_sample_findings"},{"doc":"aws_api/guardduty","title":"create_threat_intel_set","content":"pub fn create_threat_intel_set(\n  client: Client,\n  detector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.create_threat_intel_set\naws_api/guardduty create_threat_intel_set","url":"aws_api/guardduty.html#create_threat_intel_set"},{"doc":"aws_api/guardduty","title":"decline_invitations","content":"pub fn decline_invitations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.decline_invitations\naws_api/guardduty decline_invitations","url":"aws_api/guardduty.html#decline_invitations"},{"doc":"aws_api/guardduty","title":"delete_detector","content":"pub fn delete_detector(\n  client: Client,\n  detector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.delete_detector\naws_api/guardduty delete_detector","url":"aws_api/guardduty.html#delete_detector"},{"doc":"aws_api/guardduty","title":"delete_filter","content":"pub fn delete_filter(\n  client: Client,\n  detector_id: String,\n  filter_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.delete_filter\naws_api/guardduty delete_filter","url":"aws_api/guardduty.html#delete_filter"},{"doc":"aws_api/guardduty","title":"delete_invitations","content":"pub fn delete_invitations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.delete_invitations\naws_api/guardduty delete_invitations","url":"aws_api/guardduty.html#delete_invitations"},{"doc":"aws_api/guardduty","title":"delete_ip_set","content":"pub fn delete_ip_set(\n  client: Client,\n  detector_id: String,\n  ip_set_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.delete_ip_set\naws_api/guardduty delete_ip_set","url":"aws_api/guardduty.html#delete_ip_set"},{"doc":"aws_api/guardduty","title":"delete_malware_protection_plan","content":"pub fn delete_malware_protection_plan(\n  client: Client,\n  malware_protection_plan_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.delete_malware_protection_plan\naws_api/guardduty delete_malware_protection_plan","url":"aws_api/guardduty.html#delete_malware_protection_plan"},{"doc":"aws_api/guardduty","title":"delete_members","content":"pub fn delete_members(\n  client: Client,\n  detector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.delete_members\naws_api/guardduty delete_members","url":"aws_api/guardduty.html#delete_members"},{"doc":"aws_api/guardduty","title":"delete_publishing_destination","content":"pub fn delete_publishing_destination(\n  client: Client,\n  detector_id: String,\n  destination_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.delete_publishing_destination\naws_api/guardduty delete_publishing_destination","url":"aws_api/guardduty.html#delete_publishing_destination"},{"doc":"aws_api/guardduty","title":"delete_threat_intel_set","content":"pub fn delete_threat_intel_set(\n  client: Client,\n  detector_id: String,\n  threat_intel_set_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.delete_threat_intel_set\naws_api/guardduty delete_threat_intel_set","url":"aws_api/guardduty.html#delete_threat_intel_set"},{"doc":"aws_api/guardduty","title":"describe_malware_scans","content":"pub fn describe_malware_scans(\n  client: Client,\n  detector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.describe_malware_scans\naws_api/guardduty describe_malware_scans","url":"aws_api/guardduty.html#describe_malware_scans"},{"doc":"aws_api/guardduty","title":"describe_organization_configuration","content":"pub fn describe_organization_configuration(\n  client: Client,\n  detector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.describe_organization_configuration\naws_api/guardduty describe_organization_configuration","url":"aws_api/guardduty.html#describe_organization_configuration"},{"doc":"aws_api/guardduty","title":"describe_publishing_destination","content":"pub fn describe_publishing_destination(\n  client: Client,\n  detector_id: String,\n  destination_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.describe_publishing_destination\naws_api/guardduty describe_publishing_destination","url":"aws_api/guardduty.html#describe_publishing_destination"},{"doc":"aws_api/guardduty","title":"disable_organization_admin_account","content":"pub fn disable_organization_admin_account(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.disable_organization_admin_account\naws_api/guardduty disable_organization_admin_account","url":"aws_api/guardduty.html#disable_organization_admin_account"},{"doc":"aws_api/guardduty","title":"disassociate_from_administrator_account","content":"pub fn disassociate_from_administrator_account(\n  client: Client,\n  detector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.disassociate_from_administrator_account\naws_api/guardduty disassociate_from_administrator_account","url":"aws_api/guardduty.html#disassociate_from_administrator_account"},{"doc":"aws_api/guardduty","title":"disassociate_from_master_account","content":"pub fn disassociate_from_master_account(\n  client: Client,\n  detector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.disassociate_from_master_account\naws_api/guardduty disassociate_from_master_account","url":"aws_api/guardduty.html#disassociate_from_master_account"},{"doc":"aws_api/guardduty","title":"disassociate_members","content":"pub fn disassociate_members(\n  client: Client,\n  detector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.disassociate_members\naws_api/guardduty disassociate_members","url":"aws_api/guardduty.html#disassociate_members"},{"doc":"aws_api/guardduty","title":"enable_organization_admin_account","content":"pub fn enable_organization_admin_account(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.enable_organization_admin_account\naws_api/guardduty enable_organization_admin_account","url":"aws_api/guardduty.html#enable_organization_admin_account"},{"doc":"aws_api/guardduty","title":"get_administrator_account","content":"pub fn get_administrator_account(\n  client: Client,\n  detector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.get_administrator_account\naws_api/guardduty get_administrator_account","url":"aws_api/guardduty.html#get_administrator_account"},{"doc":"aws_api/guardduty","title":"get_coverage_statistics","content":"pub fn get_coverage_statistics(\n  client: Client,\n  detector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.get_coverage_statistics\naws_api/guardduty get_coverage_statistics","url":"aws_api/guardduty.html#get_coverage_statistics"},{"doc":"aws_api/guardduty","title":"get_detector","content":"pub fn get_detector(\n  client: Client,\n  detector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.get_detector\naws_api/guardduty get_detector","url":"aws_api/guardduty.html#get_detector"},{"doc":"aws_api/guardduty","title":"get_filter","content":"pub fn get_filter(\n  client: Client,\n  detector_id: String,\n  filter_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.get_filter\naws_api/guardduty get_filter","url":"aws_api/guardduty.html#get_filter"},{"doc":"aws_api/guardduty","title":"get_findings","content":"pub fn get_findings(\n  client: Client,\n  detector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.get_findings\naws_api/guardduty get_findings","url":"aws_api/guardduty.html#get_findings"},{"doc":"aws_api/guardduty","title":"get_findings_statistics","content":"pub fn get_findings_statistics(\n  client: Client,\n  detector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.get_findings_statistics\naws_api/guardduty get_findings_statistics","url":"aws_api/guardduty.html#get_findings_statistics"},{"doc":"aws_api/guardduty","title":"get_invitations_count","content":"pub fn get_invitations_count(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.get_invitations_count\naws_api/guardduty get_invitations_count","url":"aws_api/guardduty.html#get_invitations_count"},{"doc":"aws_api/guardduty","title":"get_ip_set","content":"pub fn get_ip_set(\n  client: Client,\n  detector_id: String,\n  ip_set_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.get_ip_set\naws_api/guardduty get_ip_set","url":"aws_api/guardduty.html#get_ip_set"},{"doc":"aws_api/guardduty","title":"get_malware_protection_plan","content":"pub fn get_malware_protection_plan(\n  client: Client,\n  malware_protection_plan_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.get_malware_protection_plan\naws_api/guardduty get_malware_protection_plan","url":"aws_api/guardduty.html#get_malware_protection_plan"},{"doc":"aws_api/guardduty","title":"get_malware_scan_settings","content":"pub fn get_malware_scan_settings(\n  client: Client,\n  detector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.get_malware_scan_settings\naws_api/guardduty get_malware_scan_settings","url":"aws_api/guardduty.html#get_malware_scan_settings"},{"doc":"aws_api/guardduty","title":"get_master_account","content":"pub fn get_master_account(\n  client: Client,\n  detector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.get_master_account\naws_api/guardduty get_master_account","url":"aws_api/guardduty.html#get_master_account"},{"doc":"aws_api/guardduty","title":"get_member_detectors","content":"pub fn get_member_detectors(\n  client: Client,\n  detector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.get_member_detectors\naws_api/guardduty get_member_detectors","url":"aws_api/guardduty.html#get_member_detectors"},{"doc":"aws_api/guardduty","title":"get_members","content":"pub fn get_members(\n  client: Client,\n  detector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.get_members\naws_api/guardduty get_members","url":"aws_api/guardduty.html#get_members"},{"doc":"aws_api/guardduty","title":"get_organization_statistics","content":"pub fn get_organization_statistics(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.get_organization_statistics\naws_api/guardduty get_organization_statistics","url":"aws_api/guardduty.html#get_organization_statistics"},{"doc":"aws_api/guardduty","title":"get_remaining_free_trial_days","content":"pub fn get_remaining_free_trial_days(\n  client: Client,\n  detector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.get_remaining_free_trial_days\naws_api/guardduty get_remaining_free_trial_days","url":"aws_api/guardduty.html#get_remaining_free_trial_days"},{"doc":"aws_api/guardduty","title":"get_threat_intel_set","content":"pub fn get_threat_intel_set(\n  client: Client,\n  detector_id: String,\n  threat_intel_set_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.get_threat_intel_set\naws_api/guardduty get_threat_intel_set","url":"aws_api/guardduty.html#get_threat_intel_set"},{"doc":"aws_api/guardduty","title":"get_usage_statistics","content":"pub fn get_usage_statistics(\n  client: Client,\n  detector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.get_usage_statistics\naws_api/guardduty get_usage_statistics","url":"aws_api/guardduty.html#get_usage_statistics"},{"doc":"aws_api/guardduty","title":"invite_members","content":"pub fn invite_members(\n  client: Client,\n  detector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.invite_members\naws_api/guardduty invite_members","url":"aws_api/guardduty.html#invite_members"},{"doc":"aws_api/guardduty","title":"list_coverage","content":"pub fn list_coverage(\n  client: Client,\n  detector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.list_coverage\naws_api/guardduty list_coverage","url":"aws_api/guardduty.html#list_coverage"},{"doc":"aws_api/guardduty","title":"list_detectors","content":"pub fn list_detectors(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.list_detectors\naws_api/guardduty list_detectors","url":"aws_api/guardduty.html#list_detectors"},{"doc":"aws_api/guardduty","title":"list_filters","content":"pub fn list_filters(\n  client: Client,\n  detector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.list_filters\naws_api/guardduty list_filters","url":"aws_api/guardduty.html#list_filters"},{"doc":"aws_api/guardduty","title":"list_findings","content":"pub fn list_findings(\n  client: Client,\n  detector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.list_findings\naws_api/guardduty list_findings","url":"aws_api/guardduty.html#list_findings"},{"doc":"aws_api/guardduty","title":"list_invitations","content":"pub fn list_invitations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.list_invitations\naws_api/guardduty list_invitations","url":"aws_api/guardduty.html#list_invitations"},{"doc":"aws_api/guardduty","title":"list_ip_sets","content":"pub fn list_ip_sets(\n  client: Client,\n  detector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.list_ip_sets\naws_api/guardduty list_ip_sets","url":"aws_api/guardduty.html#list_ip_sets"},{"doc":"aws_api/guardduty","title":"list_malware_protection_plans","content":"pub fn list_malware_protection_plans(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.list_malware_protection_plans\naws_api/guardduty list_malware_protection_plans","url":"aws_api/guardduty.html#list_malware_protection_plans"},{"doc":"aws_api/guardduty","title":"list_members","content":"pub fn list_members(\n  client: Client,\n  detector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.list_members\naws_api/guardduty list_members","url":"aws_api/guardduty.html#list_members"},{"doc":"aws_api/guardduty","title":"list_organization_admin_accounts","content":"pub fn list_organization_admin_accounts(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.list_organization_admin_accounts\naws_api/guardduty list_organization_admin_accounts","url":"aws_api/guardduty.html#list_organization_admin_accounts"},{"doc":"aws_api/guardduty","title":"list_publishing_destinations","content":"pub fn list_publishing_destinations(\n  client: Client,\n  detector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.list_publishing_destinations\naws_api/guardduty list_publishing_destinations","url":"aws_api/guardduty.html#list_publishing_destinations"},{"doc":"aws_api/guardduty","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.list_tags_for_resource\naws_api/guardduty list_tags_for_resource","url":"aws_api/guardduty.html#list_tags_for_resource"},{"doc":"aws_api/guardduty","title":"list_threat_intel_sets","content":"pub fn list_threat_intel_sets(\n  client: Client,\n  detector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.list_threat_intel_sets\naws_api/guardduty list_threat_intel_sets","url":"aws_api/guardduty.html#list_threat_intel_sets"},{"doc":"aws_api/guardduty","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/guardduty.new\naws_api/guardduty new","url":"aws_api/guardduty.html#new"},{"doc":"aws_api/guardduty","title":"start_malware_scan","content":"pub fn start_malware_scan(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.start_malware_scan\naws_api/guardduty start_malware_scan","url":"aws_api/guardduty.html#start_malware_scan"},{"doc":"aws_api/guardduty","title":"start_monitoring_members","content":"pub fn start_monitoring_members(\n  client: Client,\n  detector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.start_monitoring_members\naws_api/guardduty start_monitoring_members","url":"aws_api/guardduty.html#start_monitoring_members"},{"doc":"aws_api/guardduty","title":"stop_monitoring_members","content":"pub fn stop_monitoring_members(\n  client: Client,\n  detector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.stop_monitoring_members\naws_api/guardduty stop_monitoring_members","url":"aws_api/guardduty.html#stop_monitoring_members"},{"doc":"aws_api/guardduty","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.tag_resource\naws_api/guardduty tag_resource","url":"aws_api/guardduty.html#tag_resource"},{"doc":"aws_api/guardduty","title":"unarchive_findings","content":"pub fn unarchive_findings(\n  client: Client,\n  detector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.unarchive_findings\naws_api/guardduty unarchive_findings","url":"aws_api/guardduty.html#unarchive_findings"},{"doc":"aws_api/guardduty","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.untag_resource\naws_api/guardduty untag_resource","url":"aws_api/guardduty.html#untag_resource"},{"doc":"aws_api/guardduty","title":"update_detector","content":"pub fn update_detector(\n  client: Client,\n  detector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.update_detector\naws_api/guardduty update_detector","url":"aws_api/guardduty.html#update_detector"},{"doc":"aws_api/guardduty","title":"update_filter","content":"pub fn update_filter(\n  client: Client,\n  detector_id: String,\n  filter_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.update_filter\naws_api/guardduty update_filter","url":"aws_api/guardduty.html#update_filter"},{"doc":"aws_api/guardduty","title":"update_findings_feedback","content":"pub fn update_findings_feedback(\n  client: Client,\n  detector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.update_findings_feedback\naws_api/guardduty update_findings_feedback","url":"aws_api/guardduty.html#update_findings_feedback"},{"doc":"aws_api/guardduty","title":"update_ip_set","content":"pub fn update_ip_set(\n  client: Client,\n  detector_id: String,\n  ip_set_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.update_ip_set\naws_api/guardduty update_ip_set","url":"aws_api/guardduty.html#update_ip_set"},{"doc":"aws_api/guardduty","title":"update_malware_protection_plan","content":"pub fn update_malware_protection_plan(\n  client: Client,\n  malware_protection_plan_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.update_malware_protection_plan\naws_api/guardduty update_malware_protection_plan","url":"aws_api/guardduty.html#update_malware_protection_plan"},{"doc":"aws_api/guardduty","title":"update_malware_scan_settings","content":"pub fn update_malware_scan_settings(\n  client: Client,\n  detector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.update_malware_scan_settings\naws_api/guardduty update_malware_scan_settings","url":"aws_api/guardduty.html#update_malware_scan_settings"},{"doc":"aws_api/guardduty","title":"update_member_detectors","content":"pub fn update_member_detectors(\n  client: Client,\n  detector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.update_member_detectors\naws_api/guardduty update_member_detectors","url":"aws_api/guardduty.html#update_member_detectors"},{"doc":"aws_api/guardduty","title":"update_organization_configuration","content":"pub fn update_organization_configuration(\n  client: Client,\n  detector_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.update_organization_configuration\naws_api/guardduty update_organization_configuration","url":"aws_api/guardduty.html#update_organization_configuration"},{"doc":"aws_api/guardduty","title":"update_publishing_destination","content":"pub fn update_publishing_destination(\n  client: Client,\n  detector_id: String,\n  destination_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.update_publishing_destination\naws_api/guardduty update_publishing_destination","url":"aws_api/guardduty.html#update_publishing_destination"},{"doc":"aws_api/guardduty","title":"update_threat_intel_set","content":"pub fn update_threat_intel_set(\n  client: Client,\n  detector_id: String,\n  threat_intel_set_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/guardduty.update_threat_intel_set\naws_api/guardduty update_threat_intel_set","url":"aws_api/guardduty.html#update_threat_intel_set"},{"doc":"aws_api/guardduty","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/guardduty.with_custom_endpoint\naws_api/guardduty with_custom_endpoint","url":"aws_api/guardduty.html#with_custom_endpoint"},{"doc":"aws_api/guardduty","title":"aws_api/guardduty","content":"","url":"aws_api/guardduty.html"},{"doc":"aws_api/health","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/health.Client\naws_api/health Client","url":"aws_api/health.html#Client"},{"doc":"aws_api/health","title":"describe_affected_accounts_for_organization","content":"pub fn describe_affected_accounts_for_organization(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/health.describe_affected_accounts_for_organization\naws_api/health describe_affected_accounts_for_organization","url":"aws_api/health.html#describe_affected_accounts_for_organization"},{"doc":"aws_api/health","title":"describe_affected_entities","content":"pub fn describe_affected_entities(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/health.describe_affected_entities\naws_api/health describe_affected_entities","url":"aws_api/health.html#describe_affected_entities"},{"doc":"aws_api/health","title":"describe_affected_entities_for_organization","content":"pub fn describe_affected_entities_for_organization(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/health.describe_affected_entities_for_organization\naws_api/health describe_affected_entities_for_organization","url":"aws_api/health.html#describe_affected_entities_for_organization"},{"doc":"aws_api/health","title":"describe_entity_aggregates","content":"pub fn describe_entity_aggregates(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/health.describe_entity_aggregates\naws_api/health describe_entity_aggregates","url":"aws_api/health.html#describe_entity_aggregates"},{"doc":"aws_api/health","title":"describe_entity_aggregates_for_organization","content":"pub fn describe_entity_aggregates_for_organization(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/health.describe_entity_aggregates_for_organization\naws_api/health describe_entity_aggregates_for_organization","url":"aws_api/health.html#describe_entity_aggregates_for_organization"},{"doc":"aws_api/health","title":"describe_event_aggregates","content":"pub fn describe_event_aggregates(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/health.describe_event_aggregates\naws_api/health describe_event_aggregates","url":"aws_api/health.html#describe_event_aggregates"},{"doc":"aws_api/health","title":"describe_event_details","content":"pub fn describe_event_details(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/health.describe_event_details\naws_api/health describe_event_details","url":"aws_api/health.html#describe_event_details"},{"doc":"aws_api/health","title":"describe_event_details_for_organization","content":"pub fn describe_event_details_for_organization(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/health.describe_event_details_for_organization\naws_api/health describe_event_details_for_organization","url":"aws_api/health.html#describe_event_details_for_organization"},{"doc":"aws_api/health","title":"describe_event_types","content":"pub fn describe_event_types(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/health.describe_event_types\naws_api/health describe_event_types","url":"aws_api/health.html#describe_event_types"},{"doc":"aws_api/health","title":"describe_events","content":"pub fn describe_events(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/health.describe_events\naws_api/health describe_events","url":"aws_api/health.html#describe_events"},{"doc":"aws_api/health","title":"describe_events_for_organization","content":"pub fn describe_events_for_organization(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/health.describe_events_for_organization\naws_api/health describe_events_for_organization","url":"aws_api/health.html#describe_events_for_organization"},{"doc":"aws_api/health","title":"describe_health_service_status_for_organization","content":"pub fn describe_health_service_status_for_organization(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/health.describe_health_service_status_for_organization\naws_api/health describe_health_service_status_for_organization","url":"aws_api/health.html#describe_health_service_status_for_organization"},{"doc":"aws_api/health","title":"disable_health_service_access_for_organization","content":"pub fn disable_health_service_access_for_organization(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/health.disable_health_service_access_for_organization\naws_api/health disable_health_service_access_for_organization","url":"aws_api/health.html#disable_health_service_access_for_organization"},{"doc":"aws_api/health","title":"enable_health_service_access_for_organization","content":"pub fn enable_health_service_access_for_organization(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/health.enable_health_service_access_for_organization\naws_api/health enable_health_service_access_for_organization","url":"aws_api/health.html#enable_health_service_access_for_organization"},{"doc":"aws_api/health","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/health.new\naws_api/health new","url":"aws_api/health.html#new"},{"doc":"aws_api/health","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/health.with_custom_endpoint\naws_api/health with_custom_endpoint","url":"aws_api/health.html#with_custom_endpoint"},{"doc":"aws_api/health","title":"aws_api/health","content":"","url":"aws_api/health.html"},{"doc":"aws_api/healthlake","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/healthlake.Client\naws_api/healthlake Client","url":"aws_api/healthlake.html#Client"},{"doc":"aws_api/healthlake","title":"create_fhir_datastore","content":"pub fn create_fhir_datastore(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/healthlake.create_fhir_datastore\naws_api/healthlake create_fhir_datastore","url":"aws_api/healthlake.html#create_fhir_datastore"},{"doc":"aws_api/healthlake","title":"delete_fhir_datastore","content":"pub fn delete_fhir_datastore(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/healthlake.delete_fhir_datastore\naws_api/healthlake delete_fhir_datastore","url":"aws_api/healthlake.html#delete_fhir_datastore"},{"doc":"aws_api/healthlake","title":"describe_fhir_datastore","content":"pub fn describe_fhir_datastore(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/healthlake.describe_fhir_datastore\naws_api/healthlake describe_fhir_datastore","url":"aws_api/healthlake.html#describe_fhir_datastore"},{"doc":"aws_api/healthlake","title":"describe_fhir_export_job","content":"pub fn describe_fhir_export_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/healthlake.describe_fhir_export_job\naws_api/healthlake describe_fhir_export_job","url":"aws_api/healthlake.html#describe_fhir_export_job"},{"doc":"aws_api/healthlake","title":"describe_fhir_import_job","content":"pub fn describe_fhir_import_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/healthlake.describe_fhir_import_job\naws_api/healthlake describe_fhir_import_job","url":"aws_api/healthlake.html#describe_fhir_import_job"},{"doc":"aws_api/healthlake","title":"list_fhir_datastores","content":"pub fn list_fhir_datastores(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/healthlake.list_fhir_datastores\naws_api/healthlake list_fhir_datastores","url":"aws_api/healthlake.html#list_fhir_datastores"},{"doc":"aws_api/healthlake","title":"list_fhir_export_jobs","content":"pub fn list_fhir_export_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/healthlake.list_fhir_export_jobs\naws_api/healthlake list_fhir_export_jobs","url":"aws_api/healthlake.html#list_fhir_export_jobs"},{"doc":"aws_api/healthlake","title":"list_fhir_import_jobs","content":"pub fn list_fhir_import_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/healthlake.list_fhir_import_jobs\naws_api/healthlake list_fhir_import_jobs","url":"aws_api/healthlake.html#list_fhir_import_jobs"},{"doc":"aws_api/healthlake","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/healthlake.list_tags_for_resource\naws_api/healthlake list_tags_for_resource","url":"aws_api/healthlake.html#list_tags_for_resource"},{"doc":"aws_api/healthlake","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/healthlake.new\naws_api/healthlake new","url":"aws_api/healthlake.html#new"},{"doc":"aws_api/healthlake","title":"start_fhir_export_job","content":"pub fn start_fhir_export_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/healthlake.start_fhir_export_job\naws_api/healthlake start_fhir_export_job","url":"aws_api/healthlake.html#start_fhir_export_job"},{"doc":"aws_api/healthlake","title":"start_fhir_import_job","content":"pub fn start_fhir_import_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/healthlake.start_fhir_import_job\naws_api/healthlake start_fhir_import_job","url":"aws_api/healthlake.html#start_fhir_import_job"},{"doc":"aws_api/healthlake","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/healthlake.tag_resource\naws_api/healthlake tag_resource","url":"aws_api/healthlake.html#tag_resource"},{"doc":"aws_api/healthlake","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/healthlake.untag_resource\naws_api/healthlake untag_resource","url":"aws_api/healthlake.html#untag_resource"},{"doc":"aws_api/healthlake","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/healthlake.with_custom_endpoint\naws_api/healthlake with_custom_endpoint","url":"aws_api/healthlake.html#with_custom_endpoint"},{"doc":"aws_api/healthlake","title":"aws_api/healthlake","content":"","url":"aws_api/healthlake.html"},{"doc":"aws_api/iam","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/iam.Client\naws_api/iam Client","url":"aws_api/iam.html#Client"},{"doc":"aws_api/iam","title":"add_client_id_to_open_id_connect_provider","content":"pub fn add_client_id_to_open_id_connect_provider(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.add_client_id_to_open_id_connect_provider\naws_api/iam add_client_id_to_open_id_connect_provider","url":"aws_api/iam.html#add_client_id_to_open_id_connect_provider"},{"doc":"aws_api/iam","title":"add_role_to_instance_profile","content":"pub fn add_role_to_instance_profile(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.add_role_to_instance_profile\naws_api/iam add_role_to_instance_profile","url":"aws_api/iam.html#add_role_to_instance_profile"},{"doc":"aws_api/iam","title":"add_user_to_group","content":"pub fn add_user_to_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.add_user_to_group\naws_api/iam add_user_to_group","url":"aws_api/iam.html#add_user_to_group"},{"doc":"aws_api/iam","title":"attach_group_policy","content":"pub fn attach_group_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.attach_group_policy\naws_api/iam attach_group_policy","url":"aws_api/iam.html#attach_group_policy"},{"doc":"aws_api/iam","title":"attach_role_policy","content":"pub fn attach_role_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.attach_role_policy\naws_api/iam attach_role_policy","url":"aws_api/iam.html#attach_role_policy"},{"doc":"aws_api/iam","title":"attach_user_policy","content":"pub fn attach_user_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.attach_user_policy\naws_api/iam attach_user_policy","url":"aws_api/iam.html#attach_user_policy"},{"doc":"aws_api/iam","title":"change_password","content":"pub fn change_password(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.change_password\naws_api/iam change_password","url":"aws_api/iam.html#change_password"},{"doc":"aws_api/iam","title":"create_access_key","content":"pub fn create_access_key(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.create_access_key\naws_api/iam create_access_key","url":"aws_api/iam.html#create_access_key"},{"doc":"aws_api/iam","title":"create_account_alias","content":"pub fn create_account_alias(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.create_account_alias\naws_api/iam create_account_alias","url":"aws_api/iam.html#create_account_alias"},{"doc":"aws_api/iam","title":"create_group","content":"pub fn create_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.create_group\naws_api/iam create_group","url":"aws_api/iam.html#create_group"},{"doc":"aws_api/iam","title":"create_instance_profile","content":"pub fn create_instance_profile(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.create_instance_profile\naws_api/iam create_instance_profile","url":"aws_api/iam.html#create_instance_profile"},{"doc":"aws_api/iam","title":"create_login_profile","content":"pub fn create_login_profile(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.create_login_profile\naws_api/iam create_login_profile","url":"aws_api/iam.html#create_login_profile"},{"doc":"aws_api/iam","title":"create_open_id_connect_provider","content":"pub fn create_open_id_connect_provider(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.create_open_id_connect_provider\naws_api/iam create_open_id_connect_provider","url":"aws_api/iam.html#create_open_id_connect_provider"},{"doc":"aws_api/iam","title":"create_policy","content":"pub fn create_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.create_policy\naws_api/iam create_policy","url":"aws_api/iam.html#create_policy"},{"doc":"aws_api/iam","title":"create_policy_version","content":"pub fn create_policy_version(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.create_policy_version\naws_api/iam create_policy_version","url":"aws_api/iam.html#create_policy_version"},{"doc":"aws_api/iam","title":"create_role","content":"pub fn create_role(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.create_role\naws_api/iam create_role","url":"aws_api/iam.html#create_role"},{"doc":"aws_api/iam","title":"create_saml_provider","content":"pub fn create_saml_provider(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.create_saml_provider\naws_api/iam create_saml_provider","url":"aws_api/iam.html#create_saml_provider"},{"doc":"aws_api/iam","title":"create_service_linked_role","content":"pub fn create_service_linked_role(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.create_service_linked_role\naws_api/iam create_service_linked_role","url":"aws_api/iam.html#create_service_linked_role"},{"doc":"aws_api/iam","title":"create_service_specific_credential","content":"pub fn create_service_specific_credential(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.create_service_specific_credential\naws_api/iam create_service_specific_credential","url":"aws_api/iam.html#create_service_specific_credential"},{"doc":"aws_api/iam","title":"create_user","content":"pub fn create_user(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.create_user\naws_api/iam create_user","url":"aws_api/iam.html#create_user"},{"doc":"aws_api/iam","title":"create_virtual_mfa_device","content":"pub fn create_virtual_mfa_device(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.create_virtual_mfa_device\naws_api/iam create_virtual_mfa_device","url":"aws_api/iam.html#create_virtual_mfa_device"},{"doc":"aws_api/iam","title":"deactivate_mfa_device","content":"pub fn deactivate_mfa_device(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.deactivate_mfa_device\naws_api/iam deactivate_mfa_device","url":"aws_api/iam.html#deactivate_mfa_device"},{"doc":"aws_api/iam","title":"delete_access_key","content":"pub fn delete_access_key(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.delete_access_key\naws_api/iam delete_access_key","url":"aws_api/iam.html#delete_access_key"},{"doc":"aws_api/iam","title":"delete_account_alias","content":"pub fn delete_account_alias(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.delete_account_alias\naws_api/iam delete_account_alias","url":"aws_api/iam.html#delete_account_alias"},{"doc":"aws_api/iam","title":"delete_account_password_policy","content":"pub fn delete_account_password_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.delete_account_password_policy\naws_api/iam delete_account_password_policy","url":"aws_api/iam.html#delete_account_password_policy"},{"doc":"aws_api/iam","title":"delete_group","content":"pub fn delete_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.delete_group\naws_api/iam delete_group","url":"aws_api/iam.html#delete_group"},{"doc":"aws_api/iam","title":"delete_group_policy","content":"pub fn delete_group_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.delete_group_policy\naws_api/iam delete_group_policy","url":"aws_api/iam.html#delete_group_policy"},{"doc":"aws_api/iam","title":"delete_instance_profile","content":"pub fn delete_instance_profile(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.delete_instance_profile\naws_api/iam delete_instance_profile","url":"aws_api/iam.html#delete_instance_profile"},{"doc":"aws_api/iam","title":"delete_login_profile","content":"pub fn delete_login_profile(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.delete_login_profile\naws_api/iam delete_login_profile","url":"aws_api/iam.html#delete_login_profile"},{"doc":"aws_api/iam","title":"delete_open_id_connect_provider","content":"pub fn delete_open_id_connect_provider(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.delete_open_id_connect_provider\naws_api/iam delete_open_id_connect_provider","url":"aws_api/iam.html#delete_open_id_connect_provider"},{"doc":"aws_api/iam","title":"delete_policy","content":"pub fn delete_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.delete_policy\naws_api/iam delete_policy","url":"aws_api/iam.html#delete_policy"},{"doc":"aws_api/iam","title":"delete_policy_version","content":"pub fn delete_policy_version(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.delete_policy_version\naws_api/iam delete_policy_version","url":"aws_api/iam.html#delete_policy_version"},{"doc":"aws_api/iam","title":"delete_role","content":"pub fn delete_role(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.delete_role\naws_api/iam delete_role","url":"aws_api/iam.html#delete_role"},{"doc":"aws_api/iam","title":"delete_role_permissions_boundary","content":"pub fn delete_role_permissions_boundary(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.delete_role_permissions_boundary\naws_api/iam delete_role_permissions_boundary","url":"aws_api/iam.html#delete_role_permissions_boundary"},{"doc":"aws_api/iam","title":"delete_role_policy","content":"pub fn delete_role_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.delete_role_policy\naws_api/iam delete_role_policy","url":"aws_api/iam.html#delete_role_policy"},{"doc":"aws_api/iam","title":"delete_saml_provider","content":"pub fn delete_saml_provider(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.delete_saml_provider\naws_api/iam delete_saml_provider","url":"aws_api/iam.html#delete_saml_provider"},{"doc":"aws_api/iam","title":"delete_server_certificate","content":"pub fn delete_server_certificate(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.delete_server_certificate\naws_api/iam delete_server_certificate","url":"aws_api/iam.html#delete_server_certificate"},{"doc":"aws_api/iam","title":"delete_service_linked_role","content":"pub fn delete_service_linked_role(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.delete_service_linked_role\naws_api/iam delete_service_linked_role","url":"aws_api/iam.html#delete_service_linked_role"},{"doc":"aws_api/iam","title":"delete_service_specific_credential","content":"pub fn delete_service_specific_credential(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.delete_service_specific_credential\naws_api/iam delete_service_specific_credential","url":"aws_api/iam.html#delete_service_specific_credential"},{"doc":"aws_api/iam","title":"delete_signing_certificate","content":"pub fn delete_signing_certificate(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.delete_signing_certificate\naws_api/iam delete_signing_certificate","url":"aws_api/iam.html#delete_signing_certificate"},{"doc":"aws_api/iam","title":"delete_ssh_public_key","content":"pub fn delete_ssh_public_key(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.delete_ssh_public_key\naws_api/iam delete_ssh_public_key","url":"aws_api/iam.html#delete_ssh_public_key"},{"doc":"aws_api/iam","title":"delete_user","content":"pub fn delete_user(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.delete_user\naws_api/iam delete_user","url":"aws_api/iam.html#delete_user"},{"doc":"aws_api/iam","title":"delete_user_permissions_boundary","content":"pub fn delete_user_permissions_boundary(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.delete_user_permissions_boundary\naws_api/iam delete_user_permissions_boundary","url":"aws_api/iam.html#delete_user_permissions_boundary"},{"doc":"aws_api/iam","title":"delete_user_policy","content":"pub fn delete_user_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.delete_user_policy\naws_api/iam delete_user_policy","url":"aws_api/iam.html#delete_user_policy"},{"doc":"aws_api/iam","title":"delete_virtual_mfa_device","content":"pub fn delete_virtual_mfa_device(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.delete_virtual_mfa_device\naws_api/iam delete_virtual_mfa_device","url":"aws_api/iam.html#delete_virtual_mfa_device"},{"doc":"aws_api/iam","title":"detach_group_policy","content":"pub fn detach_group_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.detach_group_policy\naws_api/iam detach_group_policy","url":"aws_api/iam.html#detach_group_policy"},{"doc":"aws_api/iam","title":"detach_role_policy","content":"pub fn detach_role_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.detach_role_policy\naws_api/iam detach_role_policy","url":"aws_api/iam.html#detach_role_policy"},{"doc":"aws_api/iam","title":"detach_user_policy","content":"pub fn detach_user_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.detach_user_policy\naws_api/iam detach_user_policy","url":"aws_api/iam.html#detach_user_policy"},{"doc":"aws_api/iam","title":"enable_mfa_device","content":"pub fn enable_mfa_device(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.enable_mfa_device\naws_api/iam enable_mfa_device","url":"aws_api/iam.html#enable_mfa_device"},{"doc":"aws_api/iam","title":"generate_credential_report","content":"pub fn generate_credential_report(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.generate_credential_report\naws_api/iam generate_credential_report","url":"aws_api/iam.html#generate_credential_report"},{"doc":"aws_api/iam","title":"generate_organizations_access_report","content":"pub fn generate_organizations_access_report(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.generate_organizations_access_report\naws_api/iam generate_organizations_access_report","url":"aws_api/iam.html#generate_organizations_access_report"},{"doc":"aws_api/iam","title":"generate_service_last_accessed_details","content":"pub fn generate_service_last_accessed_details(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.generate_service_last_accessed_details\naws_api/iam generate_service_last_accessed_details","url":"aws_api/iam.html#generate_service_last_accessed_details"},{"doc":"aws_api/iam","title":"get_access_key_last_used","content":"pub fn get_access_key_last_used(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.get_access_key_last_used\naws_api/iam get_access_key_last_used","url":"aws_api/iam.html#get_access_key_last_used"},{"doc":"aws_api/iam","title":"get_account_authorization_details","content":"pub fn get_account_authorization_details(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.get_account_authorization_details\naws_api/iam get_account_authorization_details","url":"aws_api/iam.html#get_account_authorization_details"},{"doc":"aws_api/iam","title":"get_account_password_policy","content":"pub fn get_account_password_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.get_account_password_policy\naws_api/iam get_account_password_policy","url":"aws_api/iam.html#get_account_password_policy"},{"doc":"aws_api/iam","title":"get_account_summary","content":"pub fn get_account_summary(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.get_account_summary\naws_api/iam get_account_summary","url":"aws_api/iam.html#get_account_summary"},{"doc":"aws_api/iam","title":"get_context_keys_for_custom_policy","content":"pub fn get_context_keys_for_custom_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.get_context_keys_for_custom_policy\naws_api/iam get_context_keys_for_custom_policy","url":"aws_api/iam.html#get_context_keys_for_custom_policy"},{"doc":"aws_api/iam","title":"get_context_keys_for_principal_policy","content":"pub fn get_context_keys_for_principal_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.get_context_keys_for_principal_policy\naws_api/iam get_context_keys_for_principal_policy","url":"aws_api/iam.html#get_context_keys_for_principal_policy"},{"doc":"aws_api/iam","title":"get_credential_report","content":"pub fn get_credential_report(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.get_credential_report\naws_api/iam get_credential_report","url":"aws_api/iam.html#get_credential_report"},{"doc":"aws_api/iam","title":"get_group","content":"pub fn get_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.get_group\naws_api/iam get_group","url":"aws_api/iam.html#get_group"},{"doc":"aws_api/iam","title":"get_group_policy","content":"pub fn get_group_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.get_group_policy\naws_api/iam get_group_policy","url":"aws_api/iam.html#get_group_policy"},{"doc":"aws_api/iam","title":"get_instance_profile","content":"pub fn get_instance_profile(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.get_instance_profile\naws_api/iam get_instance_profile","url":"aws_api/iam.html#get_instance_profile"},{"doc":"aws_api/iam","title":"get_login_profile","content":"pub fn get_login_profile(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.get_login_profile\naws_api/iam get_login_profile","url":"aws_api/iam.html#get_login_profile"},{"doc":"aws_api/iam","title":"get_mfa_device","content":"pub fn get_mfa_device(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.get_mfa_device\naws_api/iam get_mfa_device","url":"aws_api/iam.html#get_mfa_device"},{"doc":"aws_api/iam","title":"get_open_id_connect_provider","content":"pub fn get_open_id_connect_provider(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.get_open_id_connect_provider\naws_api/iam get_open_id_connect_provider","url":"aws_api/iam.html#get_open_id_connect_provider"},{"doc":"aws_api/iam","title":"get_organizations_access_report","content":"pub fn get_organizations_access_report(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.get_organizations_access_report\naws_api/iam get_organizations_access_report","url":"aws_api/iam.html#get_organizations_access_report"},{"doc":"aws_api/iam","title":"get_policy","content":"pub fn get_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.get_policy\naws_api/iam get_policy","url":"aws_api/iam.html#get_policy"},{"doc":"aws_api/iam","title":"get_policy_version","content":"pub fn get_policy_version(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.get_policy_version\naws_api/iam get_policy_version","url":"aws_api/iam.html#get_policy_version"},{"doc":"aws_api/iam","title":"get_role","content":"pub fn get_role(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.get_role\naws_api/iam get_role","url":"aws_api/iam.html#get_role"},{"doc":"aws_api/iam","title":"get_role_policy","content":"pub fn get_role_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.get_role_policy\naws_api/iam get_role_policy","url":"aws_api/iam.html#get_role_policy"},{"doc":"aws_api/iam","title":"get_saml_provider","content":"pub fn get_saml_provider(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.get_saml_provider\naws_api/iam get_saml_provider","url":"aws_api/iam.html#get_saml_provider"},{"doc":"aws_api/iam","title":"get_server_certificate","content":"pub fn get_server_certificate(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.get_server_certificate\naws_api/iam get_server_certificate","url":"aws_api/iam.html#get_server_certificate"},{"doc":"aws_api/iam","title":"get_service_last_accessed_details","content":"pub fn get_service_last_accessed_details(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.get_service_last_accessed_details\naws_api/iam get_service_last_accessed_details","url":"aws_api/iam.html#get_service_last_accessed_details"},{"doc":"aws_api/iam","title":"get_service_last_accessed_details_with_entities","content":"pub fn get_service_last_accessed_details_with_entities(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.get_service_last_accessed_details_with_entities\naws_api/iam get_service_last_accessed_details_with_entities","url":"aws_api/iam.html#get_service_last_accessed_details_with_entities"},{"doc":"aws_api/iam","title":"get_service_linked_role_deletion_status","content":"pub fn get_service_linked_role_deletion_status(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.get_service_linked_role_deletion_status\naws_api/iam get_service_linked_role_deletion_status","url":"aws_api/iam.html#get_service_linked_role_deletion_status"},{"doc":"aws_api/iam","title":"get_ssh_public_key","content":"pub fn get_ssh_public_key(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.get_ssh_public_key\naws_api/iam get_ssh_public_key","url":"aws_api/iam.html#get_ssh_public_key"},{"doc":"aws_api/iam","title":"get_user","content":"pub fn get_user(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.get_user\naws_api/iam get_user","url":"aws_api/iam.html#get_user"},{"doc":"aws_api/iam","title":"get_user_policy","content":"pub fn get_user_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.get_user_policy\naws_api/iam get_user_policy","url":"aws_api/iam.html#get_user_policy"},{"doc":"aws_api/iam","title":"list_access_keys","content":"pub fn list_access_keys(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.list_access_keys\naws_api/iam list_access_keys","url":"aws_api/iam.html#list_access_keys"},{"doc":"aws_api/iam","title":"list_account_aliases","content":"pub fn list_account_aliases(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.list_account_aliases\naws_api/iam list_account_aliases","url":"aws_api/iam.html#list_account_aliases"},{"doc":"aws_api/iam","title":"list_attached_group_policies","content":"pub fn list_attached_group_policies(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.list_attached_group_policies\naws_api/iam list_attached_group_policies","url":"aws_api/iam.html#list_attached_group_policies"},{"doc":"aws_api/iam","title":"list_attached_role_policies","content":"pub fn list_attached_role_policies(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.list_attached_role_policies\naws_api/iam list_attached_role_policies","url":"aws_api/iam.html#list_attached_role_policies"},{"doc":"aws_api/iam","title":"list_attached_user_policies","content":"pub fn list_attached_user_policies(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.list_attached_user_policies\naws_api/iam list_attached_user_policies","url":"aws_api/iam.html#list_attached_user_policies"},{"doc":"aws_api/iam","title":"list_entities_for_policy","content":"pub fn list_entities_for_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.list_entities_for_policy\naws_api/iam list_entities_for_policy","url":"aws_api/iam.html#list_entities_for_policy"},{"doc":"aws_api/iam","title":"list_group_policies","content":"pub fn list_group_policies(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.list_group_policies\naws_api/iam list_group_policies","url":"aws_api/iam.html#list_group_policies"},{"doc":"aws_api/iam","title":"list_groups","content":"pub fn list_groups(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.list_groups\naws_api/iam list_groups","url":"aws_api/iam.html#list_groups"},{"doc":"aws_api/iam","title":"list_groups_for_user","content":"pub fn list_groups_for_user(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.list_groups_for_user\naws_api/iam list_groups_for_user","url":"aws_api/iam.html#list_groups_for_user"},{"doc":"aws_api/iam","title":"list_instance_profile_tags","content":"pub fn list_instance_profile_tags(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.list_instance_profile_tags\naws_api/iam list_instance_profile_tags","url":"aws_api/iam.html#list_instance_profile_tags"},{"doc":"aws_api/iam","title":"list_instance_profiles","content":"pub fn list_instance_profiles(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.list_instance_profiles\naws_api/iam list_instance_profiles","url":"aws_api/iam.html#list_instance_profiles"},{"doc":"aws_api/iam","title":"list_instance_profiles_for_role","content":"pub fn list_instance_profiles_for_role(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.list_instance_profiles_for_role\naws_api/iam list_instance_profiles_for_role","url":"aws_api/iam.html#list_instance_profiles_for_role"},{"doc":"aws_api/iam","title":"list_mfa_device_tags","content":"pub fn list_mfa_device_tags(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.list_mfa_device_tags\naws_api/iam list_mfa_device_tags","url":"aws_api/iam.html#list_mfa_device_tags"},{"doc":"aws_api/iam","title":"list_mfa_devices","content":"pub fn list_mfa_devices(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.list_mfa_devices\naws_api/iam list_mfa_devices","url":"aws_api/iam.html#list_mfa_devices"},{"doc":"aws_api/iam","title":"list_open_id_connect_provider_tags","content":"pub fn list_open_id_connect_provider_tags(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.list_open_id_connect_provider_tags\naws_api/iam list_open_id_connect_provider_tags","url":"aws_api/iam.html#list_open_id_connect_provider_tags"},{"doc":"aws_api/iam","title":"list_open_id_connect_providers","content":"pub fn list_open_id_connect_providers(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.list_open_id_connect_providers\naws_api/iam list_open_id_connect_providers","url":"aws_api/iam.html#list_open_id_connect_providers"},{"doc":"aws_api/iam","title":"list_policies","content":"pub fn list_policies(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.list_policies\naws_api/iam list_policies","url":"aws_api/iam.html#list_policies"},{"doc":"aws_api/iam","title":"list_policies_granting_service_access","content":"pub fn list_policies_granting_service_access(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.list_policies_granting_service_access\naws_api/iam list_policies_granting_service_access","url":"aws_api/iam.html#list_policies_granting_service_access"},{"doc":"aws_api/iam","title":"list_policy_tags","content":"pub fn list_policy_tags(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.list_policy_tags\naws_api/iam list_policy_tags","url":"aws_api/iam.html#list_policy_tags"},{"doc":"aws_api/iam","title":"list_policy_versions","content":"pub fn list_policy_versions(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.list_policy_versions\naws_api/iam list_policy_versions","url":"aws_api/iam.html#list_policy_versions"},{"doc":"aws_api/iam","title":"list_role_policies","content":"pub fn list_role_policies(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.list_role_policies\naws_api/iam list_role_policies","url":"aws_api/iam.html#list_role_policies"},{"doc":"aws_api/iam","title":"list_role_tags","content":"pub fn list_role_tags(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.list_role_tags\naws_api/iam list_role_tags","url":"aws_api/iam.html#list_role_tags"},{"doc":"aws_api/iam","title":"list_roles","content":"pub fn list_roles(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.list_roles\naws_api/iam list_roles","url":"aws_api/iam.html#list_roles"},{"doc":"aws_api/iam","title":"list_saml_provider_tags","content":"pub fn list_saml_provider_tags(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.list_saml_provider_tags\naws_api/iam list_saml_provider_tags","url":"aws_api/iam.html#list_saml_provider_tags"},{"doc":"aws_api/iam","title":"list_saml_providers","content":"pub fn list_saml_providers(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.list_saml_providers\naws_api/iam list_saml_providers","url":"aws_api/iam.html#list_saml_providers"},{"doc":"aws_api/iam","title":"list_server_certificate_tags","content":"pub fn list_server_certificate_tags(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.list_server_certificate_tags\naws_api/iam list_server_certificate_tags","url":"aws_api/iam.html#list_server_certificate_tags"},{"doc":"aws_api/iam","title":"list_server_certificates","content":"pub fn list_server_certificates(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.list_server_certificates\naws_api/iam list_server_certificates","url":"aws_api/iam.html#list_server_certificates"},{"doc":"aws_api/iam","title":"list_service_specific_credentials","content":"pub fn list_service_specific_credentials(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.list_service_specific_credentials\naws_api/iam list_service_specific_credentials","url":"aws_api/iam.html#list_service_specific_credentials"},{"doc":"aws_api/iam","title":"list_signing_certificates","content":"pub fn list_signing_certificates(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.list_signing_certificates\naws_api/iam list_signing_certificates","url":"aws_api/iam.html#list_signing_certificates"},{"doc":"aws_api/iam","title":"list_ssh_public_keys","content":"pub fn list_ssh_public_keys(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.list_ssh_public_keys\naws_api/iam list_ssh_public_keys","url":"aws_api/iam.html#list_ssh_public_keys"},{"doc":"aws_api/iam","title":"list_user_policies","content":"pub fn list_user_policies(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.list_user_policies\naws_api/iam list_user_policies","url":"aws_api/iam.html#list_user_policies"},{"doc":"aws_api/iam","title":"list_user_tags","content":"pub fn list_user_tags(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.list_user_tags\naws_api/iam list_user_tags","url":"aws_api/iam.html#list_user_tags"},{"doc":"aws_api/iam","title":"list_users","content":"pub fn list_users(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.list_users\naws_api/iam list_users","url":"aws_api/iam.html#list_users"},{"doc":"aws_api/iam","title":"list_virtual_mfa_devices","content":"pub fn list_virtual_mfa_devices(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.list_virtual_mfa_devices\naws_api/iam list_virtual_mfa_devices","url":"aws_api/iam.html#list_virtual_mfa_devices"},{"doc":"aws_api/iam","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/iam.new\naws_api/iam new","url":"aws_api/iam.html#new"},{"doc":"aws_api/iam","title":"put_group_policy","content":"pub fn put_group_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.put_group_policy\naws_api/iam put_group_policy","url":"aws_api/iam.html#put_group_policy"},{"doc":"aws_api/iam","title":"put_role_permissions_boundary","content":"pub fn put_role_permissions_boundary(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.put_role_permissions_boundary\naws_api/iam put_role_permissions_boundary","url":"aws_api/iam.html#put_role_permissions_boundary"},{"doc":"aws_api/iam","title":"put_role_policy","content":"pub fn put_role_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.put_role_policy\naws_api/iam put_role_policy","url":"aws_api/iam.html#put_role_policy"},{"doc":"aws_api/iam","title":"put_user_permissions_boundary","content":"pub fn put_user_permissions_boundary(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.put_user_permissions_boundary\naws_api/iam put_user_permissions_boundary","url":"aws_api/iam.html#put_user_permissions_boundary"},{"doc":"aws_api/iam","title":"put_user_policy","content":"pub fn put_user_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.put_user_policy\naws_api/iam put_user_policy","url":"aws_api/iam.html#put_user_policy"},{"doc":"aws_api/iam","title":"remove_client_id_from_open_id_connect_provider","content":"pub fn remove_client_id_from_open_id_connect_provider(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.remove_client_id_from_open_id_connect_provider\naws_api/iam remove_client_id_from_open_id_connect_provider","url":"aws_api/iam.html#remove_client_id_from_open_id_connect_provider"},{"doc":"aws_api/iam","title":"remove_role_from_instance_profile","content":"pub fn remove_role_from_instance_profile(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.remove_role_from_instance_profile\naws_api/iam remove_role_from_instance_profile","url":"aws_api/iam.html#remove_role_from_instance_profile"},{"doc":"aws_api/iam","title":"remove_user_from_group","content":"pub fn remove_user_from_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.remove_user_from_group\naws_api/iam remove_user_from_group","url":"aws_api/iam.html#remove_user_from_group"},{"doc":"aws_api/iam","title":"reset_service_specific_credential","content":"pub fn reset_service_specific_credential(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.reset_service_specific_credential\naws_api/iam reset_service_specific_credential","url":"aws_api/iam.html#reset_service_specific_credential"},{"doc":"aws_api/iam","title":"resync_mfa_device","content":"pub fn resync_mfa_device(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.resync_mfa_device\naws_api/iam resync_mfa_device","url":"aws_api/iam.html#resync_mfa_device"},{"doc":"aws_api/iam","title":"set_default_policy_version","content":"pub fn set_default_policy_version(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.set_default_policy_version\naws_api/iam set_default_policy_version","url":"aws_api/iam.html#set_default_policy_version"},{"doc":"aws_api/iam","title":"set_security_token_service_preferences","content":"pub fn set_security_token_service_preferences(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.set_security_token_service_preferences\naws_api/iam set_security_token_service_preferences","url":"aws_api/iam.html#set_security_token_service_preferences"},{"doc":"aws_api/iam","title":"simulate_custom_policy","content":"pub fn simulate_custom_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.simulate_custom_policy\naws_api/iam simulate_custom_policy","url":"aws_api/iam.html#simulate_custom_policy"},{"doc":"aws_api/iam","title":"simulate_principal_policy","content":"pub fn simulate_principal_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.simulate_principal_policy\naws_api/iam simulate_principal_policy","url":"aws_api/iam.html#simulate_principal_policy"},{"doc":"aws_api/iam","title":"tag_instance_profile","content":"pub fn tag_instance_profile(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.tag_instance_profile\naws_api/iam tag_instance_profile","url":"aws_api/iam.html#tag_instance_profile"},{"doc":"aws_api/iam","title":"tag_mfa_device","content":"pub fn tag_mfa_device(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.tag_mfa_device\naws_api/iam tag_mfa_device","url":"aws_api/iam.html#tag_mfa_device"},{"doc":"aws_api/iam","title":"tag_open_id_connect_provider","content":"pub fn tag_open_id_connect_provider(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.tag_open_id_connect_provider\naws_api/iam tag_open_id_connect_provider","url":"aws_api/iam.html#tag_open_id_connect_provider"},{"doc":"aws_api/iam","title":"tag_policy","content":"pub fn tag_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.tag_policy\naws_api/iam tag_policy","url":"aws_api/iam.html#tag_policy"},{"doc":"aws_api/iam","title":"tag_role","content":"pub fn tag_role(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.tag_role\naws_api/iam tag_role","url":"aws_api/iam.html#tag_role"},{"doc":"aws_api/iam","title":"tag_saml_provider","content":"pub fn tag_saml_provider(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.tag_saml_provider\naws_api/iam tag_saml_provider","url":"aws_api/iam.html#tag_saml_provider"},{"doc":"aws_api/iam","title":"tag_server_certificate","content":"pub fn tag_server_certificate(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.tag_server_certificate\naws_api/iam tag_server_certificate","url":"aws_api/iam.html#tag_server_certificate"},{"doc":"aws_api/iam","title":"tag_user","content":"pub fn tag_user(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.tag_user\naws_api/iam tag_user","url":"aws_api/iam.html#tag_user"},{"doc":"aws_api/iam","title":"untag_instance_profile","content":"pub fn untag_instance_profile(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.untag_instance_profile\naws_api/iam untag_instance_profile","url":"aws_api/iam.html#untag_instance_profile"},{"doc":"aws_api/iam","title":"untag_mfa_device","content":"pub fn untag_mfa_device(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.untag_mfa_device\naws_api/iam untag_mfa_device","url":"aws_api/iam.html#untag_mfa_device"},{"doc":"aws_api/iam","title":"untag_open_id_connect_provider","content":"pub fn untag_open_id_connect_provider(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.untag_open_id_connect_provider\naws_api/iam untag_open_id_connect_provider","url":"aws_api/iam.html#untag_open_id_connect_provider"},{"doc":"aws_api/iam","title":"untag_policy","content":"pub fn untag_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.untag_policy\naws_api/iam untag_policy","url":"aws_api/iam.html#untag_policy"},{"doc":"aws_api/iam","title":"untag_role","content":"pub fn untag_role(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.untag_role\naws_api/iam untag_role","url":"aws_api/iam.html#untag_role"},{"doc":"aws_api/iam","title":"untag_saml_provider","content":"pub fn untag_saml_provider(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.untag_saml_provider\naws_api/iam untag_saml_provider","url":"aws_api/iam.html#untag_saml_provider"},{"doc":"aws_api/iam","title":"untag_server_certificate","content":"pub fn untag_server_certificate(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.untag_server_certificate\naws_api/iam untag_server_certificate","url":"aws_api/iam.html#untag_server_certificate"},{"doc":"aws_api/iam","title":"untag_user","content":"pub fn untag_user(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.untag_user\naws_api/iam untag_user","url":"aws_api/iam.html#untag_user"},{"doc":"aws_api/iam","title":"update_access_key","content":"pub fn update_access_key(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.update_access_key\naws_api/iam update_access_key","url":"aws_api/iam.html#update_access_key"},{"doc":"aws_api/iam","title":"update_account_password_policy","content":"pub fn update_account_password_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.update_account_password_policy\naws_api/iam update_account_password_policy","url":"aws_api/iam.html#update_account_password_policy"},{"doc":"aws_api/iam","title":"update_assume_role_policy","content":"pub fn update_assume_role_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.update_assume_role_policy\naws_api/iam update_assume_role_policy","url":"aws_api/iam.html#update_assume_role_policy"},{"doc":"aws_api/iam","title":"update_group","content":"pub fn update_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.update_group\naws_api/iam update_group","url":"aws_api/iam.html#update_group"},{"doc":"aws_api/iam","title":"update_login_profile","content":"pub fn update_login_profile(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.update_login_profile\naws_api/iam update_login_profile","url":"aws_api/iam.html#update_login_profile"},{"doc":"aws_api/iam","title":"update_open_id_connect_provider_thumbprint","content":"pub fn update_open_id_connect_provider_thumbprint(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.update_open_id_connect_provider_thumbprint\naws_api/iam update_open_id_connect_provider_thumbprint","url":"aws_api/iam.html#update_open_id_connect_provider_thumbprint"},{"doc":"aws_api/iam","title":"update_role","content":"pub fn update_role(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.update_role\naws_api/iam update_role","url":"aws_api/iam.html#update_role"},{"doc":"aws_api/iam","title":"update_role_description","content":"pub fn update_role_description(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.update_role_description\naws_api/iam update_role_description","url":"aws_api/iam.html#update_role_description"},{"doc":"aws_api/iam","title":"update_saml_provider","content":"pub fn update_saml_provider(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.update_saml_provider\naws_api/iam update_saml_provider","url":"aws_api/iam.html#update_saml_provider"},{"doc":"aws_api/iam","title":"update_server_certificate","content":"pub fn update_server_certificate(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.update_server_certificate\naws_api/iam update_server_certificate","url":"aws_api/iam.html#update_server_certificate"},{"doc":"aws_api/iam","title":"update_service_specific_credential","content":"pub fn update_service_specific_credential(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.update_service_specific_credential\naws_api/iam update_service_specific_credential","url":"aws_api/iam.html#update_service_specific_credential"},{"doc":"aws_api/iam","title":"update_signing_certificate","content":"pub fn update_signing_certificate(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.update_signing_certificate\naws_api/iam update_signing_certificate","url":"aws_api/iam.html#update_signing_certificate"},{"doc":"aws_api/iam","title":"update_ssh_public_key","content":"pub fn update_ssh_public_key(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.update_ssh_public_key\naws_api/iam update_ssh_public_key","url":"aws_api/iam.html#update_ssh_public_key"},{"doc":"aws_api/iam","title":"update_user","content":"pub fn update_user(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.update_user\naws_api/iam update_user","url":"aws_api/iam.html#update_user"},{"doc":"aws_api/iam","title":"upload_server_certificate","content":"pub fn upload_server_certificate(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.upload_server_certificate\naws_api/iam upload_server_certificate","url":"aws_api/iam.html#upload_server_certificate"},{"doc":"aws_api/iam","title":"upload_signing_certificate","content":"pub fn upload_signing_certificate(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.upload_signing_certificate\naws_api/iam upload_signing_certificate","url":"aws_api/iam.html#upload_signing_certificate"},{"doc":"aws_api/iam","title":"upload_ssh_public_key","content":"pub fn upload_ssh_public_key(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iam.upload_ssh_public_key\naws_api/iam upload_ssh_public_key","url":"aws_api/iam.html#upload_ssh_public_key"},{"doc":"aws_api/iam","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/iam.with_custom_endpoint\naws_api/iam with_custom_endpoint","url":"aws_api/iam.html#with_custom_endpoint"},{"doc":"aws_api/iam","title":"aws_api/iam","content":"","url":"aws_api/iam.html"},{"doc":"aws_api/identitystore","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/identitystore.Client\naws_api/identitystore Client","url":"aws_api/identitystore.html#Client"},{"doc":"aws_api/identitystore","title":"get_group_id","content":"pub fn get_group_id(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/identitystore.get_group_id\naws_api/identitystore get_group_id","url":"aws_api/identitystore.html#get_group_id"},{"doc":"aws_api/identitystore","title":"get_group_membership_id","content":"pub fn get_group_membership_id(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/identitystore.get_group_membership_id\naws_api/identitystore get_group_membership_id","url":"aws_api/identitystore.html#get_group_membership_id"},{"doc":"aws_api/identitystore","title":"get_user_id","content":"pub fn get_user_id(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/identitystore.get_user_id\naws_api/identitystore get_user_id","url":"aws_api/identitystore.html#get_user_id"},{"doc":"aws_api/identitystore","title":"is_member_in_groups","content":"pub fn is_member_in_groups(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/identitystore.is_member_in_groups\naws_api/identitystore is_member_in_groups","url":"aws_api/identitystore.html#is_member_in_groups"},{"doc":"aws_api/identitystore","title":"list_group_memberships_for_member","content":"pub fn list_group_memberships_for_member(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/identitystore.list_group_memberships_for_member\naws_api/identitystore list_group_memberships_for_member","url":"aws_api/identitystore.html#list_group_memberships_for_member"},{"doc":"aws_api/identitystore","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/identitystore.new\naws_api/identitystore new","url":"aws_api/identitystore.html#new"},{"doc":"aws_api/identitystore","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/identitystore.with_custom_endpoint\naws_api/identitystore with_custom_endpoint","url":"aws_api/identitystore.html#with_custom_endpoint"},{"doc":"aws_api/identitystore","title":"aws_api/identitystore","content":"","url":"aws_api/identitystore.html"},{"doc":"aws_api/inspector","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/inspector.Client\naws_api/inspector Client","url":"aws_api/inspector.html#Client"},{"doc":"aws_api/inspector","title":"add_attributes_to_findings","content":"pub fn add_attributes_to_findings(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector.add_attributes_to_findings\naws_api/inspector add_attributes_to_findings","url":"aws_api/inspector.html#add_attributes_to_findings"},{"doc":"aws_api/inspector","title":"create_assessment_target","content":"pub fn create_assessment_target(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector.create_assessment_target\naws_api/inspector create_assessment_target","url":"aws_api/inspector.html#create_assessment_target"},{"doc":"aws_api/inspector","title":"create_assessment_template","content":"pub fn create_assessment_template(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector.create_assessment_template\naws_api/inspector create_assessment_template","url":"aws_api/inspector.html#create_assessment_template"},{"doc":"aws_api/inspector","title":"create_exclusions_preview","content":"pub fn create_exclusions_preview(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector.create_exclusions_preview\naws_api/inspector create_exclusions_preview","url":"aws_api/inspector.html#create_exclusions_preview"},{"doc":"aws_api/inspector","title":"create_resource_group","content":"pub fn create_resource_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector.create_resource_group\naws_api/inspector create_resource_group","url":"aws_api/inspector.html#create_resource_group"},{"doc":"aws_api/inspector","title":"delete_assessment_run","content":"pub fn delete_assessment_run(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector.delete_assessment_run\naws_api/inspector delete_assessment_run","url":"aws_api/inspector.html#delete_assessment_run"},{"doc":"aws_api/inspector","title":"delete_assessment_target","content":"pub fn delete_assessment_target(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector.delete_assessment_target\naws_api/inspector delete_assessment_target","url":"aws_api/inspector.html#delete_assessment_target"},{"doc":"aws_api/inspector","title":"delete_assessment_template","content":"pub fn delete_assessment_template(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector.delete_assessment_template\naws_api/inspector delete_assessment_template","url":"aws_api/inspector.html#delete_assessment_template"},{"doc":"aws_api/inspector","title":"describe_assessment_runs","content":"pub fn describe_assessment_runs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector.describe_assessment_runs\naws_api/inspector describe_assessment_runs","url":"aws_api/inspector.html#describe_assessment_runs"},{"doc":"aws_api/inspector","title":"describe_assessment_targets","content":"pub fn describe_assessment_targets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector.describe_assessment_targets\naws_api/inspector describe_assessment_targets","url":"aws_api/inspector.html#describe_assessment_targets"},{"doc":"aws_api/inspector","title":"describe_assessment_templates","content":"pub fn describe_assessment_templates(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector.describe_assessment_templates\naws_api/inspector describe_assessment_templates","url":"aws_api/inspector.html#describe_assessment_templates"},{"doc":"aws_api/inspector","title":"describe_cross_account_access_role","content":"pub fn describe_cross_account_access_role(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector.describe_cross_account_access_role\naws_api/inspector describe_cross_account_access_role","url":"aws_api/inspector.html#describe_cross_account_access_role"},{"doc":"aws_api/inspector","title":"describe_exclusions","content":"pub fn describe_exclusions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector.describe_exclusions\naws_api/inspector describe_exclusions","url":"aws_api/inspector.html#describe_exclusions"},{"doc":"aws_api/inspector","title":"describe_findings","content":"pub fn describe_findings(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector.describe_findings\naws_api/inspector describe_findings","url":"aws_api/inspector.html#describe_findings"},{"doc":"aws_api/inspector","title":"describe_resource_groups","content":"pub fn describe_resource_groups(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector.describe_resource_groups\naws_api/inspector describe_resource_groups","url":"aws_api/inspector.html#describe_resource_groups"},{"doc":"aws_api/inspector","title":"describe_rules_packages","content":"pub fn describe_rules_packages(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector.describe_rules_packages\naws_api/inspector describe_rules_packages","url":"aws_api/inspector.html#describe_rules_packages"},{"doc":"aws_api/inspector","title":"get_assessment_report","content":"pub fn get_assessment_report(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector.get_assessment_report\naws_api/inspector get_assessment_report","url":"aws_api/inspector.html#get_assessment_report"},{"doc":"aws_api/inspector","title":"get_exclusions_preview","content":"pub fn get_exclusions_preview(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector.get_exclusions_preview\naws_api/inspector get_exclusions_preview","url":"aws_api/inspector.html#get_exclusions_preview"},{"doc":"aws_api/inspector","title":"get_telemetry_metadata","content":"pub fn get_telemetry_metadata(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector.get_telemetry_metadata\naws_api/inspector get_telemetry_metadata","url":"aws_api/inspector.html#get_telemetry_metadata"},{"doc":"aws_api/inspector","title":"list_assessment_run_agents","content":"pub fn list_assessment_run_agents(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector.list_assessment_run_agents\naws_api/inspector list_assessment_run_agents","url":"aws_api/inspector.html#list_assessment_run_agents"},{"doc":"aws_api/inspector","title":"list_assessment_runs","content":"pub fn list_assessment_runs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector.list_assessment_runs\naws_api/inspector list_assessment_runs","url":"aws_api/inspector.html#list_assessment_runs"},{"doc":"aws_api/inspector","title":"list_assessment_targets","content":"pub fn list_assessment_targets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector.list_assessment_targets\naws_api/inspector list_assessment_targets","url":"aws_api/inspector.html#list_assessment_targets"},{"doc":"aws_api/inspector","title":"list_assessment_templates","content":"pub fn list_assessment_templates(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector.list_assessment_templates\naws_api/inspector list_assessment_templates","url":"aws_api/inspector.html#list_assessment_templates"},{"doc":"aws_api/inspector","title":"list_event_subscriptions","content":"pub fn list_event_subscriptions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector.list_event_subscriptions\naws_api/inspector list_event_subscriptions","url":"aws_api/inspector.html#list_event_subscriptions"},{"doc":"aws_api/inspector","title":"list_exclusions","content":"pub fn list_exclusions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector.list_exclusions\naws_api/inspector list_exclusions","url":"aws_api/inspector.html#list_exclusions"},{"doc":"aws_api/inspector","title":"list_findings","content":"pub fn list_findings(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector.list_findings\naws_api/inspector list_findings","url":"aws_api/inspector.html#list_findings"},{"doc":"aws_api/inspector","title":"list_rules_packages","content":"pub fn list_rules_packages(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector.list_rules_packages\naws_api/inspector list_rules_packages","url":"aws_api/inspector.html#list_rules_packages"},{"doc":"aws_api/inspector","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector.list_tags_for_resource\naws_api/inspector list_tags_for_resource","url":"aws_api/inspector.html#list_tags_for_resource"},{"doc":"aws_api/inspector","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/inspector.new\naws_api/inspector new","url":"aws_api/inspector.html#new"},{"doc":"aws_api/inspector","title":"preview_agents","content":"pub fn preview_agents(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector.preview_agents\naws_api/inspector preview_agents","url":"aws_api/inspector.html#preview_agents"},{"doc":"aws_api/inspector","title":"register_cross_account_access_role","content":"pub fn register_cross_account_access_role(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector.register_cross_account_access_role\naws_api/inspector register_cross_account_access_role","url":"aws_api/inspector.html#register_cross_account_access_role"},{"doc":"aws_api/inspector","title":"remove_attributes_from_findings","content":"pub fn remove_attributes_from_findings(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector.remove_attributes_from_findings\naws_api/inspector remove_attributes_from_findings","url":"aws_api/inspector.html#remove_attributes_from_findings"},{"doc":"aws_api/inspector","title":"set_tags_for_resource","content":"pub fn set_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector.set_tags_for_resource\naws_api/inspector set_tags_for_resource","url":"aws_api/inspector.html#set_tags_for_resource"},{"doc":"aws_api/inspector","title":"start_assessment_run","content":"pub fn start_assessment_run(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector.start_assessment_run\naws_api/inspector start_assessment_run","url":"aws_api/inspector.html#start_assessment_run"},{"doc":"aws_api/inspector","title":"stop_assessment_run","content":"pub fn stop_assessment_run(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector.stop_assessment_run\naws_api/inspector stop_assessment_run","url":"aws_api/inspector.html#stop_assessment_run"},{"doc":"aws_api/inspector","title":"subscribe_to_event","content":"pub fn subscribe_to_event(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector.subscribe_to_event\naws_api/inspector subscribe_to_event","url":"aws_api/inspector.html#subscribe_to_event"},{"doc":"aws_api/inspector","title":"unsubscribe_from_event","content":"pub fn unsubscribe_from_event(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector.unsubscribe_from_event\naws_api/inspector unsubscribe_from_event","url":"aws_api/inspector.html#unsubscribe_from_event"},{"doc":"aws_api/inspector","title":"update_assessment_target","content":"pub fn update_assessment_target(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector.update_assessment_target\naws_api/inspector update_assessment_target","url":"aws_api/inspector.html#update_assessment_target"},{"doc":"aws_api/inspector","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/inspector.with_custom_endpoint\naws_api/inspector with_custom_endpoint","url":"aws_api/inspector.html#with_custom_endpoint"},{"doc":"aws_api/inspector","title":"aws_api/inspector","content":"","url":"aws_api/inspector.html"},{"doc":"aws_api/inspector2","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/inspector2.Client\naws_api/inspector2 Client","url":"aws_api/inspector2.html#Client"},{"doc":"aws_api/inspector2","title":"associate_member","content":"pub fn associate_member(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.associate_member\naws_api/inspector2 associate_member","url":"aws_api/inspector2.html#associate_member"},{"doc":"aws_api/inspector2","title":"batch_get_account_status","content":"pub fn batch_get_account_status(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.batch_get_account_status\naws_api/inspector2 batch_get_account_status","url":"aws_api/inspector2.html#batch_get_account_status"},{"doc":"aws_api/inspector2","title":"batch_get_code_snippet","content":"pub fn batch_get_code_snippet(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.batch_get_code_snippet\naws_api/inspector2 batch_get_code_snippet","url":"aws_api/inspector2.html#batch_get_code_snippet"},{"doc":"aws_api/inspector2","title":"batch_get_finding_details","content":"pub fn batch_get_finding_details(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.batch_get_finding_details\naws_api/inspector2 batch_get_finding_details","url":"aws_api/inspector2.html#batch_get_finding_details"},{"doc":"aws_api/inspector2","title":"batch_get_free_trial_info","content":"pub fn batch_get_free_trial_info(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.batch_get_free_trial_info\naws_api/inspector2 batch_get_free_trial_info","url":"aws_api/inspector2.html#batch_get_free_trial_info"},{"doc":"aws_api/inspector2","title":"batch_get_member_ec2_deep_inspection_status","content":"pub fn batch_get_member_ec2_deep_inspection_status(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.batch_get_member_ec2_deep_inspection_status\naws_api/inspector2 batch_get_member_ec2_deep_inspection_status","url":"aws_api/inspector2.html#batch_get_member_ec2_deep_inspection_status"},{"doc":"aws_api/inspector2","title":"batch_update_member_ec2_deep_inspection_status","content":"pub fn batch_update_member_ec2_deep_inspection_status(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.batch_update_member_ec2_deep_inspection_status\naws_api/inspector2 batch_update_member_ec2_deep_inspection_status","url":"aws_api/inspector2.html#batch_update_member_ec2_deep_inspection_status"},{"doc":"aws_api/inspector2","title":"cancel_findings_report","content":"pub fn cancel_findings_report(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.cancel_findings_report\naws_api/inspector2 cancel_findings_report","url":"aws_api/inspector2.html#cancel_findings_report"},{"doc":"aws_api/inspector2","title":"cancel_sbom_export","content":"pub fn cancel_sbom_export(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.cancel_sbom_export\naws_api/inspector2 cancel_sbom_export","url":"aws_api/inspector2.html#cancel_sbom_export"},{"doc":"aws_api/inspector2","title":"create_cis_scan_configuration","content":"pub fn create_cis_scan_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.create_cis_scan_configuration\naws_api/inspector2 create_cis_scan_configuration","url":"aws_api/inspector2.html#create_cis_scan_configuration"},{"doc":"aws_api/inspector2","title":"create_filter","content":"pub fn create_filter(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.create_filter\naws_api/inspector2 create_filter","url":"aws_api/inspector2.html#create_filter"},{"doc":"aws_api/inspector2","title":"create_findings_report","content":"pub fn create_findings_report(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.create_findings_report\naws_api/inspector2 create_findings_report","url":"aws_api/inspector2.html#create_findings_report"},{"doc":"aws_api/inspector2","title":"create_sbom_export","content":"pub fn create_sbom_export(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.create_sbom_export\naws_api/inspector2 create_sbom_export","url":"aws_api/inspector2.html#create_sbom_export"},{"doc":"aws_api/inspector2","title":"delete_cis_scan_configuration","content":"pub fn delete_cis_scan_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.delete_cis_scan_configuration\naws_api/inspector2 delete_cis_scan_configuration","url":"aws_api/inspector2.html#delete_cis_scan_configuration"},{"doc":"aws_api/inspector2","title":"delete_filter","content":"pub fn delete_filter(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.delete_filter\naws_api/inspector2 delete_filter","url":"aws_api/inspector2.html#delete_filter"},{"doc":"aws_api/inspector2","title":"describe_organization_configuration","content":"pub fn describe_organization_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.describe_organization_configuration\naws_api/inspector2 describe_organization_configuration","url":"aws_api/inspector2.html#describe_organization_configuration"},{"doc":"aws_api/inspector2","title":"disable","content":"pub fn disable(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.disable\naws_api/inspector2 disable","url":"aws_api/inspector2.html#disable"},{"doc":"aws_api/inspector2","title":"disable_delegated_admin_account","content":"pub fn disable_delegated_admin_account(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.disable_delegated_admin_account\naws_api/inspector2 disable_delegated_admin_account","url":"aws_api/inspector2.html#disable_delegated_admin_account"},{"doc":"aws_api/inspector2","title":"disassociate_member","content":"pub fn disassociate_member(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.disassociate_member\naws_api/inspector2 disassociate_member","url":"aws_api/inspector2.html#disassociate_member"},{"doc":"aws_api/inspector2","title":"enable","content":"pub fn enable(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.enable\naws_api/inspector2 enable","url":"aws_api/inspector2.html#enable"},{"doc":"aws_api/inspector2","title":"enable_delegated_admin_account","content":"pub fn enable_delegated_admin_account(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.enable_delegated_admin_account\naws_api/inspector2 enable_delegated_admin_account","url":"aws_api/inspector2.html#enable_delegated_admin_account"},{"doc":"aws_api/inspector2","title":"get_cis_scan_report","content":"pub fn get_cis_scan_report(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.get_cis_scan_report\naws_api/inspector2 get_cis_scan_report","url":"aws_api/inspector2.html#get_cis_scan_report"},{"doc":"aws_api/inspector2","title":"get_cis_scan_result_details","content":"pub fn get_cis_scan_result_details(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.get_cis_scan_result_details\naws_api/inspector2 get_cis_scan_result_details","url":"aws_api/inspector2.html#get_cis_scan_result_details"},{"doc":"aws_api/inspector2","title":"get_configuration","content":"pub fn get_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.get_configuration\naws_api/inspector2 get_configuration","url":"aws_api/inspector2.html#get_configuration"},{"doc":"aws_api/inspector2","title":"get_delegated_admin_account","content":"pub fn get_delegated_admin_account(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.get_delegated_admin_account\naws_api/inspector2 get_delegated_admin_account","url":"aws_api/inspector2.html#get_delegated_admin_account"},{"doc":"aws_api/inspector2","title":"get_ec2_deep_inspection_configuration","content":"pub fn get_ec2_deep_inspection_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.get_ec2_deep_inspection_configuration\naws_api/inspector2 get_ec2_deep_inspection_configuration","url":"aws_api/inspector2.html#get_ec2_deep_inspection_configuration"},{"doc":"aws_api/inspector2","title":"get_encryption_key","content":"pub fn get_encryption_key(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.get_encryption_key\naws_api/inspector2 get_encryption_key","url":"aws_api/inspector2.html#get_encryption_key"},{"doc":"aws_api/inspector2","title":"get_findings_report_status","content":"pub fn get_findings_report_status(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.get_findings_report_status\naws_api/inspector2 get_findings_report_status","url":"aws_api/inspector2.html#get_findings_report_status"},{"doc":"aws_api/inspector2","title":"get_member","content":"pub fn get_member(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.get_member\naws_api/inspector2 get_member","url":"aws_api/inspector2.html#get_member"},{"doc":"aws_api/inspector2","title":"get_sbom_export","content":"pub fn get_sbom_export(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.get_sbom_export\naws_api/inspector2 get_sbom_export","url":"aws_api/inspector2.html#get_sbom_export"},{"doc":"aws_api/inspector2","title":"list_account_permissions","content":"pub fn list_account_permissions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.list_account_permissions\naws_api/inspector2 list_account_permissions","url":"aws_api/inspector2.html#list_account_permissions"},{"doc":"aws_api/inspector2","title":"list_cis_scan_configurations","content":"pub fn list_cis_scan_configurations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.list_cis_scan_configurations\naws_api/inspector2 list_cis_scan_configurations","url":"aws_api/inspector2.html#list_cis_scan_configurations"},{"doc":"aws_api/inspector2","title":"list_cis_scan_results_aggregated_by_checks","content":"pub fn list_cis_scan_results_aggregated_by_checks(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.list_cis_scan_results_aggregated_by_checks\naws_api/inspector2 list_cis_scan_results_aggregated_by_checks","url":"aws_api/inspector2.html#list_cis_scan_results_aggregated_by_checks"},{"doc":"aws_api/inspector2","title":"list_cis_scan_results_aggregated_by_target_resource","content":"pub fn list_cis_scan_results_aggregated_by_target_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.list_cis_scan_results_aggregated_by_target_resource\naws_api/inspector2 list_cis_scan_results_aggregated_by_target_resource","url":"aws_api/inspector2.html#list_cis_scan_results_aggregated_by_target_resource"},{"doc":"aws_api/inspector2","title":"list_cis_scans","content":"pub fn list_cis_scans(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.list_cis_scans\naws_api/inspector2 list_cis_scans","url":"aws_api/inspector2.html#list_cis_scans"},{"doc":"aws_api/inspector2","title":"list_coverage","content":"pub fn list_coverage(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.list_coverage\naws_api/inspector2 list_coverage","url":"aws_api/inspector2.html#list_coverage"},{"doc":"aws_api/inspector2","title":"list_coverage_statistics","content":"pub fn list_coverage_statistics(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.list_coverage_statistics\naws_api/inspector2 list_coverage_statistics","url":"aws_api/inspector2.html#list_coverage_statistics"},{"doc":"aws_api/inspector2","title":"list_delegated_admin_accounts","content":"pub fn list_delegated_admin_accounts(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.list_delegated_admin_accounts\naws_api/inspector2 list_delegated_admin_accounts","url":"aws_api/inspector2.html#list_delegated_admin_accounts"},{"doc":"aws_api/inspector2","title":"list_filters","content":"pub fn list_filters(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.list_filters\naws_api/inspector2 list_filters","url":"aws_api/inspector2.html#list_filters"},{"doc":"aws_api/inspector2","title":"list_finding_aggregations","content":"pub fn list_finding_aggregations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.list_finding_aggregations\naws_api/inspector2 list_finding_aggregations","url":"aws_api/inspector2.html#list_finding_aggregations"},{"doc":"aws_api/inspector2","title":"list_findings","content":"pub fn list_findings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.list_findings\naws_api/inspector2 list_findings","url":"aws_api/inspector2.html#list_findings"},{"doc":"aws_api/inspector2","title":"list_members","content":"pub fn list_members(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.list_members\naws_api/inspector2 list_members","url":"aws_api/inspector2.html#list_members"},{"doc":"aws_api/inspector2","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.list_tags_for_resource\naws_api/inspector2 list_tags_for_resource","url":"aws_api/inspector2.html#list_tags_for_resource"},{"doc":"aws_api/inspector2","title":"list_usage_totals","content":"pub fn list_usage_totals(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.list_usage_totals\naws_api/inspector2 list_usage_totals","url":"aws_api/inspector2.html#list_usage_totals"},{"doc":"aws_api/inspector2","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/inspector2.new\naws_api/inspector2 new","url":"aws_api/inspector2.html#new"},{"doc":"aws_api/inspector2","title":"reset_encryption_key","content":"pub fn reset_encryption_key(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.reset_encryption_key\naws_api/inspector2 reset_encryption_key","url":"aws_api/inspector2.html#reset_encryption_key"},{"doc":"aws_api/inspector2","title":"search_vulnerabilities","content":"pub fn search_vulnerabilities(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.search_vulnerabilities\naws_api/inspector2 search_vulnerabilities","url":"aws_api/inspector2.html#search_vulnerabilities"},{"doc":"aws_api/inspector2","title":"send_cis_session_health","content":"pub fn send_cis_session_health(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.send_cis_session_health\naws_api/inspector2 send_cis_session_health","url":"aws_api/inspector2.html#send_cis_session_health"},{"doc":"aws_api/inspector2","title":"send_cis_session_telemetry","content":"pub fn send_cis_session_telemetry(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.send_cis_session_telemetry\naws_api/inspector2 send_cis_session_telemetry","url":"aws_api/inspector2.html#send_cis_session_telemetry"},{"doc":"aws_api/inspector2","title":"start_cis_session","content":"pub fn start_cis_session(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.start_cis_session\naws_api/inspector2 start_cis_session","url":"aws_api/inspector2.html#start_cis_session"},{"doc":"aws_api/inspector2","title":"stop_cis_session","content":"pub fn stop_cis_session(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.stop_cis_session\naws_api/inspector2 stop_cis_session","url":"aws_api/inspector2.html#stop_cis_session"},{"doc":"aws_api/inspector2","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.tag_resource\naws_api/inspector2 tag_resource","url":"aws_api/inspector2.html#tag_resource"},{"doc":"aws_api/inspector2","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.untag_resource\naws_api/inspector2 untag_resource","url":"aws_api/inspector2.html#untag_resource"},{"doc":"aws_api/inspector2","title":"update_cis_scan_configuration","content":"pub fn update_cis_scan_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.update_cis_scan_configuration\naws_api/inspector2 update_cis_scan_configuration","url":"aws_api/inspector2.html#update_cis_scan_configuration"},{"doc":"aws_api/inspector2","title":"update_configuration","content":"pub fn update_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.update_configuration\naws_api/inspector2 update_configuration","url":"aws_api/inspector2.html#update_configuration"},{"doc":"aws_api/inspector2","title":"update_ec2_deep_inspection_configuration","content":"pub fn update_ec2_deep_inspection_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.update_ec2_deep_inspection_configuration\naws_api/inspector2 update_ec2_deep_inspection_configuration","url":"aws_api/inspector2.html#update_ec2_deep_inspection_configuration"},{"doc":"aws_api/inspector2","title":"update_encryption_key","content":"pub fn update_encryption_key(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.update_encryption_key\naws_api/inspector2 update_encryption_key","url":"aws_api/inspector2.html#update_encryption_key"},{"doc":"aws_api/inspector2","title":"update_filter","content":"pub fn update_filter(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.update_filter\naws_api/inspector2 update_filter","url":"aws_api/inspector2.html#update_filter"},{"doc":"aws_api/inspector2","title":"update_org_ec2_deep_inspection_configuration","content":"pub fn update_org_ec2_deep_inspection_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.update_org_ec2_deep_inspection_configuration\naws_api/inspector2 update_org_ec2_deep_inspection_configuration","url":"aws_api/inspector2.html#update_org_ec2_deep_inspection_configuration"},{"doc":"aws_api/inspector2","title":"update_organization_configuration","content":"pub fn update_organization_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/inspector2.update_organization_configuration\naws_api/inspector2 update_organization_configuration","url":"aws_api/inspector2.html#update_organization_configuration"},{"doc":"aws_api/inspector2","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/inspector2.with_custom_endpoint\naws_api/inspector2 with_custom_endpoint","url":"aws_api/inspector2.html#with_custom_endpoint"},{"doc":"aws_api/inspector2","title":"aws_api/inspector2","content":"","url":"aws_api/inspector2.html"},{"doc":"aws_api/internetmonitor","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/internetmonitor.Client\naws_api/internetmonitor Client","url":"aws_api/internetmonitor.html#Client"},{"doc":"aws_api/internetmonitor","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/internetmonitor.list_tags_for_resource\naws_api/internetmonitor list_tags_for_resource","url":"aws_api/internetmonitor.html#list_tags_for_resource"},{"doc":"aws_api/internetmonitor","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/internetmonitor.new\naws_api/internetmonitor new","url":"aws_api/internetmonitor.html#new"},{"doc":"aws_api/internetmonitor","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/internetmonitor.tag_resource\naws_api/internetmonitor tag_resource","url":"aws_api/internetmonitor.html#tag_resource"},{"doc":"aws_api/internetmonitor","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/internetmonitor.untag_resource\naws_api/internetmonitor untag_resource","url":"aws_api/internetmonitor.html#untag_resource"},{"doc":"aws_api/internetmonitor","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/internetmonitor.with_custom_endpoint\naws_api/internetmonitor with_custom_endpoint","url":"aws_api/internetmonitor.html#with_custom_endpoint"},{"doc":"aws_api/internetmonitor","title":"aws_api/internetmonitor","content":"","url":"aws_api/internetmonitor.html"},{"doc":"aws_api/iot","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/iot.Client\naws_api/iot Client","url":"aws_api/iot.html#Client"},{"doc":"aws_api/iot","title":"accept_certificate_transfer","content":"pub fn accept_certificate_transfer(\n  client: Client,\n  certificate_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.accept_certificate_transfer\naws_api/iot accept_certificate_transfer","url":"aws_api/iot.html#accept_certificate_transfer"},{"doc":"aws_api/iot","title":"add_thing_to_billing_group","content":"pub fn add_thing_to_billing_group(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.add_thing_to_billing_group\naws_api/iot add_thing_to_billing_group","url":"aws_api/iot.html#add_thing_to_billing_group"},{"doc":"aws_api/iot","title":"add_thing_to_thing_group","content":"pub fn add_thing_to_thing_group(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.add_thing_to_thing_group\naws_api/iot add_thing_to_thing_group","url":"aws_api/iot.html#add_thing_to_thing_group"},{"doc":"aws_api/iot","title":"associate_targets_with_job","content":"pub fn associate_targets_with_job(\n  client: Client,\n  job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.associate_targets_with_job\naws_api/iot associate_targets_with_job","url":"aws_api/iot.html#associate_targets_with_job"},{"doc":"aws_api/iot","title":"attach_policy","content":"pub fn attach_policy(\n  client: Client,\n  policy_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.attach_policy\naws_api/iot attach_policy","url":"aws_api/iot.html#attach_policy"},{"doc":"aws_api/iot","title":"attach_principal_policy","content":"pub fn attach_principal_policy(\n  client: Client,\n  policy_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.attach_principal_policy\naws_api/iot attach_principal_policy","url":"aws_api/iot.html#attach_principal_policy"},{"doc":"aws_api/iot","title":"attach_security_profile","content":"pub fn attach_security_profile(\n  client: Client,\n  security_profile_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.attach_security_profile\naws_api/iot attach_security_profile","url":"aws_api/iot.html#attach_security_profile"},{"doc":"aws_api/iot","title":"attach_thing_principal","content":"pub fn attach_thing_principal(\n  client: Client,\n  thing_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.attach_thing_principal\naws_api/iot attach_thing_principal","url":"aws_api/iot.html#attach_thing_principal"},{"doc":"aws_api/iot","title":"cancel_audit_mitigation_actions_task","content":"pub fn cancel_audit_mitigation_actions_task(\n  client: Client,\n  task_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.cancel_audit_mitigation_actions_task\naws_api/iot cancel_audit_mitigation_actions_task","url":"aws_api/iot.html#cancel_audit_mitigation_actions_task"},{"doc":"aws_api/iot","title":"cancel_audit_task","content":"pub fn cancel_audit_task(\n  client: Client,\n  task_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.cancel_audit_task\naws_api/iot cancel_audit_task","url":"aws_api/iot.html#cancel_audit_task"},{"doc":"aws_api/iot","title":"cancel_certificate_transfer","content":"pub fn cancel_certificate_transfer(\n  client: Client,\n  certificate_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.cancel_certificate_transfer\naws_api/iot cancel_certificate_transfer","url":"aws_api/iot.html#cancel_certificate_transfer"},{"doc":"aws_api/iot","title":"cancel_detect_mitigation_actions_task","content":"pub fn cancel_detect_mitigation_actions_task(\n  client: Client,\n  task_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.cancel_detect_mitigation_actions_task\naws_api/iot cancel_detect_mitigation_actions_task","url":"aws_api/iot.html#cancel_detect_mitigation_actions_task"},{"doc":"aws_api/iot","title":"cancel_job","content":"pub fn cancel_job(\n  client: Client,\n  job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.cancel_job\naws_api/iot cancel_job","url":"aws_api/iot.html#cancel_job"},{"doc":"aws_api/iot","title":"cancel_job_execution","content":"pub fn cancel_job_execution(\n  client: Client,\n  thing_name: String,\n  job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.cancel_job_execution\naws_api/iot cancel_job_execution","url":"aws_api/iot.html#cancel_job_execution"},{"doc":"aws_api/iot","title":"clear_default_authorizer","content":"pub fn clear_default_authorizer(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.clear_default_authorizer\naws_api/iot clear_default_authorizer","url":"aws_api/iot.html#clear_default_authorizer"},{"doc":"aws_api/iot","title":"confirm_topic_rule_destination","content":"pub fn confirm_topic_rule_destination(\n  client: Client,\n  confirmation_token: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.confirm_topic_rule_destination\naws_api/iot confirm_topic_rule_destination","url":"aws_api/iot.html#confirm_topic_rule_destination"},{"doc":"aws_api/iot","title":"create_audit_suppression","content":"pub fn create_audit_suppression(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.create_audit_suppression\naws_api/iot create_audit_suppression","url":"aws_api/iot.html#create_audit_suppression"},{"doc":"aws_api/iot","title":"create_authorizer","content":"pub fn create_authorizer(\n  client: Client,\n  authorizer_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.create_authorizer\naws_api/iot create_authorizer","url":"aws_api/iot.html#create_authorizer"},{"doc":"aws_api/iot","title":"create_billing_group","content":"pub fn create_billing_group(\n  client: Client,\n  billing_group_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.create_billing_group\naws_api/iot create_billing_group","url":"aws_api/iot.html#create_billing_group"},{"doc":"aws_api/iot","title":"create_certificate_from_csr","content":"pub fn create_certificate_from_csr(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.create_certificate_from_csr\naws_api/iot create_certificate_from_csr","url":"aws_api/iot.html#create_certificate_from_csr"},{"doc":"aws_api/iot","title":"create_certificate_provider","content":"pub fn create_certificate_provider(\n  client: Client,\n  certificate_provider_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.create_certificate_provider\naws_api/iot create_certificate_provider","url":"aws_api/iot.html#create_certificate_provider"},{"doc":"aws_api/iot","title":"create_custom_metric","content":"pub fn create_custom_metric(\n  client: Client,\n  metric_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.create_custom_metric\naws_api/iot create_custom_metric","url":"aws_api/iot.html#create_custom_metric"},{"doc":"aws_api/iot","title":"create_dimension","content":"pub fn create_dimension(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.create_dimension\naws_api/iot create_dimension","url":"aws_api/iot.html#create_dimension"},{"doc":"aws_api/iot","title":"create_domain_configuration","content":"pub fn create_domain_configuration(\n  client: Client,\n  domain_configuration_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.create_domain_configuration\naws_api/iot create_domain_configuration","url":"aws_api/iot.html#create_domain_configuration"},{"doc":"aws_api/iot","title":"create_dynamic_thing_group","content":"pub fn create_dynamic_thing_group(\n  client: Client,\n  thing_group_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.create_dynamic_thing_group\naws_api/iot create_dynamic_thing_group","url":"aws_api/iot.html#create_dynamic_thing_group"},{"doc":"aws_api/iot","title":"create_fleet_metric","content":"pub fn create_fleet_metric(\n  client: Client,\n  metric_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.create_fleet_metric\naws_api/iot create_fleet_metric","url":"aws_api/iot.html#create_fleet_metric"},{"doc":"aws_api/iot","title":"create_job","content":"pub fn create_job(\n  client: Client,\n  job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.create_job\naws_api/iot create_job","url":"aws_api/iot.html#create_job"},{"doc":"aws_api/iot","title":"create_job_template","content":"pub fn create_job_template(\n  client: Client,\n  job_template_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.create_job_template\naws_api/iot create_job_template","url":"aws_api/iot.html#create_job_template"},{"doc":"aws_api/iot","title":"create_keys_and_certificate","content":"pub fn create_keys_and_certificate(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.create_keys_and_certificate\naws_api/iot create_keys_and_certificate","url":"aws_api/iot.html#create_keys_and_certificate"},{"doc":"aws_api/iot","title":"create_mitigation_action","content":"pub fn create_mitigation_action(\n  client: Client,\n  action_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.create_mitigation_action\naws_api/iot create_mitigation_action","url":"aws_api/iot.html#create_mitigation_action"},{"doc":"aws_api/iot","title":"create_ota_update","content":"pub fn create_ota_update(\n  client: Client,\n  ota_update_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.create_ota_update\naws_api/iot create_ota_update","url":"aws_api/iot.html#create_ota_update"},{"doc":"aws_api/iot","title":"create_package","content":"pub fn create_package(\n  client: Client,\n  package_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.create_package\naws_api/iot create_package","url":"aws_api/iot.html#create_package"},{"doc":"aws_api/iot","title":"create_package_version","content":"pub fn create_package_version(\n  client: Client,\n  package_name: String,\n  version_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.create_package_version\naws_api/iot create_package_version","url":"aws_api/iot.html#create_package_version"},{"doc":"aws_api/iot","title":"create_policy","content":"pub fn create_policy(\n  client: Client,\n  policy_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.create_policy\naws_api/iot create_policy","url":"aws_api/iot.html#create_policy"},{"doc":"aws_api/iot","title":"create_policy_version","content":"pub fn create_policy_version(\n  client: Client,\n  policy_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.create_policy_version\naws_api/iot create_policy_version","url":"aws_api/iot.html#create_policy_version"},{"doc":"aws_api/iot","title":"create_provisioning_claim","content":"pub fn create_provisioning_claim(\n  client: Client,\n  template_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.create_provisioning_claim\naws_api/iot create_provisioning_claim","url":"aws_api/iot.html#create_provisioning_claim"},{"doc":"aws_api/iot","title":"create_provisioning_template","content":"pub fn create_provisioning_template(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.create_provisioning_template\naws_api/iot create_provisioning_template","url":"aws_api/iot.html#create_provisioning_template"},{"doc":"aws_api/iot","title":"create_provisioning_template_version","content":"pub fn create_provisioning_template_version(\n  client: Client,\n  template_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.create_provisioning_template_version\naws_api/iot create_provisioning_template_version","url":"aws_api/iot.html#create_provisioning_template_version"},{"doc":"aws_api/iot","title":"create_role_alias","content":"pub fn create_role_alias(\n  client: Client,\n  role_alias: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.create_role_alias\naws_api/iot create_role_alias","url":"aws_api/iot.html#create_role_alias"},{"doc":"aws_api/iot","title":"create_scheduled_audit","content":"pub fn create_scheduled_audit(\n  client: Client,\n  scheduled_audit_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.create_scheduled_audit\naws_api/iot create_scheduled_audit","url":"aws_api/iot.html#create_scheduled_audit"},{"doc":"aws_api/iot","title":"create_security_profile","content":"pub fn create_security_profile(\n  client: Client,\n  security_profile_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.create_security_profile\naws_api/iot create_security_profile","url":"aws_api/iot.html#create_security_profile"},{"doc":"aws_api/iot","title":"create_stream","content":"pub fn create_stream(\n  client: Client,\n  stream_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.create_stream\naws_api/iot create_stream","url":"aws_api/iot.html#create_stream"},{"doc":"aws_api/iot","title":"create_thing","content":"pub fn create_thing(\n  client: Client,\n  thing_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.create_thing\naws_api/iot create_thing","url":"aws_api/iot.html#create_thing"},{"doc":"aws_api/iot","title":"create_thing_group","content":"pub fn create_thing_group(\n  client: Client,\n  thing_group_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.create_thing_group\naws_api/iot create_thing_group","url":"aws_api/iot.html#create_thing_group"},{"doc":"aws_api/iot","title":"create_thing_type","content":"pub fn create_thing_type(\n  client: Client,\n  thing_type_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.create_thing_type\naws_api/iot create_thing_type","url":"aws_api/iot.html#create_thing_type"},{"doc":"aws_api/iot","title":"create_topic_rule","content":"pub fn create_topic_rule(\n  client: Client,\n  rule_name: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.create_topic_rule\naws_api/iot create_topic_rule","url":"aws_api/iot.html#create_topic_rule"},{"doc":"aws_api/iot","title":"create_topic_rule_destination","content":"pub fn create_topic_rule_destination(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.create_topic_rule_destination\naws_api/iot create_topic_rule_destination","url":"aws_api/iot.html#create_topic_rule_destination"},{"doc":"aws_api/iot","title":"delete_account_audit_configuration","content":"pub fn delete_account_audit_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.delete_account_audit_configuration\naws_api/iot delete_account_audit_configuration","url":"aws_api/iot.html#delete_account_audit_configuration"},{"doc":"aws_api/iot","title":"delete_audit_suppression","content":"pub fn delete_audit_suppression(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.delete_audit_suppression\naws_api/iot delete_audit_suppression","url":"aws_api/iot.html#delete_audit_suppression"},{"doc":"aws_api/iot","title":"delete_authorizer","content":"pub fn delete_authorizer(\n  client: Client,\n  authorizer_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.delete_authorizer\naws_api/iot delete_authorizer","url":"aws_api/iot.html#delete_authorizer"},{"doc":"aws_api/iot","title":"delete_billing_group","content":"pub fn delete_billing_group(\n  client: Client,\n  billing_group_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.delete_billing_group\naws_api/iot delete_billing_group","url":"aws_api/iot.html#delete_billing_group"},{"doc":"aws_api/iot","title":"delete_ca_certificate","content":"pub fn delete_ca_certificate(\n  client: Client,\n  certificate_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.delete_ca_certificate\naws_api/iot delete_ca_certificate","url":"aws_api/iot.html#delete_ca_certificate"},{"doc":"aws_api/iot","title":"delete_certificate","content":"pub fn delete_certificate(\n  client: Client,\n  certificate_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.delete_certificate\naws_api/iot delete_certificate","url":"aws_api/iot.html#delete_certificate"},{"doc":"aws_api/iot","title":"delete_certificate_provider","content":"pub fn delete_certificate_provider(\n  client: Client,\n  certificate_provider_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.delete_certificate_provider\naws_api/iot delete_certificate_provider","url":"aws_api/iot.html#delete_certificate_provider"},{"doc":"aws_api/iot","title":"delete_custom_metric","content":"pub fn delete_custom_metric(\n  client: Client,\n  metric_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.delete_custom_metric\naws_api/iot delete_custom_metric","url":"aws_api/iot.html#delete_custom_metric"},{"doc":"aws_api/iot","title":"delete_dimension","content":"pub fn delete_dimension(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.delete_dimension\naws_api/iot delete_dimension","url":"aws_api/iot.html#delete_dimension"},{"doc":"aws_api/iot","title":"delete_domain_configuration","content":"pub fn delete_domain_configuration(\n  client: Client,\n  domain_configuration_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.delete_domain_configuration\naws_api/iot delete_domain_configuration","url":"aws_api/iot.html#delete_domain_configuration"},{"doc":"aws_api/iot","title":"delete_dynamic_thing_group","content":"pub fn delete_dynamic_thing_group(\n  client: Client,\n  thing_group_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.delete_dynamic_thing_group\naws_api/iot delete_dynamic_thing_group","url":"aws_api/iot.html#delete_dynamic_thing_group"},{"doc":"aws_api/iot","title":"delete_fleet_metric","content":"pub fn delete_fleet_metric(\n  client: Client,\n  metric_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.delete_fleet_metric\naws_api/iot delete_fleet_metric","url":"aws_api/iot.html#delete_fleet_metric"},{"doc":"aws_api/iot","title":"delete_job","content":"pub fn delete_job(\n  client: Client,\n  job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.delete_job\naws_api/iot delete_job","url":"aws_api/iot.html#delete_job"},{"doc":"aws_api/iot","title":"delete_job_execution","content":"pub fn delete_job_execution(\n  client: Client,\n  thing_name: String,\n  job_id: String,\n  execution_number: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.delete_job_execution\naws_api/iot delete_job_execution","url":"aws_api/iot.html#delete_job_execution"},{"doc":"aws_api/iot","title":"delete_job_template","content":"pub fn delete_job_template(\n  client: Client,\n  job_template_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.delete_job_template\naws_api/iot delete_job_template","url":"aws_api/iot.html#delete_job_template"},{"doc":"aws_api/iot","title":"delete_mitigation_action","content":"pub fn delete_mitigation_action(\n  client: Client,\n  action_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.delete_mitigation_action\naws_api/iot delete_mitigation_action","url":"aws_api/iot.html#delete_mitigation_action"},{"doc":"aws_api/iot","title":"delete_ota_update","content":"pub fn delete_ota_update(\n  client: Client,\n  ota_update_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.delete_ota_update\naws_api/iot delete_ota_update","url":"aws_api/iot.html#delete_ota_update"},{"doc":"aws_api/iot","title":"delete_package","content":"pub fn delete_package(\n  client: Client,\n  package_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.delete_package\naws_api/iot delete_package","url":"aws_api/iot.html#delete_package"},{"doc":"aws_api/iot","title":"delete_package_version","content":"pub fn delete_package_version(\n  client: Client,\n  package_name: String,\n  version_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.delete_package_version\naws_api/iot delete_package_version","url":"aws_api/iot.html#delete_package_version"},{"doc":"aws_api/iot","title":"delete_policy","content":"pub fn delete_policy(\n  client: Client,\n  policy_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.delete_policy\naws_api/iot delete_policy","url":"aws_api/iot.html#delete_policy"},{"doc":"aws_api/iot","title":"delete_policy_version","content":"pub fn delete_policy_version(\n  client: Client,\n  policy_name: String,\n  policy_version_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.delete_policy_version\naws_api/iot delete_policy_version","url":"aws_api/iot.html#delete_policy_version"},{"doc":"aws_api/iot","title":"delete_provisioning_template","content":"pub fn delete_provisioning_template(\n  client: Client,\n  template_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.delete_provisioning_template\naws_api/iot delete_provisioning_template","url":"aws_api/iot.html#delete_provisioning_template"},{"doc":"aws_api/iot","title":"delete_provisioning_template_version","content":"pub fn delete_provisioning_template_version(\n  client: Client,\n  template_name: String,\n  version_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.delete_provisioning_template_version\naws_api/iot delete_provisioning_template_version","url":"aws_api/iot.html#delete_provisioning_template_version"},{"doc":"aws_api/iot","title":"delete_registration_code","content":"pub fn delete_registration_code(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.delete_registration_code\naws_api/iot delete_registration_code","url":"aws_api/iot.html#delete_registration_code"},{"doc":"aws_api/iot","title":"delete_role_alias","content":"pub fn delete_role_alias(\n  client: Client,\n  role_alias: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.delete_role_alias\naws_api/iot delete_role_alias","url":"aws_api/iot.html#delete_role_alias"},{"doc":"aws_api/iot","title":"delete_scheduled_audit","content":"pub fn delete_scheduled_audit(\n  client: Client,\n  scheduled_audit_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.delete_scheduled_audit\naws_api/iot delete_scheduled_audit","url":"aws_api/iot.html#delete_scheduled_audit"},{"doc":"aws_api/iot","title":"delete_security_profile","content":"pub fn delete_security_profile(\n  client: Client,\n  security_profile_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.delete_security_profile\naws_api/iot delete_security_profile","url":"aws_api/iot.html#delete_security_profile"},{"doc":"aws_api/iot","title":"delete_stream","content":"pub fn delete_stream(\n  client: Client,\n  stream_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.delete_stream\naws_api/iot delete_stream","url":"aws_api/iot.html#delete_stream"},{"doc":"aws_api/iot","title":"delete_thing","content":"pub fn delete_thing(\n  client: Client,\n  thing_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.delete_thing\naws_api/iot delete_thing","url":"aws_api/iot.html#delete_thing"},{"doc":"aws_api/iot","title":"delete_thing_group","content":"pub fn delete_thing_group(\n  client: Client,\n  thing_group_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.delete_thing_group\naws_api/iot delete_thing_group","url":"aws_api/iot.html#delete_thing_group"},{"doc":"aws_api/iot","title":"delete_thing_type","content":"pub fn delete_thing_type(\n  client: Client,\n  thing_type_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.delete_thing_type\naws_api/iot delete_thing_type","url":"aws_api/iot.html#delete_thing_type"},{"doc":"aws_api/iot","title":"delete_topic_rule","content":"pub fn delete_topic_rule(\n  client: Client,\n  rule_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.delete_topic_rule\naws_api/iot delete_topic_rule","url":"aws_api/iot.html#delete_topic_rule"},{"doc":"aws_api/iot","title":"delete_topic_rule_destination","content":"pub fn delete_topic_rule_destination(\n  client: Client,\n  arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.delete_topic_rule_destination\naws_api/iot delete_topic_rule_destination","url":"aws_api/iot.html#delete_topic_rule_destination"},{"doc":"aws_api/iot","title":"delete_v2_logging_level","content":"pub fn delete_v2_logging_level(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.delete_v2_logging_level\naws_api/iot delete_v2_logging_level","url":"aws_api/iot.html#delete_v2_logging_level"},{"doc":"aws_api/iot","title":"deprecate_thing_type","content":"pub fn deprecate_thing_type(\n  client: Client,\n  thing_type_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.deprecate_thing_type\naws_api/iot deprecate_thing_type","url":"aws_api/iot.html#deprecate_thing_type"},{"doc":"aws_api/iot","title":"describe_account_audit_configuration","content":"pub fn describe_account_audit_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.describe_account_audit_configuration\naws_api/iot describe_account_audit_configuration","url":"aws_api/iot.html#describe_account_audit_configuration"},{"doc":"aws_api/iot","title":"describe_audit_finding","content":"pub fn describe_audit_finding(\n  client: Client,\n  finding_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.describe_audit_finding\naws_api/iot describe_audit_finding","url":"aws_api/iot.html#describe_audit_finding"},{"doc":"aws_api/iot","title":"describe_audit_mitigation_actions_task","content":"pub fn describe_audit_mitigation_actions_task(\n  client: Client,\n  task_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.describe_audit_mitigation_actions_task\naws_api/iot describe_audit_mitigation_actions_task","url":"aws_api/iot.html#describe_audit_mitigation_actions_task"},{"doc":"aws_api/iot","title":"describe_audit_suppression","content":"pub fn describe_audit_suppression(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.describe_audit_suppression\naws_api/iot describe_audit_suppression","url":"aws_api/iot.html#describe_audit_suppression"},{"doc":"aws_api/iot","title":"describe_audit_task","content":"pub fn describe_audit_task(\n  client: Client,\n  task_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.describe_audit_task\naws_api/iot describe_audit_task","url":"aws_api/iot.html#describe_audit_task"},{"doc":"aws_api/iot","title":"describe_authorizer","content":"pub fn describe_authorizer(\n  client: Client,\n  authorizer_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.describe_authorizer\naws_api/iot describe_authorizer","url":"aws_api/iot.html#describe_authorizer"},{"doc":"aws_api/iot","title":"describe_billing_group","content":"pub fn describe_billing_group(\n  client: Client,\n  billing_group_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.describe_billing_group\naws_api/iot describe_billing_group","url":"aws_api/iot.html#describe_billing_group"},{"doc":"aws_api/iot","title":"describe_ca_certificate","content":"pub fn describe_ca_certificate(\n  client: Client,\n  certificate_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.describe_ca_certificate\naws_api/iot describe_ca_certificate","url":"aws_api/iot.html#describe_ca_certificate"},{"doc":"aws_api/iot","title":"describe_certificate","content":"pub fn describe_certificate(\n  client: Client,\n  certificate_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.describe_certificate\naws_api/iot describe_certificate","url":"aws_api/iot.html#describe_certificate"},{"doc":"aws_api/iot","title":"describe_certificate_provider","content":"pub fn describe_certificate_provider(\n  client: Client,\n  certificate_provider_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.describe_certificate_provider\naws_api/iot describe_certificate_provider","url":"aws_api/iot.html#describe_certificate_provider"},{"doc":"aws_api/iot","title":"describe_custom_metric","content":"pub fn describe_custom_metric(\n  client: Client,\n  metric_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.describe_custom_metric\naws_api/iot describe_custom_metric","url":"aws_api/iot.html#describe_custom_metric"},{"doc":"aws_api/iot","title":"describe_default_authorizer","content":"pub fn describe_default_authorizer(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.describe_default_authorizer\naws_api/iot describe_default_authorizer","url":"aws_api/iot.html#describe_default_authorizer"},{"doc":"aws_api/iot","title":"describe_detect_mitigation_actions_task","content":"pub fn describe_detect_mitigation_actions_task(\n  client: Client,\n  task_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.describe_detect_mitigation_actions_task\naws_api/iot describe_detect_mitigation_actions_task","url":"aws_api/iot.html#describe_detect_mitigation_actions_task"},{"doc":"aws_api/iot","title":"describe_dimension","content":"pub fn describe_dimension(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.describe_dimension\naws_api/iot describe_dimension","url":"aws_api/iot.html#describe_dimension"},{"doc":"aws_api/iot","title":"describe_domain_configuration","content":"pub fn describe_domain_configuration(\n  client: Client,\n  domain_configuration_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.describe_domain_configuration\naws_api/iot describe_domain_configuration","url":"aws_api/iot.html#describe_domain_configuration"},{"doc":"aws_api/iot","title":"describe_endpoint","content":"pub fn describe_endpoint(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.describe_endpoint\naws_api/iot describe_endpoint","url":"aws_api/iot.html#describe_endpoint"},{"doc":"aws_api/iot","title":"describe_event_configurations","content":"pub fn describe_event_configurations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.describe_event_configurations\naws_api/iot describe_event_configurations","url":"aws_api/iot.html#describe_event_configurations"},{"doc":"aws_api/iot","title":"describe_fleet_metric","content":"pub fn describe_fleet_metric(\n  client: Client,\n  metric_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.describe_fleet_metric\naws_api/iot describe_fleet_metric","url":"aws_api/iot.html#describe_fleet_metric"},{"doc":"aws_api/iot","title":"describe_index","content":"pub fn describe_index(\n  client: Client,\n  index_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.describe_index\naws_api/iot describe_index","url":"aws_api/iot.html#describe_index"},{"doc":"aws_api/iot","title":"describe_job","content":"pub fn describe_job(\n  client: Client,\n  job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.describe_job\naws_api/iot describe_job","url":"aws_api/iot.html#describe_job"},{"doc":"aws_api/iot","title":"describe_job_execution","content":"pub fn describe_job_execution(\n  client: Client,\n  thing_name: String,\n  job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.describe_job_execution\naws_api/iot describe_job_execution","url":"aws_api/iot.html#describe_job_execution"},{"doc":"aws_api/iot","title":"describe_job_template","content":"pub fn describe_job_template(\n  client: Client,\n  job_template_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.describe_job_template\naws_api/iot describe_job_template","url":"aws_api/iot.html#describe_job_template"},{"doc":"aws_api/iot","title":"describe_managed_job_template","content":"pub fn describe_managed_job_template(\n  client: Client,\n  template_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.describe_managed_job_template\naws_api/iot describe_managed_job_template","url":"aws_api/iot.html#describe_managed_job_template"},{"doc":"aws_api/iot","title":"describe_mitigation_action","content":"pub fn describe_mitigation_action(\n  client: Client,\n  action_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.describe_mitigation_action\naws_api/iot describe_mitigation_action","url":"aws_api/iot.html#describe_mitigation_action"},{"doc":"aws_api/iot","title":"describe_provisioning_template","content":"pub fn describe_provisioning_template(\n  client: Client,\n  template_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.describe_provisioning_template\naws_api/iot describe_provisioning_template","url":"aws_api/iot.html#describe_provisioning_template"},{"doc":"aws_api/iot","title":"describe_provisioning_template_version","content":"pub fn describe_provisioning_template_version(\n  client: Client,\n  template_name: String,\n  version_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.describe_provisioning_template_version\naws_api/iot describe_provisioning_template_version","url":"aws_api/iot.html#describe_provisioning_template_version"},{"doc":"aws_api/iot","title":"describe_role_alias","content":"pub fn describe_role_alias(\n  client: Client,\n  role_alias: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.describe_role_alias\naws_api/iot describe_role_alias","url":"aws_api/iot.html#describe_role_alias"},{"doc":"aws_api/iot","title":"describe_scheduled_audit","content":"pub fn describe_scheduled_audit(\n  client: Client,\n  scheduled_audit_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.describe_scheduled_audit\naws_api/iot describe_scheduled_audit","url":"aws_api/iot.html#describe_scheduled_audit"},{"doc":"aws_api/iot","title":"describe_security_profile","content":"pub fn describe_security_profile(\n  client: Client,\n  security_profile_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.describe_security_profile\naws_api/iot describe_security_profile","url":"aws_api/iot.html#describe_security_profile"},{"doc":"aws_api/iot","title":"describe_stream","content":"pub fn describe_stream(\n  client: Client,\n  stream_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.describe_stream\naws_api/iot describe_stream","url":"aws_api/iot.html#describe_stream"},{"doc":"aws_api/iot","title":"describe_thing","content":"pub fn describe_thing(\n  client: Client,\n  thing_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.describe_thing\naws_api/iot describe_thing","url":"aws_api/iot.html#describe_thing"},{"doc":"aws_api/iot","title":"describe_thing_group","content":"pub fn describe_thing_group(\n  client: Client,\n  thing_group_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.describe_thing_group\naws_api/iot describe_thing_group","url":"aws_api/iot.html#describe_thing_group"},{"doc":"aws_api/iot","title":"describe_thing_registration_task","content":"pub fn describe_thing_registration_task(\n  client: Client,\n  task_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.describe_thing_registration_task\naws_api/iot describe_thing_registration_task","url":"aws_api/iot.html#describe_thing_registration_task"},{"doc":"aws_api/iot","title":"describe_thing_type","content":"pub fn describe_thing_type(\n  client: Client,\n  thing_type_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.describe_thing_type\naws_api/iot describe_thing_type","url":"aws_api/iot.html#describe_thing_type"},{"doc":"aws_api/iot","title":"detach_policy","content":"pub fn detach_policy(\n  client: Client,\n  policy_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.detach_policy\naws_api/iot detach_policy","url":"aws_api/iot.html#detach_policy"},{"doc":"aws_api/iot","title":"detach_principal_policy","content":"pub fn detach_principal_policy(\n  client: Client,\n  policy_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.detach_principal_policy\naws_api/iot detach_principal_policy","url":"aws_api/iot.html#detach_principal_policy"},{"doc":"aws_api/iot","title":"detach_security_profile","content":"pub fn detach_security_profile(\n  client: Client,\n  security_profile_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.detach_security_profile\naws_api/iot detach_security_profile","url":"aws_api/iot.html#detach_security_profile"},{"doc":"aws_api/iot","title":"detach_thing_principal","content":"pub fn detach_thing_principal(\n  client: Client,\n  thing_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.detach_thing_principal\naws_api/iot detach_thing_principal","url":"aws_api/iot.html#detach_thing_principal"},{"doc":"aws_api/iot","title":"disable_topic_rule","content":"pub fn disable_topic_rule(\n  client: Client,\n  rule_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.disable_topic_rule\naws_api/iot disable_topic_rule","url":"aws_api/iot.html#disable_topic_rule"},{"doc":"aws_api/iot","title":"enable_topic_rule","content":"pub fn enable_topic_rule(\n  client: Client,\n  rule_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.enable_topic_rule\naws_api/iot enable_topic_rule","url":"aws_api/iot.html#enable_topic_rule"},{"doc":"aws_api/iot","title":"get_behavior_model_training_summaries","content":"pub fn get_behavior_model_training_summaries(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.get_behavior_model_training_summaries\naws_api/iot get_behavior_model_training_summaries","url":"aws_api/iot.html#get_behavior_model_training_summaries"},{"doc":"aws_api/iot","title":"get_buckets_aggregation","content":"pub fn get_buckets_aggregation(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.get_buckets_aggregation\naws_api/iot get_buckets_aggregation","url":"aws_api/iot.html#get_buckets_aggregation"},{"doc":"aws_api/iot","title":"get_cardinality","content":"pub fn get_cardinality(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.get_cardinality\naws_api/iot get_cardinality","url":"aws_api/iot.html#get_cardinality"},{"doc":"aws_api/iot","title":"get_effective_policies","content":"pub fn get_effective_policies(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.get_effective_policies\naws_api/iot get_effective_policies","url":"aws_api/iot.html#get_effective_policies"},{"doc":"aws_api/iot","title":"get_indexing_configuration","content":"pub fn get_indexing_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.get_indexing_configuration\naws_api/iot get_indexing_configuration","url":"aws_api/iot.html#get_indexing_configuration"},{"doc":"aws_api/iot","title":"get_job_document","content":"pub fn get_job_document(\n  client: Client,\n  job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.get_job_document\naws_api/iot get_job_document","url":"aws_api/iot.html#get_job_document"},{"doc":"aws_api/iot","title":"get_logging_options","content":"pub fn get_logging_options(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.get_logging_options\naws_api/iot get_logging_options","url":"aws_api/iot.html#get_logging_options"},{"doc":"aws_api/iot","title":"get_ota_update","content":"pub fn get_ota_update(\n  client: Client,\n  ota_update_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.get_ota_update\naws_api/iot get_ota_update","url":"aws_api/iot.html#get_ota_update"},{"doc":"aws_api/iot","title":"get_package","content":"pub fn get_package(\n  client: Client,\n  package_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.get_package\naws_api/iot get_package","url":"aws_api/iot.html#get_package"},{"doc":"aws_api/iot","title":"get_package_configuration","content":"pub fn get_package_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.get_package_configuration\naws_api/iot get_package_configuration","url":"aws_api/iot.html#get_package_configuration"},{"doc":"aws_api/iot","title":"get_package_version","content":"pub fn get_package_version(\n  client: Client,\n  package_name: String,\n  version_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.get_package_version\naws_api/iot get_package_version","url":"aws_api/iot.html#get_package_version"},{"doc":"aws_api/iot","title":"get_percentiles","content":"pub fn get_percentiles(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.get_percentiles\naws_api/iot get_percentiles","url":"aws_api/iot.html#get_percentiles"},{"doc":"aws_api/iot","title":"get_policy","content":"pub fn get_policy(\n  client: Client,\n  policy_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.get_policy\naws_api/iot get_policy","url":"aws_api/iot.html#get_policy"},{"doc":"aws_api/iot","title":"get_policy_version","content":"pub fn get_policy_version(\n  client: Client,\n  policy_name: String,\n  policy_version_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.get_policy_version\naws_api/iot get_policy_version","url":"aws_api/iot.html#get_policy_version"},{"doc":"aws_api/iot","title":"get_registration_code","content":"pub fn get_registration_code(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.get_registration_code\naws_api/iot get_registration_code","url":"aws_api/iot.html#get_registration_code"},{"doc":"aws_api/iot","title":"get_statistics","content":"pub fn get_statistics(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.get_statistics\naws_api/iot get_statistics","url":"aws_api/iot.html#get_statistics"},{"doc":"aws_api/iot","title":"get_topic_rule","content":"pub fn get_topic_rule(\n  client: Client,\n  rule_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.get_topic_rule\naws_api/iot get_topic_rule","url":"aws_api/iot.html#get_topic_rule"},{"doc":"aws_api/iot","title":"get_topic_rule_destination","content":"pub fn get_topic_rule_destination(\n  client: Client,\n  arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.get_topic_rule_destination\naws_api/iot get_topic_rule_destination","url":"aws_api/iot.html#get_topic_rule_destination"},{"doc":"aws_api/iot","title":"get_v2_logging_options","content":"pub fn get_v2_logging_options(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.get_v2_logging_options\naws_api/iot get_v2_logging_options","url":"aws_api/iot.html#get_v2_logging_options"},{"doc":"aws_api/iot","title":"list_active_violations","content":"pub fn list_active_violations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_active_violations\naws_api/iot list_active_violations","url":"aws_api/iot.html#list_active_violations"},{"doc":"aws_api/iot","title":"list_attached_policies","content":"pub fn list_attached_policies(\n  client: Client,\n  target: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_attached_policies\naws_api/iot list_attached_policies","url":"aws_api/iot.html#list_attached_policies"},{"doc":"aws_api/iot","title":"list_audit_findings","content":"pub fn list_audit_findings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_audit_findings\naws_api/iot list_audit_findings","url":"aws_api/iot.html#list_audit_findings"},{"doc":"aws_api/iot","title":"list_audit_mitigation_actions_executions","content":"pub fn list_audit_mitigation_actions_executions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_audit_mitigation_actions_executions\naws_api/iot list_audit_mitigation_actions_executions","url":"aws_api/iot.html#list_audit_mitigation_actions_executions"},{"doc":"aws_api/iot","title":"list_audit_mitigation_actions_tasks","content":"pub fn list_audit_mitigation_actions_tasks(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_audit_mitigation_actions_tasks\naws_api/iot list_audit_mitigation_actions_tasks","url":"aws_api/iot.html#list_audit_mitigation_actions_tasks"},{"doc":"aws_api/iot","title":"list_audit_suppressions","content":"pub fn list_audit_suppressions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_audit_suppressions\naws_api/iot list_audit_suppressions","url":"aws_api/iot.html#list_audit_suppressions"},{"doc":"aws_api/iot","title":"list_audit_tasks","content":"pub fn list_audit_tasks(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_audit_tasks\naws_api/iot list_audit_tasks","url":"aws_api/iot.html#list_audit_tasks"},{"doc":"aws_api/iot","title":"list_authorizers","content":"pub fn list_authorizers(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_authorizers\naws_api/iot list_authorizers","url":"aws_api/iot.html#list_authorizers"},{"doc":"aws_api/iot","title":"list_billing_groups","content":"pub fn list_billing_groups(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_billing_groups\naws_api/iot list_billing_groups","url":"aws_api/iot.html#list_billing_groups"},{"doc":"aws_api/iot","title":"list_ca_certificates","content":"pub fn list_ca_certificates(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_ca_certificates\naws_api/iot list_ca_certificates","url":"aws_api/iot.html#list_ca_certificates"},{"doc":"aws_api/iot","title":"list_certificate_providers","content":"pub fn list_certificate_providers(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_certificate_providers\naws_api/iot list_certificate_providers","url":"aws_api/iot.html#list_certificate_providers"},{"doc":"aws_api/iot","title":"list_certificates","content":"pub fn list_certificates(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_certificates\naws_api/iot list_certificates","url":"aws_api/iot.html#list_certificates"},{"doc":"aws_api/iot","title":"list_certificates_by_ca","content":"pub fn list_certificates_by_ca(\n  client: Client,\n  ca_certificate_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_certificates_by_ca\naws_api/iot list_certificates_by_ca","url":"aws_api/iot.html#list_certificates_by_ca"},{"doc":"aws_api/iot","title":"list_custom_metrics","content":"pub fn list_custom_metrics(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_custom_metrics\naws_api/iot list_custom_metrics","url":"aws_api/iot.html#list_custom_metrics"},{"doc":"aws_api/iot","title":"list_detect_mitigation_actions_executions","content":"pub fn list_detect_mitigation_actions_executions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_detect_mitigation_actions_executions\naws_api/iot list_detect_mitigation_actions_executions","url":"aws_api/iot.html#list_detect_mitigation_actions_executions"},{"doc":"aws_api/iot","title":"list_detect_mitigation_actions_tasks","content":"pub fn list_detect_mitigation_actions_tasks(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_detect_mitigation_actions_tasks\naws_api/iot list_detect_mitigation_actions_tasks","url":"aws_api/iot.html#list_detect_mitigation_actions_tasks"},{"doc":"aws_api/iot","title":"list_dimensions","content":"pub fn list_dimensions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_dimensions\naws_api/iot list_dimensions","url":"aws_api/iot.html#list_dimensions"},{"doc":"aws_api/iot","title":"list_domain_configurations","content":"pub fn list_domain_configurations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_domain_configurations\naws_api/iot list_domain_configurations","url":"aws_api/iot.html#list_domain_configurations"},{"doc":"aws_api/iot","title":"list_fleet_metrics","content":"pub fn list_fleet_metrics(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_fleet_metrics\naws_api/iot list_fleet_metrics","url":"aws_api/iot.html#list_fleet_metrics"},{"doc":"aws_api/iot","title":"list_indices","content":"pub fn list_indices(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_indices\naws_api/iot list_indices","url":"aws_api/iot.html#list_indices"},{"doc":"aws_api/iot","title":"list_job_executions_for_job","content":"pub fn list_job_executions_for_job(\n  client: Client,\n  job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_job_executions_for_job\naws_api/iot list_job_executions_for_job","url":"aws_api/iot.html#list_job_executions_for_job"},{"doc":"aws_api/iot","title":"list_job_executions_for_thing","content":"pub fn list_job_executions_for_thing(\n  client: Client,\n  thing_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_job_executions_for_thing\naws_api/iot list_job_executions_for_thing","url":"aws_api/iot.html#list_job_executions_for_thing"},{"doc":"aws_api/iot","title":"list_job_templates","content":"pub fn list_job_templates(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_job_templates\naws_api/iot list_job_templates","url":"aws_api/iot.html#list_job_templates"},{"doc":"aws_api/iot","title":"list_jobs","content":"pub fn list_jobs(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_jobs\naws_api/iot list_jobs","url":"aws_api/iot.html#list_jobs"},{"doc":"aws_api/iot","title":"list_managed_job_templates","content":"pub fn list_managed_job_templates(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_managed_job_templates\naws_api/iot list_managed_job_templates","url":"aws_api/iot.html#list_managed_job_templates"},{"doc":"aws_api/iot","title":"list_metric_values","content":"pub fn list_metric_values(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_metric_values\naws_api/iot list_metric_values","url":"aws_api/iot.html#list_metric_values"},{"doc":"aws_api/iot","title":"list_mitigation_actions","content":"pub fn list_mitigation_actions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_mitigation_actions\naws_api/iot list_mitigation_actions","url":"aws_api/iot.html#list_mitigation_actions"},{"doc":"aws_api/iot","title":"list_ota_updates","content":"pub fn list_ota_updates(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_ota_updates\naws_api/iot list_ota_updates","url":"aws_api/iot.html#list_ota_updates"},{"doc":"aws_api/iot","title":"list_outgoing_certificates","content":"pub fn list_outgoing_certificates(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_outgoing_certificates\naws_api/iot list_outgoing_certificates","url":"aws_api/iot.html#list_outgoing_certificates"},{"doc":"aws_api/iot","title":"list_package_versions","content":"pub fn list_package_versions(\n  client: Client,\n  package_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_package_versions\naws_api/iot list_package_versions","url":"aws_api/iot.html#list_package_versions"},{"doc":"aws_api/iot","title":"list_packages","content":"pub fn list_packages(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_packages\naws_api/iot list_packages","url":"aws_api/iot.html#list_packages"},{"doc":"aws_api/iot","title":"list_policies","content":"pub fn list_policies(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_policies\naws_api/iot list_policies","url":"aws_api/iot.html#list_policies"},{"doc":"aws_api/iot","title":"list_policy_principals","content":"pub fn list_policy_principals(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_policy_principals\naws_api/iot list_policy_principals","url":"aws_api/iot.html#list_policy_principals"},{"doc":"aws_api/iot","title":"list_policy_versions","content":"pub fn list_policy_versions(\n  client: Client,\n  policy_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_policy_versions\naws_api/iot list_policy_versions","url":"aws_api/iot.html#list_policy_versions"},{"doc":"aws_api/iot","title":"list_principal_policies","content":"pub fn list_principal_policies(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_principal_policies\naws_api/iot list_principal_policies","url":"aws_api/iot.html#list_principal_policies"},{"doc":"aws_api/iot","title":"list_principal_things","content":"pub fn list_principal_things(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_principal_things\naws_api/iot list_principal_things","url":"aws_api/iot.html#list_principal_things"},{"doc":"aws_api/iot","title":"list_provisioning_template_versions","content":"pub fn list_provisioning_template_versions(\n  client: Client,\n  template_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_provisioning_template_versions\naws_api/iot list_provisioning_template_versions","url":"aws_api/iot.html#list_provisioning_template_versions"},{"doc":"aws_api/iot","title":"list_provisioning_templates","content":"pub fn list_provisioning_templates(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_provisioning_templates\naws_api/iot list_provisioning_templates","url":"aws_api/iot.html#list_provisioning_templates"},{"doc":"aws_api/iot","title":"list_related_resources_for_audit_finding","content":"pub fn list_related_resources_for_audit_finding(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_related_resources_for_audit_finding\naws_api/iot list_related_resources_for_audit_finding","url":"aws_api/iot.html#list_related_resources_for_audit_finding"},{"doc":"aws_api/iot","title":"list_role_aliases","content":"pub fn list_role_aliases(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_role_aliases\naws_api/iot list_role_aliases","url":"aws_api/iot.html#list_role_aliases"},{"doc":"aws_api/iot","title":"list_scheduled_audits","content":"pub fn list_scheduled_audits(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_scheduled_audits\naws_api/iot list_scheduled_audits","url":"aws_api/iot.html#list_scheduled_audits"},{"doc":"aws_api/iot","title":"list_security_profiles","content":"pub fn list_security_profiles(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_security_profiles\naws_api/iot list_security_profiles","url":"aws_api/iot.html#list_security_profiles"},{"doc":"aws_api/iot","title":"list_security_profiles_for_target","content":"pub fn list_security_profiles_for_target(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_security_profiles_for_target\naws_api/iot list_security_profiles_for_target","url":"aws_api/iot.html#list_security_profiles_for_target"},{"doc":"aws_api/iot","title":"list_streams","content":"pub fn list_streams(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_streams\naws_api/iot list_streams","url":"aws_api/iot.html#list_streams"},{"doc":"aws_api/iot","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_tags_for_resource\naws_api/iot list_tags_for_resource","url":"aws_api/iot.html#list_tags_for_resource"},{"doc":"aws_api/iot","title":"list_targets_for_policy","content":"pub fn list_targets_for_policy(\n  client: Client,\n  policy_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_targets_for_policy\naws_api/iot list_targets_for_policy","url":"aws_api/iot.html#list_targets_for_policy"},{"doc":"aws_api/iot","title":"list_targets_for_security_profile","content":"pub fn list_targets_for_security_profile(\n  client: Client,\n  security_profile_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_targets_for_security_profile\naws_api/iot list_targets_for_security_profile","url":"aws_api/iot.html#list_targets_for_security_profile"},{"doc":"aws_api/iot","title":"list_thing_groups","content":"pub fn list_thing_groups(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_thing_groups\naws_api/iot list_thing_groups","url":"aws_api/iot.html#list_thing_groups"},{"doc":"aws_api/iot","title":"list_thing_groups_for_thing","content":"pub fn list_thing_groups_for_thing(\n  client: Client,\n  thing_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_thing_groups_for_thing\naws_api/iot list_thing_groups_for_thing","url":"aws_api/iot.html#list_thing_groups_for_thing"},{"doc":"aws_api/iot","title":"list_thing_principals","content":"pub fn list_thing_principals(\n  client: Client,\n  thing_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_thing_principals\naws_api/iot list_thing_principals","url":"aws_api/iot.html#list_thing_principals"},{"doc":"aws_api/iot","title":"list_thing_registration_task_reports","content":"pub fn list_thing_registration_task_reports(\n  client: Client,\n  task_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_thing_registration_task_reports\naws_api/iot list_thing_registration_task_reports","url":"aws_api/iot.html#list_thing_registration_task_reports"},{"doc":"aws_api/iot","title":"list_thing_registration_tasks","content":"pub fn list_thing_registration_tasks(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_thing_registration_tasks\naws_api/iot list_thing_registration_tasks","url":"aws_api/iot.html#list_thing_registration_tasks"},{"doc":"aws_api/iot","title":"list_thing_types","content":"pub fn list_thing_types(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_thing_types\naws_api/iot list_thing_types","url":"aws_api/iot.html#list_thing_types"},{"doc":"aws_api/iot","title":"list_things","content":"pub fn list_things(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_things\naws_api/iot list_things","url":"aws_api/iot.html#list_things"},{"doc":"aws_api/iot","title":"list_things_in_billing_group","content":"pub fn list_things_in_billing_group(\n  client: Client,\n  billing_group_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_things_in_billing_group\naws_api/iot list_things_in_billing_group","url":"aws_api/iot.html#list_things_in_billing_group"},{"doc":"aws_api/iot","title":"list_things_in_thing_group","content":"pub fn list_things_in_thing_group(\n  client: Client,\n  thing_group_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_things_in_thing_group\naws_api/iot list_things_in_thing_group","url":"aws_api/iot.html#list_things_in_thing_group"},{"doc":"aws_api/iot","title":"list_topic_rule_destinations","content":"pub fn list_topic_rule_destinations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_topic_rule_destinations\naws_api/iot list_topic_rule_destinations","url":"aws_api/iot.html#list_topic_rule_destinations"},{"doc":"aws_api/iot","title":"list_topic_rules","content":"pub fn list_topic_rules(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_topic_rules\naws_api/iot list_topic_rules","url":"aws_api/iot.html#list_topic_rules"},{"doc":"aws_api/iot","title":"list_v2_logging_levels","content":"pub fn list_v2_logging_levels(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_v2_logging_levels\naws_api/iot list_v2_logging_levels","url":"aws_api/iot.html#list_v2_logging_levels"},{"doc":"aws_api/iot","title":"list_violation_events","content":"pub fn list_violation_events(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.list_violation_events\naws_api/iot list_violation_events","url":"aws_api/iot.html#list_violation_events"},{"doc":"aws_api/iot","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/iot.new\naws_api/iot new","url":"aws_api/iot.html#new"},{"doc":"aws_api/iot","title":"put_verification_state_on_violation","content":"pub fn put_verification_state_on_violation(\n  client: Client,\n  violation_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.put_verification_state_on_violation\naws_api/iot put_verification_state_on_violation","url":"aws_api/iot.html#put_verification_state_on_violation"},{"doc":"aws_api/iot","title":"register_ca_certificate","content":"pub fn register_ca_certificate(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.register_ca_certificate\naws_api/iot register_ca_certificate","url":"aws_api/iot.html#register_ca_certificate"},{"doc":"aws_api/iot","title":"register_certificate","content":"pub fn register_certificate(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.register_certificate\naws_api/iot register_certificate","url":"aws_api/iot.html#register_certificate"},{"doc":"aws_api/iot","title":"register_certificate_without_ca","content":"pub fn register_certificate_without_ca(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.register_certificate_without_ca\naws_api/iot register_certificate_without_ca","url":"aws_api/iot.html#register_certificate_without_ca"},{"doc":"aws_api/iot","title":"register_thing","content":"pub fn register_thing(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.register_thing\naws_api/iot register_thing","url":"aws_api/iot.html#register_thing"},{"doc":"aws_api/iot","title":"reject_certificate_transfer","content":"pub fn reject_certificate_transfer(\n  client: Client,\n  certificate_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.reject_certificate_transfer\naws_api/iot reject_certificate_transfer","url":"aws_api/iot.html#reject_certificate_transfer"},{"doc":"aws_api/iot","title":"remove_thing_from_billing_group","content":"pub fn remove_thing_from_billing_group(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.remove_thing_from_billing_group\naws_api/iot remove_thing_from_billing_group","url":"aws_api/iot.html#remove_thing_from_billing_group"},{"doc":"aws_api/iot","title":"remove_thing_from_thing_group","content":"pub fn remove_thing_from_thing_group(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.remove_thing_from_thing_group\naws_api/iot remove_thing_from_thing_group","url":"aws_api/iot.html#remove_thing_from_thing_group"},{"doc":"aws_api/iot","title":"replace_topic_rule","content":"pub fn replace_topic_rule(\n  client: Client,\n  rule_name: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.replace_topic_rule\naws_api/iot replace_topic_rule","url":"aws_api/iot.html#replace_topic_rule"},{"doc":"aws_api/iot","title":"search_index","content":"pub fn search_index(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.search_index\naws_api/iot search_index","url":"aws_api/iot.html#search_index"},{"doc":"aws_api/iot","title":"set_default_authorizer","content":"pub fn set_default_authorizer(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.set_default_authorizer\naws_api/iot set_default_authorizer","url":"aws_api/iot.html#set_default_authorizer"},{"doc":"aws_api/iot","title":"set_default_policy_version","content":"pub fn set_default_policy_version(\n  client: Client,\n  policy_name: String,\n  policy_version_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.set_default_policy_version\naws_api/iot set_default_policy_version","url":"aws_api/iot.html#set_default_policy_version"},{"doc":"aws_api/iot","title":"set_logging_options","content":"pub fn set_logging_options(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.set_logging_options\naws_api/iot set_logging_options","url":"aws_api/iot.html#set_logging_options"},{"doc":"aws_api/iot","title":"set_v2_logging_level","content":"pub fn set_v2_logging_level(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.set_v2_logging_level\naws_api/iot set_v2_logging_level","url":"aws_api/iot.html#set_v2_logging_level"},{"doc":"aws_api/iot","title":"set_v2_logging_options","content":"pub fn set_v2_logging_options(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.set_v2_logging_options\naws_api/iot set_v2_logging_options","url":"aws_api/iot.html#set_v2_logging_options"},{"doc":"aws_api/iot","title":"start_audit_mitigation_actions_task","content":"pub fn start_audit_mitigation_actions_task(\n  client: Client,\n  task_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.start_audit_mitigation_actions_task\naws_api/iot start_audit_mitigation_actions_task","url":"aws_api/iot.html#start_audit_mitigation_actions_task"},{"doc":"aws_api/iot","title":"start_detect_mitigation_actions_task","content":"pub fn start_detect_mitigation_actions_task(\n  client: Client,\n  task_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.start_detect_mitigation_actions_task\naws_api/iot start_detect_mitigation_actions_task","url":"aws_api/iot.html#start_detect_mitigation_actions_task"},{"doc":"aws_api/iot","title":"start_on_demand_audit_task","content":"pub fn start_on_demand_audit_task(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.start_on_demand_audit_task\naws_api/iot start_on_demand_audit_task","url":"aws_api/iot.html#start_on_demand_audit_task"},{"doc":"aws_api/iot","title":"start_thing_registration_task","content":"pub fn start_thing_registration_task(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.start_thing_registration_task\naws_api/iot start_thing_registration_task","url":"aws_api/iot.html#start_thing_registration_task"},{"doc":"aws_api/iot","title":"stop_thing_registration_task","content":"pub fn stop_thing_registration_task(\n  client: Client,\n  task_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.stop_thing_registration_task\naws_api/iot stop_thing_registration_task","url":"aws_api/iot.html#stop_thing_registration_task"},{"doc":"aws_api/iot","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.tag_resource\naws_api/iot tag_resource","url":"aws_api/iot.html#tag_resource"},{"doc":"aws_api/iot","title":"test_authorization","content":"pub fn test_authorization(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.test_authorization\naws_api/iot test_authorization","url":"aws_api/iot.html#test_authorization"},{"doc":"aws_api/iot","title":"test_invoke_authorizer","content":"pub fn test_invoke_authorizer(\n  client: Client,\n  authorizer_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.test_invoke_authorizer\naws_api/iot test_invoke_authorizer","url":"aws_api/iot.html#test_invoke_authorizer"},{"doc":"aws_api/iot","title":"transfer_certificate","content":"pub fn transfer_certificate(\n  client: Client,\n  certificate_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.transfer_certificate\naws_api/iot transfer_certificate","url":"aws_api/iot.html#transfer_certificate"},{"doc":"aws_api/iot","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.untag_resource\naws_api/iot untag_resource","url":"aws_api/iot.html#untag_resource"},{"doc":"aws_api/iot","title":"update_account_audit_configuration","content":"pub fn update_account_audit_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.update_account_audit_configuration\naws_api/iot update_account_audit_configuration","url":"aws_api/iot.html#update_account_audit_configuration"},{"doc":"aws_api/iot","title":"update_audit_suppression","content":"pub fn update_audit_suppression(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.update_audit_suppression\naws_api/iot update_audit_suppression","url":"aws_api/iot.html#update_audit_suppression"},{"doc":"aws_api/iot","title":"update_authorizer","content":"pub fn update_authorizer(\n  client: Client,\n  authorizer_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.update_authorizer\naws_api/iot update_authorizer","url":"aws_api/iot.html#update_authorizer"},{"doc":"aws_api/iot","title":"update_billing_group","content":"pub fn update_billing_group(\n  client: Client,\n  billing_group_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.update_billing_group\naws_api/iot update_billing_group","url":"aws_api/iot.html#update_billing_group"},{"doc":"aws_api/iot","title":"update_ca_certificate","content":"pub fn update_ca_certificate(\n  client: Client,\n  certificate_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.update_ca_certificate\naws_api/iot update_ca_certificate","url":"aws_api/iot.html#update_ca_certificate"},{"doc":"aws_api/iot","title":"update_certificate","content":"pub fn update_certificate(\n  client: Client,\n  certificate_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.update_certificate\naws_api/iot update_certificate","url":"aws_api/iot.html#update_certificate"},{"doc":"aws_api/iot","title":"update_certificate_provider","content":"pub fn update_certificate_provider(\n  client: Client,\n  certificate_provider_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.update_certificate_provider\naws_api/iot update_certificate_provider","url":"aws_api/iot.html#update_certificate_provider"},{"doc":"aws_api/iot","title":"update_custom_metric","content":"pub fn update_custom_metric(\n  client: Client,\n  metric_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.update_custom_metric\naws_api/iot update_custom_metric","url":"aws_api/iot.html#update_custom_metric"},{"doc":"aws_api/iot","title":"update_dimension","content":"pub fn update_dimension(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.update_dimension\naws_api/iot update_dimension","url":"aws_api/iot.html#update_dimension"},{"doc":"aws_api/iot","title":"update_domain_configuration","content":"pub fn update_domain_configuration(\n  client: Client,\n  domain_configuration_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.update_domain_configuration\naws_api/iot update_domain_configuration","url":"aws_api/iot.html#update_domain_configuration"},{"doc":"aws_api/iot","title":"update_dynamic_thing_group","content":"pub fn update_dynamic_thing_group(\n  client: Client,\n  thing_group_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.update_dynamic_thing_group\naws_api/iot update_dynamic_thing_group","url":"aws_api/iot.html#update_dynamic_thing_group"},{"doc":"aws_api/iot","title":"update_event_configurations","content":"pub fn update_event_configurations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.update_event_configurations\naws_api/iot update_event_configurations","url":"aws_api/iot.html#update_event_configurations"},{"doc":"aws_api/iot","title":"update_fleet_metric","content":"pub fn update_fleet_metric(\n  client: Client,\n  metric_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.update_fleet_metric\naws_api/iot update_fleet_metric","url":"aws_api/iot.html#update_fleet_metric"},{"doc":"aws_api/iot","title":"update_indexing_configuration","content":"pub fn update_indexing_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.update_indexing_configuration\naws_api/iot update_indexing_configuration","url":"aws_api/iot.html#update_indexing_configuration"},{"doc":"aws_api/iot","title":"update_job","content":"pub fn update_job(\n  client: Client,\n  job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.update_job\naws_api/iot update_job","url":"aws_api/iot.html#update_job"},{"doc":"aws_api/iot","title":"update_mitigation_action","content":"pub fn update_mitigation_action(\n  client: Client,\n  action_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.update_mitigation_action\naws_api/iot update_mitigation_action","url":"aws_api/iot.html#update_mitigation_action"},{"doc":"aws_api/iot","title":"update_package","content":"pub fn update_package(\n  client: Client,\n  package_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.update_package\naws_api/iot update_package","url":"aws_api/iot.html#update_package"},{"doc":"aws_api/iot","title":"update_package_configuration","content":"pub fn update_package_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.update_package_configuration\naws_api/iot update_package_configuration","url":"aws_api/iot.html#update_package_configuration"},{"doc":"aws_api/iot","title":"update_package_version","content":"pub fn update_package_version(\n  client: Client,\n  package_name: String,\n  version_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.update_package_version\naws_api/iot update_package_version","url":"aws_api/iot.html#update_package_version"},{"doc":"aws_api/iot","title":"update_provisioning_template","content":"pub fn update_provisioning_template(\n  client: Client,\n  template_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.update_provisioning_template\naws_api/iot update_provisioning_template","url":"aws_api/iot.html#update_provisioning_template"},{"doc":"aws_api/iot","title":"update_role_alias","content":"pub fn update_role_alias(\n  client: Client,\n  role_alias: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.update_role_alias\naws_api/iot update_role_alias","url":"aws_api/iot.html#update_role_alias"},{"doc":"aws_api/iot","title":"update_scheduled_audit","content":"pub fn update_scheduled_audit(\n  client: Client,\n  scheduled_audit_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.update_scheduled_audit\naws_api/iot update_scheduled_audit","url":"aws_api/iot.html#update_scheduled_audit"},{"doc":"aws_api/iot","title":"update_security_profile","content":"pub fn update_security_profile(\n  client: Client,\n  security_profile_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.update_security_profile\naws_api/iot update_security_profile","url":"aws_api/iot.html#update_security_profile"},{"doc":"aws_api/iot","title":"update_stream","content":"pub fn update_stream(\n  client: Client,\n  stream_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.update_stream\naws_api/iot update_stream","url":"aws_api/iot.html#update_stream"},{"doc":"aws_api/iot","title":"update_thing","content":"pub fn update_thing(\n  client: Client,\n  thing_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.update_thing\naws_api/iot update_thing","url":"aws_api/iot.html#update_thing"},{"doc":"aws_api/iot","title":"update_thing_group","content":"pub fn update_thing_group(\n  client: Client,\n  thing_group_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.update_thing_group\naws_api/iot update_thing_group","url":"aws_api/iot.html#update_thing_group"},{"doc":"aws_api/iot","title":"update_thing_groups_for_thing","content":"pub fn update_thing_groups_for_thing(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.update_thing_groups_for_thing\naws_api/iot update_thing_groups_for_thing","url":"aws_api/iot.html#update_thing_groups_for_thing"},{"doc":"aws_api/iot","title":"update_topic_rule_destination","content":"pub fn update_topic_rule_destination(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.update_topic_rule_destination\naws_api/iot update_topic_rule_destination","url":"aws_api/iot.html#update_topic_rule_destination"},{"doc":"aws_api/iot","title":"validate_security_profile_behaviors","content":"pub fn validate_security_profile_behaviors(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot.validate_security_profile_behaviors\naws_api/iot validate_security_profile_behaviors","url":"aws_api/iot.html#validate_security_profile_behaviors"},{"doc":"aws_api/iot","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/iot.with_custom_endpoint\naws_api/iot with_custom_endpoint","url":"aws_api/iot.html#with_custom_endpoint"},{"doc":"aws_api/iot","title":"aws_api/iot","content":"","url":"aws_api/iot.html"},{"doc":"aws_api/iot_1click_projects","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/iot_1click_projects.Client\naws_api/iot_1click_projects Client","url":"aws_api/iot_1click_projects.html#Client"},{"doc":"aws_api/iot_1click_projects","title":"associate_device_with_placement","content":"pub fn associate_device_with_placement(\n  client: Client,\n  project_name: String,\n  placement_name: String,\n  device_template_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_1click_projects.associate_device_with_placement\naws_api/iot_1click_projects associate_device_with_placement","url":"aws_api/iot_1click_projects.html#associate_device_with_placement"},{"doc":"aws_api/iot_1click_projects","title":"create_placement","content":"pub fn create_placement(\n  client: Client,\n  project_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_1click_projects.create_placement\naws_api/iot_1click_projects create_placement","url":"aws_api/iot_1click_projects.html#create_placement"},{"doc":"aws_api/iot_1click_projects","title":"create_project","content":"pub fn create_project(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_1click_projects.create_project\naws_api/iot_1click_projects create_project","url":"aws_api/iot_1click_projects.html#create_project"},{"doc":"aws_api/iot_1click_projects","title":"delete_placement","content":"pub fn delete_placement(\n  client: Client,\n  project_name: String,\n  placement_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_1click_projects.delete_placement\naws_api/iot_1click_projects delete_placement","url":"aws_api/iot_1click_projects.html#delete_placement"},{"doc":"aws_api/iot_1click_projects","title":"delete_project","content":"pub fn delete_project(\n  client: Client,\n  project_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_1click_projects.delete_project\naws_api/iot_1click_projects delete_project","url":"aws_api/iot_1click_projects.html#delete_project"},{"doc":"aws_api/iot_1click_projects","title":"describe_placement","content":"pub fn describe_placement(\n  client: Client,\n  project_name: String,\n  placement_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_1click_projects.describe_placement\naws_api/iot_1click_projects describe_placement","url":"aws_api/iot_1click_projects.html#describe_placement"},{"doc":"aws_api/iot_1click_projects","title":"describe_project","content":"pub fn describe_project(\n  client: Client,\n  project_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_1click_projects.describe_project\naws_api/iot_1click_projects describe_project","url":"aws_api/iot_1click_projects.html#describe_project"},{"doc":"aws_api/iot_1click_projects","title":"disassociate_device_from_placement","content":"pub fn disassociate_device_from_placement(\n  client: Client,\n  project_name: String,\n  placement_name: String,\n  device_template_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_1click_projects.disassociate_device_from_placement\naws_api/iot_1click_projects disassociate_device_from_placement","url":"aws_api/iot_1click_projects.html#disassociate_device_from_placement"},{"doc":"aws_api/iot_1click_projects","title":"get_devices_in_placement","content":"pub fn get_devices_in_placement(\n  client: Client,\n  project_name: String,\n  placement_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_1click_projects.get_devices_in_placement\naws_api/iot_1click_projects get_devices_in_placement","url":"aws_api/iot_1click_projects.html#get_devices_in_placement"},{"doc":"aws_api/iot_1click_projects","title":"list_placements","content":"pub fn list_placements(\n  client: Client,\n  project_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_1click_projects.list_placements\naws_api/iot_1click_projects list_placements","url":"aws_api/iot_1click_projects.html#list_placements"},{"doc":"aws_api/iot_1click_projects","title":"list_projects","content":"pub fn list_projects(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_1click_projects.list_projects\naws_api/iot_1click_projects list_projects","url":"aws_api/iot_1click_projects.html#list_projects"},{"doc":"aws_api/iot_1click_projects","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_1click_projects.list_tags_for_resource\naws_api/iot_1click_projects list_tags_for_resource","url":"aws_api/iot_1click_projects.html#list_tags_for_resource"},{"doc":"aws_api/iot_1click_projects","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/iot_1click_projects.new\naws_api/iot_1click_projects new","url":"aws_api/iot_1click_projects.html#new"},{"doc":"aws_api/iot_1click_projects","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_1click_projects.tag_resource\naws_api/iot_1click_projects tag_resource","url":"aws_api/iot_1click_projects.html#tag_resource"},{"doc":"aws_api/iot_1click_projects","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_1click_projects.untag_resource\naws_api/iot_1click_projects untag_resource","url":"aws_api/iot_1click_projects.html#untag_resource"},{"doc":"aws_api/iot_1click_projects","title":"update_placement","content":"pub fn update_placement(\n  client: Client,\n  project_name: String,\n  placement_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_1click_projects.update_placement\naws_api/iot_1click_projects update_placement","url":"aws_api/iot_1click_projects.html#update_placement"},{"doc":"aws_api/iot_1click_projects","title":"update_project","content":"pub fn update_project(\n  client: Client,\n  project_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_1click_projects.update_project\naws_api/iot_1click_projects update_project","url":"aws_api/iot_1click_projects.html#update_project"},{"doc":"aws_api/iot_1click_projects","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/iot_1click_projects.with_custom_endpoint\naws_api/iot_1click_projects with_custom_endpoint","url":"aws_api/iot_1click_projects.html#with_custom_endpoint"},{"doc":"aws_api/iot_1click_projects","title":"aws_api/iot_1click_projects","content":"","url":"aws_api/iot_1click_projects.html"},{"doc":"aws_api/iot_data_plane","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/iot_data_plane.Client\naws_api/iot_data_plane Client","url":"aws_api/iot_data_plane.html#Client"},{"doc":"aws_api/iot_data_plane","title":"delete_thing_shadow","content":"pub fn delete_thing_shadow(\n  client: Client,\n  thing_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_data_plane.delete_thing_shadow\naws_api/iot_data_plane delete_thing_shadow","url":"aws_api/iot_data_plane.html#delete_thing_shadow"},{"doc":"aws_api/iot_data_plane","title":"get_retained_message","content":"pub fn get_retained_message(\n  client: Client,\n  topic: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_data_plane.get_retained_message\naws_api/iot_data_plane get_retained_message","url":"aws_api/iot_data_plane.html#get_retained_message"},{"doc":"aws_api/iot_data_plane","title":"get_thing_shadow","content":"pub fn get_thing_shadow(\n  client: Client,\n  thing_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_data_plane.get_thing_shadow\naws_api/iot_data_plane get_thing_shadow","url":"aws_api/iot_data_plane.html#get_thing_shadow"},{"doc":"aws_api/iot_data_plane","title":"list_named_shadows_for_thing","content":"pub fn list_named_shadows_for_thing(\n  client: Client,\n  thing_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_data_plane.list_named_shadows_for_thing\naws_api/iot_data_plane list_named_shadows_for_thing","url":"aws_api/iot_data_plane.html#list_named_shadows_for_thing"},{"doc":"aws_api/iot_data_plane","title":"list_retained_messages","content":"pub fn list_retained_messages(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_data_plane.list_retained_messages\naws_api/iot_data_plane list_retained_messages","url":"aws_api/iot_data_plane.html#list_retained_messages"},{"doc":"aws_api/iot_data_plane","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/iot_data_plane.new\naws_api/iot_data_plane new","url":"aws_api/iot_data_plane.html#new"},{"doc":"aws_api/iot_data_plane","title":"publish","content":"pub fn publish(\n  client: Client,\n  topic: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_data_plane.publish\naws_api/iot_data_plane publish","url":"aws_api/iot_data_plane.html#publish"},{"doc":"aws_api/iot_data_plane","title":"update_thing_shadow","content":"pub fn update_thing_shadow(\n  client: Client,\n  thing_name: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_data_plane.update_thing_shadow\naws_api/iot_data_plane update_thing_shadow","url":"aws_api/iot_data_plane.html#update_thing_shadow"},{"doc":"aws_api/iot_data_plane","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/iot_data_plane.with_custom_endpoint\naws_api/iot_data_plane with_custom_endpoint","url":"aws_api/iot_data_plane.html#with_custom_endpoint"},{"doc":"aws_api/iot_data_plane","title":"aws_api/iot_data_plane","content":"","url":"aws_api/iot_data_plane.html"},{"doc":"aws_api/iot_events","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/iot_events.Client\naws_api/iot_events Client","url":"aws_api/iot_events.html#Client"},{"doc":"aws_api/iot_events","title":"create_alarm_model","content":"pub fn create_alarm_model(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_events.create_alarm_model\naws_api/iot_events create_alarm_model","url":"aws_api/iot_events.html#create_alarm_model"},{"doc":"aws_api/iot_events","title":"create_detector_model","content":"pub fn create_detector_model(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_events.create_detector_model\naws_api/iot_events create_detector_model","url":"aws_api/iot_events.html#create_detector_model"},{"doc":"aws_api/iot_events","title":"create_input","content":"pub fn create_input(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_events.create_input\naws_api/iot_events create_input","url":"aws_api/iot_events.html#create_input"},{"doc":"aws_api/iot_events","title":"delete_alarm_model","content":"pub fn delete_alarm_model(\n  client: Client,\n  alarm_model_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_events.delete_alarm_model\naws_api/iot_events delete_alarm_model","url":"aws_api/iot_events.html#delete_alarm_model"},{"doc":"aws_api/iot_events","title":"delete_detector_model","content":"pub fn delete_detector_model(\n  client: Client,\n  detector_model_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_events.delete_detector_model\naws_api/iot_events delete_detector_model","url":"aws_api/iot_events.html#delete_detector_model"},{"doc":"aws_api/iot_events","title":"delete_input","content":"pub fn delete_input(\n  client: Client,\n  input_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_events.delete_input\naws_api/iot_events delete_input","url":"aws_api/iot_events.html#delete_input"},{"doc":"aws_api/iot_events","title":"describe_alarm_model","content":"pub fn describe_alarm_model(\n  client: Client,\n  alarm_model_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_events.describe_alarm_model\naws_api/iot_events describe_alarm_model","url":"aws_api/iot_events.html#describe_alarm_model"},{"doc":"aws_api/iot_events","title":"describe_detector_model","content":"pub fn describe_detector_model(\n  client: Client,\n  detector_model_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_events.describe_detector_model\naws_api/iot_events describe_detector_model","url":"aws_api/iot_events.html#describe_detector_model"},{"doc":"aws_api/iot_events","title":"describe_detector_model_analysis","content":"pub fn describe_detector_model_analysis(\n  client: Client,\n  analysis_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_events.describe_detector_model_analysis\naws_api/iot_events describe_detector_model_analysis","url":"aws_api/iot_events.html#describe_detector_model_analysis"},{"doc":"aws_api/iot_events","title":"describe_input","content":"pub fn describe_input(\n  client: Client,\n  input_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_events.describe_input\naws_api/iot_events describe_input","url":"aws_api/iot_events.html#describe_input"},{"doc":"aws_api/iot_events","title":"describe_logging_options","content":"pub fn describe_logging_options(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_events.describe_logging_options\naws_api/iot_events describe_logging_options","url":"aws_api/iot_events.html#describe_logging_options"},{"doc":"aws_api/iot_events","title":"get_detector_model_analysis_results","content":"pub fn get_detector_model_analysis_results(\n  client: Client,\n  analysis_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_events.get_detector_model_analysis_results\naws_api/iot_events get_detector_model_analysis_results","url":"aws_api/iot_events.html#get_detector_model_analysis_results"},{"doc":"aws_api/iot_events","title":"list_alarm_model_versions","content":"pub fn list_alarm_model_versions(\n  client: Client,\n  alarm_model_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_events.list_alarm_model_versions\naws_api/iot_events list_alarm_model_versions","url":"aws_api/iot_events.html#list_alarm_model_versions"},{"doc":"aws_api/iot_events","title":"list_alarm_models","content":"pub fn list_alarm_models(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_events.list_alarm_models\naws_api/iot_events list_alarm_models","url":"aws_api/iot_events.html#list_alarm_models"},{"doc":"aws_api/iot_events","title":"list_detector_model_versions","content":"pub fn list_detector_model_versions(\n  client: Client,\n  detector_model_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_events.list_detector_model_versions\naws_api/iot_events list_detector_model_versions","url":"aws_api/iot_events.html#list_detector_model_versions"},{"doc":"aws_api/iot_events","title":"list_detector_models","content":"pub fn list_detector_models(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_events.list_detector_models\naws_api/iot_events list_detector_models","url":"aws_api/iot_events.html#list_detector_models"},{"doc":"aws_api/iot_events","title":"list_input_routings","content":"pub fn list_input_routings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_events.list_input_routings\naws_api/iot_events list_input_routings","url":"aws_api/iot_events.html#list_input_routings"},{"doc":"aws_api/iot_events","title":"list_inputs","content":"pub fn list_inputs(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_events.list_inputs\naws_api/iot_events list_inputs","url":"aws_api/iot_events.html#list_inputs"},{"doc":"aws_api/iot_events","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_events.list_tags_for_resource\naws_api/iot_events list_tags_for_resource","url":"aws_api/iot_events.html#list_tags_for_resource"},{"doc":"aws_api/iot_events","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/iot_events.new\naws_api/iot_events new","url":"aws_api/iot_events.html#new"},{"doc":"aws_api/iot_events","title":"put_logging_options","content":"pub fn put_logging_options(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_events.put_logging_options\naws_api/iot_events put_logging_options","url":"aws_api/iot_events.html#put_logging_options"},{"doc":"aws_api/iot_events","title":"start_detector_model_analysis","content":"pub fn start_detector_model_analysis(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_events.start_detector_model_analysis\naws_api/iot_events start_detector_model_analysis","url":"aws_api/iot_events.html#start_detector_model_analysis"},{"doc":"aws_api/iot_events","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_events.tag_resource\naws_api/iot_events tag_resource","url":"aws_api/iot_events.html#tag_resource"},{"doc":"aws_api/iot_events","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_events.untag_resource\naws_api/iot_events untag_resource","url":"aws_api/iot_events.html#untag_resource"},{"doc":"aws_api/iot_events","title":"update_alarm_model","content":"pub fn update_alarm_model(\n  client: Client,\n  alarm_model_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_events.update_alarm_model\naws_api/iot_events update_alarm_model","url":"aws_api/iot_events.html#update_alarm_model"},{"doc":"aws_api/iot_events","title":"update_detector_model","content":"pub fn update_detector_model(\n  client: Client,\n  detector_model_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_events.update_detector_model\naws_api/iot_events update_detector_model","url":"aws_api/iot_events.html#update_detector_model"},{"doc":"aws_api/iot_events","title":"update_input","content":"pub fn update_input(\n  client: Client,\n  input_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_events.update_input\naws_api/iot_events update_input","url":"aws_api/iot_events.html#update_input"},{"doc":"aws_api/iot_events","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/iot_events.with_custom_endpoint\naws_api/iot_events with_custom_endpoint","url":"aws_api/iot_events.html#with_custom_endpoint"},{"doc":"aws_api/iot_events","title":"aws_api/iot_events","content":"","url":"aws_api/iot_events.html"},{"doc":"aws_api/iot_jobs_data_plane","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/iot_jobs_data_plane.Client\naws_api/iot_jobs_data_plane Client","url":"aws_api/iot_jobs_data_plane.html#Client"},{"doc":"aws_api/iot_jobs_data_plane","title":"describe_job_execution","content":"pub fn describe_job_execution(\n  client: Client,\n  thing_name: String,\n  job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_jobs_data_plane.describe_job_execution\naws_api/iot_jobs_data_plane describe_job_execution","url":"aws_api/iot_jobs_data_plane.html#describe_job_execution"},{"doc":"aws_api/iot_jobs_data_plane","title":"get_pending_job_executions","content":"pub fn get_pending_job_executions(\n  client: Client,\n  thing_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_jobs_data_plane.get_pending_job_executions\naws_api/iot_jobs_data_plane get_pending_job_executions","url":"aws_api/iot_jobs_data_plane.html#get_pending_job_executions"},{"doc":"aws_api/iot_jobs_data_plane","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/iot_jobs_data_plane.new\naws_api/iot_jobs_data_plane new","url":"aws_api/iot_jobs_data_plane.html#new"},{"doc":"aws_api/iot_jobs_data_plane","title":"start_next_pending_job_execution","content":"pub fn start_next_pending_job_execution(\n  client: Client,\n  thing_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_jobs_data_plane.start_next_pending_job_execution\naws_api/iot_jobs_data_plane start_next_pending_job_execution","url":"aws_api/iot_jobs_data_plane.html#start_next_pending_job_execution"},{"doc":"aws_api/iot_jobs_data_plane","title":"update_job_execution","content":"pub fn update_job_execution(\n  client: Client,\n  thing_name: String,\n  job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_jobs_data_plane.update_job_execution\naws_api/iot_jobs_data_plane update_job_execution","url":"aws_api/iot_jobs_data_plane.html#update_job_execution"},{"doc":"aws_api/iot_jobs_data_plane","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/iot_jobs_data_plane.with_custom_endpoint\naws_api/iot_jobs_data_plane with_custom_endpoint","url":"aws_api/iot_jobs_data_plane.html#with_custom_endpoint"},{"doc":"aws_api/iot_jobs_data_plane","title":"aws_api/iot_jobs_data_plane","content":"","url":"aws_api/iot_jobs_data_plane.html"},{"doc":"aws_api/iot_wireless","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/iot_wireless.Client\naws_api/iot_wireless Client","url":"aws_api/iot_wireless.html#Client"},{"doc":"aws_api/iot_wireless","title":"associate_aws_account_with_partner_account","content":"pub fn associate_aws_account_with_partner_account(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.associate_aws_account_with_partner_account\naws_api/iot_wireless associate_aws_account_with_partner_account","url":"aws_api/iot_wireless.html#associate_aws_account_with_partner_account"},{"doc":"aws_api/iot_wireless","title":"associate_multicast_group_with_fuota_task","content":"pub fn associate_multicast_group_with_fuota_task(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.associate_multicast_group_with_fuota_task\naws_api/iot_wireless associate_multicast_group_with_fuota_task","url":"aws_api/iot_wireless.html#associate_multicast_group_with_fuota_task"},{"doc":"aws_api/iot_wireless","title":"associate_wireless_device_with_fuota_task","content":"pub fn associate_wireless_device_with_fuota_task(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.associate_wireless_device_with_fuota_task\naws_api/iot_wireless associate_wireless_device_with_fuota_task","url":"aws_api/iot_wireless.html#associate_wireless_device_with_fuota_task"},{"doc":"aws_api/iot_wireless","title":"associate_wireless_device_with_multicast_group","content":"pub fn associate_wireless_device_with_multicast_group(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.associate_wireless_device_with_multicast_group\naws_api/iot_wireless associate_wireless_device_with_multicast_group","url":"aws_api/iot_wireless.html#associate_wireless_device_with_multicast_group"},{"doc":"aws_api/iot_wireless","title":"associate_wireless_device_with_thing","content":"pub fn associate_wireless_device_with_thing(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.associate_wireless_device_with_thing\naws_api/iot_wireless associate_wireless_device_with_thing","url":"aws_api/iot_wireless.html#associate_wireless_device_with_thing"},{"doc":"aws_api/iot_wireless","title":"associate_wireless_gateway_with_certificate","content":"pub fn associate_wireless_gateway_with_certificate(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.associate_wireless_gateway_with_certificate\naws_api/iot_wireless associate_wireless_gateway_with_certificate","url":"aws_api/iot_wireless.html#associate_wireless_gateway_with_certificate"},{"doc":"aws_api/iot_wireless","title":"associate_wireless_gateway_with_thing","content":"pub fn associate_wireless_gateway_with_thing(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.associate_wireless_gateway_with_thing\naws_api/iot_wireless associate_wireless_gateway_with_thing","url":"aws_api/iot_wireless.html#associate_wireless_gateway_with_thing"},{"doc":"aws_api/iot_wireless","title":"cancel_multicast_group_session","content":"pub fn cancel_multicast_group_session(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.cancel_multicast_group_session\naws_api/iot_wireless cancel_multicast_group_session","url":"aws_api/iot_wireless.html#cancel_multicast_group_session"},{"doc":"aws_api/iot_wireless","title":"create_destination","content":"pub fn create_destination(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.create_destination\naws_api/iot_wireless create_destination","url":"aws_api/iot_wireless.html#create_destination"},{"doc":"aws_api/iot_wireless","title":"create_device_profile","content":"pub fn create_device_profile(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.create_device_profile\naws_api/iot_wireless create_device_profile","url":"aws_api/iot_wireless.html#create_device_profile"},{"doc":"aws_api/iot_wireless","title":"create_fuota_task","content":"pub fn create_fuota_task(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.create_fuota_task\naws_api/iot_wireless create_fuota_task","url":"aws_api/iot_wireless.html#create_fuota_task"},{"doc":"aws_api/iot_wireless","title":"create_multicast_group","content":"pub fn create_multicast_group(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.create_multicast_group\naws_api/iot_wireless create_multicast_group","url":"aws_api/iot_wireless.html#create_multicast_group"},{"doc":"aws_api/iot_wireless","title":"create_network_analyzer_configuration","content":"pub fn create_network_analyzer_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.create_network_analyzer_configuration\naws_api/iot_wireless create_network_analyzer_configuration","url":"aws_api/iot_wireless.html#create_network_analyzer_configuration"},{"doc":"aws_api/iot_wireless","title":"create_service_profile","content":"pub fn create_service_profile(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.create_service_profile\naws_api/iot_wireless create_service_profile","url":"aws_api/iot_wireless.html#create_service_profile"},{"doc":"aws_api/iot_wireless","title":"create_wireless_device","content":"pub fn create_wireless_device(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.create_wireless_device\naws_api/iot_wireless create_wireless_device","url":"aws_api/iot_wireless.html#create_wireless_device"},{"doc":"aws_api/iot_wireless","title":"create_wireless_gateway","content":"pub fn create_wireless_gateway(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.create_wireless_gateway\naws_api/iot_wireless create_wireless_gateway","url":"aws_api/iot_wireless.html#create_wireless_gateway"},{"doc":"aws_api/iot_wireless","title":"create_wireless_gateway_task","content":"pub fn create_wireless_gateway_task(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.create_wireless_gateway_task\naws_api/iot_wireless create_wireless_gateway_task","url":"aws_api/iot_wireless.html#create_wireless_gateway_task"},{"doc":"aws_api/iot_wireless","title":"create_wireless_gateway_task_definition","content":"pub fn create_wireless_gateway_task_definition(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.create_wireless_gateway_task_definition\naws_api/iot_wireless create_wireless_gateway_task_definition","url":"aws_api/iot_wireless.html#create_wireless_gateway_task_definition"},{"doc":"aws_api/iot_wireless","title":"delete_destination","content":"pub fn delete_destination(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.delete_destination\naws_api/iot_wireless delete_destination","url":"aws_api/iot_wireless.html#delete_destination"},{"doc":"aws_api/iot_wireless","title":"delete_device_profile","content":"pub fn delete_device_profile(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.delete_device_profile\naws_api/iot_wireless delete_device_profile","url":"aws_api/iot_wireless.html#delete_device_profile"},{"doc":"aws_api/iot_wireless","title":"delete_fuota_task","content":"pub fn delete_fuota_task(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.delete_fuota_task\naws_api/iot_wireless delete_fuota_task","url":"aws_api/iot_wireless.html#delete_fuota_task"},{"doc":"aws_api/iot_wireless","title":"delete_multicast_group","content":"pub fn delete_multicast_group(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.delete_multicast_group\naws_api/iot_wireless delete_multicast_group","url":"aws_api/iot_wireless.html#delete_multicast_group"},{"doc":"aws_api/iot_wireless","title":"delete_network_analyzer_configuration","content":"pub fn delete_network_analyzer_configuration(\n  client: Client,\n  configuration_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.delete_network_analyzer_configuration\naws_api/iot_wireless delete_network_analyzer_configuration","url":"aws_api/iot_wireless.html#delete_network_analyzer_configuration"},{"doc":"aws_api/iot_wireless","title":"delete_queued_messages","content":"pub fn delete_queued_messages(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.delete_queued_messages\naws_api/iot_wireless delete_queued_messages","url":"aws_api/iot_wireless.html#delete_queued_messages"},{"doc":"aws_api/iot_wireless","title":"delete_service_profile","content":"pub fn delete_service_profile(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.delete_service_profile\naws_api/iot_wireless delete_service_profile","url":"aws_api/iot_wireless.html#delete_service_profile"},{"doc":"aws_api/iot_wireless","title":"delete_wireless_device","content":"pub fn delete_wireless_device(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.delete_wireless_device\naws_api/iot_wireless delete_wireless_device","url":"aws_api/iot_wireless.html#delete_wireless_device"},{"doc":"aws_api/iot_wireless","title":"delete_wireless_device_import_task","content":"pub fn delete_wireless_device_import_task(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.delete_wireless_device_import_task\naws_api/iot_wireless delete_wireless_device_import_task","url":"aws_api/iot_wireless.html#delete_wireless_device_import_task"},{"doc":"aws_api/iot_wireless","title":"delete_wireless_gateway","content":"pub fn delete_wireless_gateway(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.delete_wireless_gateway\naws_api/iot_wireless delete_wireless_gateway","url":"aws_api/iot_wireless.html#delete_wireless_gateway"},{"doc":"aws_api/iot_wireless","title":"delete_wireless_gateway_task","content":"pub fn delete_wireless_gateway_task(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.delete_wireless_gateway_task\naws_api/iot_wireless delete_wireless_gateway_task","url":"aws_api/iot_wireless.html#delete_wireless_gateway_task"},{"doc":"aws_api/iot_wireless","title":"delete_wireless_gateway_task_definition","content":"pub fn delete_wireless_gateway_task_definition(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.delete_wireless_gateway_task_definition\naws_api/iot_wireless delete_wireless_gateway_task_definition","url":"aws_api/iot_wireless.html#delete_wireless_gateway_task_definition"},{"doc":"aws_api/iot_wireless","title":"deregister_wireless_device","content":"pub fn deregister_wireless_device(\n  client: Client,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.deregister_wireless_device\naws_api/iot_wireless deregister_wireless_device","url":"aws_api/iot_wireless.html#deregister_wireless_device"},{"doc":"aws_api/iot_wireless","title":"disassociate_aws_account_from_partner_account","content":"pub fn disassociate_aws_account_from_partner_account(\n  client: Client,\n  partner_account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.disassociate_aws_account_from_partner_account\naws_api/iot_wireless disassociate_aws_account_from_partner_account","url":"aws_api/iot_wireless.html#disassociate_aws_account_from_partner_account"},{"doc":"aws_api/iot_wireless","title":"disassociate_multicast_group_from_fuota_task","content":"pub fn disassociate_multicast_group_from_fuota_task(\n  client: Client,\n  id: String,\n  multicast_group_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.disassociate_multicast_group_from_fuota_task\naws_api/iot_wireless disassociate_multicast_group_from_fuota_task","url":"aws_api/iot_wireless.html#disassociate_multicast_group_from_fuota_task"},{"doc":"aws_api/iot_wireless","title":"disassociate_wireless_device_from_fuota_task","content":"pub fn disassociate_wireless_device_from_fuota_task(\n  client: Client,\n  id: String,\n  wireless_device_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.disassociate_wireless_device_from_fuota_task\naws_api/iot_wireless disassociate_wireless_device_from_fuota_task","url":"aws_api/iot_wireless.html#disassociate_wireless_device_from_fuota_task"},{"doc":"aws_api/iot_wireless","title":"disassociate_wireless_device_from_multicast_group","content":"pub fn disassociate_wireless_device_from_multicast_group(\n  client: Client,\n  id: String,\n  wireless_device_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.disassociate_wireless_device_from_multicast_group\naws_api/iot_wireless disassociate_wireless_device_from_multicast_group","url":"aws_api/iot_wireless.html#disassociate_wireless_device_from_multicast_group"},{"doc":"aws_api/iot_wireless","title":"disassociate_wireless_device_from_thing","content":"pub fn disassociate_wireless_device_from_thing(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.disassociate_wireless_device_from_thing\naws_api/iot_wireless disassociate_wireless_device_from_thing","url":"aws_api/iot_wireless.html#disassociate_wireless_device_from_thing"},{"doc":"aws_api/iot_wireless","title":"disassociate_wireless_gateway_from_certificate","content":"pub fn disassociate_wireless_gateway_from_certificate(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.disassociate_wireless_gateway_from_certificate\naws_api/iot_wireless disassociate_wireless_gateway_from_certificate","url":"aws_api/iot_wireless.html#disassociate_wireless_gateway_from_certificate"},{"doc":"aws_api/iot_wireless","title":"disassociate_wireless_gateway_from_thing","content":"pub fn disassociate_wireless_gateway_from_thing(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.disassociate_wireless_gateway_from_thing\naws_api/iot_wireless disassociate_wireless_gateway_from_thing","url":"aws_api/iot_wireless.html#disassociate_wireless_gateway_from_thing"},{"doc":"aws_api/iot_wireless","title":"get_destination","content":"pub fn get_destination(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.get_destination\naws_api/iot_wireless get_destination","url":"aws_api/iot_wireless.html#get_destination"},{"doc":"aws_api/iot_wireless","title":"get_device_profile","content":"pub fn get_device_profile(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.get_device_profile\naws_api/iot_wireless get_device_profile","url":"aws_api/iot_wireless.html#get_device_profile"},{"doc":"aws_api/iot_wireless","title":"get_event_configuration_by_resource_types","content":"pub fn get_event_configuration_by_resource_types(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.get_event_configuration_by_resource_types\naws_api/iot_wireless get_event_configuration_by_resource_types","url":"aws_api/iot_wireless.html#get_event_configuration_by_resource_types"},{"doc":"aws_api/iot_wireless","title":"get_fuota_task","content":"pub fn get_fuota_task(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.get_fuota_task\naws_api/iot_wireless get_fuota_task","url":"aws_api/iot_wireless.html#get_fuota_task"},{"doc":"aws_api/iot_wireless","title":"get_log_levels_by_resource_types","content":"pub fn get_log_levels_by_resource_types(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.get_log_levels_by_resource_types\naws_api/iot_wireless get_log_levels_by_resource_types","url":"aws_api/iot_wireless.html#get_log_levels_by_resource_types"},{"doc":"aws_api/iot_wireless","title":"get_metric_configuration","content":"pub fn get_metric_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.get_metric_configuration\naws_api/iot_wireless get_metric_configuration","url":"aws_api/iot_wireless.html#get_metric_configuration"},{"doc":"aws_api/iot_wireless","title":"get_metrics","content":"pub fn get_metrics(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.get_metrics\naws_api/iot_wireless get_metrics","url":"aws_api/iot_wireless.html#get_metrics"},{"doc":"aws_api/iot_wireless","title":"get_multicast_group","content":"pub fn get_multicast_group(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.get_multicast_group\naws_api/iot_wireless get_multicast_group","url":"aws_api/iot_wireless.html#get_multicast_group"},{"doc":"aws_api/iot_wireless","title":"get_multicast_group_session","content":"pub fn get_multicast_group_session(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.get_multicast_group_session\naws_api/iot_wireless get_multicast_group_session","url":"aws_api/iot_wireless.html#get_multicast_group_session"},{"doc":"aws_api/iot_wireless","title":"get_network_analyzer_configuration","content":"pub fn get_network_analyzer_configuration(\n  client: Client,\n  configuration_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.get_network_analyzer_configuration\naws_api/iot_wireless get_network_analyzer_configuration","url":"aws_api/iot_wireless.html#get_network_analyzer_configuration"},{"doc":"aws_api/iot_wireless","title":"get_partner_account","content":"pub fn get_partner_account(\n  client: Client,\n  partner_account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.get_partner_account\naws_api/iot_wireless get_partner_account","url":"aws_api/iot_wireless.html#get_partner_account"},{"doc":"aws_api/iot_wireless","title":"get_position","content":"pub fn get_position(\n  client: Client,\n  resource_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.get_position\naws_api/iot_wireless get_position","url":"aws_api/iot_wireless.html#get_position"},{"doc":"aws_api/iot_wireless","title":"get_position_configuration","content":"pub fn get_position_configuration(\n  client: Client,\n  resource_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.get_position_configuration\naws_api/iot_wireless get_position_configuration","url":"aws_api/iot_wireless.html#get_position_configuration"},{"doc":"aws_api/iot_wireless","title":"get_position_estimate","content":"pub fn get_position_estimate(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.get_position_estimate\naws_api/iot_wireless get_position_estimate","url":"aws_api/iot_wireless.html#get_position_estimate"},{"doc":"aws_api/iot_wireless","title":"get_resource_event_configuration","content":"pub fn get_resource_event_configuration(\n  client: Client,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.get_resource_event_configuration\naws_api/iot_wireless get_resource_event_configuration","url":"aws_api/iot_wireless.html#get_resource_event_configuration"},{"doc":"aws_api/iot_wireless","title":"get_resource_log_level","content":"pub fn get_resource_log_level(\n  client: Client,\n  resource_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.get_resource_log_level\naws_api/iot_wireless get_resource_log_level","url":"aws_api/iot_wireless.html#get_resource_log_level"},{"doc":"aws_api/iot_wireless","title":"get_resource_position","content":"pub fn get_resource_position(\n  client: Client,\n  resource_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.get_resource_position\naws_api/iot_wireless get_resource_position","url":"aws_api/iot_wireless.html#get_resource_position"},{"doc":"aws_api/iot_wireless","title":"get_service_endpoint","content":"pub fn get_service_endpoint(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.get_service_endpoint\naws_api/iot_wireless get_service_endpoint","url":"aws_api/iot_wireless.html#get_service_endpoint"},{"doc":"aws_api/iot_wireless","title":"get_service_profile","content":"pub fn get_service_profile(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.get_service_profile\naws_api/iot_wireless get_service_profile","url":"aws_api/iot_wireless.html#get_service_profile"},{"doc":"aws_api/iot_wireless","title":"get_wireless_device","content":"pub fn get_wireless_device(\n  client: Client,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.get_wireless_device\naws_api/iot_wireless get_wireless_device","url":"aws_api/iot_wireless.html#get_wireless_device"},{"doc":"aws_api/iot_wireless","title":"get_wireless_device_import_task","content":"pub fn get_wireless_device_import_task(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.get_wireless_device_import_task\naws_api/iot_wireless get_wireless_device_import_task","url":"aws_api/iot_wireless.html#get_wireless_device_import_task"},{"doc":"aws_api/iot_wireless","title":"get_wireless_device_statistics","content":"pub fn get_wireless_device_statistics(\n  client: Client,\n  wireless_device_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.get_wireless_device_statistics\naws_api/iot_wireless get_wireless_device_statistics","url":"aws_api/iot_wireless.html#get_wireless_device_statistics"},{"doc":"aws_api/iot_wireless","title":"get_wireless_gateway","content":"pub fn get_wireless_gateway(\n  client: Client,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.get_wireless_gateway\naws_api/iot_wireless get_wireless_gateway","url":"aws_api/iot_wireless.html#get_wireless_gateway"},{"doc":"aws_api/iot_wireless","title":"get_wireless_gateway_certificate","content":"pub fn get_wireless_gateway_certificate(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.get_wireless_gateway_certificate\naws_api/iot_wireless get_wireless_gateway_certificate","url":"aws_api/iot_wireless.html#get_wireless_gateway_certificate"},{"doc":"aws_api/iot_wireless","title":"get_wireless_gateway_firmware_information","content":"pub fn get_wireless_gateway_firmware_information(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.get_wireless_gateway_firmware_information\naws_api/iot_wireless get_wireless_gateway_firmware_information","url":"aws_api/iot_wireless.html#get_wireless_gateway_firmware_information"},{"doc":"aws_api/iot_wireless","title":"get_wireless_gateway_statistics","content":"pub fn get_wireless_gateway_statistics(\n  client: Client,\n  wireless_gateway_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.get_wireless_gateway_statistics\naws_api/iot_wireless get_wireless_gateway_statistics","url":"aws_api/iot_wireless.html#get_wireless_gateway_statistics"},{"doc":"aws_api/iot_wireless","title":"get_wireless_gateway_task","content":"pub fn get_wireless_gateway_task(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.get_wireless_gateway_task\naws_api/iot_wireless get_wireless_gateway_task","url":"aws_api/iot_wireless.html#get_wireless_gateway_task"},{"doc":"aws_api/iot_wireless","title":"get_wireless_gateway_task_definition","content":"pub fn get_wireless_gateway_task_definition(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.get_wireless_gateway_task_definition\naws_api/iot_wireless get_wireless_gateway_task_definition","url":"aws_api/iot_wireless.html#get_wireless_gateway_task_definition"},{"doc":"aws_api/iot_wireless","title":"list_destinations","content":"pub fn list_destinations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.list_destinations\naws_api/iot_wireless list_destinations","url":"aws_api/iot_wireless.html#list_destinations"},{"doc":"aws_api/iot_wireless","title":"list_device_profiles","content":"pub fn list_device_profiles(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.list_device_profiles\naws_api/iot_wireless list_device_profiles","url":"aws_api/iot_wireless.html#list_device_profiles"},{"doc":"aws_api/iot_wireless","title":"list_devices_for_wireless_device_import_task","content":"pub fn list_devices_for_wireless_device_import_task(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.list_devices_for_wireless_device_import_task\naws_api/iot_wireless list_devices_for_wireless_device_import_task","url":"aws_api/iot_wireless.html#list_devices_for_wireless_device_import_task"},{"doc":"aws_api/iot_wireless","title":"list_event_configurations","content":"pub fn list_event_configurations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.list_event_configurations\naws_api/iot_wireless list_event_configurations","url":"aws_api/iot_wireless.html#list_event_configurations"},{"doc":"aws_api/iot_wireless","title":"list_fuota_tasks","content":"pub fn list_fuota_tasks(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.list_fuota_tasks\naws_api/iot_wireless list_fuota_tasks","url":"aws_api/iot_wireless.html#list_fuota_tasks"},{"doc":"aws_api/iot_wireless","title":"list_multicast_groups","content":"pub fn list_multicast_groups(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.list_multicast_groups\naws_api/iot_wireless list_multicast_groups","url":"aws_api/iot_wireless.html#list_multicast_groups"},{"doc":"aws_api/iot_wireless","title":"list_multicast_groups_by_fuota_task","content":"pub fn list_multicast_groups_by_fuota_task(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.list_multicast_groups_by_fuota_task\naws_api/iot_wireless list_multicast_groups_by_fuota_task","url":"aws_api/iot_wireless.html#list_multicast_groups_by_fuota_task"},{"doc":"aws_api/iot_wireless","title":"list_network_analyzer_configurations","content":"pub fn list_network_analyzer_configurations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.list_network_analyzer_configurations\naws_api/iot_wireless list_network_analyzer_configurations","url":"aws_api/iot_wireless.html#list_network_analyzer_configurations"},{"doc":"aws_api/iot_wireless","title":"list_partner_accounts","content":"pub fn list_partner_accounts(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.list_partner_accounts\naws_api/iot_wireless list_partner_accounts","url":"aws_api/iot_wireless.html#list_partner_accounts"},{"doc":"aws_api/iot_wireless","title":"list_position_configurations","content":"pub fn list_position_configurations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.list_position_configurations\naws_api/iot_wireless list_position_configurations","url":"aws_api/iot_wireless.html#list_position_configurations"},{"doc":"aws_api/iot_wireless","title":"list_queued_messages","content":"pub fn list_queued_messages(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.list_queued_messages\naws_api/iot_wireless list_queued_messages","url":"aws_api/iot_wireless.html#list_queued_messages"},{"doc":"aws_api/iot_wireless","title":"list_service_profiles","content":"pub fn list_service_profiles(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.list_service_profiles\naws_api/iot_wireless list_service_profiles","url":"aws_api/iot_wireless.html#list_service_profiles"},{"doc":"aws_api/iot_wireless","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.list_tags_for_resource\naws_api/iot_wireless list_tags_for_resource","url":"aws_api/iot_wireless.html#list_tags_for_resource"},{"doc":"aws_api/iot_wireless","title":"list_wireless_device_import_tasks","content":"pub fn list_wireless_device_import_tasks(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.list_wireless_device_import_tasks\naws_api/iot_wireless list_wireless_device_import_tasks","url":"aws_api/iot_wireless.html#list_wireless_device_import_tasks"},{"doc":"aws_api/iot_wireless","title":"list_wireless_devices","content":"pub fn list_wireless_devices(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.list_wireless_devices\naws_api/iot_wireless list_wireless_devices","url":"aws_api/iot_wireless.html#list_wireless_devices"},{"doc":"aws_api/iot_wireless","title":"list_wireless_gateway_task_definitions","content":"pub fn list_wireless_gateway_task_definitions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.list_wireless_gateway_task_definitions\naws_api/iot_wireless list_wireless_gateway_task_definitions","url":"aws_api/iot_wireless.html#list_wireless_gateway_task_definitions"},{"doc":"aws_api/iot_wireless","title":"list_wireless_gateways","content":"pub fn list_wireless_gateways(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.list_wireless_gateways\naws_api/iot_wireless list_wireless_gateways","url":"aws_api/iot_wireless.html#list_wireless_gateways"},{"doc":"aws_api/iot_wireless","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/iot_wireless.new\naws_api/iot_wireless new","url":"aws_api/iot_wireless.html#new"},{"doc":"aws_api/iot_wireless","title":"put_position_configuration","content":"pub fn put_position_configuration(\n  client: Client,\n  resource_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.put_position_configuration\naws_api/iot_wireless put_position_configuration","url":"aws_api/iot_wireless.html#put_position_configuration"},{"doc":"aws_api/iot_wireless","title":"put_resource_log_level","content":"pub fn put_resource_log_level(\n  client: Client,\n  resource_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.put_resource_log_level\naws_api/iot_wireless put_resource_log_level","url":"aws_api/iot_wireless.html#put_resource_log_level"},{"doc":"aws_api/iot_wireless","title":"reset_all_resource_log_levels","content":"pub fn reset_all_resource_log_levels(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.reset_all_resource_log_levels\naws_api/iot_wireless reset_all_resource_log_levels","url":"aws_api/iot_wireless.html#reset_all_resource_log_levels"},{"doc":"aws_api/iot_wireless","title":"reset_resource_log_level","content":"pub fn reset_resource_log_level(\n  client: Client,\n  resource_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.reset_resource_log_level\naws_api/iot_wireless reset_resource_log_level","url":"aws_api/iot_wireless.html#reset_resource_log_level"},{"doc":"aws_api/iot_wireless","title":"send_data_to_multicast_group","content":"pub fn send_data_to_multicast_group(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.send_data_to_multicast_group\naws_api/iot_wireless send_data_to_multicast_group","url":"aws_api/iot_wireless.html#send_data_to_multicast_group"},{"doc":"aws_api/iot_wireless","title":"send_data_to_wireless_device","content":"pub fn send_data_to_wireless_device(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.send_data_to_wireless_device\naws_api/iot_wireless send_data_to_wireless_device","url":"aws_api/iot_wireless.html#send_data_to_wireless_device"},{"doc":"aws_api/iot_wireless","title":"start_bulk_associate_wireless_device_with_multicast_group","content":"pub fn start_bulk_associate_wireless_device_with_multicast_group(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.start_bulk_associate_wireless_device_with_multicast_group\naws_api/iot_wireless start_bulk_associate_wireless_device_with_multicast_group","url":"aws_api/iot_wireless.html#start_bulk_associate_wireless_device_with_multicast_group"},{"doc":"aws_api/iot_wireless","title":"start_bulk_disassociate_wireless_device_from_multicast_group","content":"pub fn start_bulk_disassociate_wireless_device_from_multicast_group(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.start_bulk_disassociate_wireless_device_from_multicast_group\naws_api/iot_wireless start_bulk_disassociate_wireless_device_from_multicast_group","url":"aws_api/iot_wireless.html#start_bulk_disassociate_wireless_device_from_multicast_group"},{"doc":"aws_api/iot_wireless","title":"start_fuota_task","content":"pub fn start_fuota_task(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.start_fuota_task\naws_api/iot_wireless start_fuota_task","url":"aws_api/iot_wireless.html#start_fuota_task"},{"doc":"aws_api/iot_wireless","title":"start_multicast_group_session","content":"pub fn start_multicast_group_session(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.start_multicast_group_session\naws_api/iot_wireless start_multicast_group_session","url":"aws_api/iot_wireless.html#start_multicast_group_session"},{"doc":"aws_api/iot_wireless","title":"start_single_wireless_device_import_task","content":"pub fn start_single_wireless_device_import_task(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.start_single_wireless_device_import_task\naws_api/iot_wireless start_single_wireless_device_import_task","url":"aws_api/iot_wireless.html#start_single_wireless_device_import_task"},{"doc":"aws_api/iot_wireless","title":"start_wireless_device_import_task","content":"pub fn start_wireless_device_import_task(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.start_wireless_device_import_task\naws_api/iot_wireless start_wireless_device_import_task","url":"aws_api/iot_wireless.html#start_wireless_device_import_task"},{"doc":"aws_api/iot_wireless","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.tag_resource\naws_api/iot_wireless tag_resource","url":"aws_api/iot_wireless.html#tag_resource"},{"doc":"aws_api/iot_wireless","title":"test_wireless_device","content":"pub fn test_wireless_device(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.test_wireless_device\naws_api/iot_wireless test_wireless_device","url":"aws_api/iot_wireless.html#test_wireless_device"},{"doc":"aws_api/iot_wireless","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.untag_resource\naws_api/iot_wireless untag_resource","url":"aws_api/iot_wireless.html#untag_resource"},{"doc":"aws_api/iot_wireless","title":"update_destination","content":"pub fn update_destination(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.update_destination\naws_api/iot_wireless update_destination","url":"aws_api/iot_wireless.html#update_destination"},{"doc":"aws_api/iot_wireless","title":"update_event_configuration_by_resource_types","content":"pub fn update_event_configuration_by_resource_types(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.update_event_configuration_by_resource_types\naws_api/iot_wireless update_event_configuration_by_resource_types","url":"aws_api/iot_wireless.html#update_event_configuration_by_resource_types"},{"doc":"aws_api/iot_wireless","title":"update_fuota_task","content":"pub fn update_fuota_task(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.update_fuota_task\naws_api/iot_wireless update_fuota_task","url":"aws_api/iot_wireless.html#update_fuota_task"},{"doc":"aws_api/iot_wireless","title":"update_log_levels_by_resource_types","content":"pub fn update_log_levels_by_resource_types(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.update_log_levels_by_resource_types\naws_api/iot_wireless update_log_levels_by_resource_types","url":"aws_api/iot_wireless.html#update_log_levels_by_resource_types"},{"doc":"aws_api/iot_wireless","title":"update_metric_configuration","content":"pub fn update_metric_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.update_metric_configuration\naws_api/iot_wireless update_metric_configuration","url":"aws_api/iot_wireless.html#update_metric_configuration"},{"doc":"aws_api/iot_wireless","title":"update_multicast_group","content":"pub fn update_multicast_group(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.update_multicast_group\naws_api/iot_wireless update_multicast_group","url":"aws_api/iot_wireless.html#update_multicast_group"},{"doc":"aws_api/iot_wireless","title":"update_network_analyzer_configuration","content":"pub fn update_network_analyzer_configuration(\n  client: Client,\n  configuration_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.update_network_analyzer_configuration\naws_api/iot_wireless update_network_analyzer_configuration","url":"aws_api/iot_wireless.html#update_network_analyzer_configuration"},{"doc":"aws_api/iot_wireless","title":"update_partner_account","content":"pub fn update_partner_account(\n  client: Client,\n  partner_account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.update_partner_account\naws_api/iot_wireless update_partner_account","url":"aws_api/iot_wireless.html#update_partner_account"},{"doc":"aws_api/iot_wireless","title":"update_position","content":"pub fn update_position(\n  client: Client,\n  resource_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.update_position\naws_api/iot_wireless update_position","url":"aws_api/iot_wireless.html#update_position"},{"doc":"aws_api/iot_wireless","title":"update_resource_event_configuration","content":"pub fn update_resource_event_configuration(\n  client: Client,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.update_resource_event_configuration\naws_api/iot_wireless update_resource_event_configuration","url":"aws_api/iot_wireless.html#update_resource_event_configuration"},{"doc":"aws_api/iot_wireless","title":"update_resource_position","content":"pub fn update_resource_position(\n  client: Client,\n  resource_identifier: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.update_resource_position\naws_api/iot_wireless update_resource_position","url":"aws_api/iot_wireless.html#update_resource_position"},{"doc":"aws_api/iot_wireless","title":"update_wireless_device","content":"pub fn update_wireless_device(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.update_wireless_device\naws_api/iot_wireless update_wireless_device","url":"aws_api/iot_wireless.html#update_wireless_device"},{"doc":"aws_api/iot_wireless","title":"update_wireless_device_import_task","content":"pub fn update_wireless_device_import_task(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.update_wireless_device_import_task\naws_api/iot_wireless update_wireless_device_import_task","url":"aws_api/iot_wireless.html#update_wireless_device_import_task"},{"doc":"aws_api/iot_wireless","title":"update_wireless_gateway","content":"pub fn update_wireless_gateway(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iot_wireless.update_wireless_gateway\naws_api/iot_wireless update_wireless_gateway","url":"aws_api/iot_wireless.html#update_wireless_gateway"},{"doc":"aws_api/iot_wireless","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/iot_wireless.with_custom_endpoint\naws_api/iot_wireless with_custom_endpoint","url":"aws_api/iot_wireless.html#with_custom_endpoint"},{"doc":"aws_api/iot_wireless","title":"aws_api/iot_wireless","content":"","url":"aws_api/iot_wireless.html"},{"doc":"aws_api/iotanalytics","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/iotanalytics.Client\naws_api/iotanalytics Client","url":"aws_api/iotanalytics.html#Client"},{"doc":"aws_api/iotanalytics","title":"batch_put_message","content":"pub fn batch_put_message(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotanalytics.batch_put_message\naws_api/iotanalytics batch_put_message","url":"aws_api/iotanalytics.html#batch_put_message"},{"doc":"aws_api/iotanalytics","title":"cancel_pipeline_reprocessing","content":"pub fn cancel_pipeline_reprocessing(\n  client: Client,\n  pipeline_name: String,\n  reprocessing_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotanalytics.cancel_pipeline_reprocessing\naws_api/iotanalytics cancel_pipeline_reprocessing","url":"aws_api/iotanalytics.html#cancel_pipeline_reprocessing"},{"doc":"aws_api/iotanalytics","title":"create_channel","content":"pub fn create_channel(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotanalytics.create_channel\naws_api/iotanalytics create_channel","url":"aws_api/iotanalytics.html#create_channel"},{"doc":"aws_api/iotanalytics","title":"create_dataset","content":"pub fn create_dataset(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotanalytics.create_dataset\naws_api/iotanalytics create_dataset","url":"aws_api/iotanalytics.html#create_dataset"},{"doc":"aws_api/iotanalytics","title":"create_dataset_content","content":"pub fn create_dataset_content(\n  client: Client,\n  dataset_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotanalytics.create_dataset_content\naws_api/iotanalytics create_dataset_content","url":"aws_api/iotanalytics.html#create_dataset_content"},{"doc":"aws_api/iotanalytics","title":"create_datastore","content":"pub fn create_datastore(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotanalytics.create_datastore\naws_api/iotanalytics create_datastore","url":"aws_api/iotanalytics.html#create_datastore"},{"doc":"aws_api/iotanalytics","title":"create_pipeline","content":"pub fn create_pipeline(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotanalytics.create_pipeline\naws_api/iotanalytics create_pipeline","url":"aws_api/iotanalytics.html#create_pipeline"},{"doc":"aws_api/iotanalytics","title":"delete_channel","content":"pub fn delete_channel(\n  client: Client,\n  channel_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotanalytics.delete_channel\naws_api/iotanalytics delete_channel","url":"aws_api/iotanalytics.html#delete_channel"},{"doc":"aws_api/iotanalytics","title":"delete_dataset","content":"pub fn delete_dataset(\n  client: Client,\n  dataset_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotanalytics.delete_dataset\naws_api/iotanalytics delete_dataset","url":"aws_api/iotanalytics.html#delete_dataset"},{"doc":"aws_api/iotanalytics","title":"delete_dataset_content","content":"pub fn delete_dataset_content(\n  client: Client,\n  dataset_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotanalytics.delete_dataset_content\naws_api/iotanalytics delete_dataset_content","url":"aws_api/iotanalytics.html#delete_dataset_content"},{"doc":"aws_api/iotanalytics","title":"delete_datastore","content":"pub fn delete_datastore(\n  client: Client,\n  datastore_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotanalytics.delete_datastore\naws_api/iotanalytics delete_datastore","url":"aws_api/iotanalytics.html#delete_datastore"},{"doc":"aws_api/iotanalytics","title":"delete_pipeline","content":"pub fn delete_pipeline(\n  client: Client,\n  pipeline_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotanalytics.delete_pipeline\naws_api/iotanalytics delete_pipeline","url":"aws_api/iotanalytics.html#delete_pipeline"},{"doc":"aws_api/iotanalytics","title":"describe_channel","content":"pub fn describe_channel(\n  client: Client,\n  channel_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotanalytics.describe_channel\naws_api/iotanalytics describe_channel","url":"aws_api/iotanalytics.html#describe_channel"},{"doc":"aws_api/iotanalytics","title":"describe_dataset","content":"pub fn describe_dataset(\n  client: Client,\n  dataset_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotanalytics.describe_dataset\naws_api/iotanalytics describe_dataset","url":"aws_api/iotanalytics.html#describe_dataset"},{"doc":"aws_api/iotanalytics","title":"describe_datastore","content":"pub fn describe_datastore(\n  client: Client,\n  datastore_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotanalytics.describe_datastore\naws_api/iotanalytics describe_datastore","url":"aws_api/iotanalytics.html#describe_datastore"},{"doc":"aws_api/iotanalytics","title":"describe_logging_options","content":"pub fn describe_logging_options(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotanalytics.describe_logging_options\naws_api/iotanalytics describe_logging_options","url":"aws_api/iotanalytics.html#describe_logging_options"},{"doc":"aws_api/iotanalytics","title":"describe_pipeline","content":"pub fn describe_pipeline(\n  client: Client,\n  pipeline_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotanalytics.describe_pipeline\naws_api/iotanalytics describe_pipeline","url":"aws_api/iotanalytics.html#describe_pipeline"},{"doc":"aws_api/iotanalytics","title":"get_dataset_content","content":"pub fn get_dataset_content(\n  client: Client,\n  dataset_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotanalytics.get_dataset_content\naws_api/iotanalytics get_dataset_content","url":"aws_api/iotanalytics.html#get_dataset_content"},{"doc":"aws_api/iotanalytics","title":"list_channels","content":"pub fn list_channels(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotanalytics.list_channels\naws_api/iotanalytics list_channels","url":"aws_api/iotanalytics.html#list_channels"},{"doc":"aws_api/iotanalytics","title":"list_dataset_contents","content":"pub fn list_dataset_contents(\n  client: Client,\n  dataset_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotanalytics.list_dataset_contents\naws_api/iotanalytics list_dataset_contents","url":"aws_api/iotanalytics.html#list_dataset_contents"},{"doc":"aws_api/iotanalytics","title":"list_datasets","content":"pub fn list_datasets(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotanalytics.list_datasets\naws_api/iotanalytics list_datasets","url":"aws_api/iotanalytics.html#list_datasets"},{"doc":"aws_api/iotanalytics","title":"list_datastores","content":"pub fn list_datastores(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotanalytics.list_datastores\naws_api/iotanalytics list_datastores","url":"aws_api/iotanalytics.html#list_datastores"},{"doc":"aws_api/iotanalytics","title":"list_pipelines","content":"pub fn list_pipelines(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotanalytics.list_pipelines\naws_api/iotanalytics list_pipelines","url":"aws_api/iotanalytics.html#list_pipelines"},{"doc":"aws_api/iotanalytics","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotanalytics.list_tags_for_resource\naws_api/iotanalytics list_tags_for_resource","url":"aws_api/iotanalytics.html#list_tags_for_resource"},{"doc":"aws_api/iotanalytics","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/iotanalytics.new\naws_api/iotanalytics new","url":"aws_api/iotanalytics.html#new"},{"doc":"aws_api/iotanalytics","title":"put_logging_options","content":"pub fn put_logging_options(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotanalytics.put_logging_options\naws_api/iotanalytics put_logging_options","url":"aws_api/iotanalytics.html#put_logging_options"},{"doc":"aws_api/iotanalytics","title":"run_pipeline_activity","content":"pub fn run_pipeline_activity(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotanalytics.run_pipeline_activity\naws_api/iotanalytics run_pipeline_activity","url":"aws_api/iotanalytics.html#run_pipeline_activity"},{"doc":"aws_api/iotanalytics","title":"sample_channel_data","content":"pub fn sample_channel_data(\n  client: Client,\n  channel_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotanalytics.sample_channel_data\naws_api/iotanalytics sample_channel_data","url":"aws_api/iotanalytics.html#sample_channel_data"},{"doc":"aws_api/iotanalytics","title":"start_pipeline_reprocessing","content":"pub fn start_pipeline_reprocessing(\n  client: Client,\n  pipeline_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotanalytics.start_pipeline_reprocessing\naws_api/iotanalytics start_pipeline_reprocessing","url":"aws_api/iotanalytics.html#start_pipeline_reprocessing"},{"doc":"aws_api/iotanalytics","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotanalytics.tag_resource\naws_api/iotanalytics tag_resource","url":"aws_api/iotanalytics.html#tag_resource"},{"doc":"aws_api/iotanalytics","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotanalytics.untag_resource\naws_api/iotanalytics untag_resource","url":"aws_api/iotanalytics.html#untag_resource"},{"doc":"aws_api/iotanalytics","title":"update_channel","content":"pub fn update_channel(\n  client: Client,\n  channel_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotanalytics.update_channel\naws_api/iotanalytics update_channel","url":"aws_api/iotanalytics.html#update_channel"},{"doc":"aws_api/iotanalytics","title":"update_dataset","content":"pub fn update_dataset(\n  client: Client,\n  dataset_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotanalytics.update_dataset\naws_api/iotanalytics update_dataset","url":"aws_api/iotanalytics.html#update_dataset"},{"doc":"aws_api/iotanalytics","title":"update_datastore","content":"pub fn update_datastore(\n  client: Client,\n  datastore_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotanalytics.update_datastore\naws_api/iotanalytics update_datastore","url":"aws_api/iotanalytics.html#update_datastore"},{"doc":"aws_api/iotanalytics","title":"update_pipeline","content":"pub fn update_pipeline(\n  client: Client,\n  pipeline_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotanalytics.update_pipeline\naws_api/iotanalytics update_pipeline","url":"aws_api/iotanalytics.html#update_pipeline"},{"doc":"aws_api/iotanalytics","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/iotanalytics.with_custom_endpoint\naws_api/iotanalytics with_custom_endpoint","url":"aws_api/iotanalytics.html#with_custom_endpoint"},{"doc":"aws_api/iotanalytics","title":"aws_api/iotanalytics","content":"","url":"aws_api/iotanalytics.html"},{"doc":"aws_api/iotdeviceadvisor","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/iotdeviceadvisor.Client\naws_api/iotdeviceadvisor Client","url":"aws_api/iotdeviceadvisor.html#Client"},{"doc":"aws_api/iotdeviceadvisor","title":"create_suite_definition","content":"pub fn create_suite_definition(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotdeviceadvisor.create_suite_definition\naws_api/iotdeviceadvisor create_suite_definition","url":"aws_api/iotdeviceadvisor.html#create_suite_definition"},{"doc":"aws_api/iotdeviceadvisor","title":"delete_suite_definition","content":"pub fn delete_suite_definition(\n  client: Client,\n  suite_definition_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotdeviceadvisor.delete_suite_definition\naws_api/iotdeviceadvisor delete_suite_definition","url":"aws_api/iotdeviceadvisor.html#delete_suite_definition"},{"doc":"aws_api/iotdeviceadvisor","title":"get_endpoint","content":"pub fn get_endpoint(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotdeviceadvisor.get_endpoint\naws_api/iotdeviceadvisor get_endpoint","url":"aws_api/iotdeviceadvisor.html#get_endpoint"},{"doc":"aws_api/iotdeviceadvisor","title":"get_suite_definition","content":"pub fn get_suite_definition(\n  client: Client,\n  suite_definition_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotdeviceadvisor.get_suite_definition\naws_api/iotdeviceadvisor get_suite_definition","url":"aws_api/iotdeviceadvisor.html#get_suite_definition"},{"doc":"aws_api/iotdeviceadvisor","title":"get_suite_run","content":"pub fn get_suite_run(\n  client: Client,\n  suite_definition_id: String,\n  suite_run_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotdeviceadvisor.get_suite_run\naws_api/iotdeviceadvisor get_suite_run","url":"aws_api/iotdeviceadvisor.html#get_suite_run"},{"doc":"aws_api/iotdeviceadvisor","title":"get_suite_run_report","content":"pub fn get_suite_run_report(\n  client: Client,\n  suite_definition_id: String,\n  suite_run_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotdeviceadvisor.get_suite_run_report\naws_api/iotdeviceadvisor get_suite_run_report","url":"aws_api/iotdeviceadvisor.html#get_suite_run_report"},{"doc":"aws_api/iotdeviceadvisor","title":"list_suite_definitions","content":"pub fn list_suite_definitions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotdeviceadvisor.list_suite_definitions\naws_api/iotdeviceadvisor list_suite_definitions","url":"aws_api/iotdeviceadvisor.html#list_suite_definitions"},{"doc":"aws_api/iotdeviceadvisor","title":"list_suite_runs","content":"pub fn list_suite_runs(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotdeviceadvisor.list_suite_runs\naws_api/iotdeviceadvisor list_suite_runs","url":"aws_api/iotdeviceadvisor.html#list_suite_runs"},{"doc":"aws_api/iotdeviceadvisor","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotdeviceadvisor.list_tags_for_resource\naws_api/iotdeviceadvisor list_tags_for_resource","url":"aws_api/iotdeviceadvisor.html#list_tags_for_resource"},{"doc":"aws_api/iotdeviceadvisor","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/iotdeviceadvisor.new\naws_api/iotdeviceadvisor new","url":"aws_api/iotdeviceadvisor.html#new"},{"doc":"aws_api/iotdeviceadvisor","title":"start_suite_run","content":"pub fn start_suite_run(\n  client: Client,\n  suite_definition_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotdeviceadvisor.start_suite_run\naws_api/iotdeviceadvisor start_suite_run","url":"aws_api/iotdeviceadvisor.html#start_suite_run"},{"doc":"aws_api/iotdeviceadvisor","title":"stop_suite_run","content":"pub fn stop_suite_run(\n  client: Client,\n  suite_definition_id: String,\n  suite_run_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotdeviceadvisor.stop_suite_run\naws_api/iotdeviceadvisor stop_suite_run","url":"aws_api/iotdeviceadvisor.html#stop_suite_run"},{"doc":"aws_api/iotdeviceadvisor","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotdeviceadvisor.tag_resource\naws_api/iotdeviceadvisor tag_resource","url":"aws_api/iotdeviceadvisor.html#tag_resource"},{"doc":"aws_api/iotdeviceadvisor","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotdeviceadvisor.untag_resource\naws_api/iotdeviceadvisor untag_resource","url":"aws_api/iotdeviceadvisor.html#untag_resource"},{"doc":"aws_api/iotdeviceadvisor","title":"update_suite_definition","content":"pub fn update_suite_definition(\n  client: Client,\n  suite_definition_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotdeviceadvisor.update_suite_definition\naws_api/iotdeviceadvisor update_suite_definition","url":"aws_api/iotdeviceadvisor.html#update_suite_definition"},{"doc":"aws_api/iotdeviceadvisor","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/iotdeviceadvisor.with_custom_endpoint\naws_api/iotdeviceadvisor with_custom_endpoint","url":"aws_api/iotdeviceadvisor.html#with_custom_endpoint"},{"doc":"aws_api/iotdeviceadvisor","title":"aws_api/iotdeviceadvisor","content":"","url":"aws_api/iotdeviceadvisor.html"},{"doc":"aws_api/iotfleethub","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/iotfleethub.Client\naws_api/iotfleethub Client","url":"aws_api/iotfleethub.html#Client"},{"doc":"aws_api/iotfleethub","title":"create_application","content":"pub fn create_application(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotfleethub.create_application\naws_api/iotfleethub create_application","url":"aws_api/iotfleethub.html#create_application"},{"doc":"aws_api/iotfleethub","title":"delete_application","content":"pub fn delete_application(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotfleethub.delete_application\naws_api/iotfleethub delete_application","url":"aws_api/iotfleethub.html#delete_application"},{"doc":"aws_api/iotfleethub","title":"describe_application","content":"pub fn describe_application(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotfleethub.describe_application\naws_api/iotfleethub describe_application","url":"aws_api/iotfleethub.html#describe_application"},{"doc":"aws_api/iotfleethub","title":"list_applications","content":"pub fn list_applications(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotfleethub.list_applications\naws_api/iotfleethub list_applications","url":"aws_api/iotfleethub.html#list_applications"},{"doc":"aws_api/iotfleethub","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotfleethub.list_tags_for_resource\naws_api/iotfleethub list_tags_for_resource","url":"aws_api/iotfleethub.html#list_tags_for_resource"},{"doc":"aws_api/iotfleethub","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/iotfleethub.new\naws_api/iotfleethub new","url":"aws_api/iotfleethub.html#new"},{"doc":"aws_api/iotfleethub","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotfleethub.tag_resource\naws_api/iotfleethub tag_resource","url":"aws_api/iotfleethub.html#tag_resource"},{"doc":"aws_api/iotfleethub","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotfleethub.untag_resource\naws_api/iotfleethub untag_resource","url":"aws_api/iotfleethub.html#untag_resource"},{"doc":"aws_api/iotfleethub","title":"update_application","content":"pub fn update_application(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotfleethub.update_application\naws_api/iotfleethub update_application","url":"aws_api/iotfleethub.html#update_application"},{"doc":"aws_api/iotfleethub","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/iotfleethub.with_custom_endpoint\naws_api/iotfleethub with_custom_endpoint","url":"aws_api/iotfleethub.html#with_custom_endpoint"},{"doc":"aws_api/iotfleethub","title":"aws_api/iotfleethub","content":"","url":"aws_api/iotfleethub.html"},{"doc":"aws_api/iotfleetwise","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/iotfleetwise.Client\naws_api/iotfleetwise Client","url":"aws_api/iotfleetwise.html#Client"},{"doc":"aws_api/iotfleetwise","title":"batch_create_vehicle","content":"pub fn batch_create_vehicle(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotfleetwise.batch_create_vehicle\naws_api/iotfleetwise batch_create_vehicle","url":"aws_api/iotfleetwise.html#batch_create_vehicle"},{"doc":"aws_api/iotfleetwise","title":"batch_update_vehicle","content":"pub fn batch_update_vehicle(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotfleetwise.batch_update_vehicle\naws_api/iotfleetwise batch_update_vehicle","url":"aws_api/iotfleetwise.html#batch_update_vehicle"},{"doc":"aws_api/iotfleetwise","title":"get_encryption_configuration","content":"pub fn get_encryption_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotfleetwise.get_encryption_configuration\naws_api/iotfleetwise get_encryption_configuration","url":"aws_api/iotfleetwise.html#get_encryption_configuration"},{"doc":"aws_api/iotfleetwise","title":"get_logging_options","content":"pub fn get_logging_options(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotfleetwise.get_logging_options\naws_api/iotfleetwise get_logging_options","url":"aws_api/iotfleetwise.html#get_logging_options"},{"doc":"aws_api/iotfleetwise","title":"get_register_account_status","content":"pub fn get_register_account_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotfleetwise.get_register_account_status\naws_api/iotfleetwise get_register_account_status","url":"aws_api/iotfleetwise.html#get_register_account_status"},{"doc":"aws_api/iotfleetwise","title":"get_vehicle_status","content":"pub fn get_vehicle_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotfleetwise.get_vehicle_status\naws_api/iotfleetwise get_vehicle_status","url":"aws_api/iotfleetwise.html#get_vehicle_status"},{"doc":"aws_api/iotfleetwise","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotfleetwise.list_tags_for_resource\naws_api/iotfleetwise list_tags_for_resource","url":"aws_api/iotfleetwise.html#list_tags_for_resource"},{"doc":"aws_api/iotfleetwise","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/iotfleetwise.new\naws_api/iotfleetwise new","url":"aws_api/iotfleetwise.html#new"},{"doc":"aws_api/iotfleetwise","title":"put_encryption_configuration","content":"pub fn put_encryption_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotfleetwise.put_encryption_configuration\naws_api/iotfleetwise put_encryption_configuration","url":"aws_api/iotfleetwise.html#put_encryption_configuration"},{"doc":"aws_api/iotfleetwise","title":"put_logging_options","content":"pub fn put_logging_options(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotfleetwise.put_logging_options\naws_api/iotfleetwise put_logging_options","url":"aws_api/iotfleetwise.html#put_logging_options"},{"doc":"aws_api/iotfleetwise","title":"register_account","content":"pub fn register_account(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotfleetwise.register_account\naws_api/iotfleetwise register_account","url":"aws_api/iotfleetwise.html#register_account"},{"doc":"aws_api/iotfleetwise","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotfleetwise.tag_resource\naws_api/iotfleetwise tag_resource","url":"aws_api/iotfleetwise.html#tag_resource"},{"doc":"aws_api/iotfleetwise","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotfleetwise.untag_resource\naws_api/iotfleetwise untag_resource","url":"aws_api/iotfleetwise.html#untag_resource"},{"doc":"aws_api/iotfleetwise","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/iotfleetwise.with_custom_endpoint\naws_api/iotfleetwise with_custom_endpoint","url":"aws_api/iotfleetwise.html#with_custom_endpoint"},{"doc":"aws_api/iotfleetwise","title":"aws_api/iotfleetwise","content":"","url":"aws_api/iotfleetwise.html"},{"doc":"aws_api/iotsecuretunneling","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/iotsecuretunneling.Client\naws_api/iotsecuretunneling Client","url":"aws_api/iotsecuretunneling.html#Client"},{"doc":"aws_api/iotsecuretunneling","title":"close_tunnel","content":"pub fn close_tunnel(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsecuretunneling.close_tunnel\naws_api/iotsecuretunneling close_tunnel","url":"aws_api/iotsecuretunneling.html#close_tunnel"},{"doc":"aws_api/iotsecuretunneling","title":"describe_tunnel","content":"pub fn describe_tunnel(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsecuretunneling.describe_tunnel\naws_api/iotsecuretunneling describe_tunnel","url":"aws_api/iotsecuretunneling.html#describe_tunnel"},{"doc":"aws_api/iotsecuretunneling","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsecuretunneling.list_tags_for_resource\naws_api/iotsecuretunneling list_tags_for_resource","url":"aws_api/iotsecuretunneling.html#list_tags_for_resource"},{"doc":"aws_api/iotsecuretunneling","title":"list_tunnels","content":"pub fn list_tunnels(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsecuretunneling.list_tunnels\naws_api/iotsecuretunneling list_tunnels","url":"aws_api/iotsecuretunneling.html#list_tunnels"},{"doc":"aws_api/iotsecuretunneling","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/iotsecuretunneling.new\naws_api/iotsecuretunneling new","url":"aws_api/iotsecuretunneling.html#new"},{"doc":"aws_api/iotsecuretunneling","title":"open_tunnel","content":"pub fn open_tunnel(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsecuretunneling.open_tunnel\naws_api/iotsecuretunneling open_tunnel","url":"aws_api/iotsecuretunneling.html#open_tunnel"},{"doc":"aws_api/iotsecuretunneling","title":"rotate_tunnel_access_token","content":"pub fn rotate_tunnel_access_token(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsecuretunneling.rotate_tunnel_access_token\naws_api/iotsecuretunneling rotate_tunnel_access_token","url":"aws_api/iotsecuretunneling.html#rotate_tunnel_access_token"},{"doc":"aws_api/iotsecuretunneling","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsecuretunneling.tag_resource\naws_api/iotsecuretunneling tag_resource","url":"aws_api/iotsecuretunneling.html#tag_resource"},{"doc":"aws_api/iotsecuretunneling","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsecuretunneling.untag_resource\naws_api/iotsecuretunneling untag_resource","url":"aws_api/iotsecuretunneling.html#untag_resource"},{"doc":"aws_api/iotsecuretunneling","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/iotsecuretunneling.with_custom_endpoint\naws_api/iotsecuretunneling with_custom_endpoint","url":"aws_api/iotsecuretunneling.html#with_custom_endpoint"},{"doc":"aws_api/iotsecuretunneling","title":"aws_api/iotsecuretunneling","content":"","url":"aws_api/iotsecuretunneling.html"},{"doc":"aws_api/iotsitewise","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/iotsitewise.Client\naws_api/iotsitewise Client","url":"aws_api/iotsitewise.html#Client"},{"doc":"aws_api/iotsitewise","title":"associate_assets","content":"pub fn associate_assets(\n  client: Client,\n  asset_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.associate_assets\naws_api/iotsitewise associate_assets","url":"aws_api/iotsitewise.html#associate_assets"},{"doc":"aws_api/iotsitewise","title":"associate_time_series_to_asset_property","content":"pub fn associate_time_series_to_asset_property(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.associate_time_series_to_asset_property\naws_api/iotsitewise associate_time_series_to_asset_property","url":"aws_api/iotsitewise.html#associate_time_series_to_asset_property"},{"doc":"aws_api/iotsitewise","title":"batch_associate_project_assets","content":"pub fn batch_associate_project_assets(\n  client: Client,\n  project_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.batch_associate_project_assets\naws_api/iotsitewise batch_associate_project_assets","url":"aws_api/iotsitewise.html#batch_associate_project_assets"},{"doc":"aws_api/iotsitewise","title":"batch_disassociate_project_assets","content":"pub fn batch_disassociate_project_assets(\n  client: Client,\n  project_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.batch_disassociate_project_assets\naws_api/iotsitewise batch_disassociate_project_assets","url":"aws_api/iotsitewise.html#batch_disassociate_project_assets"},{"doc":"aws_api/iotsitewise","title":"batch_get_asset_property_aggregates","content":"pub fn batch_get_asset_property_aggregates(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.batch_get_asset_property_aggregates\naws_api/iotsitewise batch_get_asset_property_aggregates","url":"aws_api/iotsitewise.html#batch_get_asset_property_aggregates"},{"doc":"aws_api/iotsitewise","title":"batch_get_asset_property_value","content":"pub fn batch_get_asset_property_value(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.batch_get_asset_property_value\naws_api/iotsitewise batch_get_asset_property_value","url":"aws_api/iotsitewise.html#batch_get_asset_property_value"},{"doc":"aws_api/iotsitewise","title":"batch_get_asset_property_value_history","content":"pub fn batch_get_asset_property_value_history(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.batch_get_asset_property_value_history\naws_api/iotsitewise batch_get_asset_property_value_history","url":"aws_api/iotsitewise.html#batch_get_asset_property_value_history"},{"doc":"aws_api/iotsitewise","title":"batch_put_asset_property_value","content":"pub fn batch_put_asset_property_value(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.batch_put_asset_property_value\naws_api/iotsitewise batch_put_asset_property_value","url":"aws_api/iotsitewise.html#batch_put_asset_property_value"},{"doc":"aws_api/iotsitewise","title":"create_access_policy","content":"pub fn create_access_policy(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.create_access_policy\naws_api/iotsitewise create_access_policy","url":"aws_api/iotsitewise.html#create_access_policy"},{"doc":"aws_api/iotsitewise","title":"create_asset","content":"pub fn create_asset(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.create_asset\naws_api/iotsitewise create_asset","url":"aws_api/iotsitewise.html#create_asset"},{"doc":"aws_api/iotsitewise","title":"create_asset_model","content":"pub fn create_asset_model(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.create_asset_model\naws_api/iotsitewise create_asset_model","url":"aws_api/iotsitewise.html#create_asset_model"},{"doc":"aws_api/iotsitewise","title":"create_asset_model_composite_model","content":"pub fn create_asset_model_composite_model(\n  client: Client,\n  asset_model_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.create_asset_model_composite_model\naws_api/iotsitewise create_asset_model_composite_model","url":"aws_api/iotsitewise.html#create_asset_model_composite_model"},{"doc":"aws_api/iotsitewise","title":"create_bulk_import_job","content":"pub fn create_bulk_import_job(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.create_bulk_import_job\naws_api/iotsitewise create_bulk_import_job","url":"aws_api/iotsitewise.html#create_bulk_import_job"},{"doc":"aws_api/iotsitewise","title":"create_dashboard","content":"pub fn create_dashboard(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.create_dashboard\naws_api/iotsitewise create_dashboard","url":"aws_api/iotsitewise.html#create_dashboard"},{"doc":"aws_api/iotsitewise","title":"create_gateway","content":"pub fn create_gateway(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.create_gateway\naws_api/iotsitewise create_gateway","url":"aws_api/iotsitewise.html#create_gateway"},{"doc":"aws_api/iotsitewise","title":"create_portal","content":"pub fn create_portal(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.create_portal\naws_api/iotsitewise create_portal","url":"aws_api/iotsitewise.html#create_portal"},{"doc":"aws_api/iotsitewise","title":"create_project","content":"pub fn create_project(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.create_project\naws_api/iotsitewise create_project","url":"aws_api/iotsitewise.html#create_project"},{"doc":"aws_api/iotsitewise","title":"delete_access_policy","content":"pub fn delete_access_policy(\n  client: Client,\n  access_policy_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.delete_access_policy\naws_api/iotsitewise delete_access_policy","url":"aws_api/iotsitewise.html#delete_access_policy"},{"doc":"aws_api/iotsitewise","title":"delete_asset","content":"pub fn delete_asset(\n  client: Client,\n  asset_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.delete_asset\naws_api/iotsitewise delete_asset","url":"aws_api/iotsitewise.html#delete_asset"},{"doc":"aws_api/iotsitewise","title":"delete_asset_model","content":"pub fn delete_asset_model(\n  client: Client,\n  asset_model_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.delete_asset_model\naws_api/iotsitewise delete_asset_model","url":"aws_api/iotsitewise.html#delete_asset_model"},{"doc":"aws_api/iotsitewise","title":"delete_asset_model_composite_model","content":"pub fn delete_asset_model_composite_model(\n  client: Client,\n  asset_model_id: String,\n  asset_model_composite_model_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.delete_asset_model_composite_model\naws_api/iotsitewise delete_asset_model_composite_model","url":"aws_api/iotsitewise.html#delete_asset_model_composite_model"},{"doc":"aws_api/iotsitewise","title":"delete_dashboard","content":"pub fn delete_dashboard(\n  client: Client,\n  dashboard_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.delete_dashboard\naws_api/iotsitewise delete_dashboard","url":"aws_api/iotsitewise.html#delete_dashboard"},{"doc":"aws_api/iotsitewise","title":"delete_gateway","content":"pub fn delete_gateway(\n  client: Client,\n  gateway_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.delete_gateway\naws_api/iotsitewise delete_gateway","url":"aws_api/iotsitewise.html#delete_gateway"},{"doc":"aws_api/iotsitewise","title":"delete_portal","content":"pub fn delete_portal(\n  client: Client,\n  portal_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.delete_portal\naws_api/iotsitewise delete_portal","url":"aws_api/iotsitewise.html#delete_portal"},{"doc":"aws_api/iotsitewise","title":"delete_project","content":"pub fn delete_project(\n  client: Client,\n  project_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.delete_project\naws_api/iotsitewise delete_project","url":"aws_api/iotsitewise.html#delete_project"},{"doc":"aws_api/iotsitewise","title":"delete_time_series","content":"pub fn delete_time_series(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.delete_time_series\naws_api/iotsitewise delete_time_series","url":"aws_api/iotsitewise.html#delete_time_series"},{"doc":"aws_api/iotsitewise","title":"describe_access_policy","content":"pub fn describe_access_policy(\n  client: Client,\n  access_policy_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.describe_access_policy\naws_api/iotsitewise describe_access_policy","url":"aws_api/iotsitewise.html#describe_access_policy"},{"doc":"aws_api/iotsitewise","title":"describe_action","content":"pub fn describe_action(\n  client: Client,\n  action_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.describe_action\naws_api/iotsitewise describe_action","url":"aws_api/iotsitewise.html#describe_action"},{"doc":"aws_api/iotsitewise","title":"describe_asset","content":"pub fn describe_asset(\n  client: Client,\n  asset_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.describe_asset\naws_api/iotsitewise describe_asset","url":"aws_api/iotsitewise.html#describe_asset"},{"doc":"aws_api/iotsitewise","title":"describe_asset_composite_model","content":"pub fn describe_asset_composite_model(\n  client: Client,\n  asset_id: String,\n  asset_composite_model_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.describe_asset_composite_model\naws_api/iotsitewise describe_asset_composite_model","url":"aws_api/iotsitewise.html#describe_asset_composite_model"},{"doc":"aws_api/iotsitewise","title":"describe_asset_model","content":"pub fn describe_asset_model(\n  client: Client,\n  asset_model_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.describe_asset_model\naws_api/iotsitewise describe_asset_model","url":"aws_api/iotsitewise.html#describe_asset_model"},{"doc":"aws_api/iotsitewise","title":"describe_asset_model_composite_model","content":"pub fn describe_asset_model_composite_model(\n  client: Client,\n  asset_model_id: String,\n  asset_model_composite_model_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.describe_asset_model_composite_model\naws_api/iotsitewise describe_asset_model_composite_model","url":"aws_api/iotsitewise.html#describe_asset_model_composite_model"},{"doc":"aws_api/iotsitewise","title":"describe_asset_property","content":"pub fn describe_asset_property(\n  client: Client,\n  asset_id: String,\n  property_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.describe_asset_property\naws_api/iotsitewise describe_asset_property","url":"aws_api/iotsitewise.html#describe_asset_property"},{"doc":"aws_api/iotsitewise","title":"describe_bulk_import_job","content":"pub fn describe_bulk_import_job(\n  client: Client,\n  job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.describe_bulk_import_job\naws_api/iotsitewise describe_bulk_import_job","url":"aws_api/iotsitewise.html#describe_bulk_import_job"},{"doc":"aws_api/iotsitewise","title":"describe_dashboard","content":"pub fn describe_dashboard(\n  client: Client,\n  dashboard_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.describe_dashboard\naws_api/iotsitewise describe_dashboard","url":"aws_api/iotsitewise.html#describe_dashboard"},{"doc":"aws_api/iotsitewise","title":"describe_default_encryption_configuration","content":"pub fn describe_default_encryption_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.describe_default_encryption_configuration\naws_api/iotsitewise describe_default_encryption_configuration","url":"aws_api/iotsitewise.html#describe_default_encryption_configuration"},{"doc":"aws_api/iotsitewise","title":"describe_gateway","content":"pub fn describe_gateway(\n  client: Client,\n  gateway_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.describe_gateway\naws_api/iotsitewise describe_gateway","url":"aws_api/iotsitewise.html#describe_gateway"},{"doc":"aws_api/iotsitewise","title":"describe_gateway_capability_configuration","content":"pub fn describe_gateway_capability_configuration(\n  client: Client,\n  gateway_id: String,\n  capability_namespace: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.describe_gateway_capability_configuration\naws_api/iotsitewise describe_gateway_capability_configuration","url":"aws_api/iotsitewise.html#describe_gateway_capability_configuration"},{"doc":"aws_api/iotsitewise","title":"describe_logging_options","content":"pub fn describe_logging_options(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.describe_logging_options\naws_api/iotsitewise describe_logging_options","url":"aws_api/iotsitewise.html#describe_logging_options"},{"doc":"aws_api/iotsitewise","title":"describe_portal","content":"pub fn describe_portal(\n  client: Client,\n  portal_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.describe_portal\naws_api/iotsitewise describe_portal","url":"aws_api/iotsitewise.html#describe_portal"},{"doc":"aws_api/iotsitewise","title":"describe_project","content":"pub fn describe_project(\n  client: Client,\n  project_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.describe_project\naws_api/iotsitewise describe_project","url":"aws_api/iotsitewise.html#describe_project"},{"doc":"aws_api/iotsitewise","title":"describe_storage_configuration","content":"pub fn describe_storage_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.describe_storage_configuration\naws_api/iotsitewise describe_storage_configuration","url":"aws_api/iotsitewise.html#describe_storage_configuration"},{"doc":"aws_api/iotsitewise","title":"describe_time_series","content":"pub fn describe_time_series(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.describe_time_series\naws_api/iotsitewise describe_time_series","url":"aws_api/iotsitewise.html#describe_time_series"},{"doc":"aws_api/iotsitewise","title":"disassociate_assets","content":"pub fn disassociate_assets(\n  client: Client,\n  asset_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.disassociate_assets\naws_api/iotsitewise disassociate_assets","url":"aws_api/iotsitewise.html#disassociate_assets"},{"doc":"aws_api/iotsitewise","title":"disassociate_time_series_from_asset_property","content":"pub fn disassociate_time_series_from_asset_property(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.disassociate_time_series_from_asset_property\naws_api/iotsitewise disassociate_time_series_from_asset_property","url":"aws_api/iotsitewise.html#disassociate_time_series_from_asset_property"},{"doc":"aws_api/iotsitewise","title":"execute_action","content":"pub fn execute_action(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.execute_action\naws_api/iotsitewise execute_action","url":"aws_api/iotsitewise.html#execute_action"},{"doc":"aws_api/iotsitewise","title":"execute_query","content":"pub fn execute_query(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.execute_query\naws_api/iotsitewise execute_query","url":"aws_api/iotsitewise.html#execute_query"},{"doc":"aws_api/iotsitewise","title":"get_asset_property_aggregates","content":"pub fn get_asset_property_aggregates(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.get_asset_property_aggregates\naws_api/iotsitewise get_asset_property_aggregates","url":"aws_api/iotsitewise.html#get_asset_property_aggregates"},{"doc":"aws_api/iotsitewise","title":"get_asset_property_value","content":"pub fn get_asset_property_value(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.get_asset_property_value\naws_api/iotsitewise get_asset_property_value","url":"aws_api/iotsitewise.html#get_asset_property_value"},{"doc":"aws_api/iotsitewise","title":"get_asset_property_value_history","content":"pub fn get_asset_property_value_history(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.get_asset_property_value_history\naws_api/iotsitewise get_asset_property_value_history","url":"aws_api/iotsitewise.html#get_asset_property_value_history"},{"doc":"aws_api/iotsitewise","title":"get_interpolated_asset_property_values","content":"pub fn get_interpolated_asset_property_values(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.get_interpolated_asset_property_values\naws_api/iotsitewise get_interpolated_asset_property_values","url":"aws_api/iotsitewise.html#get_interpolated_asset_property_values"},{"doc":"aws_api/iotsitewise","title":"list_access_policies","content":"pub fn list_access_policies(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.list_access_policies\naws_api/iotsitewise list_access_policies","url":"aws_api/iotsitewise.html#list_access_policies"},{"doc":"aws_api/iotsitewise","title":"list_actions","content":"pub fn list_actions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.list_actions\naws_api/iotsitewise list_actions","url":"aws_api/iotsitewise.html#list_actions"},{"doc":"aws_api/iotsitewise","title":"list_asset_model_composite_models","content":"pub fn list_asset_model_composite_models(\n  client: Client,\n  asset_model_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.list_asset_model_composite_models\naws_api/iotsitewise list_asset_model_composite_models","url":"aws_api/iotsitewise.html#list_asset_model_composite_models"},{"doc":"aws_api/iotsitewise","title":"list_asset_model_properties","content":"pub fn list_asset_model_properties(\n  client: Client,\n  asset_model_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.list_asset_model_properties\naws_api/iotsitewise list_asset_model_properties","url":"aws_api/iotsitewise.html#list_asset_model_properties"},{"doc":"aws_api/iotsitewise","title":"list_asset_models","content":"pub fn list_asset_models(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.list_asset_models\naws_api/iotsitewise list_asset_models","url":"aws_api/iotsitewise.html#list_asset_models"},{"doc":"aws_api/iotsitewise","title":"list_asset_properties","content":"pub fn list_asset_properties(\n  client: Client,\n  asset_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.list_asset_properties\naws_api/iotsitewise list_asset_properties","url":"aws_api/iotsitewise.html#list_asset_properties"},{"doc":"aws_api/iotsitewise","title":"list_asset_relationships","content":"pub fn list_asset_relationships(\n  client: Client,\n  asset_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.list_asset_relationships\naws_api/iotsitewise list_asset_relationships","url":"aws_api/iotsitewise.html#list_asset_relationships"},{"doc":"aws_api/iotsitewise","title":"list_assets","content":"pub fn list_assets(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.list_assets\naws_api/iotsitewise list_assets","url":"aws_api/iotsitewise.html#list_assets"},{"doc":"aws_api/iotsitewise","title":"list_associated_assets","content":"pub fn list_associated_assets(\n  client: Client,\n  asset_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.list_associated_assets\naws_api/iotsitewise list_associated_assets","url":"aws_api/iotsitewise.html#list_associated_assets"},{"doc":"aws_api/iotsitewise","title":"list_bulk_import_jobs","content":"pub fn list_bulk_import_jobs(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.list_bulk_import_jobs\naws_api/iotsitewise list_bulk_import_jobs","url":"aws_api/iotsitewise.html#list_bulk_import_jobs"},{"doc":"aws_api/iotsitewise","title":"list_composition_relationships","content":"pub fn list_composition_relationships(\n  client: Client,\n  asset_model_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.list_composition_relationships\naws_api/iotsitewise list_composition_relationships","url":"aws_api/iotsitewise.html#list_composition_relationships"},{"doc":"aws_api/iotsitewise","title":"list_dashboards","content":"pub fn list_dashboards(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.list_dashboards\naws_api/iotsitewise list_dashboards","url":"aws_api/iotsitewise.html#list_dashboards"},{"doc":"aws_api/iotsitewise","title":"list_gateways","content":"pub fn list_gateways(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.list_gateways\naws_api/iotsitewise list_gateways","url":"aws_api/iotsitewise.html#list_gateways"},{"doc":"aws_api/iotsitewise","title":"list_portals","content":"pub fn list_portals(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.list_portals\naws_api/iotsitewise list_portals","url":"aws_api/iotsitewise.html#list_portals"},{"doc":"aws_api/iotsitewise","title":"list_project_assets","content":"pub fn list_project_assets(\n  client: Client,\n  project_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.list_project_assets\naws_api/iotsitewise list_project_assets","url":"aws_api/iotsitewise.html#list_project_assets"},{"doc":"aws_api/iotsitewise","title":"list_projects","content":"pub fn list_projects(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.list_projects\naws_api/iotsitewise list_projects","url":"aws_api/iotsitewise.html#list_projects"},{"doc":"aws_api/iotsitewise","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.list_tags_for_resource\naws_api/iotsitewise list_tags_for_resource","url":"aws_api/iotsitewise.html#list_tags_for_resource"},{"doc":"aws_api/iotsitewise","title":"list_time_series","content":"pub fn list_time_series(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.list_time_series\naws_api/iotsitewise list_time_series","url":"aws_api/iotsitewise.html#list_time_series"},{"doc":"aws_api/iotsitewise","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/iotsitewise.new\naws_api/iotsitewise new","url":"aws_api/iotsitewise.html#new"},{"doc":"aws_api/iotsitewise","title":"put_default_encryption_configuration","content":"pub fn put_default_encryption_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.put_default_encryption_configuration\naws_api/iotsitewise put_default_encryption_configuration","url":"aws_api/iotsitewise.html#put_default_encryption_configuration"},{"doc":"aws_api/iotsitewise","title":"put_logging_options","content":"pub fn put_logging_options(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.put_logging_options\naws_api/iotsitewise put_logging_options","url":"aws_api/iotsitewise.html#put_logging_options"},{"doc":"aws_api/iotsitewise","title":"put_storage_configuration","content":"pub fn put_storage_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.put_storage_configuration\naws_api/iotsitewise put_storage_configuration","url":"aws_api/iotsitewise.html#put_storage_configuration"},{"doc":"aws_api/iotsitewise","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.tag_resource\naws_api/iotsitewise tag_resource","url":"aws_api/iotsitewise.html#tag_resource"},{"doc":"aws_api/iotsitewise","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.untag_resource\naws_api/iotsitewise untag_resource","url":"aws_api/iotsitewise.html#untag_resource"},{"doc":"aws_api/iotsitewise","title":"update_access_policy","content":"pub fn update_access_policy(\n  client: Client,\n  access_policy_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.update_access_policy\naws_api/iotsitewise update_access_policy","url":"aws_api/iotsitewise.html#update_access_policy"},{"doc":"aws_api/iotsitewise","title":"update_asset","content":"pub fn update_asset(\n  client: Client,\n  asset_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.update_asset\naws_api/iotsitewise update_asset","url":"aws_api/iotsitewise.html#update_asset"},{"doc":"aws_api/iotsitewise","title":"update_asset_model","content":"pub fn update_asset_model(\n  client: Client,\n  asset_model_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.update_asset_model\naws_api/iotsitewise update_asset_model","url":"aws_api/iotsitewise.html#update_asset_model"},{"doc":"aws_api/iotsitewise","title":"update_asset_model_composite_model","content":"pub fn update_asset_model_composite_model(\n  client: Client,\n  asset_model_id: String,\n  asset_model_composite_model_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.update_asset_model_composite_model\naws_api/iotsitewise update_asset_model_composite_model","url":"aws_api/iotsitewise.html#update_asset_model_composite_model"},{"doc":"aws_api/iotsitewise","title":"update_asset_property","content":"pub fn update_asset_property(\n  client: Client,\n  asset_id: String,\n  property_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.update_asset_property\naws_api/iotsitewise update_asset_property","url":"aws_api/iotsitewise.html#update_asset_property"},{"doc":"aws_api/iotsitewise","title":"update_dashboard","content":"pub fn update_dashboard(\n  client: Client,\n  dashboard_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.update_dashboard\naws_api/iotsitewise update_dashboard","url":"aws_api/iotsitewise.html#update_dashboard"},{"doc":"aws_api/iotsitewise","title":"update_gateway","content":"pub fn update_gateway(\n  client: Client,\n  gateway_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.update_gateway\naws_api/iotsitewise update_gateway","url":"aws_api/iotsitewise.html#update_gateway"},{"doc":"aws_api/iotsitewise","title":"update_gateway_capability_configuration","content":"pub fn update_gateway_capability_configuration(\n  client: Client,\n  gateway_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.update_gateway_capability_configuration\naws_api/iotsitewise update_gateway_capability_configuration","url":"aws_api/iotsitewise.html#update_gateway_capability_configuration"},{"doc":"aws_api/iotsitewise","title":"update_portal","content":"pub fn update_portal(\n  client: Client,\n  portal_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.update_portal\naws_api/iotsitewise update_portal","url":"aws_api/iotsitewise.html#update_portal"},{"doc":"aws_api/iotsitewise","title":"update_project","content":"pub fn update_project(\n  client: Client,\n  project_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotsitewise.update_project\naws_api/iotsitewise update_project","url":"aws_api/iotsitewise.html#update_project"},{"doc":"aws_api/iotsitewise","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/iotsitewise.with_custom_endpoint\naws_api/iotsitewise with_custom_endpoint","url":"aws_api/iotsitewise.html#with_custom_endpoint"},{"doc":"aws_api/iotsitewise","title":"aws_api/iotsitewise","content":"","url":"aws_api/iotsitewise.html"},{"doc":"aws_api/iotthingsgraph","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/iotthingsgraph.Client\naws_api/iotthingsgraph Client","url":"aws_api/iotthingsgraph.html#Client"},{"doc":"aws_api/iotthingsgraph","title":"associate_entity_to_thing","content":"pub fn associate_entity_to_thing(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotthingsgraph.associate_entity_to_thing\naws_api/iotthingsgraph associate_entity_to_thing","url":"aws_api/iotthingsgraph.html#associate_entity_to_thing"},{"doc":"aws_api/iotthingsgraph","title":"create_flow_template","content":"pub fn create_flow_template(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotthingsgraph.create_flow_template\naws_api/iotthingsgraph create_flow_template","url":"aws_api/iotthingsgraph.html#create_flow_template"},{"doc":"aws_api/iotthingsgraph","title":"create_system_instance","content":"pub fn create_system_instance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotthingsgraph.create_system_instance\naws_api/iotthingsgraph create_system_instance","url":"aws_api/iotthingsgraph.html#create_system_instance"},{"doc":"aws_api/iotthingsgraph","title":"create_system_template","content":"pub fn create_system_template(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotthingsgraph.create_system_template\naws_api/iotthingsgraph create_system_template","url":"aws_api/iotthingsgraph.html#create_system_template"},{"doc":"aws_api/iotthingsgraph","title":"delete_flow_template","content":"pub fn delete_flow_template(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotthingsgraph.delete_flow_template\naws_api/iotthingsgraph delete_flow_template","url":"aws_api/iotthingsgraph.html#delete_flow_template"},{"doc":"aws_api/iotthingsgraph","title":"delete_namespace","content":"pub fn delete_namespace(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotthingsgraph.delete_namespace\naws_api/iotthingsgraph delete_namespace","url":"aws_api/iotthingsgraph.html#delete_namespace"},{"doc":"aws_api/iotthingsgraph","title":"delete_system_instance","content":"pub fn delete_system_instance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotthingsgraph.delete_system_instance\naws_api/iotthingsgraph delete_system_instance","url":"aws_api/iotthingsgraph.html#delete_system_instance"},{"doc":"aws_api/iotthingsgraph","title":"delete_system_template","content":"pub fn delete_system_template(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotthingsgraph.delete_system_template\naws_api/iotthingsgraph delete_system_template","url":"aws_api/iotthingsgraph.html#delete_system_template"},{"doc":"aws_api/iotthingsgraph","title":"deploy_system_instance","content":"pub fn deploy_system_instance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotthingsgraph.deploy_system_instance\naws_api/iotthingsgraph deploy_system_instance","url":"aws_api/iotthingsgraph.html#deploy_system_instance"},{"doc":"aws_api/iotthingsgraph","title":"deprecate_flow_template","content":"pub fn deprecate_flow_template(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotthingsgraph.deprecate_flow_template\naws_api/iotthingsgraph deprecate_flow_template","url":"aws_api/iotthingsgraph.html#deprecate_flow_template"},{"doc":"aws_api/iotthingsgraph","title":"deprecate_system_template","content":"pub fn deprecate_system_template(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotthingsgraph.deprecate_system_template\naws_api/iotthingsgraph deprecate_system_template","url":"aws_api/iotthingsgraph.html#deprecate_system_template"},{"doc":"aws_api/iotthingsgraph","title":"describe_namespace","content":"pub fn describe_namespace(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotthingsgraph.describe_namespace\naws_api/iotthingsgraph describe_namespace","url":"aws_api/iotthingsgraph.html#describe_namespace"},{"doc":"aws_api/iotthingsgraph","title":"dissociate_entity_from_thing","content":"pub fn dissociate_entity_from_thing(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotthingsgraph.dissociate_entity_from_thing\naws_api/iotthingsgraph dissociate_entity_from_thing","url":"aws_api/iotthingsgraph.html#dissociate_entity_from_thing"},{"doc":"aws_api/iotthingsgraph","title":"get_entities","content":"pub fn get_entities(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotthingsgraph.get_entities\naws_api/iotthingsgraph get_entities","url":"aws_api/iotthingsgraph.html#get_entities"},{"doc":"aws_api/iotthingsgraph","title":"get_flow_template","content":"pub fn get_flow_template(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotthingsgraph.get_flow_template\naws_api/iotthingsgraph get_flow_template","url":"aws_api/iotthingsgraph.html#get_flow_template"},{"doc":"aws_api/iotthingsgraph","title":"get_flow_template_revisions","content":"pub fn get_flow_template_revisions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotthingsgraph.get_flow_template_revisions\naws_api/iotthingsgraph get_flow_template_revisions","url":"aws_api/iotthingsgraph.html#get_flow_template_revisions"},{"doc":"aws_api/iotthingsgraph","title":"get_namespace_deletion_status","content":"pub fn get_namespace_deletion_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotthingsgraph.get_namespace_deletion_status\naws_api/iotthingsgraph get_namespace_deletion_status","url":"aws_api/iotthingsgraph.html#get_namespace_deletion_status"},{"doc":"aws_api/iotthingsgraph","title":"get_system_instance","content":"pub fn get_system_instance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotthingsgraph.get_system_instance\naws_api/iotthingsgraph get_system_instance","url":"aws_api/iotthingsgraph.html#get_system_instance"},{"doc":"aws_api/iotthingsgraph","title":"get_system_template","content":"pub fn get_system_template(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotthingsgraph.get_system_template\naws_api/iotthingsgraph get_system_template","url":"aws_api/iotthingsgraph.html#get_system_template"},{"doc":"aws_api/iotthingsgraph","title":"get_system_template_revisions","content":"pub fn get_system_template_revisions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotthingsgraph.get_system_template_revisions\naws_api/iotthingsgraph get_system_template_revisions","url":"aws_api/iotthingsgraph.html#get_system_template_revisions"},{"doc":"aws_api/iotthingsgraph","title":"get_upload_status","content":"pub fn get_upload_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotthingsgraph.get_upload_status\naws_api/iotthingsgraph get_upload_status","url":"aws_api/iotthingsgraph.html#get_upload_status"},{"doc":"aws_api/iotthingsgraph","title":"list_flow_execution_messages","content":"pub fn list_flow_execution_messages(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotthingsgraph.list_flow_execution_messages\naws_api/iotthingsgraph list_flow_execution_messages","url":"aws_api/iotthingsgraph.html#list_flow_execution_messages"},{"doc":"aws_api/iotthingsgraph","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotthingsgraph.list_tags_for_resource\naws_api/iotthingsgraph list_tags_for_resource","url":"aws_api/iotthingsgraph.html#list_tags_for_resource"},{"doc":"aws_api/iotthingsgraph","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/iotthingsgraph.new\naws_api/iotthingsgraph new","url":"aws_api/iotthingsgraph.html#new"},{"doc":"aws_api/iotthingsgraph","title":"search_entities","content":"pub fn search_entities(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotthingsgraph.search_entities\naws_api/iotthingsgraph search_entities","url":"aws_api/iotthingsgraph.html#search_entities"},{"doc":"aws_api/iotthingsgraph","title":"search_flow_executions","content":"pub fn search_flow_executions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotthingsgraph.search_flow_executions\naws_api/iotthingsgraph search_flow_executions","url":"aws_api/iotthingsgraph.html#search_flow_executions"},{"doc":"aws_api/iotthingsgraph","title":"search_flow_templates","content":"pub fn search_flow_templates(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotthingsgraph.search_flow_templates\naws_api/iotthingsgraph search_flow_templates","url":"aws_api/iotthingsgraph.html#search_flow_templates"},{"doc":"aws_api/iotthingsgraph","title":"search_system_instances","content":"pub fn search_system_instances(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotthingsgraph.search_system_instances\naws_api/iotthingsgraph search_system_instances","url":"aws_api/iotthingsgraph.html#search_system_instances"},{"doc":"aws_api/iotthingsgraph","title":"search_system_templates","content":"pub fn search_system_templates(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotthingsgraph.search_system_templates\naws_api/iotthingsgraph search_system_templates","url":"aws_api/iotthingsgraph.html#search_system_templates"},{"doc":"aws_api/iotthingsgraph","title":"search_things","content":"pub fn search_things(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotthingsgraph.search_things\naws_api/iotthingsgraph search_things","url":"aws_api/iotthingsgraph.html#search_things"},{"doc":"aws_api/iotthingsgraph","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotthingsgraph.tag_resource\naws_api/iotthingsgraph tag_resource","url":"aws_api/iotthingsgraph.html#tag_resource"},{"doc":"aws_api/iotthingsgraph","title":"undeploy_system_instance","content":"pub fn undeploy_system_instance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotthingsgraph.undeploy_system_instance\naws_api/iotthingsgraph undeploy_system_instance","url":"aws_api/iotthingsgraph.html#undeploy_system_instance"},{"doc":"aws_api/iotthingsgraph","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotthingsgraph.untag_resource\naws_api/iotthingsgraph untag_resource","url":"aws_api/iotthingsgraph.html#untag_resource"},{"doc":"aws_api/iotthingsgraph","title":"update_flow_template","content":"pub fn update_flow_template(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotthingsgraph.update_flow_template\naws_api/iotthingsgraph update_flow_template","url":"aws_api/iotthingsgraph.html#update_flow_template"},{"doc":"aws_api/iotthingsgraph","title":"update_system_template","content":"pub fn update_system_template(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotthingsgraph.update_system_template\naws_api/iotthingsgraph update_system_template","url":"aws_api/iotthingsgraph.html#update_system_template"},{"doc":"aws_api/iotthingsgraph","title":"upload_entity_definitions","content":"pub fn upload_entity_definitions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iotthingsgraph.upload_entity_definitions\naws_api/iotthingsgraph upload_entity_definitions","url":"aws_api/iotthingsgraph.html#upload_entity_definitions"},{"doc":"aws_api/iotthingsgraph","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/iotthingsgraph.with_custom_endpoint\naws_api/iotthingsgraph with_custom_endpoint","url":"aws_api/iotthingsgraph.html#with_custom_endpoint"},{"doc":"aws_api/iotthingsgraph","title":"aws_api/iotthingsgraph","content":"","url":"aws_api/iotthingsgraph.html"},{"doc":"aws_api/iottwinmaker","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/iottwinmaker.Client\naws_api/iottwinmaker Client","url":"aws_api/iottwinmaker.html#Client"},{"doc":"aws_api/iottwinmaker","title":"batch_put_property_values","content":"pub fn batch_put_property_values(\n  client: Client,\n  workspace_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iottwinmaker.batch_put_property_values\naws_api/iottwinmaker batch_put_property_values","url":"aws_api/iottwinmaker.html#batch_put_property_values"},{"doc":"aws_api/iottwinmaker","title":"cancel_metadata_transfer_job","content":"pub fn cancel_metadata_transfer_job(\n  client: Client,\n  metadata_transfer_job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iottwinmaker.cancel_metadata_transfer_job\naws_api/iottwinmaker cancel_metadata_transfer_job","url":"aws_api/iottwinmaker.html#cancel_metadata_transfer_job"},{"doc":"aws_api/iottwinmaker","title":"create_component_type","content":"pub fn create_component_type(\n  client: Client,\n  workspace_id: String,\n  component_type_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iottwinmaker.create_component_type\naws_api/iottwinmaker create_component_type","url":"aws_api/iottwinmaker.html#create_component_type"},{"doc":"aws_api/iottwinmaker","title":"create_entity","content":"pub fn create_entity(\n  client: Client,\n  workspace_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iottwinmaker.create_entity\naws_api/iottwinmaker create_entity","url":"aws_api/iottwinmaker.html#create_entity"},{"doc":"aws_api/iottwinmaker","title":"create_metadata_transfer_job","content":"pub fn create_metadata_transfer_job(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iottwinmaker.create_metadata_transfer_job\naws_api/iottwinmaker create_metadata_transfer_job","url":"aws_api/iottwinmaker.html#create_metadata_transfer_job"},{"doc":"aws_api/iottwinmaker","title":"create_scene","content":"pub fn create_scene(\n  client: Client,\n  workspace_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iottwinmaker.create_scene\naws_api/iottwinmaker create_scene","url":"aws_api/iottwinmaker.html#create_scene"},{"doc":"aws_api/iottwinmaker","title":"create_sync_job","content":"pub fn create_sync_job(\n  client: Client,\n  workspace_id: String,\n  sync_source: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iottwinmaker.create_sync_job\naws_api/iottwinmaker create_sync_job","url":"aws_api/iottwinmaker.html#create_sync_job"},{"doc":"aws_api/iottwinmaker","title":"create_workspace","content":"pub fn create_workspace(\n  client: Client,\n  workspace_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iottwinmaker.create_workspace\naws_api/iottwinmaker create_workspace","url":"aws_api/iottwinmaker.html#create_workspace"},{"doc":"aws_api/iottwinmaker","title":"delete_component_type","content":"pub fn delete_component_type(\n  client: Client,\n  workspace_id: String,\n  component_type_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iottwinmaker.delete_component_type\naws_api/iottwinmaker delete_component_type","url":"aws_api/iottwinmaker.html#delete_component_type"},{"doc":"aws_api/iottwinmaker","title":"delete_entity","content":"pub fn delete_entity(\n  client: Client,\n  workspace_id: String,\n  entity_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iottwinmaker.delete_entity\naws_api/iottwinmaker delete_entity","url":"aws_api/iottwinmaker.html#delete_entity"},{"doc":"aws_api/iottwinmaker","title":"delete_scene","content":"pub fn delete_scene(\n  client: Client,\n  workspace_id: String,\n  scene_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iottwinmaker.delete_scene\naws_api/iottwinmaker delete_scene","url":"aws_api/iottwinmaker.html#delete_scene"},{"doc":"aws_api/iottwinmaker","title":"delete_sync_job","content":"pub fn delete_sync_job(\n  client: Client,\n  workspace_id: String,\n  sync_source: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iottwinmaker.delete_sync_job\naws_api/iottwinmaker delete_sync_job","url":"aws_api/iottwinmaker.html#delete_sync_job"},{"doc":"aws_api/iottwinmaker","title":"delete_workspace","content":"pub fn delete_workspace(\n  client: Client,\n  workspace_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iottwinmaker.delete_workspace\naws_api/iottwinmaker delete_workspace","url":"aws_api/iottwinmaker.html#delete_workspace"},{"doc":"aws_api/iottwinmaker","title":"execute_query","content":"pub fn execute_query(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iottwinmaker.execute_query\naws_api/iottwinmaker execute_query","url":"aws_api/iottwinmaker.html#execute_query"},{"doc":"aws_api/iottwinmaker","title":"get_component_type","content":"pub fn get_component_type(\n  client: Client,\n  workspace_id: String,\n  component_type_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iottwinmaker.get_component_type\naws_api/iottwinmaker get_component_type","url":"aws_api/iottwinmaker.html#get_component_type"},{"doc":"aws_api/iottwinmaker","title":"get_entity","content":"pub fn get_entity(\n  client: Client,\n  workspace_id: String,\n  entity_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iottwinmaker.get_entity\naws_api/iottwinmaker get_entity","url":"aws_api/iottwinmaker.html#get_entity"},{"doc":"aws_api/iottwinmaker","title":"get_metadata_transfer_job","content":"pub fn get_metadata_transfer_job(\n  client: Client,\n  metadata_transfer_job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iottwinmaker.get_metadata_transfer_job\naws_api/iottwinmaker get_metadata_transfer_job","url":"aws_api/iottwinmaker.html#get_metadata_transfer_job"},{"doc":"aws_api/iottwinmaker","title":"get_pricing_plan","content":"pub fn get_pricing_plan(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iottwinmaker.get_pricing_plan\naws_api/iottwinmaker get_pricing_plan","url":"aws_api/iottwinmaker.html#get_pricing_plan"},{"doc":"aws_api/iottwinmaker","title":"get_property_value","content":"pub fn get_property_value(\n  client: Client,\n  workspace_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iottwinmaker.get_property_value\naws_api/iottwinmaker get_property_value","url":"aws_api/iottwinmaker.html#get_property_value"},{"doc":"aws_api/iottwinmaker","title":"get_property_value_history","content":"pub fn get_property_value_history(\n  client: Client,\n  workspace_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iottwinmaker.get_property_value_history\naws_api/iottwinmaker get_property_value_history","url":"aws_api/iottwinmaker.html#get_property_value_history"},{"doc":"aws_api/iottwinmaker","title":"get_scene","content":"pub fn get_scene(\n  client: Client,\n  workspace_id: String,\n  scene_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iottwinmaker.get_scene\naws_api/iottwinmaker get_scene","url":"aws_api/iottwinmaker.html#get_scene"},{"doc":"aws_api/iottwinmaker","title":"get_sync_job","content":"pub fn get_sync_job(\n  client: Client,\n  sync_source: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iottwinmaker.get_sync_job\naws_api/iottwinmaker get_sync_job","url":"aws_api/iottwinmaker.html#get_sync_job"},{"doc":"aws_api/iottwinmaker","title":"get_workspace","content":"pub fn get_workspace(\n  client: Client,\n  workspace_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iottwinmaker.get_workspace\naws_api/iottwinmaker get_workspace","url":"aws_api/iottwinmaker.html#get_workspace"},{"doc":"aws_api/iottwinmaker","title":"list_component_types","content":"pub fn list_component_types(\n  client: Client,\n  workspace_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iottwinmaker.list_component_types\naws_api/iottwinmaker list_component_types","url":"aws_api/iottwinmaker.html#list_component_types"},{"doc":"aws_api/iottwinmaker","title":"list_components","content":"pub fn list_components(\n  client: Client,\n  workspace_id: String,\n  entity_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iottwinmaker.list_components\naws_api/iottwinmaker list_components","url":"aws_api/iottwinmaker.html#list_components"},{"doc":"aws_api/iottwinmaker","title":"list_entities","content":"pub fn list_entities(\n  client: Client,\n  workspace_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iottwinmaker.list_entities\naws_api/iottwinmaker list_entities","url":"aws_api/iottwinmaker.html#list_entities"},{"doc":"aws_api/iottwinmaker","title":"list_metadata_transfer_jobs","content":"pub fn list_metadata_transfer_jobs(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iottwinmaker.list_metadata_transfer_jobs\naws_api/iottwinmaker list_metadata_transfer_jobs","url":"aws_api/iottwinmaker.html#list_metadata_transfer_jobs"},{"doc":"aws_api/iottwinmaker","title":"list_properties","content":"pub fn list_properties(\n  client: Client,\n  workspace_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iottwinmaker.list_properties\naws_api/iottwinmaker list_properties","url":"aws_api/iottwinmaker.html#list_properties"},{"doc":"aws_api/iottwinmaker","title":"list_scenes","content":"pub fn list_scenes(\n  client: Client,\n  workspace_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iottwinmaker.list_scenes\naws_api/iottwinmaker list_scenes","url":"aws_api/iottwinmaker.html#list_scenes"},{"doc":"aws_api/iottwinmaker","title":"list_sync_jobs","content":"pub fn list_sync_jobs(\n  client: Client,\n  workspace_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iottwinmaker.list_sync_jobs\naws_api/iottwinmaker list_sync_jobs","url":"aws_api/iottwinmaker.html#list_sync_jobs"},{"doc":"aws_api/iottwinmaker","title":"list_sync_resources","content":"pub fn list_sync_resources(\n  client: Client,\n  workspace_id: String,\n  sync_source: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iottwinmaker.list_sync_resources\naws_api/iottwinmaker list_sync_resources","url":"aws_api/iottwinmaker.html#list_sync_resources"},{"doc":"aws_api/iottwinmaker","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iottwinmaker.list_tags_for_resource\naws_api/iottwinmaker list_tags_for_resource","url":"aws_api/iottwinmaker.html#list_tags_for_resource"},{"doc":"aws_api/iottwinmaker","title":"list_workspaces","content":"pub fn list_workspaces(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iottwinmaker.list_workspaces\naws_api/iottwinmaker list_workspaces","url":"aws_api/iottwinmaker.html#list_workspaces"},{"doc":"aws_api/iottwinmaker","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/iottwinmaker.new\naws_api/iottwinmaker new","url":"aws_api/iottwinmaker.html#new"},{"doc":"aws_api/iottwinmaker","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iottwinmaker.tag_resource\naws_api/iottwinmaker tag_resource","url":"aws_api/iottwinmaker.html#tag_resource"},{"doc":"aws_api/iottwinmaker","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iottwinmaker.untag_resource\naws_api/iottwinmaker untag_resource","url":"aws_api/iottwinmaker.html#untag_resource"},{"doc":"aws_api/iottwinmaker","title":"update_component_type","content":"pub fn update_component_type(\n  client: Client,\n  workspace_id: String,\n  component_type_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iottwinmaker.update_component_type\naws_api/iottwinmaker update_component_type","url":"aws_api/iottwinmaker.html#update_component_type"},{"doc":"aws_api/iottwinmaker","title":"update_entity","content":"pub fn update_entity(\n  client: Client,\n  workspace_id: String,\n  entity_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iottwinmaker.update_entity\naws_api/iottwinmaker update_entity","url":"aws_api/iottwinmaker.html#update_entity"},{"doc":"aws_api/iottwinmaker","title":"update_pricing_plan","content":"pub fn update_pricing_plan(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iottwinmaker.update_pricing_plan\naws_api/iottwinmaker update_pricing_plan","url":"aws_api/iottwinmaker.html#update_pricing_plan"},{"doc":"aws_api/iottwinmaker","title":"update_scene","content":"pub fn update_scene(\n  client: Client,\n  workspace_id: String,\n  scene_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iottwinmaker.update_scene\naws_api/iottwinmaker update_scene","url":"aws_api/iottwinmaker.html#update_scene"},{"doc":"aws_api/iottwinmaker","title":"update_workspace","content":"pub fn update_workspace(\n  client: Client,\n  workspace_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/iottwinmaker.update_workspace\naws_api/iottwinmaker update_workspace","url":"aws_api/iottwinmaker.html#update_workspace"},{"doc":"aws_api/iottwinmaker","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/iottwinmaker.with_custom_endpoint\naws_api/iottwinmaker with_custom_endpoint","url":"aws_api/iottwinmaker.html#with_custom_endpoint"},{"doc":"aws_api/iottwinmaker","title":"aws_api/iottwinmaker","content":"","url":"aws_api/iottwinmaker.html"},{"doc":"aws_api/ivs","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/ivs.Client\naws_api/ivs Client","url":"aws_api/ivs.html#Client"},{"doc":"aws_api/ivs","title":"batch_get_channel","content":"pub fn batch_get_channel(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs.batch_get_channel\naws_api/ivs batch_get_channel","url":"aws_api/ivs.html#batch_get_channel"},{"doc":"aws_api/ivs","title":"batch_get_stream_key","content":"pub fn batch_get_stream_key(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs.batch_get_stream_key\naws_api/ivs batch_get_stream_key","url":"aws_api/ivs.html#batch_get_stream_key"},{"doc":"aws_api/ivs","title":"batch_start_viewer_session_revocation","content":"pub fn batch_start_viewer_session_revocation(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs.batch_start_viewer_session_revocation\naws_api/ivs batch_start_viewer_session_revocation","url":"aws_api/ivs.html#batch_start_viewer_session_revocation"},{"doc":"aws_api/ivs","title":"create_channel","content":"pub fn create_channel(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs.create_channel\naws_api/ivs create_channel","url":"aws_api/ivs.html#create_channel"},{"doc":"aws_api/ivs","title":"create_playback_restriction_policy","content":"pub fn create_playback_restriction_policy(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs.create_playback_restriction_policy\naws_api/ivs create_playback_restriction_policy","url":"aws_api/ivs.html#create_playback_restriction_policy"},{"doc":"aws_api/ivs","title":"create_recording_configuration","content":"pub fn create_recording_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs.create_recording_configuration\naws_api/ivs create_recording_configuration","url":"aws_api/ivs.html#create_recording_configuration"},{"doc":"aws_api/ivs","title":"create_stream_key","content":"pub fn create_stream_key(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs.create_stream_key\naws_api/ivs create_stream_key","url":"aws_api/ivs.html#create_stream_key"},{"doc":"aws_api/ivs","title":"delete_channel","content":"pub fn delete_channel(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs.delete_channel\naws_api/ivs delete_channel","url":"aws_api/ivs.html#delete_channel"},{"doc":"aws_api/ivs","title":"delete_playback_key_pair","content":"pub fn delete_playback_key_pair(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs.delete_playback_key_pair\naws_api/ivs delete_playback_key_pair","url":"aws_api/ivs.html#delete_playback_key_pair"},{"doc":"aws_api/ivs","title":"delete_playback_restriction_policy","content":"pub fn delete_playback_restriction_policy(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs.delete_playback_restriction_policy\naws_api/ivs delete_playback_restriction_policy","url":"aws_api/ivs.html#delete_playback_restriction_policy"},{"doc":"aws_api/ivs","title":"delete_recording_configuration","content":"pub fn delete_recording_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs.delete_recording_configuration\naws_api/ivs delete_recording_configuration","url":"aws_api/ivs.html#delete_recording_configuration"},{"doc":"aws_api/ivs","title":"delete_stream_key","content":"pub fn delete_stream_key(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs.delete_stream_key\naws_api/ivs delete_stream_key","url":"aws_api/ivs.html#delete_stream_key"},{"doc":"aws_api/ivs","title":"get_channel","content":"pub fn get_channel(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs.get_channel\naws_api/ivs get_channel","url":"aws_api/ivs.html#get_channel"},{"doc":"aws_api/ivs","title":"get_playback_key_pair","content":"pub fn get_playback_key_pair(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs.get_playback_key_pair\naws_api/ivs get_playback_key_pair","url":"aws_api/ivs.html#get_playback_key_pair"},{"doc":"aws_api/ivs","title":"get_playback_restriction_policy","content":"pub fn get_playback_restriction_policy(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs.get_playback_restriction_policy\naws_api/ivs get_playback_restriction_policy","url":"aws_api/ivs.html#get_playback_restriction_policy"},{"doc":"aws_api/ivs","title":"get_recording_configuration","content":"pub fn get_recording_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs.get_recording_configuration\naws_api/ivs get_recording_configuration","url":"aws_api/ivs.html#get_recording_configuration"},{"doc":"aws_api/ivs","title":"get_stream","content":"pub fn get_stream(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs.get_stream\naws_api/ivs get_stream","url":"aws_api/ivs.html#get_stream"},{"doc":"aws_api/ivs","title":"get_stream_key","content":"pub fn get_stream_key(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs.get_stream_key\naws_api/ivs get_stream_key","url":"aws_api/ivs.html#get_stream_key"},{"doc":"aws_api/ivs","title":"get_stream_session","content":"pub fn get_stream_session(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs.get_stream_session\naws_api/ivs get_stream_session","url":"aws_api/ivs.html#get_stream_session"},{"doc":"aws_api/ivs","title":"import_playback_key_pair","content":"pub fn import_playback_key_pair(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs.import_playback_key_pair\naws_api/ivs import_playback_key_pair","url":"aws_api/ivs.html#import_playback_key_pair"},{"doc":"aws_api/ivs","title":"list_channels","content":"pub fn list_channels(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs.list_channels\naws_api/ivs list_channels","url":"aws_api/ivs.html#list_channels"},{"doc":"aws_api/ivs","title":"list_playback_key_pairs","content":"pub fn list_playback_key_pairs(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs.list_playback_key_pairs\naws_api/ivs list_playback_key_pairs","url":"aws_api/ivs.html#list_playback_key_pairs"},{"doc":"aws_api/ivs","title":"list_playback_restriction_policies","content":"pub fn list_playback_restriction_policies(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs.list_playback_restriction_policies\naws_api/ivs list_playback_restriction_policies","url":"aws_api/ivs.html#list_playback_restriction_policies"},{"doc":"aws_api/ivs","title":"list_recording_configurations","content":"pub fn list_recording_configurations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs.list_recording_configurations\naws_api/ivs list_recording_configurations","url":"aws_api/ivs.html#list_recording_configurations"},{"doc":"aws_api/ivs","title":"list_stream_keys","content":"pub fn list_stream_keys(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs.list_stream_keys\naws_api/ivs list_stream_keys","url":"aws_api/ivs.html#list_stream_keys"},{"doc":"aws_api/ivs","title":"list_stream_sessions","content":"pub fn list_stream_sessions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs.list_stream_sessions\naws_api/ivs list_stream_sessions","url":"aws_api/ivs.html#list_stream_sessions"},{"doc":"aws_api/ivs","title":"list_streams","content":"pub fn list_streams(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs.list_streams\naws_api/ivs list_streams","url":"aws_api/ivs.html#list_streams"},{"doc":"aws_api/ivs","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs.list_tags_for_resource\naws_api/ivs list_tags_for_resource","url":"aws_api/ivs.html#list_tags_for_resource"},{"doc":"aws_api/ivs","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/ivs.new\naws_api/ivs new","url":"aws_api/ivs.html#new"},{"doc":"aws_api/ivs","title":"put_metadata","content":"pub fn put_metadata(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs.put_metadata\naws_api/ivs put_metadata","url":"aws_api/ivs.html#put_metadata"},{"doc":"aws_api/ivs","title":"start_viewer_session_revocation","content":"pub fn start_viewer_session_revocation(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs.start_viewer_session_revocation\naws_api/ivs start_viewer_session_revocation","url":"aws_api/ivs.html#start_viewer_session_revocation"},{"doc":"aws_api/ivs","title":"stop_stream","content":"pub fn stop_stream(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs.stop_stream\naws_api/ivs stop_stream","url":"aws_api/ivs.html#stop_stream"},{"doc":"aws_api/ivs","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs.tag_resource\naws_api/ivs tag_resource","url":"aws_api/ivs.html#tag_resource"},{"doc":"aws_api/ivs","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs.untag_resource\naws_api/ivs untag_resource","url":"aws_api/ivs.html#untag_resource"},{"doc":"aws_api/ivs","title":"update_channel","content":"pub fn update_channel(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs.update_channel\naws_api/ivs update_channel","url":"aws_api/ivs.html#update_channel"},{"doc":"aws_api/ivs","title":"update_playback_restriction_policy","content":"pub fn update_playback_restriction_policy(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs.update_playback_restriction_policy\naws_api/ivs update_playback_restriction_policy","url":"aws_api/ivs.html#update_playback_restriction_policy"},{"doc":"aws_api/ivs","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/ivs.with_custom_endpoint\naws_api/ivs with_custom_endpoint","url":"aws_api/ivs.html#with_custom_endpoint"},{"doc":"aws_api/ivs","title":"aws_api/ivs","content":"","url":"aws_api/ivs.html"},{"doc":"aws_api/ivs_realtime","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/ivs_realtime.Client\naws_api/ivs_realtime Client","url":"aws_api/ivs_realtime.html#Client"},{"doc":"aws_api/ivs_realtime","title":"create_encoder_configuration","content":"pub fn create_encoder_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs_realtime.create_encoder_configuration\naws_api/ivs_realtime create_encoder_configuration","url":"aws_api/ivs_realtime.html#create_encoder_configuration"},{"doc":"aws_api/ivs_realtime","title":"create_participant_token","content":"pub fn create_participant_token(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs_realtime.create_participant_token\naws_api/ivs_realtime create_participant_token","url":"aws_api/ivs_realtime.html#create_participant_token"},{"doc":"aws_api/ivs_realtime","title":"create_stage","content":"pub fn create_stage(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs_realtime.create_stage\naws_api/ivs_realtime create_stage","url":"aws_api/ivs_realtime.html#create_stage"},{"doc":"aws_api/ivs_realtime","title":"create_storage_configuration","content":"pub fn create_storage_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs_realtime.create_storage_configuration\naws_api/ivs_realtime create_storage_configuration","url":"aws_api/ivs_realtime.html#create_storage_configuration"},{"doc":"aws_api/ivs_realtime","title":"delete_encoder_configuration","content":"pub fn delete_encoder_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs_realtime.delete_encoder_configuration\naws_api/ivs_realtime delete_encoder_configuration","url":"aws_api/ivs_realtime.html#delete_encoder_configuration"},{"doc":"aws_api/ivs_realtime","title":"delete_public_key","content":"pub fn delete_public_key(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs_realtime.delete_public_key\naws_api/ivs_realtime delete_public_key","url":"aws_api/ivs_realtime.html#delete_public_key"},{"doc":"aws_api/ivs_realtime","title":"delete_stage","content":"pub fn delete_stage(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs_realtime.delete_stage\naws_api/ivs_realtime delete_stage","url":"aws_api/ivs_realtime.html#delete_stage"},{"doc":"aws_api/ivs_realtime","title":"delete_storage_configuration","content":"pub fn delete_storage_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs_realtime.delete_storage_configuration\naws_api/ivs_realtime delete_storage_configuration","url":"aws_api/ivs_realtime.html#delete_storage_configuration"},{"doc":"aws_api/ivs_realtime","title":"disconnect_participant","content":"pub fn disconnect_participant(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs_realtime.disconnect_participant\naws_api/ivs_realtime disconnect_participant","url":"aws_api/ivs_realtime.html#disconnect_participant"},{"doc":"aws_api/ivs_realtime","title":"get_composition","content":"pub fn get_composition(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs_realtime.get_composition\naws_api/ivs_realtime get_composition","url":"aws_api/ivs_realtime.html#get_composition"},{"doc":"aws_api/ivs_realtime","title":"get_encoder_configuration","content":"pub fn get_encoder_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs_realtime.get_encoder_configuration\naws_api/ivs_realtime get_encoder_configuration","url":"aws_api/ivs_realtime.html#get_encoder_configuration"},{"doc":"aws_api/ivs_realtime","title":"get_participant","content":"pub fn get_participant(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs_realtime.get_participant\naws_api/ivs_realtime get_participant","url":"aws_api/ivs_realtime.html#get_participant"},{"doc":"aws_api/ivs_realtime","title":"get_public_key","content":"pub fn get_public_key(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs_realtime.get_public_key\naws_api/ivs_realtime get_public_key","url":"aws_api/ivs_realtime.html#get_public_key"},{"doc":"aws_api/ivs_realtime","title":"get_stage","content":"pub fn get_stage(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs_realtime.get_stage\naws_api/ivs_realtime get_stage","url":"aws_api/ivs_realtime.html#get_stage"},{"doc":"aws_api/ivs_realtime","title":"get_stage_session","content":"pub fn get_stage_session(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs_realtime.get_stage_session\naws_api/ivs_realtime get_stage_session","url":"aws_api/ivs_realtime.html#get_stage_session"},{"doc":"aws_api/ivs_realtime","title":"get_storage_configuration","content":"pub fn get_storage_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs_realtime.get_storage_configuration\naws_api/ivs_realtime get_storage_configuration","url":"aws_api/ivs_realtime.html#get_storage_configuration"},{"doc":"aws_api/ivs_realtime","title":"import_public_key","content":"pub fn import_public_key(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs_realtime.import_public_key\naws_api/ivs_realtime import_public_key","url":"aws_api/ivs_realtime.html#import_public_key"},{"doc":"aws_api/ivs_realtime","title":"list_compositions","content":"pub fn list_compositions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs_realtime.list_compositions\naws_api/ivs_realtime list_compositions","url":"aws_api/ivs_realtime.html#list_compositions"},{"doc":"aws_api/ivs_realtime","title":"list_encoder_configurations","content":"pub fn list_encoder_configurations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs_realtime.list_encoder_configurations\naws_api/ivs_realtime list_encoder_configurations","url":"aws_api/ivs_realtime.html#list_encoder_configurations"},{"doc":"aws_api/ivs_realtime","title":"list_participant_events","content":"pub fn list_participant_events(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs_realtime.list_participant_events\naws_api/ivs_realtime list_participant_events","url":"aws_api/ivs_realtime.html#list_participant_events"},{"doc":"aws_api/ivs_realtime","title":"list_participants","content":"pub fn list_participants(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs_realtime.list_participants\naws_api/ivs_realtime list_participants","url":"aws_api/ivs_realtime.html#list_participants"},{"doc":"aws_api/ivs_realtime","title":"list_public_keys","content":"pub fn list_public_keys(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs_realtime.list_public_keys\naws_api/ivs_realtime list_public_keys","url":"aws_api/ivs_realtime.html#list_public_keys"},{"doc":"aws_api/ivs_realtime","title":"list_stage_sessions","content":"pub fn list_stage_sessions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs_realtime.list_stage_sessions\naws_api/ivs_realtime list_stage_sessions","url":"aws_api/ivs_realtime.html#list_stage_sessions"},{"doc":"aws_api/ivs_realtime","title":"list_stages","content":"pub fn list_stages(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs_realtime.list_stages\naws_api/ivs_realtime list_stages","url":"aws_api/ivs_realtime.html#list_stages"},{"doc":"aws_api/ivs_realtime","title":"list_storage_configurations","content":"pub fn list_storage_configurations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs_realtime.list_storage_configurations\naws_api/ivs_realtime list_storage_configurations","url":"aws_api/ivs_realtime.html#list_storage_configurations"},{"doc":"aws_api/ivs_realtime","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs_realtime.list_tags_for_resource\naws_api/ivs_realtime list_tags_for_resource","url":"aws_api/ivs_realtime.html#list_tags_for_resource"},{"doc":"aws_api/ivs_realtime","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/ivs_realtime.new\naws_api/ivs_realtime new","url":"aws_api/ivs_realtime.html#new"},{"doc":"aws_api/ivs_realtime","title":"start_composition","content":"pub fn start_composition(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs_realtime.start_composition\naws_api/ivs_realtime start_composition","url":"aws_api/ivs_realtime.html#start_composition"},{"doc":"aws_api/ivs_realtime","title":"stop_composition","content":"pub fn stop_composition(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs_realtime.stop_composition\naws_api/ivs_realtime stop_composition","url":"aws_api/ivs_realtime.html#stop_composition"},{"doc":"aws_api/ivs_realtime","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs_realtime.tag_resource\naws_api/ivs_realtime tag_resource","url":"aws_api/ivs_realtime.html#tag_resource"},{"doc":"aws_api/ivs_realtime","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs_realtime.untag_resource\naws_api/ivs_realtime untag_resource","url":"aws_api/ivs_realtime.html#untag_resource"},{"doc":"aws_api/ivs_realtime","title":"update_stage","content":"pub fn update_stage(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivs_realtime.update_stage\naws_api/ivs_realtime update_stage","url":"aws_api/ivs_realtime.html#update_stage"},{"doc":"aws_api/ivs_realtime","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/ivs_realtime.with_custom_endpoint\naws_api/ivs_realtime with_custom_endpoint","url":"aws_api/ivs_realtime.html#with_custom_endpoint"},{"doc":"aws_api/ivs_realtime","title":"aws_api/ivs_realtime","content":"","url":"aws_api/ivs_realtime.html"},{"doc":"aws_api/ivschat","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/ivschat.Client\naws_api/ivschat Client","url":"aws_api/ivschat.html#Client"},{"doc":"aws_api/ivschat","title":"create_chat_token","content":"pub fn create_chat_token(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivschat.create_chat_token\naws_api/ivschat create_chat_token","url":"aws_api/ivschat.html#create_chat_token"},{"doc":"aws_api/ivschat","title":"create_logging_configuration","content":"pub fn create_logging_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivschat.create_logging_configuration\naws_api/ivschat create_logging_configuration","url":"aws_api/ivschat.html#create_logging_configuration"},{"doc":"aws_api/ivschat","title":"create_room","content":"pub fn create_room(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivschat.create_room\naws_api/ivschat create_room","url":"aws_api/ivschat.html#create_room"},{"doc":"aws_api/ivschat","title":"delete_logging_configuration","content":"pub fn delete_logging_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivschat.delete_logging_configuration\naws_api/ivschat delete_logging_configuration","url":"aws_api/ivschat.html#delete_logging_configuration"},{"doc":"aws_api/ivschat","title":"delete_message","content":"pub fn delete_message(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivschat.delete_message\naws_api/ivschat delete_message","url":"aws_api/ivschat.html#delete_message"},{"doc":"aws_api/ivschat","title":"delete_room","content":"pub fn delete_room(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivschat.delete_room\naws_api/ivschat delete_room","url":"aws_api/ivschat.html#delete_room"},{"doc":"aws_api/ivschat","title":"disconnect_user","content":"pub fn disconnect_user(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivschat.disconnect_user\naws_api/ivschat disconnect_user","url":"aws_api/ivschat.html#disconnect_user"},{"doc":"aws_api/ivschat","title":"get_logging_configuration","content":"pub fn get_logging_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivschat.get_logging_configuration\naws_api/ivschat get_logging_configuration","url":"aws_api/ivschat.html#get_logging_configuration"},{"doc":"aws_api/ivschat","title":"get_room","content":"pub fn get_room(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivschat.get_room\naws_api/ivschat get_room","url":"aws_api/ivschat.html#get_room"},{"doc":"aws_api/ivschat","title":"list_logging_configurations","content":"pub fn list_logging_configurations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivschat.list_logging_configurations\naws_api/ivschat list_logging_configurations","url":"aws_api/ivschat.html#list_logging_configurations"},{"doc":"aws_api/ivschat","title":"list_rooms","content":"pub fn list_rooms(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivschat.list_rooms\naws_api/ivschat list_rooms","url":"aws_api/ivschat.html#list_rooms"},{"doc":"aws_api/ivschat","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivschat.list_tags_for_resource\naws_api/ivschat list_tags_for_resource","url":"aws_api/ivschat.html#list_tags_for_resource"},{"doc":"aws_api/ivschat","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/ivschat.new\naws_api/ivschat new","url":"aws_api/ivschat.html#new"},{"doc":"aws_api/ivschat","title":"send_event","content":"pub fn send_event(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivschat.send_event\naws_api/ivschat send_event","url":"aws_api/ivschat.html#send_event"},{"doc":"aws_api/ivschat","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivschat.tag_resource\naws_api/ivschat tag_resource","url":"aws_api/ivschat.html#tag_resource"},{"doc":"aws_api/ivschat","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivschat.untag_resource\naws_api/ivschat untag_resource","url":"aws_api/ivschat.html#untag_resource"},{"doc":"aws_api/ivschat","title":"update_logging_configuration","content":"pub fn update_logging_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivschat.update_logging_configuration\naws_api/ivschat update_logging_configuration","url":"aws_api/ivschat.html#update_logging_configuration"},{"doc":"aws_api/ivschat","title":"update_room","content":"pub fn update_room(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ivschat.update_room\naws_api/ivschat update_room","url":"aws_api/ivschat.html#update_room"},{"doc":"aws_api/ivschat","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/ivschat.with_custom_endpoint\naws_api/ivschat with_custom_endpoint","url":"aws_api/ivschat.html#with_custom_endpoint"},{"doc":"aws_api/ivschat","title":"aws_api/ivschat","content":"","url":"aws_api/ivschat.html"},{"doc":"aws_api/kafka","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/kafka.Client\naws_api/kafka Client","url":"aws_api/kafka.html#Client"},{"doc":"aws_api/kafka","title":"batch_associate_scram_secret","content":"pub fn batch_associate_scram_secret(\n  client: Client,\n  cluster_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.batch_associate_scram_secret\naws_api/kafka batch_associate_scram_secret","url":"aws_api/kafka.html#batch_associate_scram_secret"},{"doc":"aws_api/kafka","title":"batch_disassociate_scram_secret","content":"pub fn batch_disassociate_scram_secret(\n  client: Client,\n  cluster_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.batch_disassociate_scram_secret\naws_api/kafka batch_disassociate_scram_secret","url":"aws_api/kafka.html#batch_disassociate_scram_secret"},{"doc":"aws_api/kafka","title":"create_cluster","content":"pub fn create_cluster(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.create_cluster\naws_api/kafka create_cluster","url":"aws_api/kafka.html#create_cluster"},{"doc":"aws_api/kafka","title":"create_cluster_v2","content":"pub fn create_cluster_v2(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.create_cluster_v2\naws_api/kafka create_cluster_v2","url":"aws_api/kafka.html#create_cluster_v2"},{"doc":"aws_api/kafka","title":"create_configuration","content":"pub fn create_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.create_configuration\naws_api/kafka create_configuration","url":"aws_api/kafka.html#create_configuration"},{"doc":"aws_api/kafka","title":"create_replicator","content":"pub fn create_replicator(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.create_replicator\naws_api/kafka create_replicator","url":"aws_api/kafka.html#create_replicator"},{"doc":"aws_api/kafka","title":"create_vpc_connection","content":"pub fn create_vpc_connection(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.create_vpc_connection\naws_api/kafka create_vpc_connection","url":"aws_api/kafka.html#create_vpc_connection"},{"doc":"aws_api/kafka","title":"delete_cluster","content":"pub fn delete_cluster(\n  client: Client,\n  cluster_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.delete_cluster\naws_api/kafka delete_cluster","url":"aws_api/kafka.html#delete_cluster"},{"doc":"aws_api/kafka","title":"delete_cluster_policy","content":"pub fn delete_cluster_policy(\n  client: Client,\n  cluster_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.delete_cluster_policy\naws_api/kafka delete_cluster_policy","url":"aws_api/kafka.html#delete_cluster_policy"},{"doc":"aws_api/kafka","title":"delete_configuration","content":"pub fn delete_configuration(\n  client: Client,\n  arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.delete_configuration\naws_api/kafka delete_configuration","url":"aws_api/kafka.html#delete_configuration"},{"doc":"aws_api/kafka","title":"delete_replicator","content":"pub fn delete_replicator(\n  client: Client,\n  replicator_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.delete_replicator\naws_api/kafka delete_replicator","url":"aws_api/kafka.html#delete_replicator"},{"doc":"aws_api/kafka","title":"delete_vpc_connection","content":"pub fn delete_vpc_connection(\n  client: Client,\n  arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.delete_vpc_connection\naws_api/kafka delete_vpc_connection","url":"aws_api/kafka.html#delete_vpc_connection"},{"doc":"aws_api/kafka","title":"describe_cluster","content":"pub fn describe_cluster(\n  client: Client,\n  cluster_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.describe_cluster\naws_api/kafka describe_cluster","url":"aws_api/kafka.html#describe_cluster"},{"doc":"aws_api/kafka","title":"describe_cluster_operation","content":"pub fn describe_cluster_operation(\n  client: Client,\n  cluster_operation_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.describe_cluster_operation\naws_api/kafka describe_cluster_operation","url":"aws_api/kafka.html#describe_cluster_operation"},{"doc":"aws_api/kafka","title":"describe_cluster_operation_v2","content":"pub fn describe_cluster_operation_v2(\n  client: Client,\n  cluster_operation_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.describe_cluster_operation_v2\naws_api/kafka describe_cluster_operation_v2","url":"aws_api/kafka.html#describe_cluster_operation_v2"},{"doc":"aws_api/kafka","title":"describe_cluster_v2","content":"pub fn describe_cluster_v2(\n  client: Client,\n  cluster_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.describe_cluster_v2\naws_api/kafka describe_cluster_v2","url":"aws_api/kafka.html#describe_cluster_v2"},{"doc":"aws_api/kafka","title":"describe_configuration","content":"pub fn describe_configuration(\n  client: Client,\n  arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.describe_configuration\naws_api/kafka describe_configuration","url":"aws_api/kafka.html#describe_configuration"},{"doc":"aws_api/kafka","title":"describe_configuration_revision","content":"pub fn describe_configuration_revision(\n  client: Client,\n  arn: String,\n  revision: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.describe_configuration_revision\naws_api/kafka describe_configuration_revision","url":"aws_api/kafka.html#describe_configuration_revision"},{"doc":"aws_api/kafka","title":"describe_replicator","content":"pub fn describe_replicator(\n  client: Client,\n  replicator_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.describe_replicator\naws_api/kafka describe_replicator","url":"aws_api/kafka.html#describe_replicator"},{"doc":"aws_api/kafka","title":"describe_vpc_connection","content":"pub fn describe_vpc_connection(\n  client: Client,\n  arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.describe_vpc_connection\naws_api/kafka describe_vpc_connection","url":"aws_api/kafka.html#describe_vpc_connection"},{"doc":"aws_api/kafka","title":"get_bootstrap_brokers","content":"pub fn get_bootstrap_brokers(\n  client: Client,\n  cluster_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.get_bootstrap_brokers\naws_api/kafka get_bootstrap_brokers","url":"aws_api/kafka.html#get_bootstrap_brokers"},{"doc":"aws_api/kafka","title":"get_cluster_policy","content":"pub fn get_cluster_policy(\n  client: Client,\n  cluster_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.get_cluster_policy\naws_api/kafka get_cluster_policy","url":"aws_api/kafka.html#get_cluster_policy"},{"doc":"aws_api/kafka","title":"get_compatible_kafka_versions","content":"pub fn get_compatible_kafka_versions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.get_compatible_kafka_versions\naws_api/kafka get_compatible_kafka_versions","url":"aws_api/kafka.html#get_compatible_kafka_versions"},{"doc":"aws_api/kafka","title":"list_client_vpc_connections","content":"pub fn list_client_vpc_connections(\n  client: Client,\n  cluster_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.list_client_vpc_connections\naws_api/kafka list_client_vpc_connections","url":"aws_api/kafka.html#list_client_vpc_connections"},{"doc":"aws_api/kafka","title":"list_cluster_operations","content":"pub fn list_cluster_operations(\n  client: Client,\n  cluster_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.list_cluster_operations\naws_api/kafka list_cluster_operations","url":"aws_api/kafka.html#list_cluster_operations"},{"doc":"aws_api/kafka","title":"list_cluster_operations_v2","content":"pub fn list_cluster_operations_v2(\n  client: Client,\n  cluster_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.list_cluster_operations_v2\naws_api/kafka list_cluster_operations_v2","url":"aws_api/kafka.html#list_cluster_operations_v2"},{"doc":"aws_api/kafka","title":"list_clusters","content":"pub fn list_clusters(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.list_clusters\naws_api/kafka list_clusters","url":"aws_api/kafka.html#list_clusters"},{"doc":"aws_api/kafka","title":"list_clusters_v2","content":"pub fn list_clusters_v2(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.list_clusters_v2\naws_api/kafka list_clusters_v2","url":"aws_api/kafka.html#list_clusters_v2"},{"doc":"aws_api/kafka","title":"list_configuration_revisions","content":"pub fn list_configuration_revisions(\n  client: Client,\n  arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.list_configuration_revisions\naws_api/kafka list_configuration_revisions","url":"aws_api/kafka.html#list_configuration_revisions"},{"doc":"aws_api/kafka","title":"list_configurations","content":"pub fn list_configurations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.list_configurations\naws_api/kafka list_configurations","url":"aws_api/kafka.html#list_configurations"},{"doc":"aws_api/kafka","title":"list_kafka_versions","content":"pub fn list_kafka_versions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.list_kafka_versions\naws_api/kafka list_kafka_versions","url":"aws_api/kafka.html#list_kafka_versions"},{"doc":"aws_api/kafka","title":"list_nodes","content":"pub fn list_nodes(\n  client: Client,\n  cluster_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.list_nodes\naws_api/kafka list_nodes","url":"aws_api/kafka.html#list_nodes"},{"doc":"aws_api/kafka","title":"list_replicators","content":"pub fn list_replicators(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.list_replicators\naws_api/kafka list_replicators","url":"aws_api/kafka.html#list_replicators"},{"doc":"aws_api/kafka","title":"list_scram_secrets","content":"pub fn list_scram_secrets(\n  client: Client,\n  cluster_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.list_scram_secrets\naws_api/kafka list_scram_secrets","url":"aws_api/kafka.html#list_scram_secrets"},{"doc":"aws_api/kafka","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.list_tags_for_resource\naws_api/kafka list_tags_for_resource","url":"aws_api/kafka.html#list_tags_for_resource"},{"doc":"aws_api/kafka","title":"list_vpc_connections","content":"pub fn list_vpc_connections(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.list_vpc_connections\naws_api/kafka list_vpc_connections","url":"aws_api/kafka.html#list_vpc_connections"},{"doc":"aws_api/kafka","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/kafka.new\naws_api/kafka new","url":"aws_api/kafka.html#new"},{"doc":"aws_api/kafka","title":"put_cluster_policy","content":"pub fn put_cluster_policy(\n  client: Client,\n  cluster_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.put_cluster_policy\naws_api/kafka put_cluster_policy","url":"aws_api/kafka.html#put_cluster_policy"},{"doc":"aws_api/kafka","title":"reboot_broker","content":"pub fn reboot_broker(\n  client: Client,\n  cluster_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.reboot_broker\naws_api/kafka reboot_broker","url":"aws_api/kafka.html#reboot_broker"},{"doc":"aws_api/kafka","title":"reject_client_vpc_connection","content":"pub fn reject_client_vpc_connection(\n  client: Client,\n  cluster_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.reject_client_vpc_connection\naws_api/kafka reject_client_vpc_connection","url":"aws_api/kafka.html#reject_client_vpc_connection"},{"doc":"aws_api/kafka","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.tag_resource\naws_api/kafka tag_resource","url":"aws_api/kafka.html#tag_resource"},{"doc":"aws_api/kafka","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.untag_resource\naws_api/kafka untag_resource","url":"aws_api/kafka.html#untag_resource"},{"doc":"aws_api/kafka","title":"update_broker_count","content":"pub fn update_broker_count(\n  client: Client,\n  cluster_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.update_broker_count\naws_api/kafka update_broker_count","url":"aws_api/kafka.html#update_broker_count"},{"doc":"aws_api/kafka","title":"update_broker_storage","content":"pub fn update_broker_storage(\n  client: Client,\n  cluster_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.update_broker_storage\naws_api/kafka update_broker_storage","url":"aws_api/kafka.html#update_broker_storage"},{"doc":"aws_api/kafka","title":"update_broker_type","content":"pub fn update_broker_type(\n  client: Client,\n  cluster_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.update_broker_type\naws_api/kafka update_broker_type","url":"aws_api/kafka.html#update_broker_type"},{"doc":"aws_api/kafka","title":"update_cluster_configuration","content":"pub fn update_cluster_configuration(\n  client: Client,\n  cluster_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.update_cluster_configuration\naws_api/kafka update_cluster_configuration","url":"aws_api/kafka.html#update_cluster_configuration"},{"doc":"aws_api/kafka","title":"update_cluster_kafka_version","content":"pub fn update_cluster_kafka_version(\n  client: Client,\n  cluster_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.update_cluster_kafka_version\naws_api/kafka update_cluster_kafka_version","url":"aws_api/kafka.html#update_cluster_kafka_version"},{"doc":"aws_api/kafka","title":"update_configuration","content":"pub fn update_configuration(\n  client: Client,\n  arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.update_configuration\naws_api/kafka update_configuration","url":"aws_api/kafka.html#update_configuration"},{"doc":"aws_api/kafka","title":"update_connectivity","content":"pub fn update_connectivity(\n  client: Client,\n  cluster_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.update_connectivity\naws_api/kafka update_connectivity","url":"aws_api/kafka.html#update_connectivity"},{"doc":"aws_api/kafka","title":"update_monitoring","content":"pub fn update_monitoring(\n  client: Client,\n  cluster_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.update_monitoring\naws_api/kafka update_monitoring","url":"aws_api/kafka.html#update_monitoring"},{"doc":"aws_api/kafka","title":"update_replication_info","content":"pub fn update_replication_info(\n  client: Client,\n  replicator_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.update_replication_info\naws_api/kafka update_replication_info","url":"aws_api/kafka.html#update_replication_info"},{"doc":"aws_api/kafka","title":"update_security","content":"pub fn update_security(\n  client: Client,\n  cluster_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.update_security\naws_api/kafka update_security","url":"aws_api/kafka.html#update_security"},{"doc":"aws_api/kafka","title":"update_storage","content":"pub fn update_storage(\n  client: Client,\n  cluster_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafka.update_storage\naws_api/kafka update_storage","url":"aws_api/kafka.html#update_storage"},{"doc":"aws_api/kafka","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/kafka.with_custom_endpoint\naws_api/kafka with_custom_endpoint","url":"aws_api/kafka.html#with_custom_endpoint"},{"doc":"aws_api/kafka","title":"aws_api/kafka","content":"","url":"aws_api/kafka.html"},{"doc":"aws_api/kafkaconnect","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/kafkaconnect.Client\naws_api/kafkaconnect Client","url":"aws_api/kafkaconnect.html#Client"},{"doc":"aws_api/kafkaconnect","title":"create_connector","content":"pub fn create_connector(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafkaconnect.create_connector\naws_api/kafkaconnect create_connector","url":"aws_api/kafkaconnect.html#create_connector"},{"doc":"aws_api/kafkaconnect","title":"create_custom_plugin","content":"pub fn create_custom_plugin(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafkaconnect.create_custom_plugin\naws_api/kafkaconnect create_custom_plugin","url":"aws_api/kafkaconnect.html#create_custom_plugin"},{"doc":"aws_api/kafkaconnect","title":"create_worker_configuration","content":"pub fn create_worker_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafkaconnect.create_worker_configuration\naws_api/kafkaconnect create_worker_configuration","url":"aws_api/kafkaconnect.html#create_worker_configuration"},{"doc":"aws_api/kafkaconnect","title":"delete_connector","content":"pub fn delete_connector(\n  client: Client,\n  connector_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafkaconnect.delete_connector\naws_api/kafkaconnect delete_connector","url":"aws_api/kafkaconnect.html#delete_connector"},{"doc":"aws_api/kafkaconnect","title":"delete_custom_plugin","content":"pub fn delete_custom_plugin(\n  client: Client,\n  custom_plugin_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafkaconnect.delete_custom_plugin\naws_api/kafkaconnect delete_custom_plugin","url":"aws_api/kafkaconnect.html#delete_custom_plugin"},{"doc":"aws_api/kafkaconnect","title":"delete_worker_configuration","content":"pub fn delete_worker_configuration(\n  client: Client,\n  worker_configuration_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafkaconnect.delete_worker_configuration\naws_api/kafkaconnect delete_worker_configuration","url":"aws_api/kafkaconnect.html#delete_worker_configuration"},{"doc":"aws_api/kafkaconnect","title":"describe_connector","content":"pub fn describe_connector(\n  client: Client,\n  connector_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafkaconnect.describe_connector\naws_api/kafkaconnect describe_connector","url":"aws_api/kafkaconnect.html#describe_connector"},{"doc":"aws_api/kafkaconnect","title":"describe_custom_plugin","content":"pub fn describe_custom_plugin(\n  client: Client,\n  custom_plugin_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafkaconnect.describe_custom_plugin\naws_api/kafkaconnect describe_custom_plugin","url":"aws_api/kafkaconnect.html#describe_custom_plugin"},{"doc":"aws_api/kafkaconnect","title":"describe_worker_configuration","content":"pub fn describe_worker_configuration(\n  client: Client,\n  worker_configuration_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafkaconnect.describe_worker_configuration\naws_api/kafkaconnect describe_worker_configuration","url":"aws_api/kafkaconnect.html#describe_worker_configuration"},{"doc":"aws_api/kafkaconnect","title":"list_connectors","content":"pub fn list_connectors(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafkaconnect.list_connectors\naws_api/kafkaconnect list_connectors","url":"aws_api/kafkaconnect.html#list_connectors"},{"doc":"aws_api/kafkaconnect","title":"list_custom_plugins","content":"pub fn list_custom_plugins(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafkaconnect.list_custom_plugins\naws_api/kafkaconnect list_custom_plugins","url":"aws_api/kafkaconnect.html#list_custom_plugins"},{"doc":"aws_api/kafkaconnect","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafkaconnect.list_tags_for_resource\naws_api/kafkaconnect list_tags_for_resource","url":"aws_api/kafkaconnect.html#list_tags_for_resource"},{"doc":"aws_api/kafkaconnect","title":"list_worker_configurations","content":"pub fn list_worker_configurations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafkaconnect.list_worker_configurations\naws_api/kafkaconnect list_worker_configurations","url":"aws_api/kafkaconnect.html#list_worker_configurations"},{"doc":"aws_api/kafkaconnect","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/kafkaconnect.new\naws_api/kafkaconnect new","url":"aws_api/kafkaconnect.html#new"},{"doc":"aws_api/kafkaconnect","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafkaconnect.tag_resource\naws_api/kafkaconnect tag_resource","url":"aws_api/kafkaconnect.html#tag_resource"},{"doc":"aws_api/kafkaconnect","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafkaconnect.untag_resource\naws_api/kafkaconnect untag_resource","url":"aws_api/kafkaconnect.html#untag_resource"},{"doc":"aws_api/kafkaconnect","title":"update_connector","content":"pub fn update_connector(\n  client: Client,\n  connector_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kafkaconnect.update_connector\naws_api/kafkaconnect update_connector","url":"aws_api/kafkaconnect.html#update_connector"},{"doc":"aws_api/kafkaconnect","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/kafkaconnect.with_custom_endpoint\naws_api/kafkaconnect with_custom_endpoint","url":"aws_api/kafkaconnect.html#with_custom_endpoint"},{"doc":"aws_api/kafkaconnect","title":"aws_api/kafkaconnect","content":"","url":"aws_api/kafkaconnect.html"},{"doc":"aws_api/kendra","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/kendra.Client\naws_api/kendra Client","url":"aws_api/kendra.html#Client"},{"doc":"aws_api/kendra","title":"associate_entities_to_experience","content":"pub fn associate_entities_to_experience(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.associate_entities_to_experience\naws_api/kendra associate_entities_to_experience","url":"aws_api/kendra.html#associate_entities_to_experience"},{"doc":"aws_api/kendra","title":"associate_personas_to_entities","content":"pub fn associate_personas_to_entities(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.associate_personas_to_entities\naws_api/kendra associate_personas_to_entities","url":"aws_api/kendra.html#associate_personas_to_entities"},{"doc":"aws_api/kendra","title":"batch_delete_document","content":"pub fn batch_delete_document(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.batch_delete_document\naws_api/kendra batch_delete_document","url":"aws_api/kendra.html#batch_delete_document"},{"doc":"aws_api/kendra","title":"batch_delete_featured_results_set","content":"pub fn batch_delete_featured_results_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.batch_delete_featured_results_set\naws_api/kendra batch_delete_featured_results_set","url":"aws_api/kendra.html#batch_delete_featured_results_set"},{"doc":"aws_api/kendra","title":"batch_get_document_status","content":"pub fn batch_get_document_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.batch_get_document_status\naws_api/kendra batch_get_document_status","url":"aws_api/kendra.html#batch_get_document_status"},{"doc":"aws_api/kendra","title":"batch_put_document","content":"pub fn batch_put_document(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.batch_put_document\naws_api/kendra batch_put_document","url":"aws_api/kendra.html#batch_put_document"},{"doc":"aws_api/kendra","title":"clear_query_suggestions","content":"pub fn clear_query_suggestions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.clear_query_suggestions\naws_api/kendra clear_query_suggestions","url":"aws_api/kendra.html#clear_query_suggestions"},{"doc":"aws_api/kendra","title":"create_access_control_configuration","content":"pub fn create_access_control_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.create_access_control_configuration\naws_api/kendra create_access_control_configuration","url":"aws_api/kendra.html#create_access_control_configuration"},{"doc":"aws_api/kendra","title":"create_data_source","content":"pub fn create_data_source(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.create_data_source\naws_api/kendra create_data_source","url":"aws_api/kendra.html#create_data_source"},{"doc":"aws_api/kendra","title":"create_experience","content":"pub fn create_experience(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.create_experience\naws_api/kendra create_experience","url":"aws_api/kendra.html#create_experience"},{"doc":"aws_api/kendra","title":"create_faq","content":"pub fn create_faq(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.create_faq\naws_api/kendra create_faq","url":"aws_api/kendra.html#create_faq"},{"doc":"aws_api/kendra","title":"create_featured_results_set","content":"pub fn create_featured_results_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.create_featured_results_set\naws_api/kendra create_featured_results_set","url":"aws_api/kendra.html#create_featured_results_set"},{"doc":"aws_api/kendra","title":"create_index","content":"pub fn create_index(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.create_index\naws_api/kendra create_index","url":"aws_api/kendra.html#create_index"},{"doc":"aws_api/kendra","title":"create_query_suggestions_block_list","content":"pub fn create_query_suggestions_block_list(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.create_query_suggestions_block_list\naws_api/kendra create_query_suggestions_block_list","url":"aws_api/kendra.html#create_query_suggestions_block_list"},{"doc":"aws_api/kendra","title":"create_thesaurus","content":"pub fn create_thesaurus(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.create_thesaurus\naws_api/kendra create_thesaurus","url":"aws_api/kendra.html#create_thesaurus"},{"doc":"aws_api/kendra","title":"delete_access_control_configuration","content":"pub fn delete_access_control_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.delete_access_control_configuration\naws_api/kendra delete_access_control_configuration","url":"aws_api/kendra.html#delete_access_control_configuration"},{"doc":"aws_api/kendra","title":"delete_data_source","content":"pub fn delete_data_source(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.delete_data_source\naws_api/kendra delete_data_source","url":"aws_api/kendra.html#delete_data_source"},{"doc":"aws_api/kendra","title":"delete_experience","content":"pub fn delete_experience(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.delete_experience\naws_api/kendra delete_experience","url":"aws_api/kendra.html#delete_experience"},{"doc":"aws_api/kendra","title":"delete_faq","content":"pub fn delete_faq(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.delete_faq\naws_api/kendra delete_faq","url":"aws_api/kendra.html#delete_faq"},{"doc":"aws_api/kendra","title":"delete_index","content":"pub fn delete_index(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.delete_index\naws_api/kendra delete_index","url":"aws_api/kendra.html#delete_index"},{"doc":"aws_api/kendra","title":"delete_principal_mapping","content":"pub fn delete_principal_mapping(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.delete_principal_mapping\naws_api/kendra delete_principal_mapping","url":"aws_api/kendra.html#delete_principal_mapping"},{"doc":"aws_api/kendra","title":"delete_query_suggestions_block_list","content":"pub fn delete_query_suggestions_block_list(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.delete_query_suggestions_block_list\naws_api/kendra delete_query_suggestions_block_list","url":"aws_api/kendra.html#delete_query_suggestions_block_list"},{"doc":"aws_api/kendra","title":"delete_thesaurus","content":"pub fn delete_thesaurus(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.delete_thesaurus\naws_api/kendra delete_thesaurus","url":"aws_api/kendra.html#delete_thesaurus"},{"doc":"aws_api/kendra","title":"describe_access_control_configuration","content":"pub fn describe_access_control_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.describe_access_control_configuration\naws_api/kendra describe_access_control_configuration","url":"aws_api/kendra.html#describe_access_control_configuration"},{"doc":"aws_api/kendra","title":"describe_data_source","content":"pub fn describe_data_source(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.describe_data_source\naws_api/kendra describe_data_source","url":"aws_api/kendra.html#describe_data_source"},{"doc":"aws_api/kendra","title":"describe_experience","content":"pub fn describe_experience(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.describe_experience\naws_api/kendra describe_experience","url":"aws_api/kendra.html#describe_experience"},{"doc":"aws_api/kendra","title":"describe_faq","content":"pub fn describe_faq(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.describe_faq\naws_api/kendra describe_faq","url":"aws_api/kendra.html#describe_faq"},{"doc":"aws_api/kendra","title":"describe_featured_results_set","content":"pub fn describe_featured_results_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.describe_featured_results_set\naws_api/kendra describe_featured_results_set","url":"aws_api/kendra.html#describe_featured_results_set"},{"doc":"aws_api/kendra","title":"describe_index","content":"pub fn describe_index(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.describe_index\naws_api/kendra describe_index","url":"aws_api/kendra.html#describe_index"},{"doc":"aws_api/kendra","title":"describe_principal_mapping","content":"pub fn describe_principal_mapping(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.describe_principal_mapping\naws_api/kendra describe_principal_mapping","url":"aws_api/kendra.html#describe_principal_mapping"},{"doc":"aws_api/kendra","title":"describe_query_suggestions_block_list","content":"pub fn describe_query_suggestions_block_list(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.describe_query_suggestions_block_list\naws_api/kendra describe_query_suggestions_block_list","url":"aws_api/kendra.html#describe_query_suggestions_block_list"},{"doc":"aws_api/kendra","title":"describe_query_suggestions_config","content":"pub fn describe_query_suggestions_config(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.describe_query_suggestions_config\naws_api/kendra describe_query_suggestions_config","url":"aws_api/kendra.html#describe_query_suggestions_config"},{"doc":"aws_api/kendra","title":"describe_thesaurus","content":"pub fn describe_thesaurus(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.describe_thesaurus\naws_api/kendra describe_thesaurus","url":"aws_api/kendra.html#describe_thesaurus"},{"doc":"aws_api/kendra","title":"disassociate_entities_from_experience","content":"pub fn disassociate_entities_from_experience(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.disassociate_entities_from_experience\naws_api/kendra disassociate_entities_from_experience","url":"aws_api/kendra.html#disassociate_entities_from_experience"},{"doc":"aws_api/kendra","title":"disassociate_personas_from_entities","content":"pub fn disassociate_personas_from_entities(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.disassociate_personas_from_entities\naws_api/kendra disassociate_personas_from_entities","url":"aws_api/kendra.html#disassociate_personas_from_entities"},{"doc":"aws_api/kendra","title":"get_query_suggestions","content":"pub fn get_query_suggestions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.get_query_suggestions\naws_api/kendra get_query_suggestions","url":"aws_api/kendra.html#get_query_suggestions"},{"doc":"aws_api/kendra","title":"get_snapshots","content":"pub fn get_snapshots(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.get_snapshots\naws_api/kendra get_snapshots","url":"aws_api/kendra.html#get_snapshots"},{"doc":"aws_api/kendra","title":"list_access_control_configurations","content":"pub fn list_access_control_configurations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.list_access_control_configurations\naws_api/kendra list_access_control_configurations","url":"aws_api/kendra.html#list_access_control_configurations"},{"doc":"aws_api/kendra","title":"list_data_source_sync_jobs","content":"pub fn list_data_source_sync_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.list_data_source_sync_jobs\naws_api/kendra list_data_source_sync_jobs","url":"aws_api/kendra.html#list_data_source_sync_jobs"},{"doc":"aws_api/kendra","title":"list_data_sources","content":"pub fn list_data_sources(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.list_data_sources\naws_api/kendra list_data_sources","url":"aws_api/kendra.html#list_data_sources"},{"doc":"aws_api/kendra","title":"list_entity_personas","content":"pub fn list_entity_personas(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.list_entity_personas\naws_api/kendra list_entity_personas","url":"aws_api/kendra.html#list_entity_personas"},{"doc":"aws_api/kendra","title":"list_experience_entities","content":"pub fn list_experience_entities(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.list_experience_entities\naws_api/kendra list_experience_entities","url":"aws_api/kendra.html#list_experience_entities"},{"doc":"aws_api/kendra","title":"list_experiences","content":"pub fn list_experiences(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.list_experiences\naws_api/kendra list_experiences","url":"aws_api/kendra.html#list_experiences"},{"doc":"aws_api/kendra","title":"list_faqs","content":"pub fn list_faqs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.list_faqs\naws_api/kendra list_faqs","url":"aws_api/kendra.html#list_faqs"},{"doc":"aws_api/kendra","title":"list_featured_results_sets","content":"pub fn list_featured_results_sets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.list_featured_results_sets\naws_api/kendra list_featured_results_sets","url":"aws_api/kendra.html#list_featured_results_sets"},{"doc":"aws_api/kendra","title":"list_groups_older_than_ordering_id","content":"pub fn list_groups_older_than_ordering_id(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.list_groups_older_than_ordering_id\naws_api/kendra list_groups_older_than_ordering_id","url":"aws_api/kendra.html#list_groups_older_than_ordering_id"},{"doc":"aws_api/kendra","title":"list_indices","content":"pub fn list_indices(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.list_indices\naws_api/kendra list_indices","url":"aws_api/kendra.html#list_indices"},{"doc":"aws_api/kendra","title":"list_query_suggestions_block_lists","content":"pub fn list_query_suggestions_block_lists(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.list_query_suggestions_block_lists\naws_api/kendra list_query_suggestions_block_lists","url":"aws_api/kendra.html#list_query_suggestions_block_lists"},{"doc":"aws_api/kendra","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.list_tags_for_resource\naws_api/kendra list_tags_for_resource","url":"aws_api/kendra.html#list_tags_for_resource"},{"doc":"aws_api/kendra","title":"list_thesauri","content":"pub fn list_thesauri(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.list_thesauri\naws_api/kendra list_thesauri","url":"aws_api/kendra.html#list_thesauri"},{"doc":"aws_api/kendra","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/kendra.new\naws_api/kendra new","url":"aws_api/kendra.html#new"},{"doc":"aws_api/kendra","title":"put_principal_mapping","content":"pub fn put_principal_mapping(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.put_principal_mapping\naws_api/kendra put_principal_mapping","url":"aws_api/kendra.html#put_principal_mapping"},{"doc":"aws_api/kendra","title":"query","content":"pub fn query(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.query\naws_api/kendra query","url":"aws_api/kendra.html#query"},{"doc":"aws_api/kendra","title":"retrieve","content":"pub fn retrieve(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.retrieve\naws_api/kendra retrieve","url":"aws_api/kendra.html#retrieve"},{"doc":"aws_api/kendra","title":"start_data_source_sync_job","content":"pub fn start_data_source_sync_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.start_data_source_sync_job\naws_api/kendra start_data_source_sync_job","url":"aws_api/kendra.html#start_data_source_sync_job"},{"doc":"aws_api/kendra","title":"stop_data_source_sync_job","content":"pub fn stop_data_source_sync_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.stop_data_source_sync_job\naws_api/kendra stop_data_source_sync_job","url":"aws_api/kendra.html#stop_data_source_sync_job"},{"doc":"aws_api/kendra","title":"submit_feedback","content":"pub fn submit_feedback(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.submit_feedback\naws_api/kendra submit_feedback","url":"aws_api/kendra.html#submit_feedback"},{"doc":"aws_api/kendra","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.tag_resource\naws_api/kendra tag_resource","url":"aws_api/kendra.html#tag_resource"},{"doc":"aws_api/kendra","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.untag_resource\naws_api/kendra untag_resource","url":"aws_api/kendra.html#untag_resource"},{"doc":"aws_api/kendra","title":"update_access_control_configuration","content":"pub fn update_access_control_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.update_access_control_configuration\naws_api/kendra update_access_control_configuration","url":"aws_api/kendra.html#update_access_control_configuration"},{"doc":"aws_api/kendra","title":"update_data_source","content":"pub fn update_data_source(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.update_data_source\naws_api/kendra update_data_source","url":"aws_api/kendra.html#update_data_source"},{"doc":"aws_api/kendra","title":"update_experience","content":"pub fn update_experience(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.update_experience\naws_api/kendra update_experience","url":"aws_api/kendra.html#update_experience"},{"doc":"aws_api/kendra","title":"update_featured_results_set","content":"pub fn update_featured_results_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.update_featured_results_set\naws_api/kendra update_featured_results_set","url":"aws_api/kendra.html#update_featured_results_set"},{"doc":"aws_api/kendra","title":"update_index","content":"pub fn update_index(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.update_index\naws_api/kendra update_index","url":"aws_api/kendra.html#update_index"},{"doc":"aws_api/kendra","title":"update_query_suggestions_block_list","content":"pub fn update_query_suggestions_block_list(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.update_query_suggestions_block_list\naws_api/kendra update_query_suggestions_block_list","url":"aws_api/kendra.html#update_query_suggestions_block_list"},{"doc":"aws_api/kendra","title":"update_query_suggestions_config","content":"pub fn update_query_suggestions_config(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.update_query_suggestions_config\naws_api/kendra update_query_suggestions_config","url":"aws_api/kendra.html#update_query_suggestions_config"},{"doc":"aws_api/kendra","title":"update_thesaurus","content":"pub fn update_thesaurus(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra.update_thesaurus\naws_api/kendra update_thesaurus","url":"aws_api/kendra.html#update_thesaurus"},{"doc":"aws_api/kendra","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/kendra.with_custom_endpoint\naws_api/kendra with_custom_endpoint","url":"aws_api/kendra.html#with_custom_endpoint"},{"doc":"aws_api/kendra","title":"aws_api/kendra","content":"","url":"aws_api/kendra.html"},{"doc":"aws_api/kendra_ranking","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/kendra_ranking.Client\naws_api/kendra_ranking Client","url":"aws_api/kendra_ranking.html#Client"},{"doc":"aws_api/kendra_ranking","title":"create_rescore_execution_plan","content":"pub fn create_rescore_execution_plan(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra_ranking.create_rescore_execution_plan\naws_api/kendra_ranking create_rescore_execution_plan","url":"aws_api/kendra_ranking.html#create_rescore_execution_plan"},{"doc":"aws_api/kendra_ranking","title":"delete_rescore_execution_plan","content":"pub fn delete_rescore_execution_plan(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra_ranking.delete_rescore_execution_plan\naws_api/kendra_ranking delete_rescore_execution_plan","url":"aws_api/kendra_ranking.html#delete_rescore_execution_plan"},{"doc":"aws_api/kendra_ranking","title":"describe_rescore_execution_plan","content":"pub fn describe_rescore_execution_plan(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra_ranking.describe_rescore_execution_plan\naws_api/kendra_ranking describe_rescore_execution_plan","url":"aws_api/kendra_ranking.html#describe_rescore_execution_plan"},{"doc":"aws_api/kendra_ranking","title":"list_rescore_execution_plans","content":"pub fn list_rescore_execution_plans(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra_ranking.list_rescore_execution_plans\naws_api/kendra_ranking list_rescore_execution_plans","url":"aws_api/kendra_ranking.html#list_rescore_execution_plans"},{"doc":"aws_api/kendra_ranking","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra_ranking.list_tags_for_resource\naws_api/kendra_ranking list_tags_for_resource","url":"aws_api/kendra_ranking.html#list_tags_for_resource"},{"doc":"aws_api/kendra_ranking","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/kendra_ranking.new\naws_api/kendra_ranking new","url":"aws_api/kendra_ranking.html#new"},{"doc":"aws_api/kendra_ranking","title":"rescore","content":"pub fn rescore(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra_ranking.rescore\naws_api/kendra_ranking rescore","url":"aws_api/kendra_ranking.html#rescore"},{"doc":"aws_api/kendra_ranking","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra_ranking.tag_resource\naws_api/kendra_ranking tag_resource","url":"aws_api/kendra_ranking.html#tag_resource"},{"doc":"aws_api/kendra_ranking","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra_ranking.untag_resource\naws_api/kendra_ranking untag_resource","url":"aws_api/kendra_ranking.html#untag_resource"},{"doc":"aws_api/kendra_ranking","title":"update_rescore_execution_plan","content":"pub fn update_rescore_execution_plan(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kendra_ranking.update_rescore_execution_plan\naws_api/kendra_ranking update_rescore_execution_plan","url":"aws_api/kendra_ranking.html#update_rescore_execution_plan"},{"doc":"aws_api/kendra_ranking","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/kendra_ranking.with_custom_endpoint\naws_api/kendra_ranking with_custom_endpoint","url":"aws_api/kendra_ranking.html#with_custom_endpoint"},{"doc":"aws_api/kendra_ranking","title":"aws_api/kendra_ranking","content":"","url":"aws_api/kendra_ranking.html"},{"doc":"aws_api/keyspaces","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/keyspaces.Client\naws_api/keyspaces Client","url":"aws_api/keyspaces.html#Client"},{"doc":"aws_api/keyspaces","title":"create_keyspace","content":"pub fn create_keyspace(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/keyspaces.create_keyspace\naws_api/keyspaces create_keyspace","url":"aws_api/keyspaces.html#create_keyspace"},{"doc":"aws_api/keyspaces","title":"create_table","content":"pub fn create_table(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/keyspaces.create_table\naws_api/keyspaces create_table","url":"aws_api/keyspaces.html#create_table"},{"doc":"aws_api/keyspaces","title":"delete_keyspace","content":"pub fn delete_keyspace(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/keyspaces.delete_keyspace\naws_api/keyspaces delete_keyspace","url":"aws_api/keyspaces.html#delete_keyspace"},{"doc":"aws_api/keyspaces","title":"delete_table","content":"pub fn delete_table(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/keyspaces.delete_table\naws_api/keyspaces delete_table","url":"aws_api/keyspaces.html#delete_table"},{"doc":"aws_api/keyspaces","title":"get_keyspace","content":"pub fn get_keyspace(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/keyspaces.get_keyspace\naws_api/keyspaces get_keyspace","url":"aws_api/keyspaces.html#get_keyspace"},{"doc":"aws_api/keyspaces","title":"get_table","content":"pub fn get_table(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/keyspaces.get_table\naws_api/keyspaces get_table","url":"aws_api/keyspaces.html#get_table"},{"doc":"aws_api/keyspaces","title":"get_table_auto_scaling_settings","content":"pub fn get_table_auto_scaling_settings(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/keyspaces.get_table_auto_scaling_settings\naws_api/keyspaces get_table_auto_scaling_settings","url":"aws_api/keyspaces.html#get_table_auto_scaling_settings"},{"doc":"aws_api/keyspaces","title":"list_keyspaces","content":"pub fn list_keyspaces(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/keyspaces.list_keyspaces\naws_api/keyspaces list_keyspaces","url":"aws_api/keyspaces.html#list_keyspaces"},{"doc":"aws_api/keyspaces","title":"list_tables","content":"pub fn list_tables(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/keyspaces.list_tables\naws_api/keyspaces list_tables","url":"aws_api/keyspaces.html#list_tables"},{"doc":"aws_api/keyspaces","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/keyspaces.list_tags_for_resource\naws_api/keyspaces list_tags_for_resource","url":"aws_api/keyspaces.html#list_tags_for_resource"},{"doc":"aws_api/keyspaces","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/keyspaces.new\naws_api/keyspaces new","url":"aws_api/keyspaces.html#new"},{"doc":"aws_api/keyspaces","title":"restore_table","content":"pub fn restore_table(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/keyspaces.restore_table\naws_api/keyspaces restore_table","url":"aws_api/keyspaces.html#restore_table"},{"doc":"aws_api/keyspaces","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/keyspaces.tag_resource\naws_api/keyspaces tag_resource","url":"aws_api/keyspaces.html#tag_resource"},{"doc":"aws_api/keyspaces","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/keyspaces.untag_resource\naws_api/keyspaces untag_resource","url":"aws_api/keyspaces.html#untag_resource"},{"doc":"aws_api/keyspaces","title":"update_table","content":"pub fn update_table(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/keyspaces.update_table\naws_api/keyspaces update_table","url":"aws_api/keyspaces.html#update_table"},{"doc":"aws_api/keyspaces","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/keyspaces.with_custom_endpoint\naws_api/keyspaces with_custom_endpoint","url":"aws_api/keyspaces.html#with_custom_endpoint"},{"doc":"aws_api/keyspaces","title":"aws_api/keyspaces","content":"","url":"aws_api/keyspaces.html"},{"doc":"aws_api/kinesis","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/kinesis.Client\naws_api/kinesis Client","url":"aws_api/kinesis.html#Client"},{"doc":"aws_api/kinesis","title":"add_tags_to_stream","content":"pub fn add_tags_to_stream(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis.add_tags_to_stream\naws_api/kinesis add_tags_to_stream","url":"aws_api/kinesis.html#add_tags_to_stream"},{"doc":"aws_api/kinesis","title":"create_stream","content":"pub fn create_stream(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis.create_stream\naws_api/kinesis create_stream","url":"aws_api/kinesis.html#create_stream"},{"doc":"aws_api/kinesis","title":"decrease_stream_retention_period","content":"pub fn decrease_stream_retention_period(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis.decrease_stream_retention_period\naws_api/kinesis decrease_stream_retention_period","url":"aws_api/kinesis.html#decrease_stream_retention_period"},{"doc":"aws_api/kinesis","title":"delete_resource_policy","content":"pub fn delete_resource_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis.delete_resource_policy\naws_api/kinesis delete_resource_policy","url":"aws_api/kinesis.html#delete_resource_policy"},{"doc":"aws_api/kinesis","title":"delete_stream","content":"pub fn delete_stream(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis.delete_stream\naws_api/kinesis delete_stream","url":"aws_api/kinesis.html#delete_stream"},{"doc":"aws_api/kinesis","title":"deregister_stream_consumer","content":"pub fn deregister_stream_consumer(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis.deregister_stream_consumer\naws_api/kinesis deregister_stream_consumer","url":"aws_api/kinesis.html#deregister_stream_consumer"},{"doc":"aws_api/kinesis","title":"describe_limits","content":"pub fn describe_limits(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis.describe_limits\naws_api/kinesis describe_limits","url":"aws_api/kinesis.html#describe_limits"},{"doc":"aws_api/kinesis","title":"describe_stream","content":"pub fn describe_stream(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis.describe_stream\naws_api/kinesis describe_stream","url":"aws_api/kinesis.html#describe_stream"},{"doc":"aws_api/kinesis","title":"describe_stream_consumer","content":"pub fn describe_stream_consumer(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis.describe_stream_consumer\naws_api/kinesis describe_stream_consumer","url":"aws_api/kinesis.html#describe_stream_consumer"},{"doc":"aws_api/kinesis","title":"describe_stream_summary","content":"pub fn describe_stream_summary(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis.describe_stream_summary\naws_api/kinesis describe_stream_summary","url":"aws_api/kinesis.html#describe_stream_summary"},{"doc":"aws_api/kinesis","title":"disable_enhanced_monitoring","content":"pub fn disable_enhanced_monitoring(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis.disable_enhanced_monitoring\naws_api/kinesis disable_enhanced_monitoring","url":"aws_api/kinesis.html#disable_enhanced_monitoring"},{"doc":"aws_api/kinesis","title":"enable_enhanced_monitoring","content":"pub fn enable_enhanced_monitoring(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis.enable_enhanced_monitoring\naws_api/kinesis enable_enhanced_monitoring","url":"aws_api/kinesis.html#enable_enhanced_monitoring"},{"doc":"aws_api/kinesis","title":"get_records","content":"pub fn get_records(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis.get_records\naws_api/kinesis get_records","url":"aws_api/kinesis.html#get_records"},{"doc":"aws_api/kinesis","title":"get_resource_policy","content":"pub fn get_resource_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis.get_resource_policy\naws_api/kinesis get_resource_policy","url":"aws_api/kinesis.html#get_resource_policy"},{"doc":"aws_api/kinesis","title":"get_shard_iterator","content":"pub fn get_shard_iterator(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis.get_shard_iterator\naws_api/kinesis get_shard_iterator","url":"aws_api/kinesis.html#get_shard_iterator"},{"doc":"aws_api/kinesis","title":"increase_stream_retention_period","content":"pub fn increase_stream_retention_period(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis.increase_stream_retention_period\naws_api/kinesis increase_stream_retention_period","url":"aws_api/kinesis.html#increase_stream_retention_period"},{"doc":"aws_api/kinesis","title":"list_shards","content":"pub fn list_shards(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis.list_shards\naws_api/kinesis list_shards","url":"aws_api/kinesis.html#list_shards"},{"doc":"aws_api/kinesis","title":"list_stream_consumers","content":"pub fn list_stream_consumers(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis.list_stream_consumers\naws_api/kinesis list_stream_consumers","url":"aws_api/kinesis.html#list_stream_consumers"},{"doc":"aws_api/kinesis","title":"list_streams","content":"pub fn list_streams(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis.list_streams\naws_api/kinesis list_streams","url":"aws_api/kinesis.html#list_streams"},{"doc":"aws_api/kinesis","title":"list_tags_for_stream","content":"pub fn list_tags_for_stream(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis.list_tags_for_stream\naws_api/kinesis list_tags_for_stream","url":"aws_api/kinesis.html#list_tags_for_stream"},{"doc":"aws_api/kinesis","title":"merge_shards","content":"pub fn merge_shards(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis.merge_shards\naws_api/kinesis merge_shards","url":"aws_api/kinesis.html#merge_shards"},{"doc":"aws_api/kinesis","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/kinesis.new\naws_api/kinesis new","url":"aws_api/kinesis.html#new"},{"doc":"aws_api/kinesis","title":"put_record","content":"pub fn put_record(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis.put_record\naws_api/kinesis put_record","url":"aws_api/kinesis.html#put_record"},{"doc":"aws_api/kinesis","title":"put_records","content":"pub fn put_records(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis.put_records\naws_api/kinesis put_records","url":"aws_api/kinesis.html#put_records"},{"doc":"aws_api/kinesis","title":"put_resource_policy","content":"pub fn put_resource_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis.put_resource_policy\naws_api/kinesis put_resource_policy","url":"aws_api/kinesis.html#put_resource_policy"},{"doc":"aws_api/kinesis","title":"register_stream_consumer","content":"pub fn register_stream_consumer(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis.register_stream_consumer\naws_api/kinesis register_stream_consumer","url":"aws_api/kinesis.html#register_stream_consumer"},{"doc":"aws_api/kinesis","title":"remove_tags_from_stream","content":"pub fn remove_tags_from_stream(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis.remove_tags_from_stream\naws_api/kinesis remove_tags_from_stream","url":"aws_api/kinesis.html#remove_tags_from_stream"},{"doc":"aws_api/kinesis","title":"split_shard","content":"pub fn split_shard(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis.split_shard\naws_api/kinesis split_shard","url":"aws_api/kinesis.html#split_shard"},{"doc":"aws_api/kinesis","title":"start_stream_encryption","content":"pub fn start_stream_encryption(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis.start_stream_encryption\naws_api/kinesis start_stream_encryption","url":"aws_api/kinesis.html#start_stream_encryption"},{"doc":"aws_api/kinesis","title":"stop_stream_encryption","content":"pub fn stop_stream_encryption(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis.stop_stream_encryption\naws_api/kinesis stop_stream_encryption","url":"aws_api/kinesis.html#stop_stream_encryption"},{"doc":"aws_api/kinesis","title":"subscribe_to_shard","content":"pub fn subscribe_to_shard(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis.subscribe_to_shard\naws_api/kinesis subscribe_to_shard","url":"aws_api/kinesis.html#subscribe_to_shard"},{"doc":"aws_api/kinesis","title":"update_shard_count","content":"pub fn update_shard_count(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis.update_shard_count\naws_api/kinesis update_shard_count","url":"aws_api/kinesis.html#update_shard_count"},{"doc":"aws_api/kinesis","title":"update_stream_mode","content":"pub fn update_stream_mode(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis.update_stream_mode\naws_api/kinesis update_stream_mode","url":"aws_api/kinesis.html#update_stream_mode"},{"doc":"aws_api/kinesis","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/kinesis.with_custom_endpoint\naws_api/kinesis with_custom_endpoint","url":"aws_api/kinesis.html#with_custom_endpoint"},{"doc":"aws_api/kinesis","title":"aws_api/kinesis","content":"","url":"aws_api/kinesis.html"},{"doc":"aws_api/kinesis_analytics","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/kinesis_analytics.Client\naws_api/kinesis_analytics Client","url":"aws_api/kinesis_analytics.html#Client"},{"doc":"aws_api/kinesis_analytics","title":"add_application_cloud_watch_logging_option","content":"pub fn add_application_cloud_watch_logging_option(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics.add_application_cloud_watch_logging_option\naws_api/kinesis_analytics add_application_cloud_watch_logging_option","url":"aws_api/kinesis_analytics.html#add_application_cloud_watch_logging_option"},{"doc":"aws_api/kinesis_analytics","title":"add_application_input","content":"pub fn add_application_input(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics.add_application_input\naws_api/kinesis_analytics add_application_input","url":"aws_api/kinesis_analytics.html#add_application_input"},{"doc":"aws_api/kinesis_analytics","title":"add_application_input_processing_configuration","content":"pub fn add_application_input_processing_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics.add_application_input_processing_configuration\naws_api/kinesis_analytics add_application_input_processing_configuration","url":"aws_api/kinesis_analytics.html#add_application_input_processing_configuration"},{"doc":"aws_api/kinesis_analytics","title":"add_application_output","content":"pub fn add_application_output(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics.add_application_output\naws_api/kinesis_analytics add_application_output","url":"aws_api/kinesis_analytics.html#add_application_output"},{"doc":"aws_api/kinesis_analytics","title":"add_application_reference_data_source","content":"pub fn add_application_reference_data_source(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics.add_application_reference_data_source\naws_api/kinesis_analytics add_application_reference_data_source","url":"aws_api/kinesis_analytics.html#add_application_reference_data_source"},{"doc":"aws_api/kinesis_analytics","title":"create_application","content":"pub fn create_application(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics.create_application\naws_api/kinesis_analytics create_application","url":"aws_api/kinesis_analytics.html#create_application"},{"doc":"aws_api/kinesis_analytics","title":"delete_application","content":"pub fn delete_application(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics.delete_application\naws_api/kinesis_analytics delete_application","url":"aws_api/kinesis_analytics.html#delete_application"},{"doc":"aws_api/kinesis_analytics","title":"delete_application_cloud_watch_logging_option","content":"pub fn delete_application_cloud_watch_logging_option(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics.delete_application_cloud_watch_logging_option\naws_api/kinesis_analytics delete_application_cloud_watch_logging_option","url":"aws_api/kinesis_analytics.html#delete_application_cloud_watch_logging_option"},{"doc":"aws_api/kinesis_analytics","title":"delete_application_input_processing_configuration","content":"pub fn delete_application_input_processing_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics.delete_application_input_processing_configuration\naws_api/kinesis_analytics delete_application_input_processing_configuration","url":"aws_api/kinesis_analytics.html#delete_application_input_processing_configuration"},{"doc":"aws_api/kinesis_analytics","title":"delete_application_output","content":"pub fn delete_application_output(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics.delete_application_output\naws_api/kinesis_analytics delete_application_output","url":"aws_api/kinesis_analytics.html#delete_application_output"},{"doc":"aws_api/kinesis_analytics","title":"delete_application_reference_data_source","content":"pub fn delete_application_reference_data_source(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics.delete_application_reference_data_source\naws_api/kinesis_analytics delete_application_reference_data_source","url":"aws_api/kinesis_analytics.html#delete_application_reference_data_source"},{"doc":"aws_api/kinesis_analytics","title":"describe_application","content":"pub fn describe_application(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics.describe_application\naws_api/kinesis_analytics describe_application","url":"aws_api/kinesis_analytics.html#describe_application"},{"doc":"aws_api/kinesis_analytics","title":"discover_input_schema","content":"pub fn discover_input_schema(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics.discover_input_schema\naws_api/kinesis_analytics discover_input_schema","url":"aws_api/kinesis_analytics.html#discover_input_schema"},{"doc":"aws_api/kinesis_analytics","title":"list_applications","content":"pub fn list_applications(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics.list_applications\naws_api/kinesis_analytics list_applications","url":"aws_api/kinesis_analytics.html#list_applications"},{"doc":"aws_api/kinesis_analytics","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics.list_tags_for_resource\naws_api/kinesis_analytics list_tags_for_resource","url":"aws_api/kinesis_analytics.html#list_tags_for_resource"},{"doc":"aws_api/kinesis_analytics","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/kinesis_analytics.new\naws_api/kinesis_analytics new","url":"aws_api/kinesis_analytics.html#new"},{"doc":"aws_api/kinesis_analytics","title":"start_application","content":"pub fn start_application(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics.start_application\naws_api/kinesis_analytics start_application","url":"aws_api/kinesis_analytics.html#start_application"},{"doc":"aws_api/kinesis_analytics","title":"stop_application","content":"pub fn stop_application(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics.stop_application\naws_api/kinesis_analytics stop_application","url":"aws_api/kinesis_analytics.html#stop_application"},{"doc":"aws_api/kinesis_analytics","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics.tag_resource\naws_api/kinesis_analytics tag_resource","url":"aws_api/kinesis_analytics.html#tag_resource"},{"doc":"aws_api/kinesis_analytics","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics.untag_resource\naws_api/kinesis_analytics untag_resource","url":"aws_api/kinesis_analytics.html#untag_resource"},{"doc":"aws_api/kinesis_analytics","title":"update_application","content":"pub fn update_application(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics.update_application\naws_api/kinesis_analytics update_application","url":"aws_api/kinesis_analytics.html#update_application"},{"doc":"aws_api/kinesis_analytics","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/kinesis_analytics.with_custom_endpoint\naws_api/kinesis_analytics with_custom_endpoint","url":"aws_api/kinesis_analytics.html#with_custom_endpoint"},{"doc":"aws_api/kinesis_analytics","title":"aws_api/kinesis_analytics","content":"","url":"aws_api/kinesis_analytics.html"},{"doc":"aws_api/kinesis_analytics_v2","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/kinesis_analytics_v2.Client\naws_api/kinesis_analytics_v2 Client","url":"aws_api/kinesis_analytics_v2.html#Client"},{"doc":"aws_api/kinesis_analytics_v2","title":"add_application_cloud_watch_logging_option","content":"pub fn add_application_cloud_watch_logging_option(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics_v2.add_application_cloud_watch_logging_option\naws_api/kinesis_analytics_v2 add_application_cloud_watch_logging_option","url":"aws_api/kinesis_analytics_v2.html#add_application_cloud_watch_logging_option"},{"doc":"aws_api/kinesis_analytics_v2","title":"add_application_input","content":"pub fn add_application_input(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics_v2.add_application_input\naws_api/kinesis_analytics_v2 add_application_input","url":"aws_api/kinesis_analytics_v2.html#add_application_input"},{"doc":"aws_api/kinesis_analytics_v2","title":"add_application_input_processing_configuration","content":"pub fn add_application_input_processing_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics_v2.add_application_input_processing_configuration\naws_api/kinesis_analytics_v2 add_application_input_processing_configuration","url":"aws_api/kinesis_analytics_v2.html#add_application_input_processing_configuration"},{"doc":"aws_api/kinesis_analytics_v2","title":"add_application_output","content":"pub fn add_application_output(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics_v2.add_application_output\naws_api/kinesis_analytics_v2 add_application_output","url":"aws_api/kinesis_analytics_v2.html#add_application_output"},{"doc":"aws_api/kinesis_analytics_v2","title":"add_application_reference_data_source","content":"pub fn add_application_reference_data_source(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics_v2.add_application_reference_data_source\naws_api/kinesis_analytics_v2 add_application_reference_data_source","url":"aws_api/kinesis_analytics_v2.html#add_application_reference_data_source"},{"doc":"aws_api/kinesis_analytics_v2","title":"add_application_vpc_configuration","content":"pub fn add_application_vpc_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics_v2.add_application_vpc_configuration\naws_api/kinesis_analytics_v2 add_application_vpc_configuration","url":"aws_api/kinesis_analytics_v2.html#add_application_vpc_configuration"},{"doc":"aws_api/kinesis_analytics_v2","title":"create_application","content":"pub fn create_application(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics_v2.create_application\naws_api/kinesis_analytics_v2 create_application","url":"aws_api/kinesis_analytics_v2.html#create_application"},{"doc":"aws_api/kinesis_analytics_v2","title":"create_application_presigned_url","content":"pub fn create_application_presigned_url(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics_v2.create_application_presigned_url\naws_api/kinesis_analytics_v2 create_application_presigned_url","url":"aws_api/kinesis_analytics_v2.html#create_application_presigned_url"},{"doc":"aws_api/kinesis_analytics_v2","title":"create_application_snapshot","content":"pub fn create_application_snapshot(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics_v2.create_application_snapshot\naws_api/kinesis_analytics_v2 create_application_snapshot","url":"aws_api/kinesis_analytics_v2.html#create_application_snapshot"},{"doc":"aws_api/kinesis_analytics_v2","title":"delete_application","content":"pub fn delete_application(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics_v2.delete_application\naws_api/kinesis_analytics_v2 delete_application","url":"aws_api/kinesis_analytics_v2.html#delete_application"},{"doc":"aws_api/kinesis_analytics_v2","title":"delete_application_cloud_watch_logging_option","content":"pub fn delete_application_cloud_watch_logging_option(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics_v2.delete_application_cloud_watch_logging_option\naws_api/kinesis_analytics_v2 delete_application_cloud_watch_logging_option","url":"aws_api/kinesis_analytics_v2.html#delete_application_cloud_watch_logging_option"},{"doc":"aws_api/kinesis_analytics_v2","title":"delete_application_input_processing_configuration","content":"pub fn delete_application_input_processing_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics_v2.delete_application_input_processing_configuration\naws_api/kinesis_analytics_v2 delete_application_input_processing_configuration","url":"aws_api/kinesis_analytics_v2.html#delete_application_input_processing_configuration"},{"doc":"aws_api/kinesis_analytics_v2","title":"delete_application_output","content":"pub fn delete_application_output(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics_v2.delete_application_output\naws_api/kinesis_analytics_v2 delete_application_output","url":"aws_api/kinesis_analytics_v2.html#delete_application_output"},{"doc":"aws_api/kinesis_analytics_v2","title":"delete_application_reference_data_source","content":"pub fn delete_application_reference_data_source(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics_v2.delete_application_reference_data_source\naws_api/kinesis_analytics_v2 delete_application_reference_data_source","url":"aws_api/kinesis_analytics_v2.html#delete_application_reference_data_source"},{"doc":"aws_api/kinesis_analytics_v2","title":"delete_application_snapshot","content":"pub fn delete_application_snapshot(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics_v2.delete_application_snapshot\naws_api/kinesis_analytics_v2 delete_application_snapshot","url":"aws_api/kinesis_analytics_v2.html#delete_application_snapshot"},{"doc":"aws_api/kinesis_analytics_v2","title":"delete_application_vpc_configuration","content":"pub fn delete_application_vpc_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics_v2.delete_application_vpc_configuration\naws_api/kinesis_analytics_v2 delete_application_vpc_configuration","url":"aws_api/kinesis_analytics_v2.html#delete_application_vpc_configuration"},{"doc":"aws_api/kinesis_analytics_v2","title":"describe_application","content":"pub fn describe_application(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics_v2.describe_application\naws_api/kinesis_analytics_v2 describe_application","url":"aws_api/kinesis_analytics_v2.html#describe_application"},{"doc":"aws_api/kinesis_analytics_v2","title":"describe_application_operation","content":"pub fn describe_application_operation(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics_v2.describe_application_operation\naws_api/kinesis_analytics_v2 describe_application_operation","url":"aws_api/kinesis_analytics_v2.html#describe_application_operation"},{"doc":"aws_api/kinesis_analytics_v2","title":"describe_application_snapshot","content":"pub fn describe_application_snapshot(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics_v2.describe_application_snapshot\naws_api/kinesis_analytics_v2 describe_application_snapshot","url":"aws_api/kinesis_analytics_v2.html#describe_application_snapshot"},{"doc":"aws_api/kinesis_analytics_v2","title":"describe_application_version","content":"pub fn describe_application_version(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics_v2.describe_application_version\naws_api/kinesis_analytics_v2 describe_application_version","url":"aws_api/kinesis_analytics_v2.html#describe_application_version"},{"doc":"aws_api/kinesis_analytics_v2","title":"discover_input_schema","content":"pub fn discover_input_schema(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics_v2.discover_input_schema\naws_api/kinesis_analytics_v2 discover_input_schema","url":"aws_api/kinesis_analytics_v2.html#discover_input_schema"},{"doc":"aws_api/kinesis_analytics_v2","title":"list_application_operations","content":"pub fn list_application_operations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics_v2.list_application_operations\naws_api/kinesis_analytics_v2 list_application_operations","url":"aws_api/kinesis_analytics_v2.html#list_application_operations"},{"doc":"aws_api/kinesis_analytics_v2","title":"list_application_snapshots","content":"pub fn list_application_snapshots(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics_v2.list_application_snapshots\naws_api/kinesis_analytics_v2 list_application_snapshots","url":"aws_api/kinesis_analytics_v2.html#list_application_snapshots"},{"doc":"aws_api/kinesis_analytics_v2","title":"list_application_versions","content":"pub fn list_application_versions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics_v2.list_application_versions\naws_api/kinesis_analytics_v2 list_application_versions","url":"aws_api/kinesis_analytics_v2.html#list_application_versions"},{"doc":"aws_api/kinesis_analytics_v2","title":"list_applications","content":"pub fn list_applications(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics_v2.list_applications\naws_api/kinesis_analytics_v2 list_applications","url":"aws_api/kinesis_analytics_v2.html#list_applications"},{"doc":"aws_api/kinesis_analytics_v2","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics_v2.list_tags_for_resource\naws_api/kinesis_analytics_v2 list_tags_for_resource","url":"aws_api/kinesis_analytics_v2.html#list_tags_for_resource"},{"doc":"aws_api/kinesis_analytics_v2","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/kinesis_analytics_v2.new\naws_api/kinesis_analytics_v2 new","url":"aws_api/kinesis_analytics_v2.html#new"},{"doc":"aws_api/kinesis_analytics_v2","title":"rollback_application","content":"pub fn rollback_application(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics_v2.rollback_application\naws_api/kinesis_analytics_v2 rollback_application","url":"aws_api/kinesis_analytics_v2.html#rollback_application"},{"doc":"aws_api/kinesis_analytics_v2","title":"start_application","content":"pub fn start_application(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics_v2.start_application\naws_api/kinesis_analytics_v2 start_application","url":"aws_api/kinesis_analytics_v2.html#start_application"},{"doc":"aws_api/kinesis_analytics_v2","title":"stop_application","content":"pub fn stop_application(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics_v2.stop_application\naws_api/kinesis_analytics_v2 stop_application","url":"aws_api/kinesis_analytics_v2.html#stop_application"},{"doc":"aws_api/kinesis_analytics_v2","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics_v2.tag_resource\naws_api/kinesis_analytics_v2 tag_resource","url":"aws_api/kinesis_analytics_v2.html#tag_resource"},{"doc":"aws_api/kinesis_analytics_v2","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics_v2.untag_resource\naws_api/kinesis_analytics_v2 untag_resource","url":"aws_api/kinesis_analytics_v2.html#untag_resource"},{"doc":"aws_api/kinesis_analytics_v2","title":"update_application","content":"pub fn update_application(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics_v2.update_application\naws_api/kinesis_analytics_v2 update_application","url":"aws_api/kinesis_analytics_v2.html#update_application"},{"doc":"aws_api/kinesis_analytics_v2","title":"update_application_maintenance_configuration","content":"pub fn update_application_maintenance_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_analytics_v2.update_application_maintenance_configuration\naws_api/kinesis_analytics_v2 update_application_maintenance_configuration","url":"aws_api/kinesis_analytics_v2.html#update_application_maintenance_configuration"},{"doc":"aws_api/kinesis_analytics_v2","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/kinesis_analytics_v2.with_custom_endpoint\naws_api/kinesis_analytics_v2 with_custom_endpoint","url":"aws_api/kinesis_analytics_v2.html#with_custom_endpoint"},{"doc":"aws_api/kinesis_analytics_v2","title":"aws_api/kinesis_analytics_v2","content":"","url":"aws_api/kinesis_analytics_v2.html"},{"doc":"aws_api/kinesis_video","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/kinesis_video.Client\naws_api/kinesis_video Client","url":"aws_api/kinesis_video.html#Client"},{"doc":"aws_api/kinesis_video","title":"create_signaling_channel","content":"pub fn create_signaling_channel(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_video.create_signaling_channel\naws_api/kinesis_video create_signaling_channel","url":"aws_api/kinesis_video.html#create_signaling_channel"},{"doc":"aws_api/kinesis_video","title":"create_stream","content":"pub fn create_stream(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_video.create_stream\naws_api/kinesis_video create_stream","url":"aws_api/kinesis_video.html#create_stream"},{"doc":"aws_api/kinesis_video","title":"delete_edge_configuration","content":"pub fn delete_edge_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_video.delete_edge_configuration\naws_api/kinesis_video delete_edge_configuration","url":"aws_api/kinesis_video.html#delete_edge_configuration"},{"doc":"aws_api/kinesis_video","title":"delete_signaling_channel","content":"pub fn delete_signaling_channel(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_video.delete_signaling_channel\naws_api/kinesis_video delete_signaling_channel","url":"aws_api/kinesis_video.html#delete_signaling_channel"},{"doc":"aws_api/kinesis_video","title":"delete_stream","content":"pub fn delete_stream(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_video.delete_stream\naws_api/kinesis_video delete_stream","url":"aws_api/kinesis_video.html#delete_stream"},{"doc":"aws_api/kinesis_video","title":"describe_edge_configuration","content":"pub fn describe_edge_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_video.describe_edge_configuration\naws_api/kinesis_video describe_edge_configuration","url":"aws_api/kinesis_video.html#describe_edge_configuration"},{"doc":"aws_api/kinesis_video","title":"describe_image_generation_configuration","content":"pub fn describe_image_generation_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_video.describe_image_generation_configuration\naws_api/kinesis_video describe_image_generation_configuration","url":"aws_api/kinesis_video.html#describe_image_generation_configuration"},{"doc":"aws_api/kinesis_video","title":"describe_mapped_resource_configuration","content":"pub fn describe_mapped_resource_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_video.describe_mapped_resource_configuration\naws_api/kinesis_video describe_mapped_resource_configuration","url":"aws_api/kinesis_video.html#describe_mapped_resource_configuration"},{"doc":"aws_api/kinesis_video","title":"describe_media_storage_configuration","content":"pub fn describe_media_storage_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_video.describe_media_storage_configuration\naws_api/kinesis_video describe_media_storage_configuration","url":"aws_api/kinesis_video.html#describe_media_storage_configuration"},{"doc":"aws_api/kinesis_video","title":"describe_notification_configuration","content":"pub fn describe_notification_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_video.describe_notification_configuration\naws_api/kinesis_video describe_notification_configuration","url":"aws_api/kinesis_video.html#describe_notification_configuration"},{"doc":"aws_api/kinesis_video","title":"describe_signaling_channel","content":"pub fn describe_signaling_channel(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_video.describe_signaling_channel\naws_api/kinesis_video describe_signaling_channel","url":"aws_api/kinesis_video.html#describe_signaling_channel"},{"doc":"aws_api/kinesis_video","title":"describe_stream","content":"pub fn describe_stream(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_video.describe_stream\naws_api/kinesis_video describe_stream","url":"aws_api/kinesis_video.html#describe_stream"},{"doc":"aws_api/kinesis_video","title":"get_data_endpoint","content":"pub fn get_data_endpoint(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_video.get_data_endpoint\naws_api/kinesis_video get_data_endpoint","url":"aws_api/kinesis_video.html#get_data_endpoint"},{"doc":"aws_api/kinesis_video","title":"get_signaling_channel_endpoint","content":"pub fn get_signaling_channel_endpoint(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_video.get_signaling_channel_endpoint\naws_api/kinesis_video get_signaling_channel_endpoint","url":"aws_api/kinesis_video.html#get_signaling_channel_endpoint"},{"doc":"aws_api/kinesis_video","title":"list_edge_agent_configurations","content":"pub fn list_edge_agent_configurations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_video.list_edge_agent_configurations\naws_api/kinesis_video list_edge_agent_configurations","url":"aws_api/kinesis_video.html#list_edge_agent_configurations"},{"doc":"aws_api/kinesis_video","title":"list_signaling_channels","content":"pub fn list_signaling_channels(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_video.list_signaling_channels\naws_api/kinesis_video list_signaling_channels","url":"aws_api/kinesis_video.html#list_signaling_channels"},{"doc":"aws_api/kinesis_video","title":"list_streams","content":"pub fn list_streams(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_video.list_streams\naws_api/kinesis_video list_streams","url":"aws_api/kinesis_video.html#list_streams"},{"doc":"aws_api/kinesis_video","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_video.list_tags_for_resource\naws_api/kinesis_video list_tags_for_resource","url":"aws_api/kinesis_video.html#list_tags_for_resource"},{"doc":"aws_api/kinesis_video","title":"list_tags_for_stream","content":"pub fn list_tags_for_stream(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_video.list_tags_for_stream\naws_api/kinesis_video list_tags_for_stream","url":"aws_api/kinesis_video.html#list_tags_for_stream"},{"doc":"aws_api/kinesis_video","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/kinesis_video.new\naws_api/kinesis_video new","url":"aws_api/kinesis_video.html#new"},{"doc":"aws_api/kinesis_video","title":"start_edge_configuration_update","content":"pub fn start_edge_configuration_update(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_video.start_edge_configuration_update\naws_api/kinesis_video start_edge_configuration_update","url":"aws_api/kinesis_video.html#start_edge_configuration_update"},{"doc":"aws_api/kinesis_video","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_video.tag_resource\naws_api/kinesis_video tag_resource","url":"aws_api/kinesis_video.html#tag_resource"},{"doc":"aws_api/kinesis_video","title":"tag_stream","content":"pub fn tag_stream(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_video.tag_stream\naws_api/kinesis_video tag_stream","url":"aws_api/kinesis_video.html#tag_stream"},{"doc":"aws_api/kinesis_video","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_video.untag_resource\naws_api/kinesis_video untag_resource","url":"aws_api/kinesis_video.html#untag_resource"},{"doc":"aws_api/kinesis_video","title":"untag_stream","content":"pub fn untag_stream(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_video.untag_stream\naws_api/kinesis_video untag_stream","url":"aws_api/kinesis_video.html#untag_stream"},{"doc":"aws_api/kinesis_video","title":"update_data_retention","content":"pub fn update_data_retention(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_video.update_data_retention\naws_api/kinesis_video update_data_retention","url":"aws_api/kinesis_video.html#update_data_retention"},{"doc":"aws_api/kinesis_video","title":"update_image_generation_configuration","content":"pub fn update_image_generation_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_video.update_image_generation_configuration\naws_api/kinesis_video update_image_generation_configuration","url":"aws_api/kinesis_video.html#update_image_generation_configuration"},{"doc":"aws_api/kinesis_video","title":"update_media_storage_configuration","content":"pub fn update_media_storage_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_video.update_media_storage_configuration\naws_api/kinesis_video update_media_storage_configuration","url":"aws_api/kinesis_video.html#update_media_storage_configuration"},{"doc":"aws_api/kinesis_video","title":"update_notification_configuration","content":"pub fn update_notification_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_video.update_notification_configuration\naws_api/kinesis_video update_notification_configuration","url":"aws_api/kinesis_video.html#update_notification_configuration"},{"doc":"aws_api/kinesis_video","title":"update_signaling_channel","content":"pub fn update_signaling_channel(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_video.update_signaling_channel\naws_api/kinesis_video update_signaling_channel","url":"aws_api/kinesis_video.html#update_signaling_channel"},{"doc":"aws_api/kinesis_video","title":"update_stream","content":"pub fn update_stream(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_video.update_stream\naws_api/kinesis_video update_stream","url":"aws_api/kinesis_video.html#update_stream"},{"doc":"aws_api/kinesis_video","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/kinesis_video.with_custom_endpoint\naws_api/kinesis_video with_custom_endpoint","url":"aws_api/kinesis_video.html#with_custom_endpoint"},{"doc":"aws_api/kinesis_video","title":"aws_api/kinesis_video","content":"","url":"aws_api/kinesis_video.html"},{"doc":"aws_api/kinesis_video_archived_media","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/kinesis_video_archived_media.Client\naws_api/kinesis_video_archived_media Client","url":"aws_api/kinesis_video_archived_media.html#Client"},{"doc":"aws_api/kinesis_video_archived_media","title":"get_clip","content":"pub fn get_clip(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_video_archived_media.get_clip\naws_api/kinesis_video_archived_media get_clip","url":"aws_api/kinesis_video_archived_media.html#get_clip"},{"doc":"aws_api/kinesis_video_archived_media","title":"get_dash_streaming_session_url","content":"pub fn get_dash_streaming_session_url(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_video_archived_media.get_dash_streaming_session_url\naws_api/kinesis_video_archived_media get_dash_streaming_session_url","url":"aws_api/kinesis_video_archived_media.html#get_dash_streaming_session_url"},{"doc":"aws_api/kinesis_video_archived_media","title":"get_hls_streaming_session_url","content":"pub fn get_hls_streaming_session_url(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_video_archived_media.get_hls_streaming_session_url\naws_api/kinesis_video_archived_media get_hls_streaming_session_url","url":"aws_api/kinesis_video_archived_media.html#get_hls_streaming_session_url"},{"doc":"aws_api/kinesis_video_archived_media","title":"get_images","content":"pub fn get_images(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_video_archived_media.get_images\naws_api/kinesis_video_archived_media get_images","url":"aws_api/kinesis_video_archived_media.html#get_images"},{"doc":"aws_api/kinesis_video_archived_media","title":"get_media_for_fragment_list","content":"pub fn get_media_for_fragment_list(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_video_archived_media.get_media_for_fragment_list\naws_api/kinesis_video_archived_media get_media_for_fragment_list","url":"aws_api/kinesis_video_archived_media.html#get_media_for_fragment_list"},{"doc":"aws_api/kinesis_video_archived_media","title":"list_fragments","content":"pub fn list_fragments(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_video_archived_media.list_fragments\naws_api/kinesis_video_archived_media list_fragments","url":"aws_api/kinesis_video_archived_media.html#list_fragments"},{"doc":"aws_api/kinesis_video_archived_media","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/kinesis_video_archived_media.new\naws_api/kinesis_video_archived_media new","url":"aws_api/kinesis_video_archived_media.html#new"},{"doc":"aws_api/kinesis_video_archived_media","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/kinesis_video_archived_media.with_custom_endpoint\naws_api/kinesis_video_archived_media with_custom_endpoint","url":"aws_api/kinesis_video_archived_media.html#with_custom_endpoint"},{"doc":"aws_api/kinesis_video_archived_media","title":"aws_api/kinesis_video_archived_media","content":"","url":"aws_api/kinesis_video_archived_media.html"},{"doc":"aws_api/kinesis_video_media","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/kinesis_video_media.Client\naws_api/kinesis_video_media Client","url":"aws_api/kinesis_video_media.html#Client"},{"doc":"aws_api/kinesis_video_media","title":"get_media","content":"pub fn get_media(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_video_media.get_media\naws_api/kinesis_video_media get_media","url":"aws_api/kinesis_video_media.html#get_media"},{"doc":"aws_api/kinesis_video_media","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/kinesis_video_media.new\naws_api/kinesis_video_media new","url":"aws_api/kinesis_video_media.html#new"},{"doc":"aws_api/kinesis_video_media","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/kinesis_video_media.with_custom_endpoint\naws_api/kinesis_video_media with_custom_endpoint","url":"aws_api/kinesis_video_media.html#with_custom_endpoint"},{"doc":"aws_api/kinesis_video_media","title":"aws_api/kinesis_video_media","content":"","url":"aws_api/kinesis_video_media.html"},{"doc":"aws_api/kinesis_video_signaling","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/kinesis_video_signaling.Client\naws_api/kinesis_video_signaling Client","url":"aws_api/kinesis_video_signaling.html#Client"},{"doc":"aws_api/kinesis_video_signaling","title":"get_ice_server_config","content":"pub fn get_ice_server_config(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_video_signaling.get_ice_server_config\naws_api/kinesis_video_signaling get_ice_server_config","url":"aws_api/kinesis_video_signaling.html#get_ice_server_config"},{"doc":"aws_api/kinesis_video_signaling","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/kinesis_video_signaling.new\naws_api/kinesis_video_signaling new","url":"aws_api/kinesis_video_signaling.html#new"},{"doc":"aws_api/kinesis_video_signaling","title":"send_alexa_offer_to_master","content":"pub fn send_alexa_offer_to_master(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_video_signaling.send_alexa_offer_to_master\naws_api/kinesis_video_signaling send_alexa_offer_to_master","url":"aws_api/kinesis_video_signaling.html#send_alexa_offer_to_master"},{"doc":"aws_api/kinesis_video_signaling","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/kinesis_video_signaling.with_custom_endpoint\naws_api/kinesis_video_signaling with_custom_endpoint","url":"aws_api/kinesis_video_signaling.html#with_custom_endpoint"},{"doc":"aws_api/kinesis_video_signaling","title":"aws_api/kinesis_video_signaling","content":"","url":"aws_api/kinesis_video_signaling.html"},{"doc":"aws_api/kinesis_video_webrtc_storage","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/kinesis_video_webrtc_storage.Client\naws_api/kinesis_video_webrtc_storage Client","url":"aws_api/kinesis_video_webrtc_storage.html#Client"},{"doc":"aws_api/kinesis_video_webrtc_storage","title":"join_storage_session","content":"pub fn join_storage_session(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_video_webrtc_storage.join_storage_session\naws_api/kinesis_video_webrtc_storage join_storage_session","url":"aws_api/kinesis_video_webrtc_storage.html#join_storage_session"},{"doc":"aws_api/kinesis_video_webrtc_storage","title":"join_storage_session_as_viewer","content":"pub fn join_storage_session_as_viewer(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kinesis_video_webrtc_storage.join_storage_session_as_viewer\naws_api/kinesis_video_webrtc_storage join_storage_session_as_viewer","url":"aws_api/kinesis_video_webrtc_storage.html#join_storage_session_as_viewer"},{"doc":"aws_api/kinesis_video_webrtc_storage","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/kinesis_video_webrtc_storage.new\naws_api/kinesis_video_webrtc_storage new","url":"aws_api/kinesis_video_webrtc_storage.html#new"},{"doc":"aws_api/kinesis_video_webrtc_storage","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/kinesis_video_webrtc_storage.with_custom_endpoint\naws_api/kinesis_video_webrtc_storage with_custom_endpoint","url":"aws_api/kinesis_video_webrtc_storage.html#with_custom_endpoint"},{"doc":"aws_api/kinesis_video_webrtc_storage","title":"aws_api/kinesis_video_webrtc_storage","content":"","url":"aws_api/kinesis_video_webrtc_storage.html"},{"doc":"aws_api/kms","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/kms.Client\naws_api/kms Client","url":"aws_api/kms.html#Client"},{"doc":"aws_api/kms","title":"cancel_key_deletion","content":"pub fn cancel_key_deletion(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.cancel_key_deletion\naws_api/kms cancel_key_deletion","url":"aws_api/kms.html#cancel_key_deletion"},{"doc":"aws_api/kms","title":"connect_custom_key_store","content":"pub fn connect_custom_key_store(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.connect_custom_key_store\naws_api/kms connect_custom_key_store","url":"aws_api/kms.html#connect_custom_key_store"},{"doc":"aws_api/kms","title":"create_alias","content":"pub fn create_alias(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.create_alias\naws_api/kms create_alias","url":"aws_api/kms.html#create_alias"},{"doc":"aws_api/kms","title":"create_custom_key_store","content":"pub fn create_custom_key_store(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.create_custom_key_store\naws_api/kms create_custom_key_store","url":"aws_api/kms.html#create_custom_key_store"},{"doc":"aws_api/kms","title":"create_grant","content":"pub fn create_grant(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.create_grant\naws_api/kms create_grant","url":"aws_api/kms.html#create_grant"},{"doc":"aws_api/kms","title":"create_key","content":"pub fn create_key(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.create_key\naws_api/kms create_key","url":"aws_api/kms.html#create_key"},{"doc":"aws_api/kms","title":"decrypt","content":"pub fn decrypt(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.decrypt\naws_api/kms decrypt","url":"aws_api/kms.html#decrypt"},{"doc":"aws_api/kms","title":"delete_alias","content":"pub fn delete_alias(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.delete_alias\naws_api/kms delete_alias","url":"aws_api/kms.html#delete_alias"},{"doc":"aws_api/kms","title":"delete_custom_key_store","content":"pub fn delete_custom_key_store(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.delete_custom_key_store\naws_api/kms delete_custom_key_store","url":"aws_api/kms.html#delete_custom_key_store"},{"doc":"aws_api/kms","title":"delete_imported_key_material","content":"pub fn delete_imported_key_material(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.delete_imported_key_material\naws_api/kms delete_imported_key_material","url":"aws_api/kms.html#delete_imported_key_material"},{"doc":"aws_api/kms","title":"derive_shared_secret","content":"pub fn derive_shared_secret(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.derive_shared_secret\naws_api/kms derive_shared_secret","url":"aws_api/kms.html#derive_shared_secret"},{"doc":"aws_api/kms","title":"describe_custom_key_stores","content":"pub fn describe_custom_key_stores(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.describe_custom_key_stores\naws_api/kms describe_custom_key_stores","url":"aws_api/kms.html#describe_custom_key_stores"},{"doc":"aws_api/kms","title":"describe_key","content":"pub fn describe_key(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.describe_key\naws_api/kms describe_key","url":"aws_api/kms.html#describe_key"},{"doc":"aws_api/kms","title":"disable_key","content":"pub fn disable_key(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.disable_key\naws_api/kms disable_key","url":"aws_api/kms.html#disable_key"},{"doc":"aws_api/kms","title":"disable_key_rotation","content":"pub fn disable_key_rotation(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.disable_key_rotation\naws_api/kms disable_key_rotation","url":"aws_api/kms.html#disable_key_rotation"},{"doc":"aws_api/kms","title":"disconnect_custom_key_store","content":"pub fn disconnect_custom_key_store(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.disconnect_custom_key_store\naws_api/kms disconnect_custom_key_store","url":"aws_api/kms.html#disconnect_custom_key_store"},{"doc":"aws_api/kms","title":"enable_key","content":"pub fn enable_key(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.enable_key\naws_api/kms enable_key","url":"aws_api/kms.html#enable_key"},{"doc":"aws_api/kms","title":"enable_key_rotation","content":"pub fn enable_key_rotation(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.enable_key_rotation\naws_api/kms enable_key_rotation","url":"aws_api/kms.html#enable_key_rotation"},{"doc":"aws_api/kms","title":"encrypt","content":"pub fn encrypt(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.encrypt\naws_api/kms encrypt","url":"aws_api/kms.html#encrypt"},{"doc":"aws_api/kms","title":"generate_data_key","content":"pub fn generate_data_key(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.generate_data_key\naws_api/kms generate_data_key","url":"aws_api/kms.html#generate_data_key"},{"doc":"aws_api/kms","title":"generate_data_key_pair","content":"pub fn generate_data_key_pair(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.generate_data_key_pair\naws_api/kms generate_data_key_pair","url":"aws_api/kms.html#generate_data_key_pair"},{"doc":"aws_api/kms","title":"generate_data_key_pair_without_plaintext","content":"pub fn generate_data_key_pair_without_plaintext(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.generate_data_key_pair_without_plaintext\naws_api/kms generate_data_key_pair_without_plaintext","url":"aws_api/kms.html#generate_data_key_pair_without_plaintext"},{"doc":"aws_api/kms","title":"generate_data_key_without_plaintext","content":"pub fn generate_data_key_without_plaintext(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.generate_data_key_without_plaintext\naws_api/kms generate_data_key_without_plaintext","url":"aws_api/kms.html#generate_data_key_without_plaintext"},{"doc":"aws_api/kms","title":"generate_mac","content":"pub fn generate_mac(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.generate_mac\naws_api/kms generate_mac","url":"aws_api/kms.html#generate_mac"},{"doc":"aws_api/kms","title":"generate_random","content":"pub fn generate_random(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.generate_random\naws_api/kms generate_random","url":"aws_api/kms.html#generate_random"},{"doc":"aws_api/kms","title":"get_key_policy","content":"pub fn get_key_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.get_key_policy\naws_api/kms get_key_policy","url":"aws_api/kms.html#get_key_policy"},{"doc":"aws_api/kms","title":"get_key_rotation_status","content":"pub fn get_key_rotation_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.get_key_rotation_status\naws_api/kms get_key_rotation_status","url":"aws_api/kms.html#get_key_rotation_status"},{"doc":"aws_api/kms","title":"get_parameters_for_import","content":"pub fn get_parameters_for_import(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.get_parameters_for_import\naws_api/kms get_parameters_for_import","url":"aws_api/kms.html#get_parameters_for_import"},{"doc":"aws_api/kms","title":"get_public_key","content":"pub fn get_public_key(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.get_public_key\naws_api/kms get_public_key","url":"aws_api/kms.html#get_public_key"},{"doc":"aws_api/kms","title":"import_key_material","content":"pub fn import_key_material(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.import_key_material\naws_api/kms import_key_material","url":"aws_api/kms.html#import_key_material"},{"doc":"aws_api/kms","title":"list_aliases","content":"pub fn list_aliases(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.list_aliases\naws_api/kms list_aliases","url":"aws_api/kms.html#list_aliases"},{"doc":"aws_api/kms","title":"list_grants","content":"pub fn list_grants(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.list_grants\naws_api/kms list_grants","url":"aws_api/kms.html#list_grants"},{"doc":"aws_api/kms","title":"list_key_policies","content":"pub fn list_key_policies(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.list_key_policies\naws_api/kms list_key_policies","url":"aws_api/kms.html#list_key_policies"},{"doc":"aws_api/kms","title":"list_key_rotations","content":"pub fn list_key_rotations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.list_key_rotations\naws_api/kms list_key_rotations","url":"aws_api/kms.html#list_key_rotations"},{"doc":"aws_api/kms","title":"list_keys","content":"pub fn list_keys(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.list_keys\naws_api/kms list_keys","url":"aws_api/kms.html#list_keys"},{"doc":"aws_api/kms","title":"list_resource_tags","content":"pub fn list_resource_tags(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.list_resource_tags\naws_api/kms list_resource_tags","url":"aws_api/kms.html#list_resource_tags"},{"doc":"aws_api/kms","title":"list_retirable_grants","content":"pub fn list_retirable_grants(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.list_retirable_grants\naws_api/kms list_retirable_grants","url":"aws_api/kms.html#list_retirable_grants"},{"doc":"aws_api/kms","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/kms.new\naws_api/kms new","url":"aws_api/kms.html#new"},{"doc":"aws_api/kms","title":"put_key_policy","content":"pub fn put_key_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.put_key_policy\naws_api/kms put_key_policy","url":"aws_api/kms.html#put_key_policy"},{"doc":"aws_api/kms","title":"re_encrypt","content":"pub fn re_encrypt(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.re_encrypt\naws_api/kms re_encrypt","url":"aws_api/kms.html#re_encrypt"},{"doc":"aws_api/kms","title":"replicate_key","content":"pub fn replicate_key(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.replicate_key\naws_api/kms replicate_key","url":"aws_api/kms.html#replicate_key"},{"doc":"aws_api/kms","title":"retire_grant","content":"pub fn retire_grant(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.retire_grant\naws_api/kms retire_grant","url":"aws_api/kms.html#retire_grant"},{"doc":"aws_api/kms","title":"revoke_grant","content":"pub fn revoke_grant(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.revoke_grant\naws_api/kms revoke_grant","url":"aws_api/kms.html#revoke_grant"},{"doc":"aws_api/kms","title":"rotate_key_on_demand","content":"pub fn rotate_key_on_demand(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.rotate_key_on_demand\naws_api/kms rotate_key_on_demand","url":"aws_api/kms.html#rotate_key_on_demand"},{"doc":"aws_api/kms","title":"schedule_key_deletion","content":"pub fn schedule_key_deletion(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.schedule_key_deletion\naws_api/kms schedule_key_deletion","url":"aws_api/kms.html#schedule_key_deletion"},{"doc":"aws_api/kms","title":"sign","content":"pub fn sign(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.sign\naws_api/kms sign","url":"aws_api/kms.html#sign"},{"doc":"aws_api/kms","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.tag_resource\naws_api/kms tag_resource","url":"aws_api/kms.html#tag_resource"},{"doc":"aws_api/kms","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.untag_resource\naws_api/kms untag_resource","url":"aws_api/kms.html#untag_resource"},{"doc":"aws_api/kms","title":"update_alias","content":"pub fn update_alias(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.update_alias\naws_api/kms update_alias","url":"aws_api/kms.html#update_alias"},{"doc":"aws_api/kms","title":"update_custom_key_store","content":"pub fn update_custom_key_store(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.update_custom_key_store\naws_api/kms update_custom_key_store","url":"aws_api/kms.html#update_custom_key_store"},{"doc":"aws_api/kms","title":"update_key_description","content":"pub fn update_key_description(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.update_key_description\naws_api/kms update_key_description","url":"aws_api/kms.html#update_key_description"},{"doc":"aws_api/kms","title":"update_primary_region","content":"pub fn update_primary_region(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.update_primary_region\naws_api/kms update_primary_region","url":"aws_api/kms.html#update_primary_region"},{"doc":"aws_api/kms","title":"verify","content":"pub fn verify(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.verify\naws_api/kms verify","url":"aws_api/kms.html#verify"},{"doc":"aws_api/kms","title":"verify_mac","content":"pub fn verify_mac(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/kms.verify_mac\naws_api/kms verify_mac","url":"aws_api/kms.html#verify_mac"},{"doc":"aws_api/kms","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/kms.with_custom_endpoint\naws_api/kms with_custom_endpoint","url":"aws_api/kms.html#with_custom_endpoint"},{"doc":"aws_api/kms","title":"aws_api/kms","content":"","url":"aws_api/kms.html"},{"doc":"aws_api/lakeformation","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/lakeformation.Client\naws_api/lakeformation Client","url":"aws_api/lakeformation.html#Client"},{"doc":"aws_api/lakeformation","title":"add_lf_tags_to_resource","content":"pub fn add_lf_tags_to_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.add_lf_tags_to_resource\naws_api/lakeformation add_lf_tags_to_resource","url":"aws_api/lakeformation.html#add_lf_tags_to_resource"},{"doc":"aws_api/lakeformation","title":"assume_decorated_role_with_saml","content":"pub fn assume_decorated_role_with_saml(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.assume_decorated_role_with_saml\naws_api/lakeformation assume_decorated_role_with_saml","url":"aws_api/lakeformation.html#assume_decorated_role_with_saml"},{"doc":"aws_api/lakeformation","title":"batch_grant_permissions","content":"pub fn batch_grant_permissions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.batch_grant_permissions\naws_api/lakeformation batch_grant_permissions","url":"aws_api/lakeformation.html#batch_grant_permissions"},{"doc":"aws_api/lakeformation","title":"batch_revoke_permissions","content":"pub fn batch_revoke_permissions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.batch_revoke_permissions\naws_api/lakeformation batch_revoke_permissions","url":"aws_api/lakeformation.html#batch_revoke_permissions"},{"doc":"aws_api/lakeformation","title":"cancel_transaction","content":"pub fn cancel_transaction(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.cancel_transaction\naws_api/lakeformation cancel_transaction","url":"aws_api/lakeformation.html#cancel_transaction"},{"doc":"aws_api/lakeformation","title":"commit_transaction","content":"pub fn commit_transaction(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.commit_transaction\naws_api/lakeformation commit_transaction","url":"aws_api/lakeformation.html#commit_transaction"},{"doc":"aws_api/lakeformation","title":"create_data_cells_filter","content":"pub fn create_data_cells_filter(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.create_data_cells_filter\naws_api/lakeformation create_data_cells_filter","url":"aws_api/lakeformation.html#create_data_cells_filter"},{"doc":"aws_api/lakeformation","title":"create_lake_formation_identity_center_configuration","content":"pub fn create_lake_formation_identity_center_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.create_lake_formation_identity_center_configuration\naws_api/lakeformation create_lake_formation_identity_center_configuration","url":"aws_api/lakeformation.html#create_lake_formation_identity_center_configuration"},{"doc":"aws_api/lakeformation","title":"create_lake_formation_opt_in","content":"pub fn create_lake_formation_opt_in(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.create_lake_formation_opt_in\naws_api/lakeformation create_lake_formation_opt_in","url":"aws_api/lakeformation.html#create_lake_formation_opt_in"},{"doc":"aws_api/lakeformation","title":"create_lf_tag","content":"pub fn create_lf_tag(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.create_lf_tag\naws_api/lakeformation create_lf_tag","url":"aws_api/lakeformation.html#create_lf_tag"},{"doc":"aws_api/lakeformation","title":"delete_data_cells_filter","content":"pub fn delete_data_cells_filter(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.delete_data_cells_filter\naws_api/lakeformation delete_data_cells_filter","url":"aws_api/lakeformation.html#delete_data_cells_filter"},{"doc":"aws_api/lakeformation","title":"delete_lake_formation_identity_center_configuration","content":"pub fn delete_lake_formation_identity_center_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.delete_lake_formation_identity_center_configuration\naws_api/lakeformation delete_lake_formation_identity_center_configuration","url":"aws_api/lakeformation.html#delete_lake_formation_identity_center_configuration"},{"doc":"aws_api/lakeformation","title":"delete_lake_formation_opt_in","content":"pub fn delete_lake_formation_opt_in(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.delete_lake_formation_opt_in\naws_api/lakeformation delete_lake_formation_opt_in","url":"aws_api/lakeformation.html#delete_lake_formation_opt_in"},{"doc":"aws_api/lakeformation","title":"delete_lf_tag","content":"pub fn delete_lf_tag(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.delete_lf_tag\naws_api/lakeformation delete_lf_tag","url":"aws_api/lakeformation.html#delete_lf_tag"},{"doc":"aws_api/lakeformation","title":"delete_objects_on_cancel","content":"pub fn delete_objects_on_cancel(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.delete_objects_on_cancel\naws_api/lakeformation delete_objects_on_cancel","url":"aws_api/lakeformation.html#delete_objects_on_cancel"},{"doc":"aws_api/lakeformation","title":"deregister_resource","content":"pub fn deregister_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.deregister_resource\naws_api/lakeformation deregister_resource","url":"aws_api/lakeformation.html#deregister_resource"},{"doc":"aws_api/lakeformation","title":"describe_lake_formation_identity_center_configuration","content":"pub fn describe_lake_formation_identity_center_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.describe_lake_formation_identity_center_configuration\naws_api/lakeformation describe_lake_formation_identity_center_configuration","url":"aws_api/lakeformation.html#describe_lake_formation_identity_center_configuration"},{"doc":"aws_api/lakeformation","title":"describe_resource","content":"pub fn describe_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.describe_resource\naws_api/lakeformation describe_resource","url":"aws_api/lakeformation.html#describe_resource"},{"doc":"aws_api/lakeformation","title":"describe_transaction","content":"pub fn describe_transaction(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.describe_transaction\naws_api/lakeformation describe_transaction","url":"aws_api/lakeformation.html#describe_transaction"},{"doc":"aws_api/lakeformation","title":"extend_transaction","content":"pub fn extend_transaction(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.extend_transaction\naws_api/lakeformation extend_transaction","url":"aws_api/lakeformation.html#extend_transaction"},{"doc":"aws_api/lakeformation","title":"get_data_cells_filter","content":"pub fn get_data_cells_filter(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.get_data_cells_filter\naws_api/lakeformation get_data_cells_filter","url":"aws_api/lakeformation.html#get_data_cells_filter"},{"doc":"aws_api/lakeformation","title":"get_data_lake_principal","content":"pub fn get_data_lake_principal(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.get_data_lake_principal\naws_api/lakeformation get_data_lake_principal","url":"aws_api/lakeformation.html#get_data_lake_principal"},{"doc":"aws_api/lakeformation","title":"get_data_lake_settings","content":"pub fn get_data_lake_settings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.get_data_lake_settings\naws_api/lakeformation get_data_lake_settings","url":"aws_api/lakeformation.html#get_data_lake_settings"},{"doc":"aws_api/lakeformation","title":"get_effective_permissions_for_path","content":"pub fn get_effective_permissions_for_path(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.get_effective_permissions_for_path\naws_api/lakeformation get_effective_permissions_for_path","url":"aws_api/lakeformation.html#get_effective_permissions_for_path"},{"doc":"aws_api/lakeformation","title":"get_lf_tag","content":"pub fn get_lf_tag(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.get_lf_tag\naws_api/lakeformation get_lf_tag","url":"aws_api/lakeformation.html#get_lf_tag"},{"doc":"aws_api/lakeformation","title":"get_query_state","content":"pub fn get_query_state(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.get_query_state\naws_api/lakeformation get_query_state","url":"aws_api/lakeformation.html#get_query_state"},{"doc":"aws_api/lakeformation","title":"get_query_statistics","content":"pub fn get_query_statistics(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.get_query_statistics\naws_api/lakeformation get_query_statistics","url":"aws_api/lakeformation.html#get_query_statistics"},{"doc":"aws_api/lakeformation","title":"get_resource_lf_tags","content":"pub fn get_resource_lf_tags(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.get_resource_lf_tags\naws_api/lakeformation get_resource_lf_tags","url":"aws_api/lakeformation.html#get_resource_lf_tags"},{"doc":"aws_api/lakeformation","title":"get_table_objects","content":"pub fn get_table_objects(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.get_table_objects\naws_api/lakeformation get_table_objects","url":"aws_api/lakeformation.html#get_table_objects"},{"doc":"aws_api/lakeformation","title":"get_temporary_glue_partition_credentials","content":"pub fn get_temporary_glue_partition_credentials(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.get_temporary_glue_partition_credentials\naws_api/lakeformation get_temporary_glue_partition_credentials","url":"aws_api/lakeformation.html#get_temporary_glue_partition_credentials"},{"doc":"aws_api/lakeformation","title":"get_temporary_glue_table_credentials","content":"pub fn get_temporary_glue_table_credentials(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.get_temporary_glue_table_credentials\naws_api/lakeformation get_temporary_glue_table_credentials","url":"aws_api/lakeformation.html#get_temporary_glue_table_credentials"},{"doc":"aws_api/lakeformation","title":"get_work_unit_results","content":"pub fn get_work_unit_results(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.get_work_unit_results\naws_api/lakeformation get_work_unit_results","url":"aws_api/lakeformation.html#get_work_unit_results"},{"doc":"aws_api/lakeformation","title":"get_work_units","content":"pub fn get_work_units(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.get_work_units\naws_api/lakeformation get_work_units","url":"aws_api/lakeformation.html#get_work_units"},{"doc":"aws_api/lakeformation","title":"grant_permissions","content":"pub fn grant_permissions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.grant_permissions\naws_api/lakeformation grant_permissions","url":"aws_api/lakeformation.html#grant_permissions"},{"doc":"aws_api/lakeformation","title":"list_data_cells_filter","content":"pub fn list_data_cells_filter(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.list_data_cells_filter\naws_api/lakeformation list_data_cells_filter","url":"aws_api/lakeformation.html#list_data_cells_filter"},{"doc":"aws_api/lakeformation","title":"list_lake_formation_opt_ins","content":"pub fn list_lake_formation_opt_ins(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.list_lake_formation_opt_ins\naws_api/lakeformation list_lake_formation_opt_ins","url":"aws_api/lakeformation.html#list_lake_formation_opt_ins"},{"doc":"aws_api/lakeformation","title":"list_lf_tags","content":"pub fn list_lf_tags(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.list_lf_tags\naws_api/lakeformation list_lf_tags","url":"aws_api/lakeformation.html#list_lf_tags"},{"doc":"aws_api/lakeformation","title":"list_permissions","content":"pub fn list_permissions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.list_permissions\naws_api/lakeformation list_permissions","url":"aws_api/lakeformation.html#list_permissions"},{"doc":"aws_api/lakeformation","title":"list_resources","content":"pub fn list_resources(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.list_resources\naws_api/lakeformation list_resources","url":"aws_api/lakeformation.html#list_resources"},{"doc":"aws_api/lakeformation","title":"list_table_storage_optimizers","content":"pub fn list_table_storage_optimizers(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.list_table_storage_optimizers\naws_api/lakeformation list_table_storage_optimizers","url":"aws_api/lakeformation.html#list_table_storage_optimizers"},{"doc":"aws_api/lakeformation","title":"list_transactions","content":"pub fn list_transactions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.list_transactions\naws_api/lakeformation list_transactions","url":"aws_api/lakeformation.html#list_transactions"},{"doc":"aws_api/lakeformation","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/lakeformation.new\naws_api/lakeformation new","url":"aws_api/lakeformation.html#new"},{"doc":"aws_api/lakeformation","title":"put_data_lake_settings","content":"pub fn put_data_lake_settings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.put_data_lake_settings\naws_api/lakeformation put_data_lake_settings","url":"aws_api/lakeformation.html#put_data_lake_settings"},{"doc":"aws_api/lakeformation","title":"register_resource","content":"pub fn register_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.register_resource\naws_api/lakeformation register_resource","url":"aws_api/lakeformation.html#register_resource"},{"doc":"aws_api/lakeformation","title":"remove_lf_tags_from_resource","content":"pub fn remove_lf_tags_from_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.remove_lf_tags_from_resource\naws_api/lakeformation remove_lf_tags_from_resource","url":"aws_api/lakeformation.html#remove_lf_tags_from_resource"},{"doc":"aws_api/lakeformation","title":"revoke_permissions","content":"pub fn revoke_permissions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.revoke_permissions\naws_api/lakeformation revoke_permissions","url":"aws_api/lakeformation.html#revoke_permissions"},{"doc":"aws_api/lakeformation","title":"search_databases_by_lf_tags","content":"pub fn search_databases_by_lf_tags(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.search_databases_by_lf_tags\naws_api/lakeformation search_databases_by_lf_tags","url":"aws_api/lakeformation.html#search_databases_by_lf_tags"},{"doc":"aws_api/lakeformation","title":"search_tables_by_lf_tags","content":"pub fn search_tables_by_lf_tags(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.search_tables_by_lf_tags\naws_api/lakeformation search_tables_by_lf_tags","url":"aws_api/lakeformation.html#search_tables_by_lf_tags"},{"doc":"aws_api/lakeformation","title":"start_query_planning","content":"pub fn start_query_planning(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.start_query_planning\naws_api/lakeformation start_query_planning","url":"aws_api/lakeformation.html#start_query_planning"},{"doc":"aws_api/lakeformation","title":"start_transaction","content":"pub fn start_transaction(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.start_transaction\naws_api/lakeformation start_transaction","url":"aws_api/lakeformation.html#start_transaction"},{"doc":"aws_api/lakeformation","title":"update_data_cells_filter","content":"pub fn update_data_cells_filter(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.update_data_cells_filter\naws_api/lakeformation update_data_cells_filter","url":"aws_api/lakeformation.html#update_data_cells_filter"},{"doc":"aws_api/lakeformation","title":"update_lake_formation_identity_center_configuration","content":"pub fn update_lake_formation_identity_center_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.update_lake_formation_identity_center_configuration\naws_api/lakeformation update_lake_formation_identity_center_configuration","url":"aws_api/lakeformation.html#update_lake_formation_identity_center_configuration"},{"doc":"aws_api/lakeformation","title":"update_lf_tag","content":"pub fn update_lf_tag(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.update_lf_tag\naws_api/lakeformation update_lf_tag","url":"aws_api/lakeformation.html#update_lf_tag"},{"doc":"aws_api/lakeformation","title":"update_resource","content":"pub fn update_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.update_resource\naws_api/lakeformation update_resource","url":"aws_api/lakeformation.html#update_resource"},{"doc":"aws_api/lakeformation","title":"update_table_objects","content":"pub fn update_table_objects(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.update_table_objects\naws_api/lakeformation update_table_objects","url":"aws_api/lakeformation.html#update_table_objects"},{"doc":"aws_api/lakeformation","title":"update_table_storage_optimizer","content":"pub fn update_table_storage_optimizer(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lakeformation.update_table_storage_optimizer\naws_api/lakeformation update_table_storage_optimizer","url":"aws_api/lakeformation.html#update_table_storage_optimizer"},{"doc":"aws_api/lakeformation","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/lakeformation.with_custom_endpoint\naws_api/lakeformation with_custom_endpoint","url":"aws_api/lakeformation.html#with_custom_endpoint"},{"doc":"aws_api/lakeformation","title":"aws_api/lakeformation","content":"","url":"aws_api/lakeformation.html"},{"doc":"aws_api/lambda","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/lambda.Client\naws_api/lambda Client","url":"aws_api/lambda.html#Client"},{"doc":"aws_api/lambda","title":"add_layer_version_permission","content":"pub fn add_layer_version_permission(\n  client: Client,\n  layer_name: String,\n  version_number: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.add_layer_version_permission\naws_api/lambda add_layer_version_permission","url":"aws_api/lambda.html#add_layer_version_permission"},{"doc":"aws_api/lambda","title":"add_permission","content":"pub fn add_permission(\n  client: Client,\n  function_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.add_permission\naws_api/lambda add_permission","url":"aws_api/lambda.html#add_permission"},{"doc":"aws_api/lambda","title":"create_alias","content":"pub fn create_alias(\n  client: Client,\n  function_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.create_alias\naws_api/lambda create_alias","url":"aws_api/lambda.html#create_alias"},{"doc":"aws_api/lambda","title":"create_code_signing_config","content":"pub fn create_code_signing_config(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.create_code_signing_config\naws_api/lambda create_code_signing_config","url":"aws_api/lambda.html#create_code_signing_config"},{"doc":"aws_api/lambda","title":"create_event_source_mapping","content":"pub fn create_event_source_mapping(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.create_event_source_mapping\naws_api/lambda create_event_source_mapping","url":"aws_api/lambda.html#create_event_source_mapping"},{"doc":"aws_api/lambda","title":"create_function","content":"pub fn create_function(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.create_function\naws_api/lambda create_function","url":"aws_api/lambda.html#create_function"},{"doc":"aws_api/lambda","title":"create_function_url_config","content":"pub fn create_function_url_config(\n  client: Client,\n  function_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.create_function_url_config\naws_api/lambda create_function_url_config","url":"aws_api/lambda.html#create_function_url_config"},{"doc":"aws_api/lambda","title":"delete_alias","content":"pub fn delete_alias(\n  client: Client,\n  function_name: String,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.delete_alias\naws_api/lambda delete_alias","url":"aws_api/lambda.html#delete_alias"},{"doc":"aws_api/lambda","title":"delete_code_signing_config","content":"pub fn delete_code_signing_config(\n  client: Client,\n  code_signing_config_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.delete_code_signing_config\naws_api/lambda delete_code_signing_config","url":"aws_api/lambda.html#delete_code_signing_config"},{"doc":"aws_api/lambda","title":"delete_event_source_mapping","content":"pub fn delete_event_source_mapping(\n  client: Client,\n  uuid: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.delete_event_source_mapping\naws_api/lambda delete_event_source_mapping","url":"aws_api/lambda.html#delete_event_source_mapping"},{"doc":"aws_api/lambda","title":"delete_function","content":"pub fn delete_function(\n  client: Client,\n  function_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.delete_function\naws_api/lambda delete_function","url":"aws_api/lambda.html#delete_function"},{"doc":"aws_api/lambda","title":"delete_function_code_signing_config","content":"pub fn delete_function_code_signing_config(\n  client: Client,\n  function_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.delete_function_code_signing_config\naws_api/lambda delete_function_code_signing_config","url":"aws_api/lambda.html#delete_function_code_signing_config"},{"doc":"aws_api/lambda","title":"delete_function_concurrency","content":"pub fn delete_function_concurrency(\n  client: Client,\n  function_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.delete_function_concurrency\naws_api/lambda delete_function_concurrency","url":"aws_api/lambda.html#delete_function_concurrency"},{"doc":"aws_api/lambda","title":"delete_function_event_invoke_config","content":"pub fn delete_function_event_invoke_config(\n  client: Client,\n  function_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.delete_function_event_invoke_config\naws_api/lambda delete_function_event_invoke_config","url":"aws_api/lambda.html#delete_function_event_invoke_config"},{"doc":"aws_api/lambda","title":"delete_function_url_config","content":"pub fn delete_function_url_config(\n  client: Client,\n  function_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.delete_function_url_config\naws_api/lambda delete_function_url_config","url":"aws_api/lambda.html#delete_function_url_config"},{"doc":"aws_api/lambda","title":"delete_layer_version","content":"pub fn delete_layer_version(\n  client: Client,\n  layer_name: String,\n  version_number: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.delete_layer_version\naws_api/lambda delete_layer_version","url":"aws_api/lambda.html#delete_layer_version"},{"doc":"aws_api/lambda","title":"delete_provisioned_concurrency_config","content":"pub fn delete_provisioned_concurrency_config(\n  client: Client,\n  function_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.delete_provisioned_concurrency_config\naws_api/lambda delete_provisioned_concurrency_config","url":"aws_api/lambda.html#delete_provisioned_concurrency_config"},{"doc":"aws_api/lambda","title":"get_account_settings","content":"pub fn get_account_settings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.get_account_settings\naws_api/lambda get_account_settings","url":"aws_api/lambda.html#get_account_settings"},{"doc":"aws_api/lambda","title":"get_alias","content":"pub fn get_alias(\n  client: Client,\n  function_name: String,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.get_alias\naws_api/lambda get_alias","url":"aws_api/lambda.html#get_alias"},{"doc":"aws_api/lambda","title":"get_code_signing_config","content":"pub fn get_code_signing_config(\n  client: Client,\n  code_signing_config_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.get_code_signing_config\naws_api/lambda get_code_signing_config","url":"aws_api/lambda.html#get_code_signing_config"},{"doc":"aws_api/lambda","title":"get_event_source_mapping","content":"pub fn get_event_source_mapping(\n  client: Client,\n  uuid: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.get_event_source_mapping\naws_api/lambda get_event_source_mapping","url":"aws_api/lambda.html#get_event_source_mapping"},{"doc":"aws_api/lambda","title":"get_function","content":"pub fn get_function(\n  client: Client,\n  function_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.get_function\naws_api/lambda get_function","url":"aws_api/lambda.html#get_function"},{"doc":"aws_api/lambda","title":"get_function_code_signing_config","content":"pub fn get_function_code_signing_config(\n  client: Client,\n  function_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.get_function_code_signing_config\naws_api/lambda get_function_code_signing_config","url":"aws_api/lambda.html#get_function_code_signing_config"},{"doc":"aws_api/lambda","title":"get_function_concurrency","content":"pub fn get_function_concurrency(\n  client: Client,\n  function_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.get_function_concurrency\naws_api/lambda get_function_concurrency","url":"aws_api/lambda.html#get_function_concurrency"},{"doc":"aws_api/lambda","title":"get_function_configuration","content":"pub fn get_function_configuration(\n  client: Client,\n  function_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.get_function_configuration\naws_api/lambda get_function_configuration","url":"aws_api/lambda.html#get_function_configuration"},{"doc":"aws_api/lambda","title":"get_function_event_invoke_config","content":"pub fn get_function_event_invoke_config(\n  client: Client,\n  function_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.get_function_event_invoke_config\naws_api/lambda get_function_event_invoke_config","url":"aws_api/lambda.html#get_function_event_invoke_config"},{"doc":"aws_api/lambda","title":"get_function_url_config","content":"pub fn get_function_url_config(\n  client: Client,\n  function_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.get_function_url_config\naws_api/lambda get_function_url_config","url":"aws_api/lambda.html#get_function_url_config"},{"doc":"aws_api/lambda","title":"get_layer_version","content":"pub fn get_layer_version(\n  client: Client,\n  layer_name: String,\n  version_number: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.get_layer_version\naws_api/lambda get_layer_version","url":"aws_api/lambda.html#get_layer_version"},{"doc":"aws_api/lambda","title":"get_layer_version_by_arn","content":"pub fn get_layer_version_by_arn(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.get_layer_version_by_arn\naws_api/lambda get_layer_version_by_arn","url":"aws_api/lambda.html#get_layer_version_by_arn"},{"doc":"aws_api/lambda","title":"get_layer_version_policy","content":"pub fn get_layer_version_policy(\n  client: Client,\n  layer_name: String,\n  version_number: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.get_layer_version_policy\naws_api/lambda get_layer_version_policy","url":"aws_api/lambda.html#get_layer_version_policy"},{"doc":"aws_api/lambda","title":"get_policy","content":"pub fn get_policy(\n  client: Client,\n  function_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.get_policy\naws_api/lambda get_policy","url":"aws_api/lambda.html#get_policy"},{"doc":"aws_api/lambda","title":"get_provisioned_concurrency_config","content":"pub fn get_provisioned_concurrency_config(\n  client: Client,\n  function_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.get_provisioned_concurrency_config\naws_api/lambda get_provisioned_concurrency_config","url":"aws_api/lambda.html#get_provisioned_concurrency_config"},{"doc":"aws_api/lambda","title":"get_runtime_management_config","content":"pub fn get_runtime_management_config(\n  client: Client,\n  function_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.get_runtime_management_config\naws_api/lambda get_runtime_management_config","url":"aws_api/lambda.html#get_runtime_management_config"},{"doc":"aws_api/lambda","title":"invoke","content":"pub fn invoke(\n  client: Client,\n  function_name: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.invoke\naws_api/lambda invoke","url":"aws_api/lambda.html#invoke"},{"doc":"aws_api/lambda","title":"invoke_async","content":"pub fn invoke_async(\n  client: Client,\n  function_name: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.invoke_async\naws_api/lambda invoke_async","url":"aws_api/lambda.html#invoke_async"},{"doc":"aws_api/lambda","title":"invoke_with_response_stream","content":"pub fn invoke_with_response_stream(\n  client: Client,\n  function_name: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.invoke_with_response_stream\naws_api/lambda invoke_with_response_stream","url":"aws_api/lambda.html#invoke_with_response_stream"},{"doc":"aws_api/lambda","title":"list_aliases","content":"pub fn list_aliases(\n  client: Client,\n  function_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.list_aliases\naws_api/lambda list_aliases","url":"aws_api/lambda.html#list_aliases"},{"doc":"aws_api/lambda","title":"list_code_signing_configs","content":"pub fn list_code_signing_configs(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.list_code_signing_configs\naws_api/lambda list_code_signing_configs","url":"aws_api/lambda.html#list_code_signing_configs"},{"doc":"aws_api/lambda","title":"list_event_source_mappings","content":"pub fn list_event_source_mappings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.list_event_source_mappings\naws_api/lambda list_event_source_mappings","url":"aws_api/lambda.html#list_event_source_mappings"},{"doc":"aws_api/lambda","title":"list_function_event_invoke_configs","content":"pub fn list_function_event_invoke_configs(\n  client: Client,\n  function_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.list_function_event_invoke_configs\naws_api/lambda list_function_event_invoke_configs","url":"aws_api/lambda.html#list_function_event_invoke_configs"},{"doc":"aws_api/lambda","title":"list_function_url_configs","content":"pub fn list_function_url_configs(\n  client: Client,\n  function_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.list_function_url_configs\naws_api/lambda list_function_url_configs","url":"aws_api/lambda.html#list_function_url_configs"},{"doc":"aws_api/lambda","title":"list_functions","content":"pub fn list_functions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.list_functions\naws_api/lambda list_functions","url":"aws_api/lambda.html#list_functions"},{"doc":"aws_api/lambda","title":"list_functions_by_code_signing_config","content":"pub fn list_functions_by_code_signing_config(\n  client: Client,\n  code_signing_config_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.list_functions_by_code_signing_config\naws_api/lambda list_functions_by_code_signing_config","url":"aws_api/lambda.html#list_functions_by_code_signing_config"},{"doc":"aws_api/lambda","title":"list_layer_versions","content":"pub fn list_layer_versions(\n  client: Client,\n  layer_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.list_layer_versions\naws_api/lambda list_layer_versions","url":"aws_api/lambda.html#list_layer_versions"},{"doc":"aws_api/lambda","title":"list_layers","content":"pub fn list_layers(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.list_layers\naws_api/lambda list_layers","url":"aws_api/lambda.html#list_layers"},{"doc":"aws_api/lambda","title":"list_provisioned_concurrency_configs","content":"pub fn list_provisioned_concurrency_configs(\n  client: Client,\n  function_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.list_provisioned_concurrency_configs\naws_api/lambda list_provisioned_concurrency_configs","url":"aws_api/lambda.html#list_provisioned_concurrency_configs"},{"doc":"aws_api/lambda","title":"list_tags","content":"pub fn list_tags(\n  client: Client,\n  resource: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.list_tags\naws_api/lambda list_tags","url":"aws_api/lambda.html#list_tags"},{"doc":"aws_api/lambda","title":"list_versions_by_function","content":"pub fn list_versions_by_function(\n  client: Client,\n  function_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.list_versions_by_function\naws_api/lambda list_versions_by_function","url":"aws_api/lambda.html#list_versions_by_function"},{"doc":"aws_api/lambda","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/lambda.new\naws_api/lambda new","url":"aws_api/lambda.html#new"},{"doc":"aws_api/lambda","title":"publish_layer_version","content":"pub fn publish_layer_version(\n  client: Client,\n  layer_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.publish_layer_version\naws_api/lambda publish_layer_version","url":"aws_api/lambda.html#publish_layer_version"},{"doc":"aws_api/lambda","title":"publish_version","content":"pub fn publish_version(\n  client: Client,\n  function_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.publish_version\naws_api/lambda publish_version","url":"aws_api/lambda.html#publish_version"},{"doc":"aws_api/lambda","title":"put_function_code_signing_config","content":"pub fn put_function_code_signing_config(\n  client: Client,\n  function_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.put_function_code_signing_config\naws_api/lambda put_function_code_signing_config","url":"aws_api/lambda.html#put_function_code_signing_config"},{"doc":"aws_api/lambda","title":"put_function_concurrency","content":"pub fn put_function_concurrency(\n  client: Client,\n  function_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.put_function_concurrency\naws_api/lambda put_function_concurrency","url":"aws_api/lambda.html#put_function_concurrency"},{"doc":"aws_api/lambda","title":"put_function_event_invoke_config","content":"pub fn put_function_event_invoke_config(\n  client: Client,\n  function_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.put_function_event_invoke_config\naws_api/lambda put_function_event_invoke_config","url":"aws_api/lambda.html#put_function_event_invoke_config"},{"doc":"aws_api/lambda","title":"put_provisioned_concurrency_config","content":"pub fn put_provisioned_concurrency_config(\n  client: Client,\n  function_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.put_provisioned_concurrency_config\naws_api/lambda put_provisioned_concurrency_config","url":"aws_api/lambda.html#put_provisioned_concurrency_config"},{"doc":"aws_api/lambda","title":"put_runtime_management_config","content":"pub fn put_runtime_management_config(\n  client: Client,\n  function_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.put_runtime_management_config\naws_api/lambda put_runtime_management_config","url":"aws_api/lambda.html#put_runtime_management_config"},{"doc":"aws_api/lambda","title":"remove_layer_version_permission","content":"pub fn remove_layer_version_permission(\n  client: Client,\n  layer_name: String,\n  version_number: String,\n  statement_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.remove_layer_version_permission\naws_api/lambda remove_layer_version_permission","url":"aws_api/lambda.html#remove_layer_version_permission"},{"doc":"aws_api/lambda","title":"remove_permission","content":"pub fn remove_permission(\n  client: Client,\n  function_name: String,\n  statement_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.remove_permission\naws_api/lambda remove_permission","url":"aws_api/lambda.html#remove_permission"},{"doc":"aws_api/lambda","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.tag_resource\naws_api/lambda tag_resource","url":"aws_api/lambda.html#tag_resource"},{"doc":"aws_api/lambda","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.untag_resource\naws_api/lambda untag_resource","url":"aws_api/lambda.html#untag_resource"},{"doc":"aws_api/lambda","title":"update_alias","content":"pub fn update_alias(\n  client: Client,\n  function_name: String,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.update_alias\naws_api/lambda update_alias","url":"aws_api/lambda.html#update_alias"},{"doc":"aws_api/lambda","title":"update_code_signing_config","content":"pub fn update_code_signing_config(\n  client: Client,\n  code_signing_config_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.update_code_signing_config\naws_api/lambda update_code_signing_config","url":"aws_api/lambda.html#update_code_signing_config"},{"doc":"aws_api/lambda","title":"update_event_source_mapping","content":"pub fn update_event_source_mapping(\n  client: Client,\n  uuid: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.update_event_source_mapping\naws_api/lambda update_event_source_mapping","url":"aws_api/lambda.html#update_event_source_mapping"},{"doc":"aws_api/lambda","title":"update_function_code","content":"pub fn update_function_code(\n  client: Client,\n  function_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.update_function_code\naws_api/lambda update_function_code","url":"aws_api/lambda.html#update_function_code"},{"doc":"aws_api/lambda","title":"update_function_configuration","content":"pub fn update_function_configuration(\n  client: Client,\n  function_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.update_function_configuration\naws_api/lambda update_function_configuration","url":"aws_api/lambda.html#update_function_configuration"},{"doc":"aws_api/lambda","title":"update_function_event_invoke_config","content":"pub fn update_function_event_invoke_config(\n  client: Client,\n  function_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.update_function_event_invoke_config\naws_api/lambda update_function_event_invoke_config","url":"aws_api/lambda.html#update_function_event_invoke_config"},{"doc":"aws_api/lambda","title":"update_function_url_config","content":"pub fn update_function_url_config(\n  client: Client,\n  function_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lambda.update_function_url_config\naws_api/lambda update_function_url_config","url":"aws_api/lambda.html#update_function_url_config"},{"doc":"aws_api/lambda","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/lambda.with_custom_endpoint\naws_api/lambda with_custom_endpoint","url":"aws_api/lambda.html#with_custom_endpoint"},{"doc":"aws_api/lambda","title":"aws_api/lambda","content":"","url":"aws_api/lambda.html"},{"doc":"aws_api/lex_model_building_service","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/lex_model_building_service.Client\naws_api/lex_model_building_service Client","url":"aws_api/lex_model_building_service.html#Client"},{"doc":"aws_api/lex_model_building_service","title":"create_bot_version","content":"pub fn create_bot_version(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_model_building_service.create_bot_version\naws_api/lex_model_building_service create_bot_version","url":"aws_api/lex_model_building_service.html#create_bot_version"},{"doc":"aws_api/lex_model_building_service","title":"create_intent_version","content":"pub fn create_intent_version(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_model_building_service.create_intent_version\naws_api/lex_model_building_service create_intent_version","url":"aws_api/lex_model_building_service.html#create_intent_version"},{"doc":"aws_api/lex_model_building_service","title":"create_slot_type_version","content":"pub fn create_slot_type_version(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_model_building_service.create_slot_type_version\naws_api/lex_model_building_service create_slot_type_version","url":"aws_api/lex_model_building_service.html#create_slot_type_version"},{"doc":"aws_api/lex_model_building_service","title":"delete_bot","content":"pub fn delete_bot(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_model_building_service.delete_bot\naws_api/lex_model_building_service delete_bot","url":"aws_api/lex_model_building_service.html#delete_bot"},{"doc":"aws_api/lex_model_building_service","title":"delete_bot_alias","content":"pub fn delete_bot_alias(\n  client: Client,\n  bot_name: String,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_model_building_service.delete_bot_alias\naws_api/lex_model_building_service delete_bot_alias","url":"aws_api/lex_model_building_service.html#delete_bot_alias"},{"doc":"aws_api/lex_model_building_service","title":"delete_bot_channel_association","content":"pub fn delete_bot_channel_association(\n  client: Client,\n  bot_name: String,\n  bot_alias: String,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_model_building_service.delete_bot_channel_association\naws_api/lex_model_building_service delete_bot_channel_association","url":"aws_api/lex_model_building_service.html#delete_bot_channel_association"},{"doc":"aws_api/lex_model_building_service","title":"delete_bot_version","content":"pub fn delete_bot_version(\n  client: Client,\n  name: String,\n  version: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_model_building_service.delete_bot_version\naws_api/lex_model_building_service delete_bot_version","url":"aws_api/lex_model_building_service.html#delete_bot_version"},{"doc":"aws_api/lex_model_building_service","title":"delete_intent","content":"pub fn delete_intent(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_model_building_service.delete_intent\naws_api/lex_model_building_service delete_intent","url":"aws_api/lex_model_building_service.html#delete_intent"},{"doc":"aws_api/lex_model_building_service","title":"delete_intent_version","content":"pub fn delete_intent_version(\n  client: Client,\n  name: String,\n  version: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_model_building_service.delete_intent_version\naws_api/lex_model_building_service delete_intent_version","url":"aws_api/lex_model_building_service.html#delete_intent_version"},{"doc":"aws_api/lex_model_building_service","title":"delete_slot_type","content":"pub fn delete_slot_type(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_model_building_service.delete_slot_type\naws_api/lex_model_building_service delete_slot_type","url":"aws_api/lex_model_building_service.html#delete_slot_type"},{"doc":"aws_api/lex_model_building_service","title":"delete_slot_type_version","content":"pub fn delete_slot_type_version(\n  client: Client,\n  name: String,\n  version: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_model_building_service.delete_slot_type_version\naws_api/lex_model_building_service delete_slot_type_version","url":"aws_api/lex_model_building_service.html#delete_slot_type_version"},{"doc":"aws_api/lex_model_building_service","title":"delete_utterances","content":"pub fn delete_utterances(\n  client: Client,\n  bot_name: String,\n  user_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_model_building_service.delete_utterances\naws_api/lex_model_building_service delete_utterances","url":"aws_api/lex_model_building_service.html#delete_utterances"},{"doc":"aws_api/lex_model_building_service","title":"get_bot","content":"pub fn get_bot(\n  client: Client,\n  name: String,\n  version_or_alias: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_model_building_service.get_bot\naws_api/lex_model_building_service get_bot","url":"aws_api/lex_model_building_service.html#get_bot"},{"doc":"aws_api/lex_model_building_service","title":"get_bot_alias","content":"pub fn get_bot_alias(\n  client: Client,\n  bot_name: String,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_model_building_service.get_bot_alias\naws_api/lex_model_building_service get_bot_alias","url":"aws_api/lex_model_building_service.html#get_bot_alias"},{"doc":"aws_api/lex_model_building_service","title":"get_bot_aliases","content":"pub fn get_bot_aliases(\n  client: Client,\n  bot_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_model_building_service.get_bot_aliases\naws_api/lex_model_building_service get_bot_aliases","url":"aws_api/lex_model_building_service.html#get_bot_aliases"},{"doc":"aws_api/lex_model_building_service","title":"get_bot_channel_association","content":"pub fn get_bot_channel_association(\n  client: Client,\n  bot_name: String,\n  bot_alias: String,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_model_building_service.get_bot_channel_association\naws_api/lex_model_building_service get_bot_channel_association","url":"aws_api/lex_model_building_service.html#get_bot_channel_association"},{"doc":"aws_api/lex_model_building_service","title":"get_bot_channel_associations","content":"pub fn get_bot_channel_associations(\n  client: Client,\n  bot_name: String,\n  bot_alias: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_model_building_service.get_bot_channel_associations\naws_api/lex_model_building_service get_bot_channel_associations","url":"aws_api/lex_model_building_service.html#get_bot_channel_associations"},{"doc":"aws_api/lex_model_building_service","title":"get_bot_versions","content":"pub fn get_bot_versions(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_model_building_service.get_bot_versions\naws_api/lex_model_building_service get_bot_versions","url":"aws_api/lex_model_building_service.html#get_bot_versions"},{"doc":"aws_api/lex_model_building_service","title":"get_bots","content":"pub fn get_bots(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_model_building_service.get_bots\naws_api/lex_model_building_service get_bots","url":"aws_api/lex_model_building_service.html#get_bots"},{"doc":"aws_api/lex_model_building_service","title":"get_builtin_intent","content":"pub fn get_builtin_intent(\n  client: Client,\n  signature: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_model_building_service.get_builtin_intent\naws_api/lex_model_building_service get_builtin_intent","url":"aws_api/lex_model_building_service.html#get_builtin_intent"},{"doc":"aws_api/lex_model_building_service","title":"get_builtin_intents","content":"pub fn get_builtin_intents(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_model_building_service.get_builtin_intents\naws_api/lex_model_building_service get_builtin_intents","url":"aws_api/lex_model_building_service.html#get_builtin_intents"},{"doc":"aws_api/lex_model_building_service","title":"get_builtin_slot_types","content":"pub fn get_builtin_slot_types(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_model_building_service.get_builtin_slot_types\naws_api/lex_model_building_service get_builtin_slot_types","url":"aws_api/lex_model_building_service.html#get_builtin_slot_types"},{"doc":"aws_api/lex_model_building_service","title":"get_export","content":"pub fn get_export(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_model_building_service.get_export\naws_api/lex_model_building_service get_export","url":"aws_api/lex_model_building_service.html#get_export"},{"doc":"aws_api/lex_model_building_service","title":"get_import","content":"pub fn get_import(\n  client: Client,\n  import_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_model_building_service.get_import\naws_api/lex_model_building_service get_import","url":"aws_api/lex_model_building_service.html#get_import"},{"doc":"aws_api/lex_model_building_service","title":"get_intent","content":"pub fn get_intent(\n  client: Client,\n  name: String,\n  version: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_model_building_service.get_intent\naws_api/lex_model_building_service get_intent","url":"aws_api/lex_model_building_service.html#get_intent"},{"doc":"aws_api/lex_model_building_service","title":"get_intent_versions","content":"pub fn get_intent_versions(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_model_building_service.get_intent_versions\naws_api/lex_model_building_service get_intent_versions","url":"aws_api/lex_model_building_service.html#get_intent_versions"},{"doc":"aws_api/lex_model_building_service","title":"get_intents","content":"pub fn get_intents(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_model_building_service.get_intents\naws_api/lex_model_building_service get_intents","url":"aws_api/lex_model_building_service.html#get_intents"},{"doc":"aws_api/lex_model_building_service","title":"get_migration","content":"pub fn get_migration(\n  client: Client,\n  migration_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_model_building_service.get_migration\naws_api/lex_model_building_service get_migration","url":"aws_api/lex_model_building_service.html#get_migration"},{"doc":"aws_api/lex_model_building_service","title":"get_migrations","content":"pub fn get_migrations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_model_building_service.get_migrations\naws_api/lex_model_building_service get_migrations","url":"aws_api/lex_model_building_service.html#get_migrations"},{"doc":"aws_api/lex_model_building_service","title":"get_slot_type","content":"pub fn get_slot_type(\n  client: Client,\n  name: String,\n  version: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_model_building_service.get_slot_type\naws_api/lex_model_building_service get_slot_type","url":"aws_api/lex_model_building_service.html#get_slot_type"},{"doc":"aws_api/lex_model_building_service","title":"get_slot_type_versions","content":"pub fn get_slot_type_versions(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_model_building_service.get_slot_type_versions\naws_api/lex_model_building_service get_slot_type_versions","url":"aws_api/lex_model_building_service.html#get_slot_type_versions"},{"doc":"aws_api/lex_model_building_service","title":"get_slot_types","content":"pub fn get_slot_types(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_model_building_service.get_slot_types\naws_api/lex_model_building_service get_slot_types","url":"aws_api/lex_model_building_service.html#get_slot_types"},{"doc":"aws_api/lex_model_building_service","title":"get_utterances_view","content":"pub fn get_utterances_view(\n  client: Client,\n  bot_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_model_building_service.get_utterances_view\naws_api/lex_model_building_service get_utterances_view","url":"aws_api/lex_model_building_service.html#get_utterances_view"},{"doc":"aws_api/lex_model_building_service","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_model_building_service.list_tags_for_resource\naws_api/lex_model_building_service list_tags_for_resource","url":"aws_api/lex_model_building_service.html#list_tags_for_resource"},{"doc":"aws_api/lex_model_building_service","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/lex_model_building_service.new\naws_api/lex_model_building_service new","url":"aws_api/lex_model_building_service.html#new"},{"doc":"aws_api/lex_model_building_service","title":"put_bot","content":"pub fn put_bot(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_model_building_service.put_bot\naws_api/lex_model_building_service put_bot","url":"aws_api/lex_model_building_service.html#put_bot"},{"doc":"aws_api/lex_model_building_service","title":"put_bot_alias","content":"pub fn put_bot_alias(\n  client: Client,\n  bot_name: String,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_model_building_service.put_bot_alias\naws_api/lex_model_building_service put_bot_alias","url":"aws_api/lex_model_building_service.html#put_bot_alias"},{"doc":"aws_api/lex_model_building_service","title":"put_intent","content":"pub fn put_intent(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_model_building_service.put_intent\naws_api/lex_model_building_service put_intent","url":"aws_api/lex_model_building_service.html#put_intent"},{"doc":"aws_api/lex_model_building_service","title":"put_slot_type","content":"pub fn put_slot_type(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_model_building_service.put_slot_type\naws_api/lex_model_building_service put_slot_type","url":"aws_api/lex_model_building_service.html#put_slot_type"},{"doc":"aws_api/lex_model_building_service","title":"start_import","content":"pub fn start_import(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_model_building_service.start_import\naws_api/lex_model_building_service start_import","url":"aws_api/lex_model_building_service.html#start_import"},{"doc":"aws_api/lex_model_building_service","title":"start_migration","content":"pub fn start_migration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_model_building_service.start_migration\naws_api/lex_model_building_service start_migration","url":"aws_api/lex_model_building_service.html#start_migration"},{"doc":"aws_api/lex_model_building_service","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_model_building_service.tag_resource\naws_api/lex_model_building_service tag_resource","url":"aws_api/lex_model_building_service.html#tag_resource"},{"doc":"aws_api/lex_model_building_service","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_model_building_service.untag_resource\naws_api/lex_model_building_service untag_resource","url":"aws_api/lex_model_building_service.html#untag_resource"},{"doc":"aws_api/lex_model_building_service","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/lex_model_building_service.with_custom_endpoint\naws_api/lex_model_building_service with_custom_endpoint","url":"aws_api/lex_model_building_service.html#with_custom_endpoint"},{"doc":"aws_api/lex_model_building_service","title":"aws_api/lex_model_building_service","content":"","url":"aws_api/lex_model_building_service.html"},{"doc":"aws_api/lex_models_v2","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/lex_models_v2.Client\naws_api/lex_models_v2 Client","url":"aws_api/lex_models_v2.html#Client"},{"doc":"aws_api/lex_models_v2","title":"batch_create_custom_vocabulary_item","content":"pub fn batch_create_custom_vocabulary_item(\n  client: Client,\n  bot_id: String,\n  bot_version: String,\n  locale_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.batch_create_custom_vocabulary_item\naws_api/lex_models_v2 batch_create_custom_vocabulary_item","url":"aws_api/lex_models_v2.html#batch_create_custom_vocabulary_item"},{"doc":"aws_api/lex_models_v2","title":"batch_delete_custom_vocabulary_item","content":"pub fn batch_delete_custom_vocabulary_item(\n  client: Client,\n  bot_id: String,\n  bot_version: String,\n  locale_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.batch_delete_custom_vocabulary_item\naws_api/lex_models_v2 batch_delete_custom_vocabulary_item","url":"aws_api/lex_models_v2.html#batch_delete_custom_vocabulary_item"},{"doc":"aws_api/lex_models_v2","title":"batch_update_custom_vocabulary_item","content":"pub fn batch_update_custom_vocabulary_item(\n  client: Client,\n  bot_id: String,\n  bot_version: String,\n  locale_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.batch_update_custom_vocabulary_item\naws_api/lex_models_v2 batch_update_custom_vocabulary_item","url":"aws_api/lex_models_v2.html#batch_update_custom_vocabulary_item"},{"doc":"aws_api/lex_models_v2","title":"build_bot_locale","content":"pub fn build_bot_locale(\n  client: Client,\n  bot_id: String,\n  bot_version: String,\n  locale_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.build_bot_locale\naws_api/lex_models_v2 build_bot_locale","url":"aws_api/lex_models_v2.html#build_bot_locale"},{"doc":"aws_api/lex_models_v2","title":"create_bot","content":"pub fn create_bot(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.create_bot\naws_api/lex_models_v2 create_bot","url":"aws_api/lex_models_v2.html#create_bot"},{"doc":"aws_api/lex_models_v2","title":"create_bot_alias","content":"pub fn create_bot_alias(\n  client: Client,\n  bot_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.create_bot_alias\naws_api/lex_models_v2 create_bot_alias","url":"aws_api/lex_models_v2.html#create_bot_alias"},{"doc":"aws_api/lex_models_v2","title":"create_bot_locale","content":"pub fn create_bot_locale(\n  client: Client,\n  bot_id: String,\n  bot_version: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.create_bot_locale\naws_api/lex_models_v2 create_bot_locale","url":"aws_api/lex_models_v2.html#create_bot_locale"},{"doc":"aws_api/lex_models_v2","title":"create_bot_replica","content":"pub fn create_bot_replica(\n  client: Client,\n  bot_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.create_bot_replica\naws_api/lex_models_v2 create_bot_replica","url":"aws_api/lex_models_v2.html#create_bot_replica"},{"doc":"aws_api/lex_models_v2","title":"create_bot_version","content":"pub fn create_bot_version(\n  client: Client,\n  bot_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.create_bot_version\naws_api/lex_models_v2 create_bot_version","url":"aws_api/lex_models_v2.html#create_bot_version"},{"doc":"aws_api/lex_models_v2","title":"create_export","content":"pub fn create_export(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.create_export\naws_api/lex_models_v2 create_export","url":"aws_api/lex_models_v2.html#create_export"},{"doc":"aws_api/lex_models_v2","title":"create_intent","content":"pub fn create_intent(\n  client: Client,\n  bot_id: String,\n  bot_version: String,\n  locale_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.create_intent\naws_api/lex_models_v2 create_intent","url":"aws_api/lex_models_v2.html#create_intent"},{"doc":"aws_api/lex_models_v2","title":"create_resource_policy","content":"pub fn create_resource_policy(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.create_resource_policy\naws_api/lex_models_v2 create_resource_policy","url":"aws_api/lex_models_v2.html#create_resource_policy"},{"doc":"aws_api/lex_models_v2","title":"create_resource_policy_statement","content":"pub fn create_resource_policy_statement(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.create_resource_policy_statement\naws_api/lex_models_v2 create_resource_policy_statement","url":"aws_api/lex_models_v2.html#create_resource_policy_statement"},{"doc":"aws_api/lex_models_v2","title":"create_slot","content":"pub fn create_slot(\n  client: Client,\n  bot_id: String,\n  bot_version: String,\n  locale_id: String,\n  intent_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.create_slot\naws_api/lex_models_v2 create_slot","url":"aws_api/lex_models_v2.html#create_slot"},{"doc":"aws_api/lex_models_v2","title":"create_slot_type","content":"pub fn create_slot_type(\n  client: Client,\n  bot_id: String,\n  bot_version: String,\n  locale_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.create_slot_type\naws_api/lex_models_v2 create_slot_type","url":"aws_api/lex_models_v2.html#create_slot_type"},{"doc":"aws_api/lex_models_v2","title":"create_test_set_discrepancy_report","content":"pub fn create_test_set_discrepancy_report(\n  client: Client,\n  test_set_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.create_test_set_discrepancy_report\naws_api/lex_models_v2 create_test_set_discrepancy_report","url":"aws_api/lex_models_v2.html#create_test_set_discrepancy_report"},{"doc":"aws_api/lex_models_v2","title":"create_upload_url","content":"pub fn create_upload_url(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.create_upload_url\naws_api/lex_models_v2 create_upload_url","url":"aws_api/lex_models_v2.html#create_upload_url"},{"doc":"aws_api/lex_models_v2","title":"delete_bot","content":"pub fn delete_bot(\n  client: Client,\n  bot_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.delete_bot\naws_api/lex_models_v2 delete_bot","url":"aws_api/lex_models_v2.html#delete_bot"},{"doc":"aws_api/lex_models_v2","title":"delete_bot_alias","content":"pub fn delete_bot_alias(\n  client: Client,\n  bot_id: String,\n  bot_alias_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.delete_bot_alias\naws_api/lex_models_v2 delete_bot_alias","url":"aws_api/lex_models_v2.html#delete_bot_alias"},{"doc":"aws_api/lex_models_v2","title":"delete_bot_locale","content":"pub fn delete_bot_locale(\n  client: Client,\n  bot_id: String,\n  bot_version: String,\n  locale_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.delete_bot_locale\naws_api/lex_models_v2 delete_bot_locale","url":"aws_api/lex_models_v2.html#delete_bot_locale"},{"doc":"aws_api/lex_models_v2","title":"delete_bot_replica","content":"pub fn delete_bot_replica(\n  client: Client,\n  bot_id: String,\n  replica_region: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.delete_bot_replica\naws_api/lex_models_v2 delete_bot_replica","url":"aws_api/lex_models_v2.html#delete_bot_replica"},{"doc":"aws_api/lex_models_v2","title":"delete_bot_version","content":"pub fn delete_bot_version(\n  client: Client,\n  bot_id: String,\n  bot_version: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.delete_bot_version\naws_api/lex_models_v2 delete_bot_version","url":"aws_api/lex_models_v2.html#delete_bot_version"},{"doc":"aws_api/lex_models_v2","title":"delete_custom_vocabulary","content":"pub fn delete_custom_vocabulary(\n  client: Client,\n  bot_id: String,\n  bot_version: String,\n  locale_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.delete_custom_vocabulary\naws_api/lex_models_v2 delete_custom_vocabulary","url":"aws_api/lex_models_v2.html#delete_custom_vocabulary"},{"doc":"aws_api/lex_models_v2","title":"delete_export","content":"pub fn delete_export(\n  client: Client,\n  export_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.delete_export\naws_api/lex_models_v2 delete_export","url":"aws_api/lex_models_v2.html#delete_export"},{"doc":"aws_api/lex_models_v2","title":"delete_import","content":"pub fn delete_import(\n  client: Client,\n  import_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.delete_import\naws_api/lex_models_v2 delete_import","url":"aws_api/lex_models_v2.html#delete_import"},{"doc":"aws_api/lex_models_v2","title":"delete_intent","content":"pub fn delete_intent(\n  client: Client,\n  bot_id: String,\n  bot_version: String,\n  locale_id: String,\n  intent_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.delete_intent\naws_api/lex_models_v2 delete_intent","url":"aws_api/lex_models_v2.html#delete_intent"},{"doc":"aws_api/lex_models_v2","title":"delete_resource_policy","content":"pub fn delete_resource_policy(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.delete_resource_policy\naws_api/lex_models_v2 delete_resource_policy","url":"aws_api/lex_models_v2.html#delete_resource_policy"},{"doc":"aws_api/lex_models_v2","title":"delete_resource_policy_statement","content":"pub fn delete_resource_policy_statement(\n  client: Client,\n  resource_arn: String,\n  statement_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.delete_resource_policy_statement\naws_api/lex_models_v2 delete_resource_policy_statement","url":"aws_api/lex_models_v2.html#delete_resource_policy_statement"},{"doc":"aws_api/lex_models_v2","title":"delete_slot","content":"pub fn delete_slot(\n  client: Client,\n  bot_id: String,\n  bot_version: String,\n  locale_id: String,\n  intent_id: String,\n  slot_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.delete_slot\naws_api/lex_models_v2 delete_slot","url":"aws_api/lex_models_v2.html#delete_slot"},{"doc":"aws_api/lex_models_v2","title":"delete_slot_type","content":"pub fn delete_slot_type(\n  client: Client,\n  bot_id: String,\n  bot_version: String,\n  locale_id: String,\n  slot_type_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.delete_slot_type\naws_api/lex_models_v2 delete_slot_type","url":"aws_api/lex_models_v2.html#delete_slot_type"},{"doc":"aws_api/lex_models_v2","title":"delete_test_set","content":"pub fn delete_test_set(\n  client: Client,\n  test_set_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.delete_test_set\naws_api/lex_models_v2 delete_test_set","url":"aws_api/lex_models_v2.html#delete_test_set"},{"doc":"aws_api/lex_models_v2","title":"delete_utterances","content":"pub fn delete_utterances(\n  client: Client,\n  bot_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.delete_utterances\naws_api/lex_models_v2 delete_utterances","url":"aws_api/lex_models_v2.html#delete_utterances"},{"doc":"aws_api/lex_models_v2","title":"describe_bot","content":"pub fn describe_bot(\n  client: Client,\n  bot_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.describe_bot\naws_api/lex_models_v2 describe_bot","url":"aws_api/lex_models_v2.html#describe_bot"},{"doc":"aws_api/lex_models_v2","title":"describe_bot_alias","content":"pub fn describe_bot_alias(\n  client: Client,\n  bot_id: String,\n  bot_alias_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.describe_bot_alias\naws_api/lex_models_v2 describe_bot_alias","url":"aws_api/lex_models_v2.html#describe_bot_alias"},{"doc":"aws_api/lex_models_v2","title":"describe_bot_locale","content":"pub fn describe_bot_locale(\n  client: Client,\n  bot_id: String,\n  bot_version: String,\n  locale_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.describe_bot_locale\naws_api/lex_models_v2 describe_bot_locale","url":"aws_api/lex_models_v2.html#describe_bot_locale"},{"doc":"aws_api/lex_models_v2","title":"describe_bot_recommendation","content":"pub fn describe_bot_recommendation(\n  client: Client,\n  bot_id: String,\n  bot_version: String,\n  locale_id: String,\n  bot_recommendation_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.describe_bot_recommendation\naws_api/lex_models_v2 describe_bot_recommendation","url":"aws_api/lex_models_v2.html#describe_bot_recommendation"},{"doc":"aws_api/lex_models_v2","title":"describe_bot_replica","content":"pub fn describe_bot_replica(\n  client: Client,\n  bot_id: String,\n  replica_region: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.describe_bot_replica\naws_api/lex_models_v2 describe_bot_replica","url":"aws_api/lex_models_v2.html#describe_bot_replica"},{"doc":"aws_api/lex_models_v2","title":"describe_bot_resource_generation","content":"pub fn describe_bot_resource_generation(\n  client: Client,\n  bot_id: String,\n  bot_version: String,\n  locale_id: String,\n  generation_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.describe_bot_resource_generation\naws_api/lex_models_v2 describe_bot_resource_generation","url":"aws_api/lex_models_v2.html#describe_bot_resource_generation"},{"doc":"aws_api/lex_models_v2","title":"describe_bot_version","content":"pub fn describe_bot_version(\n  client: Client,\n  bot_id: String,\n  bot_version: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.describe_bot_version\naws_api/lex_models_v2 describe_bot_version","url":"aws_api/lex_models_v2.html#describe_bot_version"},{"doc":"aws_api/lex_models_v2","title":"describe_custom_vocabulary_metadata","content":"pub fn describe_custom_vocabulary_metadata(\n  client: Client,\n  bot_id: String,\n  bot_version: String,\n  locale_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.describe_custom_vocabulary_metadata\naws_api/lex_models_v2 describe_custom_vocabulary_metadata","url":"aws_api/lex_models_v2.html#describe_custom_vocabulary_metadata"},{"doc":"aws_api/lex_models_v2","title":"describe_export","content":"pub fn describe_export(\n  client: Client,\n  export_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.describe_export\naws_api/lex_models_v2 describe_export","url":"aws_api/lex_models_v2.html#describe_export"},{"doc":"aws_api/lex_models_v2","title":"describe_import","content":"pub fn describe_import(\n  client: Client,\n  import_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.describe_import\naws_api/lex_models_v2 describe_import","url":"aws_api/lex_models_v2.html#describe_import"},{"doc":"aws_api/lex_models_v2","title":"describe_intent","content":"pub fn describe_intent(\n  client: Client,\n  bot_id: String,\n  bot_version: String,\n  locale_id: String,\n  intent_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.describe_intent\naws_api/lex_models_v2 describe_intent","url":"aws_api/lex_models_v2.html#describe_intent"},{"doc":"aws_api/lex_models_v2","title":"describe_resource_policy","content":"pub fn describe_resource_policy(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.describe_resource_policy\naws_api/lex_models_v2 describe_resource_policy","url":"aws_api/lex_models_v2.html#describe_resource_policy"},{"doc":"aws_api/lex_models_v2","title":"describe_slot","content":"pub fn describe_slot(\n  client: Client,\n  bot_id: String,\n  bot_version: String,\n  locale_id: String,\n  intent_id: String,\n  slot_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.describe_slot\naws_api/lex_models_v2 describe_slot","url":"aws_api/lex_models_v2.html#describe_slot"},{"doc":"aws_api/lex_models_v2","title":"describe_slot_type","content":"pub fn describe_slot_type(\n  client: Client,\n  bot_id: String,\n  bot_version: String,\n  locale_id: String,\n  slot_type_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.describe_slot_type\naws_api/lex_models_v2 describe_slot_type","url":"aws_api/lex_models_v2.html#describe_slot_type"},{"doc":"aws_api/lex_models_v2","title":"describe_test_execution","content":"pub fn describe_test_execution(\n  client: Client,\n  test_execution_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.describe_test_execution\naws_api/lex_models_v2 describe_test_execution","url":"aws_api/lex_models_v2.html#describe_test_execution"},{"doc":"aws_api/lex_models_v2","title":"describe_test_set","content":"pub fn describe_test_set(\n  client: Client,\n  test_set_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.describe_test_set\naws_api/lex_models_v2 describe_test_set","url":"aws_api/lex_models_v2.html#describe_test_set"},{"doc":"aws_api/lex_models_v2","title":"describe_test_set_discrepancy_report","content":"pub fn describe_test_set_discrepancy_report(\n  client: Client,\n  test_set_discrepancy_report_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.describe_test_set_discrepancy_report\naws_api/lex_models_v2 describe_test_set_discrepancy_report","url":"aws_api/lex_models_v2.html#describe_test_set_discrepancy_report"},{"doc":"aws_api/lex_models_v2","title":"describe_test_set_generation","content":"pub fn describe_test_set_generation(\n  client: Client,\n  test_set_generation_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.describe_test_set_generation\naws_api/lex_models_v2 describe_test_set_generation","url":"aws_api/lex_models_v2.html#describe_test_set_generation"},{"doc":"aws_api/lex_models_v2","title":"generate_bot_element","content":"pub fn generate_bot_element(\n  client: Client,\n  bot_id: String,\n  bot_version: String,\n  locale_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.generate_bot_element\naws_api/lex_models_v2 generate_bot_element","url":"aws_api/lex_models_v2.html#generate_bot_element"},{"doc":"aws_api/lex_models_v2","title":"get_test_execution_artifacts_url","content":"pub fn get_test_execution_artifacts_url(\n  client: Client,\n  test_execution_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.get_test_execution_artifacts_url\naws_api/lex_models_v2 get_test_execution_artifacts_url","url":"aws_api/lex_models_v2.html#get_test_execution_artifacts_url"},{"doc":"aws_api/lex_models_v2","title":"list_aggregated_utterances","content":"pub fn list_aggregated_utterances(\n  client: Client,\n  bot_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.list_aggregated_utterances\naws_api/lex_models_v2 list_aggregated_utterances","url":"aws_api/lex_models_v2.html#list_aggregated_utterances"},{"doc":"aws_api/lex_models_v2","title":"list_bot_alias_replicas","content":"pub fn list_bot_alias_replicas(\n  client: Client,\n  bot_id: String,\n  replica_region: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.list_bot_alias_replicas\naws_api/lex_models_v2 list_bot_alias_replicas","url":"aws_api/lex_models_v2.html#list_bot_alias_replicas"},{"doc":"aws_api/lex_models_v2","title":"list_bot_aliases","content":"pub fn list_bot_aliases(\n  client: Client,\n  bot_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.list_bot_aliases\naws_api/lex_models_v2 list_bot_aliases","url":"aws_api/lex_models_v2.html#list_bot_aliases"},{"doc":"aws_api/lex_models_v2","title":"list_bot_locales","content":"pub fn list_bot_locales(\n  client: Client,\n  bot_id: String,\n  bot_version: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.list_bot_locales\naws_api/lex_models_v2 list_bot_locales","url":"aws_api/lex_models_v2.html#list_bot_locales"},{"doc":"aws_api/lex_models_v2","title":"list_bot_recommendations","content":"pub fn list_bot_recommendations(\n  client: Client,\n  bot_id: String,\n  bot_version: String,\n  locale_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.list_bot_recommendations\naws_api/lex_models_v2 list_bot_recommendations","url":"aws_api/lex_models_v2.html#list_bot_recommendations"},{"doc":"aws_api/lex_models_v2","title":"list_bot_replicas","content":"pub fn list_bot_replicas(\n  client: Client,\n  bot_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.list_bot_replicas\naws_api/lex_models_v2 list_bot_replicas","url":"aws_api/lex_models_v2.html#list_bot_replicas"},{"doc":"aws_api/lex_models_v2","title":"list_bot_resource_generations","content":"pub fn list_bot_resource_generations(\n  client: Client,\n  bot_id: String,\n  bot_version: String,\n  locale_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.list_bot_resource_generations\naws_api/lex_models_v2 list_bot_resource_generations","url":"aws_api/lex_models_v2.html#list_bot_resource_generations"},{"doc":"aws_api/lex_models_v2","title":"list_bot_version_replicas","content":"pub fn list_bot_version_replicas(\n  client: Client,\n  bot_id: String,\n  replica_region: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.list_bot_version_replicas\naws_api/lex_models_v2 list_bot_version_replicas","url":"aws_api/lex_models_v2.html#list_bot_version_replicas"},{"doc":"aws_api/lex_models_v2","title":"list_bot_versions","content":"pub fn list_bot_versions(\n  client: Client,\n  bot_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.list_bot_versions\naws_api/lex_models_v2 list_bot_versions","url":"aws_api/lex_models_v2.html#list_bot_versions"},{"doc":"aws_api/lex_models_v2","title":"list_bots","content":"pub fn list_bots(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.list_bots\naws_api/lex_models_v2 list_bots","url":"aws_api/lex_models_v2.html#list_bots"},{"doc":"aws_api/lex_models_v2","title":"list_built_in_intents","content":"pub fn list_built_in_intents(\n  client: Client,\n  locale_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.list_built_in_intents\naws_api/lex_models_v2 list_built_in_intents","url":"aws_api/lex_models_v2.html#list_built_in_intents"},{"doc":"aws_api/lex_models_v2","title":"list_built_in_slot_types","content":"pub fn list_built_in_slot_types(\n  client: Client,\n  locale_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.list_built_in_slot_types\naws_api/lex_models_v2 list_built_in_slot_types","url":"aws_api/lex_models_v2.html#list_built_in_slot_types"},{"doc":"aws_api/lex_models_v2","title":"list_custom_vocabulary_items","content":"pub fn list_custom_vocabulary_items(\n  client: Client,\n  bot_id: String,\n  bot_version: String,\n  locale_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.list_custom_vocabulary_items\naws_api/lex_models_v2 list_custom_vocabulary_items","url":"aws_api/lex_models_v2.html#list_custom_vocabulary_items"},{"doc":"aws_api/lex_models_v2","title":"list_exports","content":"pub fn list_exports(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.list_exports\naws_api/lex_models_v2 list_exports","url":"aws_api/lex_models_v2.html#list_exports"},{"doc":"aws_api/lex_models_v2","title":"list_imports","content":"pub fn list_imports(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.list_imports\naws_api/lex_models_v2 list_imports","url":"aws_api/lex_models_v2.html#list_imports"},{"doc":"aws_api/lex_models_v2","title":"list_intent_metrics","content":"pub fn list_intent_metrics(\n  client: Client,\n  bot_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.list_intent_metrics\naws_api/lex_models_v2 list_intent_metrics","url":"aws_api/lex_models_v2.html#list_intent_metrics"},{"doc":"aws_api/lex_models_v2","title":"list_intent_paths","content":"pub fn list_intent_paths(\n  client: Client,\n  bot_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.list_intent_paths\naws_api/lex_models_v2 list_intent_paths","url":"aws_api/lex_models_v2.html#list_intent_paths"},{"doc":"aws_api/lex_models_v2","title":"list_intent_stage_metrics","content":"pub fn list_intent_stage_metrics(\n  client: Client,\n  bot_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.list_intent_stage_metrics\naws_api/lex_models_v2 list_intent_stage_metrics","url":"aws_api/lex_models_v2.html#list_intent_stage_metrics"},{"doc":"aws_api/lex_models_v2","title":"list_intents","content":"pub fn list_intents(\n  client: Client,\n  bot_id: String,\n  bot_version: String,\n  locale_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.list_intents\naws_api/lex_models_v2 list_intents","url":"aws_api/lex_models_v2.html#list_intents"},{"doc":"aws_api/lex_models_v2","title":"list_recommended_intents","content":"pub fn list_recommended_intents(\n  client: Client,\n  bot_id: String,\n  bot_version: String,\n  locale_id: String,\n  bot_recommendation_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.list_recommended_intents\naws_api/lex_models_v2 list_recommended_intents","url":"aws_api/lex_models_v2.html#list_recommended_intents"},{"doc":"aws_api/lex_models_v2","title":"list_session_analytics_data","content":"pub fn list_session_analytics_data(\n  client: Client,\n  bot_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.list_session_analytics_data\naws_api/lex_models_v2 list_session_analytics_data","url":"aws_api/lex_models_v2.html#list_session_analytics_data"},{"doc":"aws_api/lex_models_v2","title":"list_session_metrics","content":"pub fn list_session_metrics(\n  client: Client,\n  bot_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.list_session_metrics\naws_api/lex_models_v2 list_session_metrics","url":"aws_api/lex_models_v2.html#list_session_metrics"},{"doc":"aws_api/lex_models_v2","title":"list_slot_types","content":"pub fn list_slot_types(\n  client: Client,\n  bot_id: String,\n  bot_version: String,\n  locale_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.list_slot_types\naws_api/lex_models_v2 list_slot_types","url":"aws_api/lex_models_v2.html#list_slot_types"},{"doc":"aws_api/lex_models_v2","title":"list_slots","content":"pub fn list_slots(\n  client: Client,\n  bot_id: String,\n  bot_version: String,\n  locale_id: String,\n  intent_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.list_slots\naws_api/lex_models_v2 list_slots","url":"aws_api/lex_models_v2.html#list_slots"},{"doc":"aws_api/lex_models_v2","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.list_tags_for_resource\naws_api/lex_models_v2 list_tags_for_resource","url":"aws_api/lex_models_v2.html#list_tags_for_resource"},{"doc":"aws_api/lex_models_v2","title":"list_test_execution_result_items","content":"pub fn list_test_execution_result_items(\n  client: Client,\n  test_execution_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.list_test_execution_result_items\naws_api/lex_models_v2 list_test_execution_result_items","url":"aws_api/lex_models_v2.html#list_test_execution_result_items"},{"doc":"aws_api/lex_models_v2","title":"list_test_executions","content":"pub fn list_test_executions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.list_test_executions\naws_api/lex_models_v2 list_test_executions","url":"aws_api/lex_models_v2.html#list_test_executions"},{"doc":"aws_api/lex_models_v2","title":"list_test_set_records","content":"pub fn list_test_set_records(\n  client: Client,\n  test_set_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.list_test_set_records\naws_api/lex_models_v2 list_test_set_records","url":"aws_api/lex_models_v2.html#list_test_set_records"},{"doc":"aws_api/lex_models_v2","title":"list_test_sets","content":"pub fn list_test_sets(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.list_test_sets\naws_api/lex_models_v2 list_test_sets","url":"aws_api/lex_models_v2.html#list_test_sets"},{"doc":"aws_api/lex_models_v2","title":"list_utterance_analytics_data","content":"pub fn list_utterance_analytics_data(\n  client: Client,\n  bot_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.list_utterance_analytics_data\naws_api/lex_models_v2 list_utterance_analytics_data","url":"aws_api/lex_models_v2.html#list_utterance_analytics_data"},{"doc":"aws_api/lex_models_v2","title":"list_utterance_metrics","content":"pub fn list_utterance_metrics(\n  client: Client,\n  bot_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.list_utterance_metrics\naws_api/lex_models_v2 list_utterance_metrics","url":"aws_api/lex_models_v2.html#list_utterance_metrics"},{"doc":"aws_api/lex_models_v2","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/lex_models_v2.new\naws_api/lex_models_v2 new","url":"aws_api/lex_models_v2.html#new"},{"doc":"aws_api/lex_models_v2","title":"search_associated_transcripts","content":"pub fn search_associated_transcripts(\n  client: Client,\n  bot_id: String,\n  bot_version: String,\n  locale_id: String,\n  bot_recommendation_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.search_associated_transcripts\naws_api/lex_models_v2 search_associated_transcripts","url":"aws_api/lex_models_v2.html#search_associated_transcripts"},{"doc":"aws_api/lex_models_v2","title":"start_bot_recommendation","content":"pub fn start_bot_recommendation(\n  client: Client,\n  bot_id: String,\n  bot_version: String,\n  locale_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.start_bot_recommendation\naws_api/lex_models_v2 start_bot_recommendation","url":"aws_api/lex_models_v2.html#start_bot_recommendation"},{"doc":"aws_api/lex_models_v2","title":"start_bot_resource_generation","content":"pub fn start_bot_resource_generation(\n  client: Client,\n  bot_id: String,\n  bot_version: String,\n  locale_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.start_bot_resource_generation\naws_api/lex_models_v2 start_bot_resource_generation","url":"aws_api/lex_models_v2.html#start_bot_resource_generation"},{"doc":"aws_api/lex_models_v2","title":"start_import","content":"pub fn start_import(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.start_import\naws_api/lex_models_v2 start_import","url":"aws_api/lex_models_v2.html#start_import"},{"doc":"aws_api/lex_models_v2","title":"start_test_execution","content":"pub fn start_test_execution(\n  client: Client,\n  test_set_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.start_test_execution\naws_api/lex_models_v2 start_test_execution","url":"aws_api/lex_models_v2.html#start_test_execution"},{"doc":"aws_api/lex_models_v2","title":"start_test_set_generation","content":"pub fn start_test_set_generation(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.start_test_set_generation\naws_api/lex_models_v2 start_test_set_generation","url":"aws_api/lex_models_v2.html#start_test_set_generation"},{"doc":"aws_api/lex_models_v2","title":"stop_bot_recommendation","content":"pub fn stop_bot_recommendation(\n  client: Client,\n  bot_id: String,\n  bot_version: String,\n  locale_id: String,\n  bot_recommendation_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.stop_bot_recommendation\naws_api/lex_models_v2 stop_bot_recommendation","url":"aws_api/lex_models_v2.html#stop_bot_recommendation"},{"doc":"aws_api/lex_models_v2","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.tag_resource\naws_api/lex_models_v2 tag_resource","url":"aws_api/lex_models_v2.html#tag_resource"},{"doc":"aws_api/lex_models_v2","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.untag_resource\naws_api/lex_models_v2 untag_resource","url":"aws_api/lex_models_v2.html#untag_resource"},{"doc":"aws_api/lex_models_v2","title":"update_bot","content":"pub fn update_bot(\n  client: Client,\n  bot_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.update_bot\naws_api/lex_models_v2 update_bot","url":"aws_api/lex_models_v2.html#update_bot"},{"doc":"aws_api/lex_models_v2","title":"update_bot_alias","content":"pub fn update_bot_alias(\n  client: Client,\n  bot_id: String,\n  bot_alias_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.update_bot_alias\naws_api/lex_models_v2 update_bot_alias","url":"aws_api/lex_models_v2.html#update_bot_alias"},{"doc":"aws_api/lex_models_v2","title":"update_bot_locale","content":"pub fn update_bot_locale(\n  client: Client,\n  bot_id: String,\n  bot_version: String,\n  locale_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.update_bot_locale\naws_api/lex_models_v2 update_bot_locale","url":"aws_api/lex_models_v2.html#update_bot_locale"},{"doc":"aws_api/lex_models_v2","title":"update_bot_recommendation","content":"pub fn update_bot_recommendation(\n  client: Client,\n  bot_id: String,\n  bot_version: String,\n  locale_id: String,\n  bot_recommendation_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.update_bot_recommendation\naws_api/lex_models_v2 update_bot_recommendation","url":"aws_api/lex_models_v2.html#update_bot_recommendation"},{"doc":"aws_api/lex_models_v2","title":"update_export","content":"pub fn update_export(\n  client: Client,\n  export_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.update_export\naws_api/lex_models_v2 update_export","url":"aws_api/lex_models_v2.html#update_export"},{"doc":"aws_api/lex_models_v2","title":"update_intent","content":"pub fn update_intent(\n  client: Client,\n  bot_id: String,\n  bot_version: String,\n  locale_id: String,\n  intent_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.update_intent\naws_api/lex_models_v2 update_intent","url":"aws_api/lex_models_v2.html#update_intent"},{"doc":"aws_api/lex_models_v2","title":"update_resource_policy","content":"pub fn update_resource_policy(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.update_resource_policy\naws_api/lex_models_v2 update_resource_policy","url":"aws_api/lex_models_v2.html#update_resource_policy"},{"doc":"aws_api/lex_models_v2","title":"update_slot","content":"pub fn update_slot(\n  client: Client,\n  bot_id: String,\n  bot_version: String,\n  locale_id: String,\n  intent_id: String,\n  slot_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.update_slot\naws_api/lex_models_v2 update_slot","url":"aws_api/lex_models_v2.html#update_slot"},{"doc":"aws_api/lex_models_v2","title":"update_slot_type","content":"pub fn update_slot_type(\n  client: Client,\n  bot_id: String,\n  bot_version: String,\n  locale_id: String,\n  slot_type_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.update_slot_type\naws_api/lex_models_v2 update_slot_type","url":"aws_api/lex_models_v2.html#update_slot_type"},{"doc":"aws_api/lex_models_v2","title":"update_test_set","content":"pub fn update_test_set(\n  client: Client,\n  test_set_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_models_v2.update_test_set\naws_api/lex_models_v2 update_test_set","url":"aws_api/lex_models_v2.html#update_test_set"},{"doc":"aws_api/lex_models_v2","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/lex_models_v2.with_custom_endpoint\naws_api/lex_models_v2 with_custom_endpoint","url":"aws_api/lex_models_v2.html#with_custom_endpoint"},{"doc":"aws_api/lex_models_v2","title":"aws_api/lex_models_v2","content":"","url":"aws_api/lex_models_v2.html"},{"doc":"aws_api/lex_runtime_service","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/lex_runtime_service.Client\naws_api/lex_runtime_service Client","url":"aws_api/lex_runtime_service.html#Client"},{"doc":"aws_api/lex_runtime_service","title":"delete_session","content":"pub fn delete_session(\n  client: Client,\n  bot_name: String,\n  bot_alias: String,\n  user_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_runtime_service.delete_session\naws_api/lex_runtime_service delete_session","url":"aws_api/lex_runtime_service.html#delete_session"},{"doc":"aws_api/lex_runtime_service","title":"get_session","content":"pub fn get_session(\n  client: Client,\n  bot_name: String,\n  bot_alias: String,\n  user_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_runtime_service.get_session\naws_api/lex_runtime_service get_session","url":"aws_api/lex_runtime_service.html#get_session"},{"doc":"aws_api/lex_runtime_service","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/lex_runtime_service.new\naws_api/lex_runtime_service new","url":"aws_api/lex_runtime_service.html#new"},{"doc":"aws_api/lex_runtime_service","title":"post_content","content":"pub fn post_content(\n  client: Client,\n  bot_name: String,\n  bot_alias: String,\n  user_id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_runtime_service.post_content\naws_api/lex_runtime_service post_content","url":"aws_api/lex_runtime_service.html#post_content"},{"doc":"aws_api/lex_runtime_service","title":"post_text","content":"pub fn post_text(\n  client: Client,\n  bot_name: String,\n  bot_alias: String,\n  user_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_runtime_service.post_text\naws_api/lex_runtime_service post_text","url":"aws_api/lex_runtime_service.html#post_text"},{"doc":"aws_api/lex_runtime_service","title":"put_session","content":"pub fn put_session(\n  client: Client,\n  bot_name: String,\n  bot_alias: String,\n  user_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_runtime_service.put_session\naws_api/lex_runtime_service put_session","url":"aws_api/lex_runtime_service.html#put_session"},{"doc":"aws_api/lex_runtime_service","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/lex_runtime_service.with_custom_endpoint\naws_api/lex_runtime_service with_custom_endpoint","url":"aws_api/lex_runtime_service.html#with_custom_endpoint"},{"doc":"aws_api/lex_runtime_service","title":"aws_api/lex_runtime_service","content":"","url":"aws_api/lex_runtime_service.html"},{"doc":"aws_api/lex_runtime_v2","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/lex_runtime_v2.Client\naws_api/lex_runtime_v2 Client","url":"aws_api/lex_runtime_v2.html#Client"},{"doc":"aws_api/lex_runtime_v2","title":"delete_session","content":"pub fn delete_session(\n  client: Client,\n  bot_id: String,\n  bot_alias_id: String,\n  locale_id: String,\n  session_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_runtime_v2.delete_session\naws_api/lex_runtime_v2 delete_session","url":"aws_api/lex_runtime_v2.html#delete_session"},{"doc":"aws_api/lex_runtime_v2","title":"get_session","content":"pub fn get_session(\n  client: Client,\n  bot_id: String,\n  bot_alias_id: String,\n  locale_id: String,\n  session_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_runtime_v2.get_session\naws_api/lex_runtime_v2 get_session","url":"aws_api/lex_runtime_v2.html#get_session"},{"doc":"aws_api/lex_runtime_v2","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/lex_runtime_v2.new\naws_api/lex_runtime_v2 new","url":"aws_api/lex_runtime_v2.html#new"},{"doc":"aws_api/lex_runtime_v2","title":"put_session","content":"pub fn put_session(\n  client: Client,\n  bot_id: String,\n  bot_alias_id: String,\n  locale_id: String,\n  session_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_runtime_v2.put_session\naws_api/lex_runtime_v2 put_session","url":"aws_api/lex_runtime_v2.html#put_session"},{"doc":"aws_api/lex_runtime_v2","title":"recognize_text","content":"pub fn recognize_text(\n  client: Client,\n  bot_id: String,\n  bot_alias_id: String,\n  locale_id: String,\n  session_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_runtime_v2.recognize_text\naws_api/lex_runtime_v2 recognize_text","url":"aws_api/lex_runtime_v2.html#recognize_text"},{"doc":"aws_api/lex_runtime_v2","title":"recognize_utterance","content":"pub fn recognize_utterance(\n  client: Client,\n  bot_id: String,\n  bot_alias_id: String,\n  locale_id: String,\n  session_id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_runtime_v2.recognize_utterance\naws_api/lex_runtime_v2 recognize_utterance","url":"aws_api/lex_runtime_v2.html#recognize_utterance"},{"doc":"aws_api/lex_runtime_v2","title":"start_conversation","content":"pub fn start_conversation(\n  client: Client,\n  bot_id: String,\n  bot_alias_id: String,\n  locale_id: String,\n  session_id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lex_runtime_v2.start_conversation\naws_api/lex_runtime_v2 start_conversation","url":"aws_api/lex_runtime_v2.html#start_conversation"},{"doc":"aws_api/lex_runtime_v2","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/lex_runtime_v2.with_custom_endpoint\naws_api/lex_runtime_v2 with_custom_endpoint","url":"aws_api/lex_runtime_v2.html#with_custom_endpoint"},{"doc":"aws_api/lex_runtime_v2","title":"aws_api/lex_runtime_v2","content":"","url":"aws_api/lex_runtime_v2.html"},{"doc":"aws_api/license_manager","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/license_manager.Client\naws_api/license_manager Client","url":"aws_api/license_manager.html#Client"},{"doc":"aws_api/license_manager","title":"accept_grant","content":"pub fn accept_grant(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager.accept_grant\naws_api/license_manager accept_grant","url":"aws_api/license_manager.html#accept_grant"},{"doc":"aws_api/license_manager","title":"check_in_license","content":"pub fn check_in_license(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager.check_in_license\naws_api/license_manager check_in_license","url":"aws_api/license_manager.html#check_in_license"},{"doc":"aws_api/license_manager","title":"checkout_borrow_license","content":"pub fn checkout_borrow_license(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager.checkout_borrow_license\naws_api/license_manager checkout_borrow_license","url":"aws_api/license_manager.html#checkout_borrow_license"},{"doc":"aws_api/license_manager","title":"checkout_license","content":"pub fn checkout_license(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager.checkout_license\naws_api/license_manager checkout_license","url":"aws_api/license_manager.html#checkout_license"},{"doc":"aws_api/license_manager","title":"create_grant","content":"pub fn create_grant(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager.create_grant\naws_api/license_manager create_grant","url":"aws_api/license_manager.html#create_grant"},{"doc":"aws_api/license_manager","title":"create_grant_version","content":"pub fn create_grant_version(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager.create_grant_version\naws_api/license_manager create_grant_version","url":"aws_api/license_manager.html#create_grant_version"},{"doc":"aws_api/license_manager","title":"create_license","content":"pub fn create_license(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager.create_license\naws_api/license_manager create_license","url":"aws_api/license_manager.html#create_license"},{"doc":"aws_api/license_manager","title":"create_license_configuration","content":"pub fn create_license_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager.create_license_configuration\naws_api/license_manager create_license_configuration","url":"aws_api/license_manager.html#create_license_configuration"},{"doc":"aws_api/license_manager","title":"create_license_conversion_task_for_resource","content":"pub fn create_license_conversion_task_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager.create_license_conversion_task_for_resource\naws_api/license_manager create_license_conversion_task_for_resource","url":"aws_api/license_manager.html#create_license_conversion_task_for_resource"},{"doc":"aws_api/license_manager","title":"create_license_manager_report_generator","content":"pub fn create_license_manager_report_generator(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager.create_license_manager_report_generator\naws_api/license_manager create_license_manager_report_generator","url":"aws_api/license_manager.html#create_license_manager_report_generator"},{"doc":"aws_api/license_manager","title":"create_license_version","content":"pub fn create_license_version(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager.create_license_version\naws_api/license_manager create_license_version","url":"aws_api/license_manager.html#create_license_version"},{"doc":"aws_api/license_manager","title":"create_token","content":"pub fn create_token(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager.create_token\naws_api/license_manager create_token","url":"aws_api/license_manager.html#create_token"},{"doc":"aws_api/license_manager","title":"delete_grant","content":"pub fn delete_grant(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager.delete_grant\naws_api/license_manager delete_grant","url":"aws_api/license_manager.html#delete_grant"},{"doc":"aws_api/license_manager","title":"delete_license","content":"pub fn delete_license(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager.delete_license\naws_api/license_manager delete_license","url":"aws_api/license_manager.html#delete_license"},{"doc":"aws_api/license_manager","title":"delete_license_configuration","content":"pub fn delete_license_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager.delete_license_configuration\naws_api/license_manager delete_license_configuration","url":"aws_api/license_manager.html#delete_license_configuration"},{"doc":"aws_api/license_manager","title":"delete_license_manager_report_generator","content":"pub fn delete_license_manager_report_generator(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager.delete_license_manager_report_generator\naws_api/license_manager delete_license_manager_report_generator","url":"aws_api/license_manager.html#delete_license_manager_report_generator"},{"doc":"aws_api/license_manager","title":"delete_token","content":"pub fn delete_token(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager.delete_token\naws_api/license_manager delete_token","url":"aws_api/license_manager.html#delete_token"},{"doc":"aws_api/license_manager","title":"extend_license_consumption","content":"pub fn extend_license_consumption(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager.extend_license_consumption\naws_api/license_manager extend_license_consumption","url":"aws_api/license_manager.html#extend_license_consumption"},{"doc":"aws_api/license_manager","title":"get_access_token","content":"pub fn get_access_token(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager.get_access_token\naws_api/license_manager get_access_token","url":"aws_api/license_manager.html#get_access_token"},{"doc":"aws_api/license_manager","title":"get_grant","content":"pub fn get_grant(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager.get_grant\naws_api/license_manager get_grant","url":"aws_api/license_manager.html#get_grant"},{"doc":"aws_api/license_manager","title":"get_license","content":"pub fn get_license(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager.get_license\naws_api/license_manager get_license","url":"aws_api/license_manager.html#get_license"},{"doc":"aws_api/license_manager","title":"get_license_configuration","content":"pub fn get_license_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager.get_license_configuration\naws_api/license_manager get_license_configuration","url":"aws_api/license_manager.html#get_license_configuration"},{"doc":"aws_api/license_manager","title":"get_license_conversion_task","content":"pub fn get_license_conversion_task(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager.get_license_conversion_task\naws_api/license_manager get_license_conversion_task","url":"aws_api/license_manager.html#get_license_conversion_task"},{"doc":"aws_api/license_manager","title":"get_license_manager_report_generator","content":"pub fn get_license_manager_report_generator(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager.get_license_manager_report_generator\naws_api/license_manager get_license_manager_report_generator","url":"aws_api/license_manager.html#get_license_manager_report_generator"},{"doc":"aws_api/license_manager","title":"get_license_usage","content":"pub fn get_license_usage(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager.get_license_usage\naws_api/license_manager get_license_usage","url":"aws_api/license_manager.html#get_license_usage"},{"doc":"aws_api/license_manager","title":"get_service_settings","content":"pub fn get_service_settings(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager.get_service_settings\naws_api/license_manager get_service_settings","url":"aws_api/license_manager.html#get_service_settings"},{"doc":"aws_api/license_manager","title":"list_associations_for_license_configuration","content":"pub fn list_associations_for_license_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager.list_associations_for_license_configuration\naws_api/license_manager list_associations_for_license_configuration","url":"aws_api/license_manager.html#list_associations_for_license_configuration"},{"doc":"aws_api/license_manager","title":"list_distributed_grants","content":"pub fn list_distributed_grants(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager.list_distributed_grants\naws_api/license_manager list_distributed_grants","url":"aws_api/license_manager.html#list_distributed_grants"},{"doc":"aws_api/license_manager","title":"list_failures_for_license_configuration_operations","content":"pub fn list_failures_for_license_configuration_operations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager.list_failures_for_license_configuration_operations\naws_api/license_manager list_failures_for_license_configuration_operations","url":"aws_api/license_manager.html#list_failures_for_license_configuration_operations"},{"doc":"aws_api/license_manager","title":"list_license_configurations","content":"pub fn list_license_configurations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager.list_license_configurations\naws_api/license_manager list_license_configurations","url":"aws_api/license_manager.html#list_license_configurations"},{"doc":"aws_api/license_manager","title":"list_license_conversion_tasks","content":"pub fn list_license_conversion_tasks(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager.list_license_conversion_tasks\naws_api/license_manager list_license_conversion_tasks","url":"aws_api/license_manager.html#list_license_conversion_tasks"},{"doc":"aws_api/license_manager","title":"list_license_manager_report_generators","content":"pub fn list_license_manager_report_generators(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager.list_license_manager_report_generators\naws_api/license_manager list_license_manager_report_generators","url":"aws_api/license_manager.html#list_license_manager_report_generators"},{"doc":"aws_api/license_manager","title":"list_license_specifications_for_resource","content":"pub fn list_license_specifications_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager.list_license_specifications_for_resource\naws_api/license_manager list_license_specifications_for_resource","url":"aws_api/license_manager.html#list_license_specifications_for_resource"},{"doc":"aws_api/license_manager","title":"list_license_versions","content":"pub fn list_license_versions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager.list_license_versions\naws_api/license_manager list_license_versions","url":"aws_api/license_manager.html#list_license_versions"},{"doc":"aws_api/license_manager","title":"list_licenses","content":"pub fn list_licenses(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager.list_licenses\naws_api/license_manager list_licenses","url":"aws_api/license_manager.html#list_licenses"},{"doc":"aws_api/license_manager","title":"list_received_grants","content":"pub fn list_received_grants(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager.list_received_grants\naws_api/license_manager list_received_grants","url":"aws_api/license_manager.html#list_received_grants"},{"doc":"aws_api/license_manager","title":"list_received_grants_for_organization","content":"pub fn list_received_grants_for_organization(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager.list_received_grants_for_organization\naws_api/license_manager list_received_grants_for_organization","url":"aws_api/license_manager.html#list_received_grants_for_organization"},{"doc":"aws_api/license_manager","title":"list_received_licenses","content":"pub fn list_received_licenses(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager.list_received_licenses\naws_api/license_manager list_received_licenses","url":"aws_api/license_manager.html#list_received_licenses"},{"doc":"aws_api/license_manager","title":"list_received_licenses_for_organization","content":"pub fn list_received_licenses_for_organization(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager.list_received_licenses_for_organization\naws_api/license_manager list_received_licenses_for_organization","url":"aws_api/license_manager.html#list_received_licenses_for_organization"},{"doc":"aws_api/license_manager","title":"list_resource_inventory","content":"pub fn list_resource_inventory(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager.list_resource_inventory\naws_api/license_manager list_resource_inventory","url":"aws_api/license_manager.html#list_resource_inventory"},{"doc":"aws_api/license_manager","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager.list_tags_for_resource\naws_api/license_manager list_tags_for_resource","url":"aws_api/license_manager.html#list_tags_for_resource"},{"doc":"aws_api/license_manager","title":"list_tokens","content":"pub fn list_tokens(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager.list_tokens\naws_api/license_manager list_tokens","url":"aws_api/license_manager.html#list_tokens"},{"doc":"aws_api/license_manager","title":"list_usage_for_license_configuration","content":"pub fn list_usage_for_license_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager.list_usage_for_license_configuration\naws_api/license_manager list_usage_for_license_configuration","url":"aws_api/license_manager.html#list_usage_for_license_configuration"},{"doc":"aws_api/license_manager","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/license_manager.new\naws_api/license_manager new","url":"aws_api/license_manager.html#new"},{"doc":"aws_api/license_manager","title":"reject_grant","content":"pub fn reject_grant(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager.reject_grant\naws_api/license_manager reject_grant","url":"aws_api/license_manager.html#reject_grant"},{"doc":"aws_api/license_manager","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager.tag_resource\naws_api/license_manager tag_resource","url":"aws_api/license_manager.html#tag_resource"},{"doc":"aws_api/license_manager","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager.untag_resource\naws_api/license_manager untag_resource","url":"aws_api/license_manager.html#untag_resource"},{"doc":"aws_api/license_manager","title":"update_license_configuration","content":"pub fn update_license_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager.update_license_configuration\naws_api/license_manager update_license_configuration","url":"aws_api/license_manager.html#update_license_configuration"},{"doc":"aws_api/license_manager","title":"update_license_manager_report_generator","content":"pub fn update_license_manager_report_generator(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager.update_license_manager_report_generator\naws_api/license_manager update_license_manager_report_generator","url":"aws_api/license_manager.html#update_license_manager_report_generator"},{"doc":"aws_api/license_manager","title":"update_license_specifications_for_resource","content":"pub fn update_license_specifications_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager.update_license_specifications_for_resource\naws_api/license_manager update_license_specifications_for_resource","url":"aws_api/license_manager.html#update_license_specifications_for_resource"},{"doc":"aws_api/license_manager","title":"update_service_settings","content":"pub fn update_service_settings(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager.update_service_settings\naws_api/license_manager update_service_settings","url":"aws_api/license_manager.html#update_service_settings"},{"doc":"aws_api/license_manager","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/license_manager.with_custom_endpoint\naws_api/license_manager with_custom_endpoint","url":"aws_api/license_manager.html#with_custom_endpoint"},{"doc":"aws_api/license_manager","title":"aws_api/license_manager","content":"","url":"aws_api/license_manager.html"},{"doc":"aws_api/license_manager_linux_subscriptions","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/license_manager_linux_subscriptions.Client\naws_api/license_manager_linux_subscriptions Client","url":"aws_api/license_manager_linux_subscriptions.html#Client"},{"doc":"aws_api/license_manager_linux_subscriptions","title":"deregister_subscription_provider","content":"pub fn deregister_subscription_provider(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager_linux_subscriptions.deregister_subscription_provider\naws_api/license_manager_linux_subscriptions deregister_subscription_provider","url":"aws_api/license_manager_linux_subscriptions.html#deregister_subscription_provider"},{"doc":"aws_api/license_manager_linux_subscriptions","title":"get_registered_subscription_provider","content":"pub fn get_registered_subscription_provider(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager_linux_subscriptions.get_registered_subscription_provider\naws_api/license_manager_linux_subscriptions get_registered_subscription_provider","url":"aws_api/license_manager_linux_subscriptions.html#get_registered_subscription_provider"},{"doc":"aws_api/license_manager_linux_subscriptions","title":"get_service_settings","content":"pub fn get_service_settings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager_linux_subscriptions.get_service_settings\naws_api/license_manager_linux_subscriptions get_service_settings","url":"aws_api/license_manager_linux_subscriptions.html#get_service_settings"},{"doc":"aws_api/license_manager_linux_subscriptions","title":"list_linux_subscription_instances","content":"pub fn list_linux_subscription_instances(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager_linux_subscriptions.list_linux_subscription_instances\naws_api/license_manager_linux_subscriptions list_linux_subscription_instances","url":"aws_api/license_manager_linux_subscriptions.html#list_linux_subscription_instances"},{"doc":"aws_api/license_manager_linux_subscriptions","title":"list_linux_subscriptions","content":"pub fn list_linux_subscriptions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager_linux_subscriptions.list_linux_subscriptions\naws_api/license_manager_linux_subscriptions list_linux_subscriptions","url":"aws_api/license_manager_linux_subscriptions.html#list_linux_subscriptions"},{"doc":"aws_api/license_manager_linux_subscriptions","title":"list_registered_subscription_providers","content":"pub fn list_registered_subscription_providers(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager_linux_subscriptions.list_registered_subscription_providers\naws_api/license_manager_linux_subscriptions list_registered_subscription_providers","url":"aws_api/license_manager_linux_subscriptions.html#list_registered_subscription_providers"},{"doc":"aws_api/license_manager_linux_subscriptions","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager_linux_subscriptions.list_tags_for_resource\naws_api/license_manager_linux_subscriptions list_tags_for_resource","url":"aws_api/license_manager_linux_subscriptions.html#list_tags_for_resource"},{"doc":"aws_api/license_manager_linux_subscriptions","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/license_manager_linux_subscriptions.new\naws_api/license_manager_linux_subscriptions new","url":"aws_api/license_manager_linux_subscriptions.html#new"},{"doc":"aws_api/license_manager_linux_subscriptions","title":"register_subscription_provider","content":"pub fn register_subscription_provider(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager_linux_subscriptions.register_subscription_provider\naws_api/license_manager_linux_subscriptions register_subscription_provider","url":"aws_api/license_manager_linux_subscriptions.html#register_subscription_provider"},{"doc":"aws_api/license_manager_linux_subscriptions","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager_linux_subscriptions.tag_resource\naws_api/license_manager_linux_subscriptions tag_resource","url":"aws_api/license_manager_linux_subscriptions.html#tag_resource"},{"doc":"aws_api/license_manager_linux_subscriptions","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager_linux_subscriptions.untag_resource\naws_api/license_manager_linux_subscriptions untag_resource","url":"aws_api/license_manager_linux_subscriptions.html#untag_resource"},{"doc":"aws_api/license_manager_linux_subscriptions","title":"update_service_settings","content":"pub fn update_service_settings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager_linux_subscriptions.update_service_settings\naws_api/license_manager_linux_subscriptions update_service_settings","url":"aws_api/license_manager_linux_subscriptions.html#update_service_settings"},{"doc":"aws_api/license_manager_linux_subscriptions","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/license_manager_linux_subscriptions.with_custom_endpoint\naws_api/license_manager_linux_subscriptions with_custom_endpoint","url":"aws_api/license_manager_linux_subscriptions.html#with_custom_endpoint"},{"doc":"aws_api/license_manager_linux_subscriptions","title":"aws_api/license_manager_linux_subscriptions","content":"","url":"aws_api/license_manager_linux_subscriptions.html"},{"doc":"aws_api/license_manager_user_subscriptions","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/license_manager_user_subscriptions.Client\naws_api/license_manager_user_subscriptions Client","url":"aws_api/license_manager_user_subscriptions.html#Client"},{"doc":"aws_api/license_manager_user_subscriptions","title":"associate_user","content":"pub fn associate_user(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager_user_subscriptions.associate_user\naws_api/license_manager_user_subscriptions associate_user","url":"aws_api/license_manager_user_subscriptions.html#associate_user"},{"doc":"aws_api/license_manager_user_subscriptions","title":"deregister_identity_provider","content":"pub fn deregister_identity_provider(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager_user_subscriptions.deregister_identity_provider\naws_api/license_manager_user_subscriptions deregister_identity_provider","url":"aws_api/license_manager_user_subscriptions.html#deregister_identity_provider"},{"doc":"aws_api/license_manager_user_subscriptions","title":"disassociate_user","content":"pub fn disassociate_user(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager_user_subscriptions.disassociate_user\naws_api/license_manager_user_subscriptions disassociate_user","url":"aws_api/license_manager_user_subscriptions.html#disassociate_user"},{"doc":"aws_api/license_manager_user_subscriptions","title":"list_identity_providers","content":"pub fn list_identity_providers(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager_user_subscriptions.list_identity_providers\naws_api/license_manager_user_subscriptions list_identity_providers","url":"aws_api/license_manager_user_subscriptions.html#list_identity_providers"},{"doc":"aws_api/license_manager_user_subscriptions","title":"list_instances","content":"pub fn list_instances(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager_user_subscriptions.list_instances\naws_api/license_manager_user_subscriptions list_instances","url":"aws_api/license_manager_user_subscriptions.html#list_instances"},{"doc":"aws_api/license_manager_user_subscriptions","title":"list_product_subscriptions","content":"pub fn list_product_subscriptions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager_user_subscriptions.list_product_subscriptions\naws_api/license_manager_user_subscriptions list_product_subscriptions","url":"aws_api/license_manager_user_subscriptions.html#list_product_subscriptions"},{"doc":"aws_api/license_manager_user_subscriptions","title":"list_user_associations","content":"pub fn list_user_associations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager_user_subscriptions.list_user_associations\naws_api/license_manager_user_subscriptions list_user_associations","url":"aws_api/license_manager_user_subscriptions.html#list_user_associations"},{"doc":"aws_api/license_manager_user_subscriptions","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/license_manager_user_subscriptions.new\naws_api/license_manager_user_subscriptions new","url":"aws_api/license_manager_user_subscriptions.html#new"},{"doc":"aws_api/license_manager_user_subscriptions","title":"register_identity_provider","content":"pub fn register_identity_provider(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager_user_subscriptions.register_identity_provider\naws_api/license_manager_user_subscriptions register_identity_provider","url":"aws_api/license_manager_user_subscriptions.html#register_identity_provider"},{"doc":"aws_api/license_manager_user_subscriptions","title":"start_product_subscription","content":"pub fn start_product_subscription(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager_user_subscriptions.start_product_subscription\naws_api/license_manager_user_subscriptions start_product_subscription","url":"aws_api/license_manager_user_subscriptions.html#start_product_subscription"},{"doc":"aws_api/license_manager_user_subscriptions","title":"stop_product_subscription","content":"pub fn stop_product_subscription(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager_user_subscriptions.stop_product_subscription\naws_api/license_manager_user_subscriptions stop_product_subscription","url":"aws_api/license_manager_user_subscriptions.html#stop_product_subscription"},{"doc":"aws_api/license_manager_user_subscriptions","title":"update_identity_provider_settings","content":"pub fn update_identity_provider_settings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/license_manager_user_subscriptions.update_identity_provider_settings\naws_api/license_manager_user_subscriptions update_identity_provider_settings","url":"aws_api/license_manager_user_subscriptions.html#update_identity_provider_settings"},{"doc":"aws_api/license_manager_user_subscriptions","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/license_manager_user_subscriptions.with_custom_endpoint\naws_api/license_manager_user_subscriptions with_custom_endpoint","url":"aws_api/license_manager_user_subscriptions.html#with_custom_endpoint"},{"doc":"aws_api/license_manager_user_subscriptions","title":"aws_api/license_manager_user_subscriptions","content":"","url":"aws_api/license_manager_user_subscriptions.html"},{"doc":"aws_api/lightsail","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/lightsail.Client\naws_api/lightsail Client","url":"aws_api/lightsail.html#Client"},{"doc":"aws_api/lightsail","title":"allocate_static_ip","content":"pub fn allocate_static_ip(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.allocate_static_ip\naws_api/lightsail allocate_static_ip","url":"aws_api/lightsail.html#allocate_static_ip"},{"doc":"aws_api/lightsail","title":"attach_certificate_to_distribution","content":"pub fn attach_certificate_to_distribution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.attach_certificate_to_distribution\naws_api/lightsail attach_certificate_to_distribution","url":"aws_api/lightsail.html#attach_certificate_to_distribution"},{"doc":"aws_api/lightsail","title":"attach_disk","content":"pub fn attach_disk(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.attach_disk\naws_api/lightsail attach_disk","url":"aws_api/lightsail.html#attach_disk"},{"doc":"aws_api/lightsail","title":"attach_instances_to_load_balancer","content":"pub fn attach_instances_to_load_balancer(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.attach_instances_to_load_balancer\naws_api/lightsail attach_instances_to_load_balancer","url":"aws_api/lightsail.html#attach_instances_to_load_balancer"},{"doc":"aws_api/lightsail","title":"attach_load_balancer_tls_certificate","content":"pub fn attach_load_balancer_tls_certificate(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.attach_load_balancer_tls_certificate\naws_api/lightsail attach_load_balancer_tls_certificate","url":"aws_api/lightsail.html#attach_load_balancer_tls_certificate"},{"doc":"aws_api/lightsail","title":"attach_static_ip","content":"pub fn attach_static_ip(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.attach_static_ip\naws_api/lightsail attach_static_ip","url":"aws_api/lightsail.html#attach_static_ip"},{"doc":"aws_api/lightsail","title":"close_instance_public_ports","content":"pub fn close_instance_public_ports(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.close_instance_public_ports\naws_api/lightsail close_instance_public_ports","url":"aws_api/lightsail.html#close_instance_public_ports"},{"doc":"aws_api/lightsail","title":"copy_snapshot","content":"pub fn copy_snapshot(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.copy_snapshot\naws_api/lightsail copy_snapshot","url":"aws_api/lightsail.html#copy_snapshot"},{"doc":"aws_api/lightsail","title":"create_bucket","content":"pub fn create_bucket(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.create_bucket\naws_api/lightsail create_bucket","url":"aws_api/lightsail.html#create_bucket"},{"doc":"aws_api/lightsail","title":"create_bucket_access_key","content":"pub fn create_bucket_access_key(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.create_bucket_access_key\naws_api/lightsail create_bucket_access_key","url":"aws_api/lightsail.html#create_bucket_access_key"},{"doc":"aws_api/lightsail","title":"create_certificate","content":"pub fn create_certificate(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.create_certificate\naws_api/lightsail create_certificate","url":"aws_api/lightsail.html#create_certificate"},{"doc":"aws_api/lightsail","title":"create_cloud_formation_stack","content":"pub fn create_cloud_formation_stack(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.create_cloud_formation_stack\naws_api/lightsail create_cloud_formation_stack","url":"aws_api/lightsail.html#create_cloud_formation_stack"},{"doc":"aws_api/lightsail","title":"create_contact_method","content":"pub fn create_contact_method(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.create_contact_method\naws_api/lightsail create_contact_method","url":"aws_api/lightsail.html#create_contact_method"},{"doc":"aws_api/lightsail","title":"create_container_service","content":"pub fn create_container_service(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.create_container_service\naws_api/lightsail create_container_service","url":"aws_api/lightsail.html#create_container_service"},{"doc":"aws_api/lightsail","title":"create_container_service_deployment","content":"pub fn create_container_service_deployment(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.create_container_service_deployment\naws_api/lightsail create_container_service_deployment","url":"aws_api/lightsail.html#create_container_service_deployment"},{"doc":"aws_api/lightsail","title":"create_container_service_registry_login","content":"pub fn create_container_service_registry_login(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.create_container_service_registry_login\naws_api/lightsail create_container_service_registry_login","url":"aws_api/lightsail.html#create_container_service_registry_login"},{"doc":"aws_api/lightsail","title":"create_disk","content":"pub fn create_disk(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.create_disk\naws_api/lightsail create_disk","url":"aws_api/lightsail.html#create_disk"},{"doc":"aws_api/lightsail","title":"create_disk_from_snapshot","content":"pub fn create_disk_from_snapshot(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.create_disk_from_snapshot\naws_api/lightsail create_disk_from_snapshot","url":"aws_api/lightsail.html#create_disk_from_snapshot"},{"doc":"aws_api/lightsail","title":"create_disk_snapshot","content":"pub fn create_disk_snapshot(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.create_disk_snapshot\naws_api/lightsail create_disk_snapshot","url":"aws_api/lightsail.html#create_disk_snapshot"},{"doc":"aws_api/lightsail","title":"create_distribution","content":"pub fn create_distribution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.create_distribution\naws_api/lightsail create_distribution","url":"aws_api/lightsail.html#create_distribution"},{"doc":"aws_api/lightsail","title":"create_domain","content":"pub fn create_domain(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.create_domain\naws_api/lightsail create_domain","url":"aws_api/lightsail.html#create_domain"},{"doc":"aws_api/lightsail","title":"create_domain_entry","content":"pub fn create_domain_entry(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.create_domain_entry\naws_api/lightsail create_domain_entry","url":"aws_api/lightsail.html#create_domain_entry"},{"doc":"aws_api/lightsail","title":"create_gui_session_access_details","content":"pub fn create_gui_session_access_details(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.create_gui_session_access_details\naws_api/lightsail create_gui_session_access_details","url":"aws_api/lightsail.html#create_gui_session_access_details"},{"doc":"aws_api/lightsail","title":"create_instance_snapshot","content":"pub fn create_instance_snapshot(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.create_instance_snapshot\naws_api/lightsail create_instance_snapshot","url":"aws_api/lightsail.html#create_instance_snapshot"},{"doc":"aws_api/lightsail","title":"create_instances","content":"pub fn create_instances(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.create_instances\naws_api/lightsail create_instances","url":"aws_api/lightsail.html#create_instances"},{"doc":"aws_api/lightsail","title":"create_instances_from_snapshot","content":"pub fn create_instances_from_snapshot(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.create_instances_from_snapshot\naws_api/lightsail create_instances_from_snapshot","url":"aws_api/lightsail.html#create_instances_from_snapshot"},{"doc":"aws_api/lightsail","title":"create_key_pair","content":"pub fn create_key_pair(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.create_key_pair\naws_api/lightsail create_key_pair","url":"aws_api/lightsail.html#create_key_pair"},{"doc":"aws_api/lightsail","title":"create_load_balancer","content":"pub fn create_load_balancer(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.create_load_balancer\naws_api/lightsail create_load_balancer","url":"aws_api/lightsail.html#create_load_balancer"},{"doc":"aws_api/lightsail","title":"create_load_balancer_tls_certificate","content":"pub fn create_load_balancer_tls_certificate(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.create_load_balancer_tls_certificate\naws_api/lightsail create_load_balancer_tls_certificate","url":"aws_api/lightsail.html#create_load_balancer_tls_certificate"},{"doc":"aws_api/lightsail","title":"create_relational_database","content":"pub fn create_relational_database(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.create_relational_database\naws_api/lightsail create_relational_database","url":"aws_api/lightsail.html#create_relational_database"},{"doc":"aws_api/lightsail","title":"create_relational_database_from_snapshot","content":"pub fn create_relational_database_from_snapshot(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.create_relational_database_from_snapshot\naws_api/lightsail create_relational_database_from_snapshot","url":"aws_api/lightsail.html#create_relational_database_from_snapshot"},{"doc":"aws_api/lightsail","title":"create_relational_database_snapshot","content":"pub fn create_relational_database_snapshot(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.create_relational_database_snapshot\naws_api/lightsail create_relational_database_snapshot","url":"aws_api/lightsail.html#create_relational_database_snapshot"},{"doc":"aws_api/lightsail","title":"delete_alarm","content":"pub fn delete_alarm(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.delete_alarm\naws_api/lightsail delete_alarm","url":"aws_api/lightsail.html#delete_alarm"},{"doc":"aws_api/lightsail","title":"delete_auto_snapshot","content":"pub fn delete_auto_snapshot(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.delete_auto_snapshot\naws_api/lightsail delete_auto_snapshot","url":"aws_api/lightsail.html#delete_auto_snapshot"},{"doc":"aws_api/lightsail","title":"delete_bucket","content":"pub fn delete_bucket(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.delete_bucket\naws_api/lightsail delete_bucket","url":"aws_api/lightsail.html#delete_bucket"},{"doc":"aws_api/lightsail","title":"delete_bucket_access_key","content":"pub fn delete_bucket_access_key(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.delete_bucket_access_key\naws_api/lightsail delete_bucket_access_key","url":"aws_api/lightsail.html#delete_bucket_access_key"},{"doc":"aws_api/lightsail","title":"delete_certificate","content":"pub fn delete_certificate(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.delete_certificate\naws_api/lightsail delete_certificate","url":"aws_api/lightsail.html#delete_certificate"},{"doc":"aws_api/lightsail","title":"delete_contact_method","content":"pub fn delete_contact_method(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.delete_contact_method\naws_api/lightsail delete_contact_method","url":"aws_api/lightsail.html#delete_contact_method"},{"doc":"aws_api/lightsail","title":"delete_container_image","content":"pub fn delete_container_image(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.delete_container_image\naws_api/lightsail delete_container_image","url":"aws_api/lightsail.html#delete_container_image"},{"doc":"aws_api/lightsail","title":"delete_container_service","content":"pub fn delete_container_service(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.delete_container_service\naws_api/lightsail delete_container_service","url":"aws_api/lightsail.html#delete_container_service"},{"doc":"aws_api/lightsail","title":"delete_disk","content":"pub fn delete_disk(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.delete_disk\naws_api/lightsail delete_disk","url":"aws_api/lightsail.html#delete_disk"},{"doc":"aws_api/lightsail","title":"delete_disk_snapshot","content":"pub fn delete_disk_snapshot(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.delete_disk_snapshot\naws_api/lightsail delete_disk_snapshot","url":"aws_api/lightsail.html#delete_disk_snapshot"},{"doc":"aws_api/lightsail","title":"delete_distribution","content":"pub fn delete_distribution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.delete_distribution\naws_api/lightsail delete_distribution","url":"aws_api/lightsail.html#delete_distribution"},{"doc":"aws_api/lightsail","title":"delete_domain","content":"pub fn delete_domain(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.delete_domain\naws_api/lightsail delete_domain","url":"aws_api/lightsail.html#delete_domain"},{"doc":"aws_api/lightsail","title":"delete_domain_entry","content":"pub fn delete_domain_entry(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.delete_domain_entry\naws_api/lightsail delete_domain_entry","url":"aws_api/lightsail.html#delete_domain_entry"},{"doc":"aws_api/lightsail","title":"delete_instance","content":"pub fn delete_instance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.delete_instance\naws_api/lightsail delete_instance","url":"aws_api/lightsail.html#delete_instance"},{"doc":"aws_api/lightsail","title":"delete_instance_snapshot","content":"pub fn delete_instance_snapshot(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.delete_instance_snapshot\naws_api/lightsail delete_instance_snapshot","url":"aws_api/lightsail.html#delete_instance_snapshot"},{"doc":"aws_api/lightsail","title":"delete_key_pair","content":"pub fn delete_key_pair(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.delete_key_pair\naws_api/lightsail delete_key_pair","url":"aws_api/lightsail.html#delete_key_pair"},{"doc":"aws_api/lightsail","title":"delete_known_host_keys","content":"pub fn delete_known_host_keys(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.delete_known_host_keys\naws_api/lightsail delete_known_host_keys","url":"aws_api/lightsail.html#delete_known_host_keys"},{"doc":"aws_api/lightsail","title":"delete_load_balancer","content":"pub fn delete_load_balancer(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.delete_load_balancer\naws_api/lightsail delete_load_balancer","url":"aws_api/lightsail.html#delete_load_balancer"},{"doc":"aws_api/lightsail","title":"delete_load_balancer_tls_certificate","content":"pub fn delete_load_balancer_tls_certificate(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.delete_load_balancer_tls_certificate\naws_api/lightsail delete_load_balancer_tls_certificate","url":"aws_api/lightsail.html#delete_load_balancer_tls_certificate"},{"doc":"aws_api/lightsail","title":"delete_relational_database","content":"pub fn delete_relational_database(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.delete_relational_database\naws_api/lightsail delete_relational_database","url":"aws_api/lightsail.html#delete_relational_database"},{"doc":"aws_api/lightsail","title":"delete_relational_database_snapshot","content":"pub fn delete_relational_database_snapshot(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.delete_relational_database_snapshot\naws_api/lightsail delete_relational_database_snapshot","url":"aws_api/lightsail.html#delete_relational_database_snapshot"},{"doc":"aws_api/lightsail","title":"detach_certificate_from_distribution","content":"pub fn detach_certificate_from_distribution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.detach_certificate_from_distribution\naws_api/lightsail detach_certificate_from_distribution","url":"aws_api/lightsail.html#detach_certificate_from_distribution"},{"doc":"aws_api/lightsail","title":"detach_disk","content":"pub fn detach_disk(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.detach_disk\naws_api/lightsail detach_disk","url":"aws_api/lightsail.html#detach_disk"},{"doc":"aws_api/lightsail","title":"detach_instances_from_load_balancer","content":"pub fn detach_instances_from_load_balancer(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.detach_instances_from_load_balancer\naws_api/lightsail detach_instances_from_load_balancer","url":"aws_api/lightsail.html#detach_instances_from_load_balancer"},{"doc":"aws_api/lightsail","title":"detach_static_ip","content":"pub fn detach_static_ip(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.detach_static_ip\naws_api/lightsail detach_static_ip","url":"aws_api/lightsail.html#detach_static_ip"},{"doc":"aws_api/lightsail","title":"disable_add_on","content":"pub fn disable_add_on(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.disable_add_on\naws_api/lightsail disable_add_on","url":"aws_api/lightsail.html#disable_add_on"},{"doc":"aws_api/lightsail","title":"download_default_key_pair","content":"pub fn download_default_key_pair(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.download_default_key_pair\naws_api/lightsail download_default_key_pair","url":"aws_api/lightsail.html#download_default_key_pair"},{"doc":"aws_api/lightsail","title":"enable_add_on","content":"pub fn enable_add_on(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.enable_add_on\naws_api/lightsail enable_add_on","url":"aws_api/lightsail.html#enable_add_on"},{"doc":"aws_api/lightsail","title":"export_snapshot","content":"pub fn export_snapshot(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.export_snapshot\naws_api/lightsail export_snapshot","url":"aws_api/lightsail.html#export_snapshot"},{"doc":"aws_api/lightsail","title":"get_active_names","content":"pub fn get_active_names(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_active_names\naws_api/lightsail get_active_names","url":"aws_api/lightsail.html#get_active_names"},{"doc":"aws_api/lightsail","title":"get_alarms","content":"pub fn get_alarms(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_alarms\naws_api/lightsail get_alarms","url":"aws_api/lightsail.html#get_alarms"},{"doc":"aws_api/lightsail","title":"get_auto_snapshots","content":"pub fn get_auto_snapshots(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_auto_snapshots\naws_api/lightsail get_auto_snapshots","url":"aws_api/lightsail.html#get_auto_snapshots"},{"doc":"aws_api/lightsail","title":"get_blueprints","content":"pub fn get_blueprints(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_blueprints\naws_api/lightsail get_blueprints","url":"aws_api/lightsail.html#get_blueprints"},{"doc":"aws_api/lightsail","title":"get_bucket_access_keys","content":"pub fn get_bucket_access_keys(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_bucket_access_keys\naws_api/lightsail get_bucket_access_keys","url":"aws_api/lightsail.html#get_bucket_access_keys"},{"doc":"aws_api/lightsail","title":"get_bucket_bundles","content":"pub fn get_bucket_bundles(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_bucket_bundles\naws_api/lightsail get_bucket_bundles","url":"aws_api/lightsail.html#get_bucket_bundles"},{"doc":"aws_api/lightsail","title":"get_bucket_metric_data","content":"pub fn get_bucket_metric_data(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_bucket_metric_data\naws_api/lightsail get_bucket_metric_data","url":"aws_api/lightsail.html#get_bucket_metric_data"},{"doc":"aws_api/lightsail","title":"get_buckets","content":"pub fn get_buckets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_buckets\naws_api/lightsail get_buckets","url":"aws_api/lightsail.html#get_buckets"},{"doc":"aws_api/lightsail","title":"get_bundles","content":"pub fn get_bundles(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_bundles\naws_api/lightsail get_bundles","url":"aws_api/lightsail.html#get_bundles"},{"doc":"aws_api/lightsail","title":"get_certificates","content":"pub fn get_certificates(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_certificates\naws_api/lightsail get_certificates","url":"aws_api/lightsail.html#get_certificates"},{"doc":"aws_api/lightsail","title":"get_cloud_formation_stack_records","content":"pub fn get_cloud_formation_stack_records(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_cloud_formation_stack_records\naws_api/lightsail get_cloud_formation_stack_records","url":"aws_api/lightsail.html#get_cloud_formation_stack_records"},{"doc":"aws_api/lightsail","title":"get_contact_methods","content":"pub fn get_contact_methods(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_contact_methods\naws_api/lightsail get_contact_methods","url":"aws_api/lightsail.html#get_contact_methods"},{"doc":"aws_api/lightsail","title":"get_container_api_metadata","content":"pub fn get_container_api_metadata(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_container_api_metadata\naws_api/lightsail get_container_api_metadata","url":"aws_api/lightsail.html#get_container_api_metadata"},{"doc":"aws_api/lightsail","title":"get_container_images","content":"pub fn get_container_images(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_container_images\naws_api/lightsail get_container_images","url":"aws_api/lightsail.html#get_container_images"},{"doc":"aws_api/lightsail","title":"get_container_log","content":"pub fn get_container_log(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_container_log\naws_api/lightsail get_container_log","url":"aws_api/lightsail.html#get_container_log"},{"doc":"aws_api/lightsail","title":"get_container_service_deployments","content":"pub fn get_container_service_deployments(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_container_service_deployments\naws_api/lightsail get_container_service_deployments","url":"aws_api/lightsail.html#get_container_service_deployments"},{"doc":"aws_api/lightsail","title":"get_container_service_metric_data","content":"pub fn get_container_service_metric_data(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_container_service_metric_data\naws_api/lightsail get_container_service_metric_data","url":"aws_api/lightsail.html#get_container_service_metric_data"},{"doc":"aws_api/lightsail","title":"get_container_service_powers","content":"pub fn get_container_service_powers(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_container_service_powers\naws_api/lightsail get_container_service_powers","url":"aws_api/lightsail.html#get_container_service_powers"},{"doc":"aws_api/lightsail","title":"get_container_services","content":"pub fn get_container_services(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_container_services\naws_api/lightsail get_container_services","url":"aws_api/lightsail.html#get_container_services"},{"doc":"aws_api/lightsail","title":"get_cost_estimate","content":"pub fn get_cost_estimate(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_cost_estimate\naws_api/lightsail get_cost_estimate","url":"aws_api/lightsail.html#get_cost_estimate"},{"doc":"aws_api/lightsail","title":"get_disk","content":"pub fn get_disk(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_disk\naws_api/lightsail get_disk","url":"aws_api/lightsail.html#get_disk"},{"doc":"aws_api/lightsail","title":"get_disk_snapshot","content":"pub fn get_disk_snapshot(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_disk_snapshot\naws_api/lightsail get_disk_snapshot","url":"aws_api/lightsail.html#get_disk_snapshot"},{"doc":"aws_api/lightsail","title":"get_disk_snapshots","content":"pub fn get_disk_snapshots(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_disk_snapshots\naws_api/lightsail get_disk_snapshots","url":"aws_api/lightsail.html#get_disk_snapshots"},{"doc":"aws_api/lightsail","title":"get_disks","content":"pub fn get_disks(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_disks\naws_api/lightsail get_disks","url":"aws_api/lightsail.html#get_disks"},{"doc":"aws_api/lightsail","title":"get_distribution_bundles","content":"pub fn get_distribution_bundles(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_distribution_bundles\naws_api/lightsail get_distribution_bundles","url":"aws_api/lightsail.html#get_distribution_bundles"},{"doc":"aws_api/lightsail","title":"get_distribution_latest_cache_reset","content":"pub fn get_distribution_latest_cache_reset(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_distribution_latest_cache_reset\naws_api/lightsail get_distribution_latest_cache_reset","url":"aws_api/lightsail.html#get_distribution_latest_cache_reset"},{"doc":"aws_api/lightsail","title":"get_distribution_metric_data","content":"pub fn get_distribution_metric_data(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_distribution_metric_data\naws_api/lightsail get_distribution_metric_data","url":"aws_api/lightsail.html#get_distribution_metric_data"},{"doc":"aws_api/lightsail","title":"get_distributions","content":"pub fn get_distributions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_distributions\naws_api/lightsail get_distributions","url":"aws_api/lightsail.html#get_distributions"},{"doc":"aws_api/lightsail","title":"get_domain","content":"pub fn get_domain(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_domain\naws_api/lightsail get_domain","url":"aws_api/lightsail.html#get_domain"},{"doc":"aws_api/lightsail","title":"get_domains","content":"pub fn get_domains(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_domains\naws_api/lightsail get_domains","url":"aws_api/lightsail.html#get_domains"},{"doc":"aws_api/lightsail","title":"get_export_snapshot_records","content":"pub fn get_export_snapshot_records(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_export_snapshot_records\naws_api/lightsail get_export_snapshot_records","url":"aws_api/lightsail.html#get_export_snapshot_records"},{"doc":"aws_api/lightsail","title":"get_instance","content":"pub fn get_instance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_instance\naws_api/lightsail get_instance","url":"aws_api/lightsail.html#get_instance"},{"doc":"aws_api/lightsail","title":"get_instance_access_details","content":"pub fn get_instance_access_details(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_instance_access_details\naws_api/lightsail get_instance_access_details","url":"aws_api/lightsail.html#get_instance_access_details"},{"doc":"aws_api/lightsail","title":"get_instance_metric_data","content":"pub fn get_instance_metric_data(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_instance_metric_data\naws_api/lightsail get_instance_metric_data","url":"aws_api/lightsail.html#get_instance_metric_data"},{"doc":"aws_api/lightsail","title":"get_instance_port_states","content":"pub fn get_instance_port_states(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_instance_port_states\naws_api/lightsail get_instance_port_states","url":"aws_api/lightsail.html#get_instance_port_states"},{"doc":"aws_api/lightsail","title":"get_instance_snapshot","content":"pub fn get_instance_snapshot(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_instance_snapshot\naws_api/lightsail get_instance_snapshot","url":"aws_api/lightsail.html#get_instance_snapshot"},{"doc":"aws_api/lightsail","title":"get_instance_snapshots","content":"pub fn get_instance_snapshots(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_instance_snapshots\naws_api/lightsail get_instance_snapshots","url":"aws_api/lightsail.html#get_instance_snapshots"},{"doc":"aws_api/lightsail","title":"get_instance_state","content":"pub fn get_instance_state(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_instance_state\naws_api/lightsail get_instance_state","url":"aws_api/lightsail.html#get_instance_state"},{"doc":"aws_api/lightsail","title":"get_instances","content":"pub fn get_instances(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_instances\naws_api/lightsail get_instances","url":"aws_api/lightsail.html#get_instances"},{"doc":"aws_api/lightsail","title":"get_key_pair","content":"pub fn get_key_pair(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_key_pair\naws_api/lightsail get_key_pair","url":"aws_api/lightsail.html#get_key_pair"},{"doc":"aws_api/lightsail","title":"get_key_pairs","content":"pub fn get_key_pairs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_key_pairs\naws_api/lightsail get_key_pairs","url":"aws_api/lightsail.html#get_key_pairs"},{"doc":"aws_api/lightsail","title":"get_load_balancer","content":"pub fn get_load_balancer(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_load_balancer\naws_api/lightsail get_load_balancer","url":"aws_api/lightsail.html#get_load_balancer"},{"doc":"aws_api/lightsail","title":"get_load_balancer_metric_data","content":"pub fn get_load_balancer_metric_data(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_load_balancer_metric_data\naws_api/lightsail get_load_balancer_metric_data","url":"aws_api/lightsail.html#get_load_balancer_metric_data"},{"doc":"aws_api/lightsail","title":"get_load_balancer_tls_certificates","content":"pub fn get_load_balancer_tls_certificates(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_load_balancer_tls_certificates\naws_api/lightsail get_load_balancer_tls_certificates","url":"aws_api/lightsail.html#get_load_balancer_tls_certificates"},{"doc":"aws_api/lightsail","title":"get_load_balancer_tls_policies","content":"pub fn get_load_balancer_tls_policies(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_load_balancer_tls_policies\naws_api/lightsail get_load_balancer_tls_policies","url":"aws_api/lightsail.html#get_load_balancer_tls_policies"},{"doc":"aws_api/lightsail","title":"get_load_balancers","content":"pub fn get_load_balancers(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_load_balancers\naws_api/lightsail get_load_balancers","url":"aws_api/lightsail.html#get_load_balancers"},{"doc":"aws_api/lightsail","title":"get_operation","content":"pub fn get_operation(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_operation\naws_api/lightsail get_operation","url":"aws_api/lightsail.html#get_operation"},{"doc":"aws_api/lightsail","title":"get_operations","content":"pub fn get_operations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_operations\naws_api/lightsail get_operations","url":"aws_api/lightsail.html#get_operations"},{"doc":"aws_api/lightsail","title":"get_operations_for_resource","content":"pub fn get_operations_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_operations_for_resource\naws_api/lightsail get_operations_for_resource","url":"aws_api/lightsail.html#get_operations_for_resource"},{"doc":"aws_api/lightsail","title":"get_regions","content":"pub fn get_regions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_regions\naws_api/lightsail get_regions","url":"aws_api/lightsail.html#get_regions"},{"doc":"aws_api/lightsail","title":"get_relational_database","content":"pub fn get_relational_database(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_relational_database\naws_api/lightsail get_relational_database","url":"aws_api/lightsail.html#get_relational_database"},{"doc":"aws_api/lightsail","title":"get_relational_database_blueprints","content":"pub fn get_relational_database_blueprints(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_relational_database_blueprints\naws_api/lightsail get_relational_database_blueprints","url":"aws_api/lightsail.html#get_relational_database_blueprints"},{"doc":"aws_api/lightsail","title":"get_relational_database_bundles","content":"pub fn get_relational_database_bundles(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_relational_database_bundles\naws_api/lightsail get_relational_database_bundles","url":"aws_api/lightsail.html#get_relational_database_bundles"},{"doc":"aws_api/lightsail","title":"get_relational_database_events","content":"pub fn get_relational_database_events(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_relational_database_events\naws_api/lightsail get_relational_database_events","url":"aws_api/lightsail.html#get_relational_database_events"},{"doc":"aws_api/lightsail","title":"get_relational_database_log_events","content":"pub fn get_relational_database_log_events(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_relational_database_log_events\naws_api/lightsail get_relational_database_log_events","url":"aws_api/lightsail.html#get_relational_database_log_events"},{"doc":"aws_api/lightsail","title":"get_relational_database_log_streams","content":"pub fn get_relational_database_log_streams(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_relational_database_log_streams\naws_api/lightsail get_relational_database_log_streams","url":"aws_api/lightsail.html#get_relational_database_log_streams"},{"doc":"aws_api/lightsail","title":"get_relational_database_master_user_password","content":"pub fn get_relational_database_master_user_password(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_relational_database_master_user_password\naws_api/lightsail get_relational_database_master_user_password","url":"aws_api/lightsail.html#get_relational_database_master_user_password"},{"doc":"aws_api/lightsail","title":"get_relational_database_metric_data","content":"pub fn get_relational_database_metric_data(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_relational_database_metric_data\naws_api/lightsail get_relational_database_metric_data","url":"aws_api/lightsail.html#get_relational_database_metric_data"},{"doc":"aws_api/lightsail","title":"get_relational_database_parameters","content":"pub fn get_relational_database_parameters(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_relational_database_parameters\naws_api/lightsail get_relational_database_parameters","url":"aws_api/lightsail.html#get_relational_database_parameters"},{"doc":"aws_api/lightsail","title":"get_relational_database_snapshot","content":"pub fn get_relational_database_snapshot(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_relational_database_snapshot\naws_api/lightsail get_relational_database_snapshot","url":"aws_api/lightsail.html#get_relational_database_snapshot"},{"doc":"aws_api/lightsail","title":"get_relational_database_snapshots","content":"pub fn get_relational_database_snapshots(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_relational_database_snapshots\naws_api/lightsail get_relational_database_snapshots","url":"aws_api/lightsail.html#get_relational_database_snapshots"},{"doc":"aws_api/lightsail","title":"get_relational_databases","content":"pub fn get_relational_databases(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_relational_databases\naws_api/lightsail get_relational_databases","url":"aws_api/lightsail.html#get_relational_databases"},{"doc":"aws_api/lightsail","title":"get_setup_history","content":"pub fn get_setup_history(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_setup_history\naws_api/lightsail get_setup_history","url":"aws_api/lightsail.html#get_setup_history"},{"doc":"aws_api/lightsail","title":"get_static_ip","content":"pub fn get_static_ip(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_static_ip\naws_api/lightsail get_static_ip","url":"aws_api/lightsail.html#get_static_ip"},{"doc":"aws_api/lightsail","title":"get_static_ips","content":"pub fn get_static_ips(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.get_static_ips\naws_api/lightsail get_static_ips","url":"aws_api/lightsail.html#get_static_ips"},{"doc":"aws_api/lightsail","title":"import_key_pair","content":"pub fn import_key_pair(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.import_key_pair\naws_api/lightsail import_key_pair","url":"aws_api/lightsail.html#import_key_pair"},{"doc":"aws_api/lightsail","title":"is_vpc_peered","content":"pub fn is_vpc_peered(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.is_vpc_peered\naws_api/lightsail is_vpc_peered","url":"aws_api/lightsail.html#is_vpc_peered"},{"doc":"aws_api/lightsail","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/lightsail.new\naws_api/lightsail new","url":"aws_api/lightsail.html#new"},{"doc":"aws_api/lightsail","title":"open_instance_public_ports","content":"pub fn open_instance_public_ports(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.open_instance_public_ports\naws_api/lightsail open_instance_public_ports","url":"aws_api/lightsail.html#open_instance_public_ports"},{"doc":"aws_api/lightsail","title":"peer_vpc","content":"pub fn peer_vpc(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.peer_vpc\naws_api/lightsail peer_vpc","url":"aws_api/lightsail.html#peer_vpc"},{"doc":"aws_api/lightsail","title":"put_alarm","content":"pub fn put_alarm(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.put_alarm\naws_api/lightsail put_alarm","url":"aws_api/lightsail.html#put_alarm"},{"doc":"aws_api/lightsail","title":"put_instance_public_ports","content":"pub fn put_instance_public_ports(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.put_instance_public_ports\naws_api/lightsail put_instance_public_ports","url":"aws_api/lightsail.html#put_instance_public_ports"},{"doc":"aws_api/lightsail","title":"reboot_instance","content":"pub fn reboot_instance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.reboot_instance\naws_api/lightsail reboot_instance","url":"aws_api/lightsail.html#reboot_instance"},{"doc":"aws_api/lightsail","title":"reboot_relational_database","content":"pub fn reboot_relational_database(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.reboot_relational_database\naws_api/lightsail reboot_relational_database","url":"aws_api/lightsail.html#reboot_relational_database"},{"doc":"aws_api/lightsail","title":"register_container_image","content":"pub fn register_container_image(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.register_container_image\naws_api/lightsail register_container_image","url":"aws_api/lightsail.html#register_container_image"},{"doc":"aws_api/lightsail","title":"release_static_ip","content":"pub fn release_static_ip(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.release_static_ip\naws_api/lightsail release_static_ip","url":"aws_api/lightsail.html#release_static_ip"},{"doc":"aws_api/lightsail","title":"reset_distribution_cache","content":"pub fn reset_distribution_cache(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.reset_distribution_cache\naws_api/lightsail reset_distribution_cache","url":"aws_api/lightsail.html#reset_distribution_cache"},{"doc":"aws_api/lightsail","title":"send_contact_method_verification","content":"pub fn send_contact_method_verification(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.send_contact_method_verification\naws_api/lightsail send_contact_method_verification","url":"aws_api/lightsail.html#send_contact_method_verification"},{"doc":"aws_api/lightsail","title":"set_ip_address_type","content":"pub fn set_ip_address_type(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.set_ip_address_type\naws_api/lightsail set_ip_address_type","url":"aws_api/lightsail.html#set_ip_address_type"},{"doc":"aws_api/lightsail","title":"set_resource_access_for_bucket","content":"pub fn set_resource_access_for_bucket(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.set_resource_access_for_bucket\naws_api/lightsail set_resource_access_for_bucket","url":"aws_api/lightsail.html#set_resource_access_for_bucket"},{"doc":"aws_api/lightsail","title":"setup_instance_https","content":"pub fn setup_instance_https(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.setup_instance_https\naws_api/lightsail setup_instance_https","url":"aws_api/lightsail.html#setup_instance_https"},{"doc":"aws_api/lightsail","title":"start_gui_session","content":"pub fn start_gui_session(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.start_gui_session\naws_api/lightsail start_gui_session","url":"aws_api/lightsail.html#start_gui_session"},{"doc":"aws_api/lightsail","title":"start_instance","content":"pub fn start_instance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.start_instance\naws_api/lightsail start_instance","url":"aws_api/lightsail.html#start_instance"},{"doc":"aws_api/lightsail","title":"start_relational_database","content":"pub fn start_relational_database(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.start_relational_database\naws_api/lightsail start_relational_database","url":"aws_api/lightsail.html#start_relational_database"},{"doc":"aws_api/lightsail","title":"stop_gui_session","content":"pub fn stop_gui_session(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.stop_gui_session\naws_api/lightsail stop_gui_session","url":"aws_api/lightsail.html#stop_gui_session"},{"doc":"aws_api/lightsail","title":"stop_instance","content":"pub fn stop_instance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.stop_instance\naws_api/lightsail stop_instance","url":"aws_api/lightsail.html#stop_instance"},{"doc":"aws_api/lightsail","title":"stop_relational_database","content":"pub fn stop_relational_database(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.stop_relational_database\naws_api/lightsail stop_relational_database","url":"aws_api/lightsail.html#stop_relational_database"},{"doc":"aws_api/lightsail","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.tag_resource\naws_api/lightsail tag_resource","url":"aws_api/lightsail.html#tag_resource"},{"doc":"aws_api/lightsail","title":"test_alarm","content":"pub fn test_alarm(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.test_alarm\naws_api/lightsail test_alarm","url":"aws_api/lightsail.html#test_alarm"},{"doc":"aws_api/lightsail","title":"unpeer_vpc","content":"pub fn unpeer_vpc(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.unpeer_vpc\naws_api/lightsail unpeer_vpc","url":"aws_api/lightsail.html#unpeer_vpc"},{"doc":"aws_api/lightsail","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.untag_resource\naws_api/lightsail untag_resource","url":"aws_api/lightsail.html#untag_resource"},{"doc":"aws_api/lightsail","title":"update_bucket","content":"pub fn update_bucket(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.update_bucket\naws_api/lightsail update_bucket","url":"aws_api/lightsail.html#update_bucket"},{"doc":"aws_api/lightsail","title":"update_bucket_bundle","content":"pub fn update_bucket_bundle(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.update_bucket_bundle\naws_api/lightsail update_bucket_bundle","url":"aws_api/lightsail.html#update_bucket_bundle"},{"doc":"aws_api/lightsail","title":"update_container_service","content":"pub fn update_container_service(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.update_container_service\naws_api/lightsail update_container_service","url":"aws_api/lightsail.html#update_container_service"},{"doc":"aws_api/lightsail","title":"update_distribution","content":"pub fn update_distribution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.update_distribution\naws_api/lightsail update_distribution","url":"aws_api/lightsail.html#update_distribution"},{"doc":"aws_api/lightsail","title":"update_distribution_bundle","content":"pub fn update_distribution_bundle(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.update_distribution_bundle\naws_api/lightsail update_distribution_bundle","url":"aws_api/lightsail.html#update_distribution_bundle"},{"doc":"aws_api/lightsail","title":"update_domain_entry","content":"pub fn update_domain_entry(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.update_domain_entry\naws_api/lightsail update_domain_entry","url":"aws_api/lightsail.html#update_domain_entry"},{"doc":"aws_api/lightsail","title":"update_instance_metadata_options","content":"pub fn update_instance_metadata_options(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.update_instance_metadata_options\naws_api/lightsail update_instance_metadata_options","url":"aws_api/lightsail.html#update_instance_metadata_options"},{"doc":"aws_api/lightsail","title":"update_load_balancer_attribute","content":"pub fn update_load_balancer_attribute(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.update_load_balancer_attribute\naws_api/lightsail update_load_balancer_attribute","url":"aws_api/lightsail.html#update_load_balancer_attribute"},{"doc":"aws_api/lightsail","title":"update_relational_database","content":"pub fn update_relational_database(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.update_relational_database\naws_api/lightsail update_relational_database","url":"aws_api/lightsail.html#update_relational_database"},{"doc":"aws_api/lightsail","title":"update_relational_database_parameters","content":"pub fn update_relational_database_parameters(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lightsail.update_relational_database_parameters\naws_api/lightsail update_relational_database_parameters","url":"aws_api/lightsail.html#update_relational_database_parameters"},{"doc":"aws_api/lightsail","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/lightsail.with_custom_endpoint\naws_api/lightsail with_custom_endpoint","url":"aws_api/lightsail.html#with_custom_endpoint"},{"doc":"aws_api/lightsail","title":"aws_api/lightsail","content":"","url":"aws_api/lightsail.html"},{"doc":"aws_api/lookoutequipment","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/lookoutequipment.Client\naws_api/lookoutequipment Client","url":"aws_api/lookoutequipment.html#Client"},{"doc":"aws_api/lookoutequipment","title":"create_dataset","content":"pub fn create_dataset(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutequipment.create_dataset\naws_api/lookoutequipment create_dataset","url":"aws_api/lookoutequipment.html#create_dataset"},{"doc":"aws_api/lookoutequipment","title":"create_inference_scheduler","content":"pub fn create_inference_scheduler(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutequipment.create_inference_scheduler\naws_api/lookoutequipment create_inference_scheduler","url":"aws_api/lookoutequipment.html#create_inference_scheduler"},{"doc":"aws_api/lookoutequipment","title":"create_label","content":"pub fn create_label(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutequipment.create_label\naws_api/lookoutequipment create_label","url":"aws_api/lookoutequipment.html#create_label"},{"doc":"aws_api/lookoutequipment","title":"create_label_group","content":"pub fn create_label_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutequipment.create_label_group\naws_api/lookoutequipment create_label_group","url":"aws_api/lookoutequipment.html#create_label_group"},{"doc":"aws_api/lookoutequipment","title":"create_model","content":"pub fn create_model(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutequipment.create_model\naws_api/lookoutequipment create_model","url":"aws_api/lookoutequipment.html#create_model"},{"doc":"aws_api/lookoutequipment","title":"create_retraining_scheduler","content":"pub fn create_retraining_scheduler(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutequipment.create_retraining_scheduler\naws_api/lookoutequipment create_retraining_scheduler","url":"aws_api/lookoutequipment.html#create_retraining_scheduler"},{"doc":"aws_api/lookoutequipment","title":"delete_dataset","content":"pub fn delete_dataset(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutequipment.delete_dataset\naws_api/lookoutequipment delete_dataset","url":"aws_api/lookoutequipment.html#delete_dataset"},{"doc":"aws_api/lookoutequipment","title":"delete_inference_scheduler","content":"pub fn delete_inference_scheduler(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutequipment.delete_inference_scheduler\naws_api/lookoutequipment delete_inference_scheduler","url":"aws_api/lookoutequipment.html#delete_inference_scheduler"},{"doc":"aws_api/lookoutequipment","title":"delete_label","content":"pub fn delete_label(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutequipment.delete_label\naws_api/lookoutequipment delete_label","url":"aws_api/lookoutequipment.html#delete_label"},{"doc":"aws_api/lookoutequipment","title":"delete_label_group","content":"pub fn delete_label_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutequipment.delete_label_group\naws_api/lookoutequipment delete_label_group","url":"aws_api/lookoutequipment.html#delete_label_group"},{"doc":"aws_api/lookoutequipment","title":"delete_model","content":"pub fn delete_model(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutequipment.delete_model\naws_api/lookoutequipment delete_model","url":"aws_api/lookoutequipment.html#delete_model"},{"doc":"aws_api/lookoutequipment","title":"delete_resource_policy","content":"pub fn delete_resource_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutequipment.delete_resource_policy\naws_api/lookoutequipment delete_resource_policy","url":"aws_api/lookoutequipment.html#delete_resource_policy"},{"doc":"aws_api/lookoutequipment","title":"delete_retraining_scheduler","content":"pub fn delete_retraining_scheduler(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutequipment.delete_retraining_scheduler\naws_api/lookoutequipment delete_retraining_scheduler","url":"aws_api/lookoutequipment.html#delete_retraining_scheduler"},{"doc":"aws_api/lookoutequipment","title":"describe_data_ingestion_job","content":"pub fn describe_data_ingestion_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutequipment.describe_data_ingestion_job\naws_api/lookoutequipment describe_data_ingestion_job","url":"aws_api/lookoutequipment.html#describe_data_ingestion_job"},{"doc":"aws_api/lookoutequipment","title":"describe_dataset","content":"pub fn describe_dataset(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutequipment.describe_dataset\naws_api/lookoutequipment describe_dataset","url":"aws_api/lookoutequipment.html#describe_dataset"},{"doc":"aws_api/lookoutequipment","title":"describe_inference_scheduler","content":"pub fn describe_inference_scheduler(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutequipment.describe_inference_scheduler\naws_api/lookoutequipment describe_inference_scheduler","url":"aws_api/lookoutequipment.html#describe_inference_scheduler"},{"doc":"aws_api/lookoutequipment","title":"describe_label","content":"pub fn describe_label(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutequipment.describe_label\naws_api/lookoutequipment describe_label","url":"aws_api/lookoutequipment.html#describe_label"},{"doc":"aws_api/lookoutequipment","title":"describe_label_group","content":"pub fn describe_label_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutequipment.describe_label_group\naws_api/lookoutequipment describe_label_group","url":"aws_api/lookoutequipment.html#describe_label_group"},{"doc":"aws_api/lookoutequipment","title":"describe_model","content":"pub fn describe_model(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutequipment.describe_model\naws_api/lookoutequipment describe_model","url":"aws_api/lookoutequipment.html#describe_model"},{"doc":"aws_api/lookoutequipment","title":"describe_model_version","content":"pub fn describe_model_version(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutequipment.describe_model_version\naws_api/lookoutequipment describe_model_version","url":"aws_api/lookoutequipment.html#describe_model_version"},{"doc":"aws_api/lookoutequipment","title":"describe_resource_policy","content":"pub fn describe_resource_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutequipment.describe_resource_policy\naws_api/lookoutequipment describe_resource_policy","url":"aws_api/lookoutequipment.html#describe_resource_policy"},{"doc":"aws_api/lookoutequipment","title":"describe_retraining_scheduler","content":"pub fn describe_retraining_scheduler(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutequipment.describe_retraining_scheduler\naws_api/lookoutequipment describe_retraining_scheduler","url":"aws_api/lookoutequipment.html#describe_retraining_scheduler"},{"doc":"aws_api/lookoutequipment","title":"import_dataset","content":"pub fn import_dataset(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutequipment.import_dataset\naws_api/lookoutequipment import_dataset","url":"aws_api/lookoutequipment.html#import_dataset"},{"doc":"aws_api/lookoutequipment","title":"import_model_version","content":"pub fn import_model_version(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutequipment.import_model_version\naws_api/lookoutequipment import_model_version","url":"aws_api/lookoutequipment.html#import_model_version"},{"doc":"aws_api/lookoutequipment","title":"list_data_ingestion_jobs","content":"pub fn list_data_ingestion_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutequipment.list_data_ingestion_jobs\naws_api/lookoutequipment list_data_ingestion_jobs","url":"aws_api/lookoutequipment.html#list_data_ingestion_jobs"},{"doc":"aws_api/lookoutequipment","title":"list_datasets","content":"pub fn list_datasets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutequipment.list_datasets\naws_api/lookoutequipment list_datasets","url":"aws_api/lookoutequipment.html#list_datasets"},{"doc":"aws_api/lookoutequipment","title":"list_inference_events","content":"pub fn list_inference_events(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutequipment.list_inference_events\naws_api/lookoutequipment list_inference_events","url":"aws_api/lookoutequipment.html#list_inference_events"},{"doc":"aws_api/lookoutequipment","title":"list_inference_executions","content":"pub fn list_inference_executions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutequipment.list_inference_executions\naws_api/lookoutequipment list_inference_executions","url":"aws_api/lookoutequipment.html#list_inference_executions"},{"doc":"aws_api/lookoutequipment","title":"list_inference_schedulers","content":"pub fn list_inference_schedulers(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutequipment.list_inference_schedulers\naws_api/lookoutequipment list_inference_schedulers","url":"aws_api/lookoutequipment.html#list_inference_schedulers"},{"doc":"aws_api/lookoutequipment","title":"list_label_groups","content":"pub fn list_label_groups(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutequipment.list_label_groups\naws_api/lookoutequipment list_label_groups","url":"aws_api/lookoutequipment.html#list_label_groups"},{"doc":"aws_api/lookoutequipment","title":"list_labels","content":"pub fn list_labels(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutequipment.list_labels\naws_api/lookoutequipment list_labels","url":"aws_api/lookoutequipment.html#list_labels"},{"doc":"aws_api/lookoutequipment","title":"list_model_versions","content":"pub fn list_model_versions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutequipment.list_model_versions\naws_api/lookoutequipment list_model_versions","url":"aws_api/lookoutequipment.html#list_model_versions"},{"doc":"aws_api/lookoutequipment","title":"list_models","content":"pub fn list_models(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutequipment.list_models\naws_api/lookoutequipment list_models","url":"aws_api/lookoutequipment.html#list_models"},{"doc":"aws_api/lookoutequipment","title":"list_retraining_schedulers","content":"pub fn list_retraining_schedulers(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutequipment.list_retraining_schedulers\naws_api/lookoutequipment list_retraining_schedulers","url":"aws_api/lookoutequipment.html#list_retraining_schedulers"},{"doc":"aws_api/lookoutequipment","title":"list_sensor_statistics","content":"pub fn list_sensor_statistics(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutequipment.list_sensor_statistics\naws_api/lookoutequipment list_sensor_statistics","url":"aws_api/lookoutequipment.html#list_sensor_statistics"},{"doc":"aws_api/lookoutequipment","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutequipment.list_tags_for_resource\naws_api/lookoutequipment list_tags_for_resource","url":"aws_api/lookoutequipment.html#list_tags_for_resource"},{"doc":"aws_api/lookoutequipment","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/lookoutequipment.new\naws_api/lookoutequipment new","url":"aws_api/lookoutequipment.html#new"},{"doc":"aws_api/lookoutequipment","title":"put_resource_policy","content":"pub fn put_resource_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutequipment.put_resource_policy\naws_api/lookoutequipment put_resource_policy","url":"aws_api/lookoutequipment.html#put_resource_policy"},{"doc":"aws_api/lookoutequipment","title":"start_data_ingestion_job","content":"pub fn start_data_ingestion_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutequipment.start_data_ingestion_job\naws_api/lookoutequipment start_data_ingestion_job","url":"aws_api/lookoutequipment.html#start_data_ingestion_job"},{"doc":"aws_api/lookoutequipment","title":"start_inference_scheduler","content":"pub fn start_inference_scheduler(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutequipment.start_inference_scheduler\naws_api/lookoutequipment start_inference_scheduler","url":"aws_api/lookoutequipment.html#start_inference_scheduler"},{"doc":"aws_api/lookoutequipment","title":"start_retraining_scheduler","content":"pub fn start_retraining_scheduler(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutequipment.start_retraining_scheduler\naws_api/lookoutequipment start_retraining_scheduler","url":"aws_api/lookoutequipment.html#start_retraining_scheduler"},{"doc":"aws_api/lookoutequipment","title":"stop_inference_scheduler","content":"pub fn stop_inference_scheduler(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutequipment.stop_inference_scheduler\naws_api/lookoutequipment stop_inference_scheduler","url":"aws_api/lookoutequipment.html#stop_inference_scheduler"},{"doc":"aws_api/lookoutequipment","title":"stop_retraining_scheduler","content":"pub fn stop_retraining_scheduler(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutequipment.stop_retraining_scheduler\naws_api/lookoutequipment stop_retraining_scheduler","url":"aws_api/lookoutequipment.html#stop_retraining_scheduler"},{"doc":"aws_api/lookoutequipment","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutequipment.tag_resource\naws_api/lookoutequipment tag_resource","url":"aws_api/lookoutequipment.html#tag_resource"},{"doc":"aws_api/lookoutequipment","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutequipment.untag_resource\naws_api/lookoutequipment untag_resource","url":"aws_api/lookoutequipment.html#untag_resource"},{"doc":"aws_api/lookoutequipment","title":"update_active_model_version","content":"pub fn update_active_model_version(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutequipment.update_active_model_version\naws_api/lookoutequipment update_active_model_version","url":"aws_api/lookoutequipment.html#update_active_model_version"},{"doc":"aws_api/lookoutequipment","title":"update_inference_scheduler","content":"pub fn update_inference_scheduler(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutequipment.update_inference_scheduler\naws_api/lookoutequipment update_inference_scheduler","url":"aws_api/lookoutequipment.html#update_inference_scheduler"},{"doc":"aws_api/lookoutequipment","title":"update_label_group","content":"pub fn update_label_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutequipment.update_label_group\naws_api/lookoutequipment update_label_group","url":"aws_api/lookoutequipment.html#update_label_group"},{"doc":"aws_api/lookoutequipment","title":"update_model","content":"pub fn update_model(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutequipment.update_model\naws_api/lookoutequipment update_model","url":"aws_api/lookoutequipment.html#update_model"},{"doc":"aws_api/lookoutequipment","title":"update_retraining_scheduler","content":"pub fn update_retraining_scheduler(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutequipment.update_retraining_scheduler\naws_api/lookoutequipment update_retraining_scheduler","url":"aws_api/lookoutequipment.html#update_retraining_scheduler"},{"doc":"aws_api/lookoutequipment","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/lookoutequipment.with_custom_endpoint\naws_api/lookoutequipment with_custom_endpoint","url":"aws_api/lookoutequipment.html#with_custom_endpoint"},{"doc":"aws_api/lookoutequipment","title":"aws_api/lookoutequipment","content":"","url":"aws_api/lookoutequipment.html"},{"doc":"aws_api/lookoutmetrics","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/lookoutmetrics.Client\naws_api/lookoutmetrics Client","url":"aws_api/lookoutmetrics.html#Client"},{"doc":"aws_api/lookoutmetrics","title":"activate_anomaly_detector","content":"pub fn activate_anomaly_detector(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutmetrics.activate_anomaly_detector\naws_api/lookoutmetrics activate_anomaly_detector","url":"aws_api/lookoutmetrics.html#activate_anomaly_detector"},{"doc":"aws_api/lookoutmetrics","title":"back_test_anomaly_detector","content":"pub fn back_test_anomaly_detector(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutmetrics.back_test_anomaly_detector\naws_api/lookoutmetrics back_test_anomaly_detector","url":"aws_api/lookoutmetrics.html#back_test_anomaly_detector"},{"doc":"aws_api/lookoutmetrics","title":"create_alert","content":"pub fn create_alert(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutmetrics.create_alert\naws_api/lookoutmetrics create_alert","url":"aws_api/lookoutmetrics.html#create_alert"},{"doc":"aws_api/lookoutmetrics","title":"create_anomaly_detector","content":"pub fn create_anomaly_detector(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutmetrics.create_anomaly_detector\naws_api/lookoutmetrics create_anomaly_detector","url":"aws_api/lookoutmetrics.html#create_anomaly_detector"},{"doc":"aws_api/lookoutmetrics","title":"create_metric_set","content":"pub fn create_metric_set(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutmetrics.create_metric_set\naws_api/lookoutmetrics create_metric_set","url":"aws_api/lookoutmetrics.html#create_metric_set"},{"doc":"aws_api/lookoutmetrics","title":"deactivate_anomaly_detector","content":"pub fn deactivate_anomaly_detector(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutmetrics.deactivate_anomaly_detector\naws_api/lookoutmetrics deactivate_anomaly_detector","url":"aws_api/lookoutmetrics.html#deactivate_anomaly_detector"},{"doc":"aws_api/lookoutmetrics","title":"delete_alert","content":"pub fn delete_alert(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutmetrics.delete_alert\naws_api/lookoutmetrics delete_alert","url":"aws_api/lookoutmetrics.html#delete_alert"},{"doc":"aws_api/lookoutmetrics","title":"delete_anomaly_detector","content":"pub fn delete_anomaly_detector(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutmetrics.delete_anomaly_detector\naws_api/lookoutmetrics delete_anomaly_detector","url":"aws_api/lookoutmetrics.html#delete_anomaly_detector"},{"doc":"aws_api/lookoutmetrics","title":"describe_alert","content":"pub fn describe_alert(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutmetrics.describe_alert\naws_api/lookoutmetrics describe_alert","url":"aws_api/lookoutmetrics.html#describe_alert"},{"doc":"aws_api/lookoutmetrics","title":"describe_anomaly_detection_executions","content":"pub fn describe_anomaly_detection_executions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutmetrics.describe_anomaly_detection_executions\naws_api/lookoutmetrics describe_anomaly_detection_executions","url":"aws_api/lookoutmetrics.html#describe_anomaly_detection_executions"},{"doc":"aws_api/lookoutmetrics","title":"describe_anomaly_detector","content":"pub fn describe_anomaly_detector(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutmetrics.describe_anomaly_detector\naws_api/lookoutmetrics describe_anomaly_detector","url":"aws_api/lookoutmetrics.html#describe_anomaly_detector"},{"doc":"aws_api/lookoutmetrics","title":"describe_metric_set","content":"pub fn describe_metric_set(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutmetrics.describe_metric_set\naws_api/lookoutmetrics describe_metric_set","url":"aws_api/lookoutmetrics.html#describe_metric_set"},{"doc":"aws_api/lookoutmetrics","title":"detect_metric_set_config","content":"pub fn detect_metric_set_config(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutmetrics.detect_metric_set_config\naws_api/lookoutmetrics detect_metric_set_config","url":"aws_api/lookoutmetrics.html#detect_metric_set_config"},{"doc":"aws_api/lookoutmetrics","title":"get_anomaly_group","content":"pub fn get_anomaly_group(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutmetrics.get_anomaly_group\naws_api/lookoutmetrics get_anomaly_group","url":"aws_api/lookoutmetrics.html#get_anomaly_group"},{"doc":"aws_api/lookoutmetrics","title":"get_data_quality_metrics","content":"pub fn get_data_quality_metrics(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutmetrics.get_data_quality_metrics\naws_api/lookoutmetrics get_data_quality_metrics","url":"aws_api/lookoutmetrics.html#get_data_quality_metrics"},{"doc":"aws_api/lookoutmetrics","title":"get_feedback","content":"pub fn get_feedback(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutmetrics.get_feedback\naws_api/lookoutmetrics get_feedback","url":"aws_api/lookoutmetrics.html#get_feedback"},{"doc":"aws_api/lookoutmetrics","title":"get_sample_data","content":"pub fn get_sample_data(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutmetrics.get_sample_data\naws_api/lookoutmetrics get_sample_data","url":"aws_api/lookoutmetrics.html#get_sample_data"},{"doc":"aws_api/lookoutmetrics","title":"list_alerts","content":"pub fn list_alerts(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutmetrics.list_alerts\naws_api/lookoutmetrics list_alerts","url":"aws_api/lookoutmetrics.html#list_alerts"},{"doc":"aws_api/lookoutmetrics","title":"list_anomaly_detectors","content":"pub fn list_anomaly_detectors(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutmetrics.list_anomaly_detectors\naws_api/lookoutmetrics list_anomaly_detectors","url":"aws_api/lookoutmetrics.html#list_anomaly_detectors"},{"doc":"aws_api/lookoutmetrics","title":"list_anomaly_group_related_metrics","content":"pub fn list_anomaly_group_related_metrics(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutmetrics.list_anomaly_group_related_metrics\naws_api/lookoutmetrics list_anomaly_group_related_metrics","url":"aws_api/lookoutmetrics.html#list_anomaly_group_related_metrics"},{"doc":"aws_api/lookoutmetrics","title":"list_anomaly_group_summaries","content":"pub fn list_anomaly_group_summaries(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutmetrics.list_anomaly_group_summaries\naws_api/lookoutmetrics list_anomaly_group_summaries","url":"aws_api/lookoutmetrics.html#list_anomaly_group_summaries"},{"doc":"aws_api/lookoutmetrics","title":"list_anomaly_group_time_series","content":"pub fn list_anomaly_group_time_series(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutmetrics.list_anomaly_group_time_series\naws_api/lookoutmetrics list_anomaly_group_time_series","url":"aws_api/lookoutmetrics.html#list_anomaly_group_time_series"},{"doc":"aws_api/lookoutmetrics","title":"list_metric_sets","content":"pub fn list_metric_sets(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutmetrics.list_metric_sets\naws_api/lookoutmetrics list_metric_sets","url":"aws_api/lookoutmetrics.html#list_metric_sets"},{"doc":"aws_api/lookoutmetrics","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutmetrics.list_tags_for_resource\naws_api/lookoutmetrics list_tags_for_resource","url":"aws_api/lookoutmetrics.html#list_tags_for_resource"},{"doc":"aws_api/lookoutmetrics","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/lookoutmetrics.new\naws_api/lookoutmetrics new","url":"aws_api/lookoutmetrics.html#new"},{"doc":"aws_api/lookoutmetrics","title":"put_feedback","content":"pub fn put_feedback(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutmetrics.put_feedback\naws_api/lookoutmetrics put_feedback","url":"aws_api/lookoutmetrics.html#put_feedback"},{"doc":"aws_api/lookoutmetrics","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutmetrics.tag_resource\naws_api/lookoutmetrics tag_resource","url":"aws_api/lookoutmetrics.html#tag_resource"},{"doc":"aws_api/lookoutmetrics","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutmetrics.untag_resource\naws_api/lookoutmetrics untag_resource","url":"aws_api/lookoutmetrics.html#untag_resource"},{"doc":"aws_api/lookoutmetrics","title":"update_alert","content":"pub fn update_alert(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutmetrics.update_alert\naws_api/lookoutmetrics update_alert","url":"aws_api/lookoutmetrics.html#update_alert"},{"doc":"aws_api/lookoutmetrics","title":"update_anomaly_detector","content":"pub fn update_anomaly_detector(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutmetrics.update_anomaly_detector\naws_api/lookoutmetrics update_anomaly_detector","url":"aws_api/lookoutmetrics.html#update_anomaly_detector"},{"doc":"aws_api/lookoutmetrics","title":"update_metric_set","content":"pub fn update_metric_set(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutmetrics.update_metric_set\naws_api/lookoutmetrics update_metric_set","url":"aws_api/lookoutmetrics.html#update_metric_set"},{"doc":"aws_api/lookoutmetrics","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/lookoutmetrics.with_custom_endpoint\naws_api/lookoutmetrics with_custom_endpoint","url":"aws_api/lookoutmetrics.html#with_custom_endpoint"},{"doc":"aws_api/lookoutmetrics","title":"aws_api/lookoutmetrics","content":"","url":"aws_api/lookoutmetrics.html"},{"doc":"aws_api/lookoutvision","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/lookoutvision.Client\naws_api/lookoutvision Client","url":"aws_api/lookoutvision.html#Client"},{"doc":"aws_api/lookoutvision","title":"create_dataset","content":"pub fn create_dataset(\n  client: Client,\n  project_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutvision.create_dataset\naws_api/lookoutvision create_dataset","url":"aws_api/lookoutvision.html#create_dataset"},{"doc":"aws_api/lookoutvision","title":"create_model","content":"pub fn create_model(\n  client: Client,\n  project_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutvision.create_model\naws_api/lookoutvision create_model","url":"aws_api/lookoutvision.html#create_model"},{"doc":"aws_api/lookoutvision","title":"create_project","content":"pub fn create_project(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutvision.create_project\naws_api/lookoutvision create_project","url":"aws_api/lookoutvision.html#create_project"},{"doc":"aws_api/lookoutvision","title":"delete_dataset","content":"pub fn delete_dataset(\n  client: Client,\n  project_name: String,\n  dataset_type: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutvision.delete_dataset\naws_api/lookoutvision delete_dataset","url":"aws_api/lookoutvision.html#delete_dataset"},{"doc":"aws_api/lookoutvision","title":"delete_model","content":"pub fn delete_model(\n  client: Client,\n  project_name: String,\n  model_version: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutvision.delete_model\naws_api/lookoutvision delete_model","url":"aws_api/lookoutvision.html#delete_model"},{"doc":"aws_api/lookoutvision","title":"delete_project","content":"pub fn delete_project(\n  client: Client,\n  project_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutvision.delete_project\naws_api/lookoutvision delete_project","url":"aws_api/lookoutvision.html#delete_project"},{"doc":"aws_api/lookoutvision","title":"describe_dataset","content":"pub fn describe_dataset(\n  client: Client,\n  project_name: String,\n  dataset_type: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutvision.describe_dataset\naws_api/lookoutvision describe_dataset","url":"aws_api/lookoutvision.html#describe_dataset"},{"doc":"aws_api/lookoutvision","title":"describe_model","content":"pub fn describe_model(\n  client: Client,\n  project_name: String,\n  model_version: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutvision.describe_model\naws_api/lookoutvision describe_model","url":"aws_api/lookoutvision.html#describe_model"},{"doc":"aws_api/lookoutvision","title":"describe_model_packaging_job","content":"pub fn describe_model_packaging_job(\n  client: Client,\n  project_name: String,\n  job_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutvision.describe_model_packaging_job\naws_api/lookoutvision describe_model_packaging_job","url":"aws_api/lookoutvision.html#describe_model_packaging_job"},{"doc":"aws_api/lookoutvision","title":"describe_project","content":"pub fn describe_project(\n  client: Client,\n  project_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutvision.describe_project\naws_api/lookoutvision describe_project","url":"aws_api/lookoutvision.html#describe_project"},{"doc":"aws_api/lookoutvision","title":"detect_anomalies","content":"pub fn detect_anomalies(\n  client: Client,\n  project_name: String,\n  model_version: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutvision.detect_anomalies\naws_api/lookoutvision detect_anomalies","url":"aws_api/lookoutvision.html#detect_anomalies"},{"doc":"aws_api/lookoutvision","title":"list_dataset_entries","content":"pub fn list_dataset_entries(\n  client: Client,\n  project_name: String,\n  dataset_type: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutvision.list_dataset_entries\naws_api/lookoutvision list_dataset_entries","url":"aws_api/lookoutvision.html#list_dataset_entries"},{"doc":"aws_api/lookoutvision","title":"list_model_packaging_jobs","content":"pub fn list_model_packaging_jobs(\n  client: Client,\n  project_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutvision.list_model_packaging_jobs\naws_api/lookoutvision list_model_packaging_jobs","url":"aws_api/lookoutvision.html#list_model_packaging_jobs"},{"doc":"aws_api/lookoutvision","title":"list_models","content":"pub fn list_models(\n  client: Client,\n  project_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutvision.list_models\naws_api/lookoutvision list_models","url":"aws_api/lookoutvision.html#list_models"},{"doc":"aws_api/lookoutvision","title":"list_projects","content":"pub fn list_projects(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutvision.list_projects\naws_api/lookoutvision list_projects","url":"aws_api/lookoutvision.html#list_projects"},{"doc":"aws_api/lookoutvision","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutvision.list_tags_for_resource\naws_api/lookoutvision list_tags_for_resource","url":"aws_api/lookoutvision.html#list_tags_for_resource"},{"doc":"aws_api/lookoutvision","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/lookoutvision.new\naws_api/lookoutvision new","url":"aws_api/lookoutvision.html#new"},{"doc":"aws_api/lookoutvision","title":"start_model","content":"pub fn start_model(\n  client: Client,\n  project_name: String,\n  model_version: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutvision.start_model\naws_api/lookoutvision start_model","url":"aws_api/lookoutvision.html#start_model"},{"doc":"aws_api/lookoutvision","title":"start_model_packaging_job","content":"pub fn start_model_packaging_job(\n  client: Client,\n  project_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutvision.start_model_packaging_job\naws_api/lookoutvision start_model_packaging_job","url":"aws_api/lookoutvision.html#start_model_packaging_job"},{"doc":"aws_api/lookoutvision","title":"stop_model","content":"pub fn stop_model(\n  client: Client,\n  project_name: String,\n  model_version: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutvision.stop_model\naws_api/lookoutvision stop_model","url":"aws_api/lookoutvision.html#stop_model"},{"doc":"aws_api/lookoutvision","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutvision.tag_resource\naws_api/lookoutvision tag_resource","url":"aws_api/lookoutvision.html#tag_resource"},{"doc":"aws_api/lookoutvision","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutvision.untag_resource\naws_api/lookoutvision untag_resource","url":"aws_api/lookoutvision.html#untag_resource"},{"doc":"aws_api/lookoutvision","title":"update_dataset_entries","content":"pub fn update_dataset_entries(\n  client: Client,\n  project_name: String,\n  dataset_type: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/lookoutvision.update_dataset_entries\naws_api/lookoutvision update_dataset_entries","url":"aws_api/lookoutvision.html#update_dataset_entries"},{"doc":"aws_api/lookoutvision","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/lookoutvision.with_custom_endpoint\naws_api/lookoutvision with_custom_endpoint","url":"aws_api/lookoutvision.html#with_custom_endpoint"},{"doc":"aws_api/lookoutvision","title":"aws_api/lookoutvision","content":"","url":"aws_api/lookoutvision.html"},{"doc":"aws_api/m2","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/m2.Client\naws_api/m2 Client","url":"aws_api/m2.html#Client"},{"doc":"aws_api/m2","title":"get_signed_bluinsights_url","content":"pub fn get_signed_bluinsights_url(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/m2.get_signed_bluinsights_url\naws_api/m2 get_signed_bluinsights_url","url":"aws_api/m2.html#get_signed_bluinsights_url"},{"doc":"aws_api/m2","title":"list_engine_versions","content":"pub fn list_engine_versions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/m2.list_engine_versions\naws_api/m2 list_engine_versions","url":"aws_api/m2.html#list_engine_versions"},{"doc":"aws_api/m2","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/m2.list_tags_for_resource\naws_api/m2 list_tags_for_resource","url":"aws_api/m2.html#list_tags_for_resource"},{"doc":"aws_api/m2","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/m2.new\naws_api/m2 new","url":"aws_api/m2.html#new"},{"doc":"aws_api/m2","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/m2.tag_resource\naws_api/m2 tag_resource","url":"aws_api/m2.html#tag_resource"},{"doc":"aws_api/m2","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/m2.untag_resource\naws_api/m2 untag_resource","url":"aws_api/m2.html#untag_resource"},{"doc":"aws_api/m2","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/m2.with_custom_endpoint\naws_api/m2 with_custom_endpoint","url":"aws_api/m2.html#with_custom_endpoint"},{"doc":"aws_api/m2","title":"aws_api/m2","content":"","url":"aws_api/m2.html"},{"doc":"aws_api/machine_learning","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/machine_learning.Client\naws_api/machine_learning Client","url":"aws_api/machine_learning.html#Client"},{"doc":"aws_api/machine_learning","title":"add_tags","content":"pub fn add_tags(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/machine_learning.add_tags\naws_api/machine_learning add_tags","url":"aws_api/machine_learning.html#add_tags"},{"doc":"aws_api/machine_learning","title":"create_batch_prediction","content":"pub fn create_batch_prediction(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/machine_learning.create_batch_prediction\naws_api/machine_learning create_batch_prediction","url":"aws_api/machine_learning.html#create_batch_prediction"},{"doc":"aws_api/machine_learning","title":"create_data_source_from_rds","content":"pub fn create_data_source_from_rds(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/machine_learning.create_data_source_from_rds\naws_api/machine_learning create_data_source_from_rds","url":"aws_api/machine_learning.html#create_data_source_from_rds"},{"doc":"aws_api/machine_learning","title":"create_data_source_from_redshift","content":"pub fn create_data_source_from_redshift(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/machine_learning.create_data_source_from_redshift\naws_api/machine_learning create_data_source_from_redshift","url":"aws_api/machine_learning.html#create_data_source_from_redshift"},{"doc":"aws_api/machine_learning","title":"create_data_source_from_s3","content":"pub fn create_data_source_from_s3(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/machine_learning.create_data_source_from_s3\naws_api/machine_learning create_data_source_from_s3","url":"aws_api/machine_learning.html#create_data_source_from_s3"},{"doc":"aws_api/machine_learning","title":"create_evaluation","content":"pub fn create_evaluation(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/machine_learning.create_evaluation\naws_api/machine_learning create_evaluation","url":"aws_api/machine_learning.html#create_evaluation"},{"doc":"aws_api/machine_learning","title":"create_ml_model","content":"pub fn create_ml_model(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/machine_learning.create_ml_model\naws_api/machine_learning create_ml_model","url":"aws_api/machine_learning.html#create_ml_model"},{"doc":"aws_api/machine_learning","title":"create_realtime_endpoint","content":"pub fn create_realtime_endpoint(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/machine_learning.create_realtime_endpoint\naws_api/machine_learning create_realtime_endpoint","url":"aws_api/machine_learning.html#create_realtime_endpoint"},{"doc":"aws_api/machine_learning","title":"delete_batch_prediction","content":"pub fn delete_batch_prediction(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/machine_learning.delete_batch_prediction\naws_api/machine_learning delete_batch_prediction","url":"aws_api/machine_learning.html#delete_batch_prediction"},{"doc":"aws_api/machine_learning","title":"delete_data_source","content":"pub fn delete_data_source(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/machine_learning.delete_data_source\naws_api/machine_learning delete_data_source","url":"aws_api/machine_learning.html#delete_data_source"},{"doc":"aws_api/machine_learning","title":"delete_evaluation","content":"pub fn delete_evaluation(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/machine_learning.delete_evaluation\naws_api/machine_learning delete_evaluation","url":"aws_api/machine_learning.html#delete_evaluation"},{"doc":"aws_api/machine_learning","title":"delete_ml_model","content":"pub fn delete_ml_model(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/machine_learning.delete_ml_model\naws_api/machine_learning delete_ml_model","url":"aws_api/machine_learning.html#delete_ml_model"},{"doc":"aws_api/machine_learning","title":"delete_realtime_endpoint","content":"pub fn delete_realtime_endpoint(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/machine_learning.delete_realtime_endpoint\naws_api/machine_learning delete_realtime_endpoint","url":"aws_api/machine_learning.html#delete_realtime_endpoint"},{"doc":"aws_api/machine_learning","title":"delete_tags","content":"pub fn delete_tags(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/machine_learning.delete_tags\naws_api/machine_learning delete_tags","url":"aws_api/machine_learning.html#delete_tags"},{"doc":"aws_api/machine_learning","title":"describe_batch_predictions","content":"pub fn describe_batch_predictions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/machine_learning.describe_batch_predictions\naws_api/machine_learning describe_batch_predictions","url":"aws_api/machine_learning.html#describe_batch_predictions"},{"doc":"aws_api/machine_learning","title":"describe_data_sources","content":"pub fn describe_data_sources(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/machine_learning.describe_data_sources\naws_api/machine_learning describe_data_sources","url":"aws_api/machine_learning.html#describe_data_sources"},{"doc":"aws_api/machine_learning","title":"describe_evaluations","content":"pub fn describe_evaluations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/machine_learning.describe_evaluations\naws_api/machine_learning describe_evaluations","url":"aws_api/machine_learning.html#describe_evaluations"},{"doc":"aws_api/machine_learning","title":"describe_ml_models","content":"pub fn describe_ml_models(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/machine_learning.describe_ml_models\naws_api/machine_learning describe_ml_models","url":"aws_api/machine_learning.html#describe_ml_models"},{"doc":"aws_api/machine_learning","title":"describe_tags","content":"pub fn describe_tags(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/machine_learning.describe_tags\naws_api/machine_learning describe_tags","url":"aws_api/machine_learning.html#describe_tags"},{"doc":"aws_api/machine_learning","title":"get_batch_prediction","content":"pub fn get_batch_prediction(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/machine_learning.get_batch_prediction\naws_api/machine_learning get_batch_prediction","url":"aws_api/machine_learning.html#get_batch_prediction"},{"doc":"aws_api/machine_learning","title":"get_data_source","content":"pub fn get_data_source(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/machine_learning.get_data_source\naws_api/machine_learning get_data_source","url":"aws_api/machine_learning.html#get_data_source"},{"doc":"aws_api/machine_learning","title":"get_evaluation","content":"pub fn get_evaluation(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/machine_learning.get_evaluation\naws_api/machine_learning get_evaluation","url":"aws_api/machine_learning.html#get_evaluation"},{"doc":"aws_api/machine_learning","title":"get_ml_model","content":"pub fn get_ml_model(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/machine_learning.get_ml_model\naws_api/machine_learning get_ml_model","url":"aws_api/machine_learning.html#get_ml_model"},{"doc":"aws_api/machine_learning","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/machine_learning.new\naws_api/machine_learning new","url":"aws_api/machine_learning.html#new"},{"doc":"aws_api/machine_learning","title":"predict","content":"pub fn predict(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/machine_learning.predict\naws_api/machine_learning predict","url":"aws_api/machine_learning.html#predict"},{"doc":"aws_api/machine_learning","title":"update_batch_prediction","content":"pub fn update_batch_prediction(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/machine_learning.update_batch_prediction\naws_api/machine_learning update_batch_prediction","url":"aws_api/machine_learning.html#update_batch_prediction"},{"doc":"aws_api/machine_learning","title":"update_data_source","content":"pub fn update_data_source(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/machine_learning.update_data_source\naws_api/machine_learning update_data_source","url":"aws_api/machine_learning.html#update_data_source"},{"doc":"aws_api/machine_learning","title":"update_evaluation","content":"pub fn update_evaluation(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/machine_learning.update_evaluation\naws_api/machine_learning update_evaluation","url":"aws_api/machine_learning.html#update_evaluation"},{"doc":"aws_api/machine_learning","title":"update_ml_model","content":"pub fn update_ml_model(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/machine_learning.update_ml_model\naws_api/machine_learning update_ml_model","url":"aws_api/machine_learning.html#update_ml_model"},{"doc":"aws_api/machine_learning","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/machine_learning.with_custom_endpoint\naws_api/machine_learning with_custom_endpoint","url":"aws_api/machine_learning.html#with_custom_endpoint"},{"doc":"aws_api/machine_learning","title":"aws_api/machine_learning","content":"","url":"aws_api/machine_learning.html"},{"doc":"aws_api/macie2","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/macie2.Client\naws_api/macie2 Client","url":"aws_api/macie2.html#Client"},{"doc":"aws_api/macie2","title":"accept_invitation","content":"pub fn accept_invitation(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.accept_invitation\naws_api/macie2 accept_invitation","url":"aws_api/macie2.html#accept_invitation"},{"doc":"aws_api/macie2","title":"batch_get_custom_data_identifiers","content":"pub fn batch_get_custom_data_identifiers(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.batch_get_custom_data_identifiers\naws_api/macie2 batch_get_custom_data_identifiers","url":"aws_api/macie2.html#batch_get_custom_data_identifiers"},{"doc":"aws_api/macie2","title":"batch_update_automated_discovery_accounts","content":"pub fn batch_update_automated_discovery_accounts(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.batch_update_automated_discovery_accounts\naws_api/macie2 batch_update_automated_discovery_accounts","url":"aws_api/macie2.html#batch_update_automated_discovery_accounts"},{"doc":"aws_api/macie2","title":"create_allow_list","content":"pub fn create_allow_list(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.create_allow_list\naws_api/macie2 create_allow_list","url":"aws_api/macie2.html#create_allow_list"},{"doc":"aws_api/macie2","title":"create_classification_job","content":"pub fn create_classification_job(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.create_classification_job\naws_api/macie2 create_classification_job","url":"aws_api/macie2.html#create_classification_job"},{"doc":"aws_api/macie2","title":"create_custom_data_identifier","content":"pub fn create_custom_data_identifier(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.create_custom_data_identifier\naws_api/macie2 create_custom_data_identifier","url":"aws_api/macie2.html#create_custom_data_identifier"},{"doc":"aws_api/macie2","title":"create_findings_filter","content":"pub fn create_findings_filter(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.create_findings_filter\naws_api/macie2 create_findings_filter","url":"aws_api/macie2.html#create_findings_filter"},{"doc":"aws_api/macie2","title":"create_invitations","content":"pub fn create_invitations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.create_invitations\naws_api/macie2 create_invitations","url":"aws_api/macie2.html#create_invitations"},{"doc":"aws_api/macie2","title":"create_member","content":"pub fn create_member(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.create_member\naws_api/macie2 create_member","url":"aws_api/macie2.html#create_member"},{"doc":"aws_api/macie2","title":"create_sample_findings","content":"pub fn create_sample_findings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.create_sample_findings\naws_api/macie2 create_sample_findings","url":"aws_api/macie2.html#create_sample_findings"},{"doc":"aws_api/macie2","title":"decline_invitations","content":"pub fn decline_invitations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.decline_invitations\naws_api/macie2 decline_invitations","url":"aws_api/macie2.html#decline_invitations"},{"doc":"aws_api/macie2","title":"delete_allow_list","content":"pub fn delete_allow_list(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.delete_allow_list\naws_api/macie2 delete_allow_list","url":"aws_api/macie2.html#delete_allow_list"},{"doc":"aws_api/macie2","title":"delete_custom_data_identifier","content":"pub fn delete_custom_data_identifier(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.delete_custom_data_identifier\naws_api/macie2 delete_custom_data_identifier","url":"aws_api/macie2.html#delete_custom_data_identifier"},{"doc":"aws_api/macie2","title":"delete_findings_filter","content":"pub fn delete_findings_filter(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.delete_findings_filter\naws_api/macie2 delete_findings_filter","url":"aws_api/macie2.html#delete_findings_filter"},{"doc":"aws_api/macie2","title":"delete_invitations","content":"pub fn delete_invitations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.delete_invitations\naws_api/macie2 delete_invitations","url":"aws_api/macie2.html#delete_invitations"},{"doc":"aws_api/macie2","title":"delete_member","content":"pub fn delete_member(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.delete_member\naws_api/macie2 delete_member","url":"aws_api/macie2.html#delete_member"},{"doc":"aws_api/macie2","title":"describe_buckets","content":"pub fn describe_buckets(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.describe_buckets\naws_api/macie2 describe_buckets","url":"aws_api/macie2.html#describe_buckets"},{"doc":"aws_api/macie2","title":"describe_classification_job","content":"pub fn describe_classification_job(\n  client: Client,\n  job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.describe_classification_job\naws_api/macie2 describe_classification_job","url":"aws_api/macie2.html#describe_classification_job"},{"doc":"aws_api/macie2","title":"describe_organization_configuration","content":"pub fn describe_organization_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.describe_organization_configuration\naws_api/macie2 describe_organization_configuration","url":"aws_api/macie2.html#describe_organization_configuration"},{"doc":"aws_api/macie2","title":"disable_macie","content":"pub fn disable_macie(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.disable_macie\naws_api/macie2 disable_macie","url":"aws_api/macie2.html#disable_macie"},{"doc":"aws_api/macie2","title":"disable_organization_admin_account","content":"pub fn disable_organization_admin_account(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.disable_organization_admin_account\naws_api/macie2 disable_organization_admin_account","url":"aws_api/macie2.html#disable_organization_admin_account"},{"doc":"aws_api/macie2","title":"disassociate_from_administrator_account","content":"pub fn disassociate_from_administrator_account(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.disassociate_from_administrator_account\naws_api/macie2 disassociate_from_administrator_account","url":"aws_api/macie2.html#disassociate_from_administrator_account"},{"doc":"aws_api/macie2","title":"disassociate_from_master_account","content":"pub fn disassociate_from_master_account(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.disassociate_from_master_account\naws_api/macie2 disassociate_from_master_account","url":"aws_api/macie2.html#disassociate_from_master_account"},{"doc":"aws_api/macie2","title":"disassociate_member","content":"pub fn disassociate_member(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.disassociate_member\naws_api/macie2 disassociate_member","url":"aws_api/macie2.html#disassociate_member"},{"doc":"aws_api/macie2","title":"enable_macie","content":"pub fn enable_macie(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.enable_macie\naws_api/macie2 enable_macie","url":"aws_api/macie2.html#enable_macie"},{"doc":"aws_api/macie2","title":"enable_organization_admin_account","content":"pub fn enable_organization_admin_account(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.enable_organization_admin_account\naws_api/macie2 enable_organization_admin_account","url":"aws_api/macie2.html#enable_organization_admin_account"},{"doc":"aws_api/macie2","title":"get_administrator_account","content":"pub fn get_administrator_account(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.get_administrator_account\naws_api/macie2 get_administrator_account","url":"aws_api/macie2.html#get_administrator_account"},{"doc":"aws_api/macie2","title":"get_allow_list","content":"pub fn get_allow_list(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.get_allow_list\naws_api/macie2 get_allow_list","url":"aws_api/macie2.html#get_allow_list"},{"doc":"aws_api/macie2","title":"get_automated_discovery_configuration","content":"pub fn get_automated_discovery_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.get_automated_discovery_configuration\naws_api/macie2 get_automated_discovery_configuration","url":"aws_api/macie2.html#get_automated_discovery_configuration"},{"doc":"aws_api/macie2","title":"get_bucket_statistics","content":"pub fn get_bucket_statistics(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.get_bucket_statistics\naws_api/macie2 get_bucket_statistics","url":"aws_api/macie2.html#get_bucket_statistics"},{"doc":"aws_api/macie2","title":"get_classification_export_configuration","content":"pub fn get_classification_export_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.get_classification_export_configuration\naws_api/macie2 get_classification_export_configuration","url":"aws_api/macie2.html#get_classification_export_configuration"},{"doc":"aws_api/macie2","title":"get_classification_scope","content":"pub fn get_classification_scope(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.get_classification_scope\naws_api/macie2 get_classification_scope","url":"aws_api/macie2.html#get_classification_scope"},{"doc":"aws_api/macie2","title":"get_custom_data_identifier","content":"pub fn get_custom_data_identifier(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.get_custom_data_identifier\naws_api/macie2 get_custom_data_identifier","url":"aws_api/macie2.html#get_custom_data_identifier"},{"doc":"aws_api/macie2","title":"get_finding_statistics","content":"pub fn get_finding_statistics(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.get_finding_statistics\naws_api/macie2 get_finding_statistics","url":"aws_api/macie2.html#get_finding_statistics"},{"doc":"aws_api/macie2","title":"get_findings","content":"pub fn get_findings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.get_findings\naws_api/macie2 get_findings","url":"aws_api/macie2.html#get_findings"},{"doc":"aws_api/macie2","title":"get_findings_filter","content":"pub fn get_findings_filter(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.get_findings_filter\naws_api/macie2 get_findings_filter","url":"aws_api/macie2.html#get_findings_filter"},{"doc":"aws_api/macie2","title":"get_findings_publication_configuration","content":"pub fn get_findings_publication_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.get_findings_publication_configuration\naws_api/macie2 get_findings_publication_configuration","url":"aws_api/macie2.html#get_findings_publication_configuration"},{"doc":"aws_api/macie2","title":"get_invitations_count","content":"pub fn get_invitations_count(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.get_invitations_count\naws_api/macie2 get_invitations_count","url":"aws_api/macie2.html#get_invitations_count"},{"doc":"aws_api/macie2","title":"get_macie_session","content":"pub fn get_macie_session(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.get_macie_session\naws_api/macie2 get_macie_session","url":"aws_api/macie2.html#get_macie_session"},{"doc":"aws_api/macie2","title":"get_master_account","content":"pub fn get_master_account(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.get_master_account\naws_api/macie2 get_master_account","url":"aws_api/macie2.html#get_master_account"},{"doc":"aws_api/macie2","title":"get_member","content":"pub fn get_member(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.get_member\naws_api/macie2 get_member","url":"aws_api/macie2.html#get_member"},{"doc":"aws_api/macie2","title":"get_resource_profile","content":"pub fn get_resource_profile(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.get_resource_profile\naws_api/macie2 get_resource_profile","url":"aws_api/macie2.html#get_resource_profile"},{"doc":"aws_api/macie2","title":"get_reveal_configuration","content":"pub fn get_reveal_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.get_reveal_configuration\naws_api/macie2 get_reveal_configuration","url":"aws_api/macie2.html#get_reveal_configuration"},{"doc":"aws_api/macie2","title":"get_sensitive_data_occurrences","content":"pub fn get_sensitive_data_occurrences(\n  client: Client,\n  finding_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.get_sensitive_data_occurrences\naws_api/macie2 get_sensitive_data_occurrences","url":"aws_api/macie2.html#get_sensitive_data_occurrences"},{"doc":"aws_api/macie2","title":"get_sensitive_data_occurrences_availability","content":"pub fn get_sensitive_data_occurrences_availability(\n  client: Client,\n  finding_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.get_sensitive_data_occurrences_availability\naws_api/macie2 get_sensitive_data_occurrences_availability","url":"aws_api/macie2.html#get_sensitive_data_occurrences_availability"},{"doc":"aws_api/macie2","title":"get_sensitivity_inspection_template","content":"pub fn get_sensitivity_inspection_template(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.get_sensitivity_inspection_template\naws_api/macie2 get_sensitivity_inspection_template","url":"aws_api/macie2.html#get_sensitivity_inspection_template"},{"doc":"aws_api/macie2","title":"get_usage_statistics","content":"pub fn get_usage_statistics(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.get_usage_statistics\naws_api/macie2 get_usage_statistics","url":"aws_api/macie2.html#get_usage_statistics"},{"doc":"aws_api/macie2","title":"get_usage_totals","content":"pub fn get_usage_totals(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.get_usage_totals\naws_api/macie2 get_usage_totals","url":"aws_api/macie2.html#get_usage_totals"},{"doc":"aws_api/macie2","title":"list_allow_lists","content":"pub fn list_allow_lists(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.list_allow_lists\naws_api/macie2 list_allow_lists","url":"aws_api/macie2.html#list_allow_lists"},{"doc":"aws_api/macie2","title":"list_automated_discovery_accounts","content":"pub fn list_automated_discovery_accounts(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.list_automated_discovery_accounts\naws_api/macie2 list_automated_discovery_accounts","url":"aws_api/macie2.html#list_automated_discovery_accounts"},{"doc":"aws_api/macie2","title":"list_classification_jobs","content":"pub fn list_classification_jobs(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.list_classification_jobs\naws_api/macie2 list_classification_jobs","url":"aws_api/macie2.html#list_classification_jobs"},{"doc":"aws_api/macie2","title":"list_classification_scopes","content":"pub fn list_classification_scopes(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.list_classification_scopes\naws_api/macie2 list_classification_scopes","url":"aws_api/macie2.html#list_classification_scopes"},{"doc":"aws_api/macie2","title":"list_custom_data_identifiers","content":"pub fn list_custom_data_identifiers(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.list_custom_data_identifiers\naws_api/macie2 list_custom_data_identifiers","url":"aws_api/macie2.html#list_custom_data_identifiers"},{"doc":"aws_api/macie2","title":"list_findings","content":"pub fn list_findings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.list_findings\naws_api/macie2 list_findings","url":"aws_api/macie2.html#list_findings"},{"doc":"aws_api/macie2","title":"list_findings_filters","content":"pub fn list_findings_filters(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.list_findings_filters\naws_api/macie2 list_findings_filters","url":"aws_api/macie2.html#list_findings_filters"},{"doc":"aws_api/macie2","title":"list_invitations","content":"pub fn list_invitations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.list_invitations\naws_api/macie2 list_invitations","url":"aws_api/macie2.html#list_invitations"},{"doc":"aws_api/macie2","title":"list_managed_data_identifiers","content":"pub fn list_managed_data_identifiers(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.list_managed_data_identifiers\naws_api/macie2 list_managed_data_identifiers","url":"aws_api/macie2.html#list_managed_data_identifiers"},{"doc":"aws_api/macie2","title":"list_members","content":"pub fn list_members(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.list_members\naws_api/macie2 list_members","url":"aws_api/macie2.html#list_members"},{"doc":"aws_api/macie2","title":"list_organization_admin_accounts","content":"pub fn list_organization_admin_accounts(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.list_organization_admin_accounts\naws_api/macie2 list_organization_admin_accounts","url":"aws_api/macie2.html#list_organization_admin_accounts"},{"doc":"aws_api/macie2","title":"list_resource_profile_artifacts","content":"pub fn list_resource_profile_artifacts(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.list_resource_profile_artifacts\naws_api/macie2 list_resource_profile_artifacts","url":"aws_api/macie2.html#list_resource_profile_artifacts"},{"doc":"aws_api/macie2","title":"list_resource_profile_detections","content":"pub fn list_resource_profile_detections(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.list_resource_profile_detections\naws_api/macie2 list_resource_profile_detections","url":"aws_api/macie2.html#list_resource_profile_detections"},{"doc":"aws_api/macie2","title":"list_sensitivity_inspection_templates","content":"pub fn list_sensitivity_inspection_templates(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.list_sensitivity_inspection_templates\naws_api/macie2 list_sensitivity_inspection_templates","url":"aws_api/macie2.html#list_sensitivity_inspection_templates"},{"doc":"aws_api/macie2","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.list_tags_for_resource\naws_api/macie2 list_tags_for_resource","url":"aws_api/macie2.html#list_tags_for_resource"},{"doc":"aws_api/macie2","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/macie2.new\naws_api/macie2 new","url":"aws_api/macie2.html#new"},{"doc":"aws_api/macie2","title":"put_classification_export_configuration","content":"pub fn put_classification_export_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.put_classification_export_configuration\naws_api/macie2 put_classification_export_configuration","url":"aws_api/macie2.html#put_classification_export_configuration"},{"doc":"aws_api/macie2","title":"put_findings_publication_configuration","content":"pub fn put_findings_publication_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.put_findings_publication_configuration\naws_api/macie2 put_findings_publication_configuration","url":"aws_api/macie2.html#put_findings_publication_configuration"},{"doc":"aws_api/macie2","title":"search_resources","content":"pub fn search_resources(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.search_resources\naws_api/macie2 search_resources","url":"aws_api/macie2.html#search_resources"},{"doc":"aws_api/macie2","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.tag_resource\naws_api/macie2 tag_resource","url":"aws_api/macie2.html#tag_resource"},{"doc":"aws_api/macie2","title":"test_custom_data_identifier","content":"pub fn test_custom_data_identifier(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.test_custom_data_identifier\naws_api/macie2 test_custom_data_identifier","url":"aws_api/macie2.html#test_custom_data_identifier"},{"doc":"aws_api/macie2","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.untag_resource\naws_api/macie2 untag_resource","url":"aws_api/macie2.html#untag_resource"},{"doc":"aws_api/macie2","title":"update_allow_list","content":"pub fn update_allow_list(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.update_allow_list\naws_api/macie2 update_allow_list","url":"aws_api/macie2.html#update_allow_list"},{"doc":"aws_api/macie2","title":"update_automated_discovery_configuration","content":"pub fn update_automated_discovery_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.update_automated_discovery_configuration\naws_api/macie2 update_automated_discovery_configuration","url":"aws_api/macie2.html#update_automated_discovery_configuration"},{"doc":"aws_api/macie2","title":"update_classification_job","content":"pub fn update_classification_job(\n  client: Client,\n  job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.update_classification_job\naws_api/macie2 update_classification_job","url":"aws_api/macie2.html#update_classification_job"},{"doc":"aws_api/macie2","title":"update_classification_scope","content":"pub fn update_classification_scope(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.update_classification_scope\naws_api/macie2 update_classification_scope","url":"aws_api/macie2.html#update_classification_scope"},{"doc":"aws_api/macie2","title":"update_findings_filter","content":"pub fn update_findings_filter(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.update_findings_filter\naws_api/macie2 update_findings_filter","url":"aws_api/macie2.html#update_findings_filter"},{"doc":"aws_api/macie2","title":"update_macie_session","content":"pub fn update_macie_session(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.update_macie_session\naws_api/macie2 update_macie_session","url":"aws_api/macie2.html#update_macie_session"},{"doc":"aws_api/macie2","title":"update_member_session","content":"pub fn update_member_session(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.update_member_session\naws_api/macie2 update_member_session","url":"aws_api/macie2.html#update_member_session"},{"doc":"aws_api/macie2","title":"update_organization_configuration","content":"pub fn update_organization_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.update_organization_configuration\naws_api/macie2 update_organization_configuration","url":"aws_api/macie2.html#update_organization_configuration"},{"doc":"aws_api/macie2","title":"update_resource_profile","content":"pub fn update_resource_profile(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.update_resource_profile\naws_api/macie2 update_resource_profile","url":"aws_api/macie2.html#update_resource_profile"},{"doc":"aws_api/macie2","title":"update_resource_profile_detections","content":"pub fn update_resource_profile_detections(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.update_resource_profile_detections\naws_api/macie2 update_resource_profile_detections","url":"aws_api/macie2.html#update_resource_profile_detections"},{"doc":"aws_api/macie2","title":"update_reveal_configuration","content":"pub fn update_reveal_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.update_reveal_configuration\naws_api/macie2 update_reveal_configuration","url":"aws_api/macie2.html#update_reveal_configuration"},{"doc":"aws_api/macie2","title":"update_sensitivity_inspection_template","content":"pub fn update_sensitivity_inspection_template(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/macie2.update_sensitivity_inspection_template\naws_api/macie2 update_sensitivity_inspection_template","url":"aws_api/macie2.html#update_sensitivity_inspection_template"},{"doc":"aws_api/macie2","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/macie2.with_custom_endpoint\naws_api/macie2 with_custom_endpoint","url":"aws_api/macie2.html#with_custom_endpoint"},{"doc":"aws_api/macie2","title":"aws_api/macie2","content":"","url":"aws_api/macie2.html"},{"doc":"aws_api/managedblockchain","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/managedblockchain.Client\naws_api/managedblockchain Client","url":"aws_api/managedblockchain.html#Client"},{"doc":"aws_api/managedblockchain","title":"create_accessor","content":"pub fn create_accessor(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/managedblockchain.create_accessor\naws_api/managedblockchain create_accessor","url":"aws_api/managedblockchain.html#create_accessor"},{"doc":"aws_api/managedblockchain","title":"create_member","content":"pub fn create_member(\n  client: Client,\n  network_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/managedblockchain.create_member\naws_api/managedblockchain create_member","url":"aws_api/managedblockchain.html#create_member"},{"doc":"aws_api/managedblockchain","title":"create_network","content":"pub fn create_network(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/managedblockchain.create_network\naws_api/managedblockchain create_network","url":"aws_api/managedblockchain.html#create_network"},{"doc":"aws_api/managedblockchain","title":"create_node","content":"pub fn create_node(\n  client: Client,\n  network_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/managedblockchain.create_node\naws_api/managedblockchain create_node","url":"aws_api/managedblockchain.html#create_node"},{"doc":"aws_api/managedblockchain","title":"create_proposal","content":"pub fn create_proposal(\n  client: Client,\n  network_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/managedblockchain.create_proposal\naws_api/managedblockchain create_proposal","url":"aws_api/managedblockchain.html#create_proposal"},{"doc":"aws_api/managedblockchain","title":"delete_accessor","content":"pub fn delete_accessor(\n  client: Client,\n  accessor_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/managedblockchain.delete_accessor\naws_api/managedblockchain delete_accessor","url":"aws_api/managedblockchain.html#delete_accessor"},{"doc":"aws_api/managedblockchain","title":"delete_member","content":"pub fn delete_member(\n  client: Client,\n  network_id: String,\n  member_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/managedblockchain.delete_member\naws_api/managedblockchain delete_member","url":"aws_api/managedblockchain.html#delete_member"},{"doc":"aws_api/managedblockchain","title":"delete_node","content":"pub fn delete_node(\n  client: Client,\n  network_id: String,\n  node_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/managedblockchain.delete_node\naws_api/managedblockchain delete_node","url":"aws_api/managedblockchain.html#delete_node"},{"doc":"aws_api/managedblockchain","title":"get_accessor","content":"pub fn get_accessor(\n  client: Client,\n  accessor_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/managedblockchain.get_accessor\naws_api/managedblockchain get_accessor","url":"aws_api/managedblockchain.html#get_accessor"},{"doc":"aws_api/managedblockchain","title":"get_member","content":"pub fn get_member(\n  client: Client,\n  network_id: String,\n  member_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/managedblockchain.get_member\naws_api/managedblockchain get_member","url":"aws_api/managedblockchain.html#get_member"},{"doc":"aws_api/managedblockchain","title":"get_network","content":"pub fn get_network(\n  client: Client,\n  network_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/managedblockchain.get_network\naws_api/managedblockchain get_network","url":"aws_api/managedblockchain.html#get_network"},{"doc":"aws_api/managedblockchain","title":"get_node","content":"pub fn get_node(\n  client: Client,\n  network_id: String,\n  node_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/managedblockchain.get_node\naws_api/managedblockchain get_node","url":"aws_api/managedblockchain.html#get_node"},{"doc":"aws_api/managedblockchain","title":"get_proposal","content":"pub fn get_proposal(\n  client: Client,\n  network_id: String,\n  proposal_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/managedblockchain.get_proposal\naws_api/managedblockchain get_proposal","url":"aws_api/managedblockchain.html#get_proposal"},{"doc":"aws_api/managedblockchain","title":"list_accessors","content":"pub fn list_accessors(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/managedblockchain.list_accessors\naws_api/managedblockchain list_accessors","url":"aws_api/managedblockchain.html#list_accessors"},{"doc":"aws_api/managedblockchain","title":"list_invitations","content":"pub fn list_invitations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/managedblockchain.list_invitations\naws_api/managedblockchain list_invitations","url":"aws_api/managedblockchain.html#list_invitations"},{"doc":"aws_api/managedblockchain","title":"list_members","content":"pub fn list_members(\n  client: Client,\n  network_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/managedblockchain.list_members\naws_api/managedblockchain list_members","url":"aws_api/managedblockchain.html#list_members"},{"doc":"aws_api/managedblockchain","title":"list_networks","content":"pub fn list_networks(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/managedblockchain.list_networks\naws_api/managedblockchain list_networks","url":"aws_api/managedblockchain.html#list_networks"},{"doc":"aws_api/managedblockchain","title":"list_nodes","content":"pub fn list_nodes(\n  client: Client,\n  network_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/managedblockchain.list_nodes\naws_api/managedblockchain list_nodes","url":"aws_api/managedblockchain.html#list_nodes"},{"doc":"aws_api/managedblockchain","title":"list_proposal_votes","content":"pub fn list_proposal_votes(\n  client: Client,\n  network_id: String,\n  proposal_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/managedblockchain.list_proposal_votes\naws_api/managedblockchain list_proposal_votes","url":"aws_api/managedblockchain.html#list_proposal_votes"},{"doc":"aws_api/managedblockchain","title":"list_proposals","content":"pub fn list_proposals(\n  client: Client,\n  network_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/managedblockchain.list_proposals\naws_api/managedblockchain list_proposals","url":"aws_api/managedblockchain.html#list_proposals"},{"doc":"aws_api/managedblockchain","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/managedblockchain.list_tags_for_resource\naws_api/managedblockchain list_tags_for_resource","url":"aws_api/managedblockchain.html#list_tags_for_resource"},{"doc":"aws_api/managedblockchain","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/managedblockchain.new\naws_api/managedblockchain new","url":"aws_api/managedblockchain.html#new"},{"doc":"aws_api/managedblockchain","title":"reject_invitation","content":"pub fn reject_invitation(\n  client: Client,\n  invitation_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/managedblockchain.reject_invitation\naws_api/managedblockchain reject_invitation","url":"aws_api/managedblockchain.html#reject_invitation"},{"doc":"aws_api/managedblockchain","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/managedblockchain.tag_resource\naws_api/managedblockchain tag_resource","url":"aws_api/managedblockchain.html#tag_resource"},{"doc":"aws_api/managedblockchain","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/managedblockchain.untag_resource\naws_api/managedblockchain untag_resource","url":"aws_api/managedblockchain.html#untag_resource"},{"doc":"aws_api/managedblockchain","title":"update_member","content":"pub fn update_member(\n  client: Client,\n  network_id: String,\n  member_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/managedblockchain.update_member\naws_api/managedblockchain update_member","url":"aws_api/managedblockchain.html#update_member"},{"doc":"aws_api/managedblockchain","title":"update_node","content":"pub fn update_node(\n  client: Client,\n  network_id: String,\n  node_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/managedblockchain.update_node\naws_api/managedblockchain update_node","url":"aws_api/managedblockchain.html#update_node"},{"doc":"aws_api/managedblockchain","title":"vote_on_proposal","content":"pub fn vote_on_proposal(\n  client: Client,\n  network_id: String,\n  proposal_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/managedblockchain.vote_on_proposal\naws_api/managedblockchain vote_on_proposal","url":"aws_api/managedblockchain.html#vote_on_proposal"},{"doc":"aws_api/managedblockchain","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/managedblockchain.with_custom_endpoint\naws_api/managedblockchain with_custom_endpoint","url":"aws_api/managedblockchain.html#with_custom_endpoint"},{"doc":"aws_api/managedblockchain","title":"aws_api/managedblockchain","content":"","url":"aws_api/managedblockchain.html"},{"doc":"aws_api/managedblockchain_query","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/managedblockchain_query.Client\naws_api/managedblockchain_query Client","url":"aws_api/managedblockchain_query.html#Client"},{"doc":"aws_api/managedblockchain_query","title":"batch_get_token_balance","content":"pub fn batch_get_token_balance(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/managedblockchain_query.batch_get_token_balance\naws_api/managedblockchain_query batch_get_token_balance","url":"aws_api/managedblockchain_query.html#batch_get_token_balance"},{"doc":"aws_api/managedblockchain_query","title":"get_asset_contract","content":"pub fn get_asset_contract(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/managedblockchain_query.get_asset_contract\naws_api/managedblockchain_query get_asset_contract","url":"aws_api/managedblockchain_query.html#get_asset_contract"},{"doc":"aws_api/managedblockchain_query","title":"get_token_balance","content":"pub fn get_token_balance(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/managedblockchain_query.get_token_balance\naws_api/managedblockchain_query get_token_balance","url":"aws_api/managedblockchain_query.html#get_token_balance"},{"doc":"aws_api/managedblockchain_query","title":"get_transaction","content":"pub fn get_transaction(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/managedblockchain_query.get_transaction\naws_api/managedblockchain_query get_transaction","url":"aws_api/managedblockchain_query.html#get_transaction"},{"doc":"aws_api/managedblockchain_query","title":"list_asset_contracts","content":"pub fn list_asset_contracts(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/managedblockchain_query.list_asset_contracts\naws_api/managedblockchain_query list_asset_contracts","url":"aws_api/managedblockchain_query.html#list_asset_contracts"},{"doc":"aws_api/managedblockchain_query","title":"list_filtered_transaction_events","content":"pub fn list_filtered_transaction_events(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/managedblockchain_query.list_filtered_transaction_events\naws_api/managedblockchain_query list_filtered_transaction_events","url":"aws_api/managedblockchain_query.html#list_filtered_transaction_events"},{"doc":"aws_api/managedblockchain_query","title":"list_token_balances","content":"pub fn list_token_balances(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/managedblockchain_query.list_token_balances\naws_api/managedblockchain_query list_token_balances","url":"aws_api/managedblockchain_query.html#list_token_balances"},{"doc":"aws_api/managedblockchain_query","title":"list_transaction_events","content":"pub fn list_transaction_events(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/managedblockchain_query.list_transaction_events\naws_api/managedblockchain_query list_transaction_events","url":"aws_api/managedblockchain_query.html#list_transaction_events"},{"doc":"aws_api/managedblockchain_query","title":"list_transactions","content":"pub fn list_transactions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/managedblockchain_query.list_transactions\naws_api/managedblockchain_query list_transactions","url":"aws_api/managedblockchain_query.html#list_transactions"},{"doc":"aws_api/managedblockchain_query","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/managedblockchain_query.new\naws_api/managedblockchain_query new","url":"aws_api/managedblockchain_query.html#new"},{"doc":"aws_api/managedblockchain_query","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/managedblockchain_query.with_custom_endpoint\naws_api/managedblockchain_query with_custom_endpoint","url":"aws_api/managedblockchain_query.html#with_custom_endpoint"},{"doc":"aws_api/managedblockchain_query","title":"aws_api/managedblockchain_query","content":"","url":"aws_api/managedblockchain_query.html"},{"doc":"aws_api/marketplace_agreement","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/marketplace_agreement.Client\naws_api/marketplace_agreement Client","url":"aws_api/marketplace_agreement.html#Client"},{"doc":"aws_api/marketplace_agreement","title":"describe_agreement","content":"pub fn describe_agreement(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/marketplace_agreement.describe_agreement\naws_api/marketplace_agreement describe_agreement","url":"aws_api/marketplace_agreement.html#describe_agreement"},{"doc":"aws_api/marketplace_agreement","title":"get_agreement_terms","content":"pub fn get_agreement_terms(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/marketplace_agreement.get_agreement_terms\naws_api/marketplace_agreement get_agreement_terms","url":"aws_api/marketplace_agreement.html#get_agreement_terms"},{"doc":"aws_api/marketplace_agreement","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/marketplace_agreement.new\naws_api/marketplace_agreement new","url":"aws_api/marketplace_agreement.html#new"},{"doc":"aws_api/marketplace_agreement","title":"search_agreements","content":"pub fn search_agreements(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/marketplace_agreement.search_agreements\naws_api/marketplace_agreement search_agreements","url":"aws_api/marketplace_agreement.html#search_agreements"},{"doc":"aws_api/marketplace_agreement","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/marketplace_agreement.with_custom_endpoint\naws_api/marketplace_agreement with_custom_endpoint","url":"aws_api/marketplace_agreement.html#with_custom_endpoint"},{"doc":"aws_api/marketplace_agreement","title":"aws_api/marketplace_agreement","content":"","url":"aws_api/marketplace_agreement.html"},{"doc":"aws_api/marketplace_catalog","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/marketplace_catalog.Client\naws_api/marketplace_catalog Client","url":"aws_api/marketplace_catalog.html#Client"},{"doc":"aws_api/marketplace_catalog","title":"batch_describe_entities","content":"pub fn batch_describe_entities(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/marketplace_catalog.batch_describe_entities\naws_api/marketplace_catalog batch_describe_entities","url":"aws_api/marketplace_catalog.html#batch_describe_entities"},{"doc":"aws_api/marketplace_catalog","title":"cancel_change_set","content":"pub fn cancel_change_set(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/marketplace_catalog.cancel_change_set\naws_api/marketplace_catalog cancel_change_set","url":"aws_api/marketplace_catalog.html#cancel_change_set"},{"doc":"aws_api/marketplace_catalog","title":"delete_resource_policy","content":"pub fn delete_resource_policy(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/marketplace_catalog.delete_resource_policy\naws_api/marketplace_catalog delete_resource_policy","url":"aws_api/marketplace_catalog.html#delete_resource_policy"},{"doc":"aws_api/marketplace_catalog","title":"describe_change_set","content":"pub fn describe_change_set(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/marketplace_catalog.describe_change_set\naws_api/marketplace_catalog describe_change_set","url":"aws_api/marketplace_catalog.html#describe_change_set"},{"doc":"aws_api/marketplace_catalog","title":"describe_entity","content":"pub fn describe_entity(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/marketplace_catalog.describe_entity\naws_api/marketplace_catalog describe_entity","url":"aws_api/marketplace_catalog.html#describe_entity"},{"doc":"aws_api/marketplace_catalog","title":"get_resource_policy","content":"pub fn get_resource_policy(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/marketplace_catalog.get_resource_policy\naws_api/marketplace_catalog get_resource_policy","url":"aws_api/marketplace_catalog.html#get_resource_policy"},{"doc":"aws_api/marketplace_catalog","title":"list_change_sets","content":"pub fn list_change_sets(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/marketplace_catalog.list_change_sets\naws_api/marketplace_catalog list_change_sets","url":"aws_api/marketplace_catalog.html#list_change_sets"},{"doc":"aws_api/marketplace_catalog","title":"list_entities","content":"pub fn list_entities(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/marketplace_catalog.list_entities\naws_api/marketplace_catalog list_entities","url":"aws_api/marketplace_catalog.html#list_entities"},{"doc":"aws_api/marketplace_catalog","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/marketplace_catalog.list_tags_for_resource\naws_api/marketplace_catalog list_tags_for_resource","url":"aws_api/marketplace_catalog.html#list_tags_for_resource"},{"doc":"aws_api/marketplace_catalog","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/marketplace_catalog.new\naws_api/marketplace_catalog new","url":"aws_api/marketplace_catalog.html#new"},{"doc":"aws_api/marketplace_catalog","title":"put_resource_policy","content":"pub fn put_resource_policy(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/marketplace_catalog.put_resource_policy\naws_api/marketplace_catalog put_resource_policy","url":"aws_api/marketplace_catalog.html#put_resource_policy"},{"doc":"aws_api/marketplace_catalog","title":"start_change_set","content":"pub fn start_change_set(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/marketplace_catalog.start_change_set\naws_api/marketplace_catalog start_change_set","url":"aws_api/marketplace_catalog.html#start_change_set"},{"doc":"aws_api/marketplace_catalog","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/marketplace_catalog.tag_resource\naws_api/marketplace_catalog tag_resource","url":"aws_api/marketplace_catalog.html#tag_resource"},{"doc":"aws_api/marketplace_catalog","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/marketplace_catalog.untag_resource\naws_api/marketplace_catalog untag_resource","url":"aws_api/marketplace_catalog.html#untag_resource"},{"doc":"aws_api/marketplace_catalog","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/marketplace_catalog.with_custom_endpoint\naws_api/marketplace_catalog with_custom_endpoint","url":"aws_api/marketplace_catalog.html#with_custom_endpoint"},{"doc":"aws_api/marketplace_catalog","title":"aws_api/marketplace_catalog","content":"","url":"aws_api/marketplace_catalog.html"},{"doc":"aws_api/marketplace_commerce_analytics","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/marketplace_commerce_analytics.Client\naws_api/marketplace_commerce_analytics Client","url":"aws_api/marketplace_commerce_analytics.html#Client"},{"doc":"aws_api/marketplace_commerce_analytics","title":"generate_data_set","content":"pub fn generate_data_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/marketplace_commerce_analytics.generate_data_set\naws_api/marketplace_commerce_analytics generate_data_set","url":"aws_api/marketplace_commerce_analytics.html#generate_data_set"},{"doc":"aws_api/marketplace_commerce_analytics","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/marketplace_commerce_analytics.new\naws_api/marketplace_commerce_analytics new","url":"aws_api/marketplace_commerce_analytics.html#new"},{"doc":"aws_api/marketplace_commerce_analytics","title":"start_support_data_export","content":"pub fn start_support_data_export(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/marketplace_commerce_analytics.start_support_data_export\naws_api/marketplace_commerce_analytics start_support_data_export","url":"aws_api/marketplace_commerce_analytics.html#start_support_data_export"},{"doc":"aws_api/marketplace_commerce_analytics","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/marketplace_commerce_analytics.with_custom_endpoint\naws_api/marketplace_commerce_analytics with_custom_endpoint","url":"aws_api/marketplace_commerce_analytics.html#with_custom_endpoint"},{"doc":"aws_api/marketplace_commerce_analytics","title":"aws_api/marketplace_commerce_analytics","content":"","url":"aws_api/marketplace_commerce_analytics.html"},{"doc":"aws_api/marketplace_entitlement_service","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/marketplace_entitlement_service.Client\naws_api/marketplace_entitlement_service Client","url":"aws_api/marketplace_entitlement_service.html#Client"},{"doc":"aws_api/marketplace_entitlement_service","title":"get_entitlements","content":"pub fn get_entitlements(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/marketplace_entitlement_service.get_entitlements\naws_api/marketplace_entitlement_service get_entitlements","url":"aws_api/marketplace_entitlement_service.html#get_entitlements"},{"doc":"aws_api/marketplace_entitlement_service","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/marketplace_entitlement_service.new\naws_api/marketplace_entitlement_service new","url":"aws_api/marketplace_entitlement_service.html#new"},{"doc":"aws_api/marketplace_entitlement_service","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/marketplace_entitlement_service.with_custom_endpoint\naws_api/marketplace_entitlement_service with_custom_endpoint","url":"aws_api/marketplace_entitlement_service.html#with_custom_endpoint"},{"doc":"aws_api/marketplace_entitlement_service","title":"aws_api/marketplace_entitlement_service","content":"","url":"aws_api/marketplace_entitlement_service.html"},{"doc":"aws_api/marketplace_metering","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/marketplace_metering.Client\naws_api/marketplace_metering Client","url":"aws_api/marketplace_metering.html#Client"},{"doc":"aws_api/marketplace_metering","title":"batch_meter_usage","content":"pub fn batch_meter_usage(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/marketplace_metering.batch_meter_usage\naws_api/marketplace_metering batch_meter_usage","url":"aws_api/marketplace_metering.html#batch_meter_usage"},{"doc":"aws_api/marketplace_metering","title":"meter_usage","content":"pub fn meter_usage(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/marketplace_metering.meter_usage\naws_api/marketplace_metering meter_usage","url":"aws_api/marketplace_metering.html#meter_usage"},{"doc":"aws_api/marketplace_metering","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/marketplace_metering.new\naws_api/marketplace_metering new","url":"aws_api/marketplace_metering.html#new"},{"doc":"aws_api/marketplace_metering","title":"register_usage","content":"pub fn register_usage(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/marketplace_metering.register_usage\naws_api/marketplace_metering register_usage","url":"aws_api/marketplace_metering.html#register_usage"},{"doc":"aws_api/marketplace_metering","title":"resolve_customer","content":"pub fn resolve_customer(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/marketplace_metering.resolve_customer\naws_api/marketplace_metering resolve_customer","url":"aws_api/marketplace_metering.html#resolve_customer"},{"doc":"aws_api/marketplace_metering","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/marketplace_metering.with_custom_endpoint\naws_api/marketplace_metering with_custom_endpoint","url":"aws_api/marketplace_metering.html#with_custom_endpoint"},{"doc":"aws_api/marketplace_metering","title":"aws_api/marketplace_metering","content":"","url":"aws_api/marketplace_metering.html"},{"doc":"aws_api/mediaconnect","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/mediaconnect.Client\naws_api/mediaconnect Client","url":"aws_api/mediaconnect.html#Client"},{"doc":"aws_api/mediaconnect","title":"add_bridge_outputs","content":"pub fn add_bridge_outputs(\n  client: Client,\n  bridge_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.add_bridge_outputs\naws_api/mediaconnect add_bridge_outputs","url":"aws_api/mediaconnect.html#add_bridge_outputs"},{"doc":"aws_api/mediaconnect","title":"add_bridge_sources","content":"pub fn add_bridge_sources(\n  client: Client,\n  bridge_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.add_bridge_sources\naws_api/mediaconnect add_bridge_sources","url":"aws_api/mediaconnect.html#add_bridge_sources"},{"doc":"aws_api/mediaconnect","title":"add_flow_media_streams","content":"pub fn add_flow_media_streams(\n  client: Client,\n  flow_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.add_flow_media_streams\naws_api/mediaconnect add_flow_media_streams","url":"aws_api/mediaconnect.html#add_flow_media_streams"},{"doc":"aws_api/mediaconnect","title":"add_flow_outputs","content":"pub fn add_flow_outputs(\n  client: Client,\n  flow_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.add_flow_outputs\naws_api/mediaconnect add_flow_outputs","url":"aws_api/mediaconnect.html#add_flow_outputs"},{"doc":"aws_api/mediaconnect","title":"add_flow_sources","content":"pub fn add_flow_sources(\n  client: Client,\n  flow_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.add_flow_sources\naws_api/mediaconnect add_flow_sources","url":"aws_api/mediaconnect.html#add_flow_sources"},{"doc":"aws_api/mediaconnect","title":"add_flow_vpc_interfaces","content":"pub fn add_flow_vpc_interfaces(\n  client: Client,\n  flow_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.add_flow_vpc_interfaces\naws_api/mediaconnect add_flow_vpc_interfaces","url":"aws_api/mediaconnect.html#add_flow_vpc_interfaces"},{"doc":"aws_api/mediaconnect","title":"create_bridge","content":"pub fn create_bridge(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.create_bridge\naws_api/mediaconnect create_bridge","url":"aws_api/mediaconnect.html#create_bridge"},{"doc":"aws_api/mediaconnect","title":"create_flow","content":"pub fn create_flow(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.create_flow\naws_api/mediaconnect create_flow","url":"aws_api/mediaconnect.html#create_flow"},{"doc":"aws_api/mediaconnect","title":"create_gateway","content":"pub fn create_gateway(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.create_gateway\naws_api/mediaconnect create_gateway","url":"aws_api/mediaconnect.html#create_gateway"},{"doc":"aws_api/mediaconnect","title":"delete_bridge","content":"pub fn delete_bridge(\n  client: Client,\n  bridge_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.delete_bridge\naws_api/mediaconnect delete_bridge","url":"aws_api/mediaconnect.html#delete_bridge"},{"doc":"aws_api/mediaconnect","title":"delete_flow","content":"pub fn delete_flow(\n  client: Client,\n  flow_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.delete_flow\naws_api/mediaconnect delete_flow","url":"aws_api/mediaconnect.html#delete_flow"},{"doc":"aws_api/mediaconnect","title":"delete_gateway","content":"pub fn delete_gateway(\n  client: Client,\n  gateway_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.delete_gateway\naws_api/mediaconnect delete_gateway","url":"aws_api/mediaconnect.html#delete_gateway"},{"doc":"aws_api/mediaconnect","title":"deregister_gateway_instance","content":"pub fn deregister_gateway_instance(\n  client: Client,\n  gateway_instance_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.deregister_gateway_instance\naws_api/mediaconnect deregister_gateway_instance","url":"aws_api/mediaconnect.html#deregister_gateway_instance"},{"doc":"aws_api/mediaconnect","title":"describe_bridge","content":"pub fn describe_bridge(\n  client: Client,\n  bridge_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.describe_bridge\naws_api/mediaconnect describe_bridge","url":"aws_api/mediaconnect.html#describe_bridge"},{"doc":"aws_api/mediaconnect","title":"describe_flow","content":"pub fn describe_flow(\n  client: Client,\n  flow_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.describe_flow\naws_api/mediaconnect describe_flow","url":"aws_api/mediaconnect.html#describe_flow"},{"doc":"aws_api/mediaconnect","title":"describe_flow_source_metadata","content":"pub fn describe_flow_source_metadata(\n  client: Client,\n  flow_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.describe_flow_source_metadata\naws_api/mediaconnect describe_flow_source_metadata","url":"aws_api/mediaconnect.html#describe_flow_source_metadata"},{"doc":"aws_api/mediaconnect","title":"describe_gateway","content":"pub fn describe_gateway(\n  client: Client,\n  gateway_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.describe_gateway\naws_api/mediaconnect describe_gateway","url":"aws_api/mediaconnect.html#describe_gateway"},{"doc":"aws_api/mediaconnect","title":"describe_gateway_instance","content":"pub fn describe_gateway_instance(\n  client: Client,\n  gateway_instance_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.describe_gateway_instance\naws_api/mediaconnect describe_gateway_instance","url":"aws_api/mediaconnect.html#describe_gateway_instance"},{"doc":"aws_api/mediaconnect","title":"describe_offering","content":"pub fn describe_offering(\n  client: Client,\n  offering_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.describe_offering\naws_api/mediaconnect describe_offering","url":"aws_api/mediaconnect.html#describe_offering"},{"doc":"aws_api/mediaconnect","title":"describe_reservation","content":"pub fn describe_reservation(\n  client: Client,\n  reservation_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.describe_reservation\naws_api/mediaconnect describe_reservation","url":"aws_api/mediaconnect.html#describe_reservation"},{"doc":"aws_api/mediaconnect","title":"grant_flow_entitlements","content":"pub fn grant_flow_entitlements(\n  client: Client,\n  flow_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.grant_flow_entitlements\naws_api/mediaconnect grant_flow_entitlements","url":"aws_api/mediaconnect.html#grant_flow_entitlements"},{"doc":"aws_api/mediaconnect","title":"list_bridges","content":"pub fn list_bridges(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.list_bridges\naws_api/mediaconnect list_bridges","url":"aws_api/mediaconnect.html#list_bridges"},{"doc":"aws_api/mediaconnect","title":"list_entitlements","content":"pub fn list_entitlements(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.list_entitlements\naws_api/mediaconnect list_entitlements","url":"aws_api/mediaconnect.html#list_entitlements"},{"doc":"aws_api/mediaconnect","title":"list_flows","content":"pub fn list_flows(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.list_flows\naws_api/mediaconnect list_flows","url":"aws_api/mediaconnect.html#list_flows"},{"doc":"aws_api/mediaconnect","title":"list_gateway_instances","content":"pub fn list_gateway_instances(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.list_gateway_instances\naws_api/mediaconnect list_gateway_instances","url":"aws_api/mediaconnect.html#list_gateway_instances"},{"doc":"aws_api/mediaconnect","title":"list_gateways","content":"pub fn list_gateways(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.list_gateways\naws_api/mediaconnect list_gateways","url":"aws_api/mediaconnect.html#list_gateways"},{"doc":"aws_api/mediaconnect","title":"list_offerings","content":"pub fn list_offerings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.list_offerings\naws_api/mediaconnect list_offerings","url":"aws_api/mediaconnect.html#list_offerings"},{"doc":"aws_api/mediaconnect","title":"list_reservations","content":"pub fn list_reservations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.list_reservations\naws_api/mediaconnect list_reservations","url":"aws_api/mediaconnect.html#list_reservations"},{"doc":"aws_api/mediaconnect","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.list_tags_for_resource\naws_api/mediaconnect list_tags_for_resource","url":"aws_api/mediaconnect.html#list_tags_for_resource"},{"doc":"aws_api/mediaconnect","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/mediaconnect.new\naws_api/mediaconnect new","url":"aws_api/mediaconnect.html#new"},{"doc":"aws_api/mediaconnect","title":"purchase_offering","content":"pub fn purchase_offering(\n  client: Client,\n  offering_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.purchase_offering\naws_api/mediaconnect purchase_offering","url":"aws_api/mediaconnect.html#purchase_offering"},{"doc":"aws_api/mediaconnect","title":"remove_bridge_output","content":"pub fn remove_bridge_output(\n  client: Client,\n  bridge_arn: String,\n  output_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.remove_bridge_output\naws_api/mediaconnect remove_bridge_output","url":"aws_api/mediaconnect.html#remove_bridge_output"},{"doc":"aws_api/mediaconnect","title":"remove_bridge_source","content":"pub fn remove_bridge_source(\n  client: Client,\n  bridge_arn: String,\n  source_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.remove_bridge_source\naws_api/mediaconnect remove_bridge_source","url":"aws_api/mediaconnect.html#remove_bridge_source"},{"doc":"aws_api/mediaconnect","title":"remove_flow_media_stream","content":"pub fn remove_flow_media_stream(\n  client: Client,\n  flow_arn: String,\n  media_stream_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.remove_flow_media_stream\naws_api/mediaconnect remove_flow_media_stream","url":"aws_api/mediaconnect.html#remove_flow_media_stream"},{"doc":"aws_api/mediaconnect","title":"remove_flow_output","content":"pub fn remove_flow_output(\n  client: Client,\n  flow_arn: String,\n  output_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.remove_flow_output\naws_api/mediaconnect remove_flow_output","url":"aws_api/mediaconnect.html#remove_flow_output"},{"doc":"aws_api/mediaconnect","title":"remove_flow_source","content":"pub fn remove_flow_source(\n  client: Client,\n  flow_arn: String,\n  source_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.remove_flow_source\naws_api/mediaconnect remove_flow_source","url":"aws_api/mediaconnect.html#remove_flow_source"},{"doc":"aws_api/mediaconnect","title":"remove_flow_vpc_interface","content":"pub fn remove_flow_vpc_interface(\n  client: Client,\n  flow_arn: String,\n  vpc_interface_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.remove_flow_vpc_interface\naws_api/mediaconnect remove_flow_vpc_interface","url":"aws_api/mediaconnect.html#remove_flow_vpc_interface"},{"doc":"aws_api/mediaconnect","title":"revoke_flow_entitlement","content":"pub fn revoke_flow_entitlement(\n  client: Client,\n  flow_arn: String,\n  entitlement_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.revoke_flow_entitlement\naws_api/mediaconnect revoke_flow_entitlement","url":"aws_api/mediaconnect.html#revoke_flow_entitlement"},{"doc":"aws_api/mediaconnect","title":"start_flow","content":"pub fn start_flow(\n  client: Client,\n  flow_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.start_flow\naws_api/mediaconnect start_flow","url":"aws_api/mediaconnect.html#start_flow"},{"doc":"aws_api/mediaconnect","title":"stop_flow","content":"pub fn stop_flow(\n  client: Client,\n  flow_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.stop_flow\naws_api/mediaconnect stop_flow","url":"aws_api/mediaconnect.html#stop_flow"},{"doc":"aws_api/mediaconnect","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.tag_resource\naws_api/mediaconnect tag_resource","url":"aws_api/mediaconnect.html#tag_resource"},{"doc":"aws_api/mediaconnect","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.untag_resource\naws_api/mediaconnect untag_resource","url":"aws_api/mediaconnect.html#untag_resource"},{"doc":"aws_api/mediaconnect","title":"update_bridge","content":"pub fn update_bridge(\n  client: Client,\n  bridge_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.update_bridge\naws_api/mediaconnect update_bridge","url":"aws_api/mediaconnect.html#update_bridge"},{"doc":"aws_api/mediaconnect","title":"update_bridge_output","content":"pub fn update_bridge_output(\n  client: Client,\n  bridge_arn: String,\n  output_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.update_bridge_output\naws_api/mediaconnect update_bridge_output","url":"aws_api/mediaconnect.html#update_bridge_output"},{"doc":"aws_api/mediaconnect","title":"update_bridge_source","content":"pub fn update_bridge_source(\n  client: Client,\n  bridge_arn: String,\n  source_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.update_bridge_source\naws_api/mediaconnect update_bridge_source","url":"aws_api/mediaconnect.html#update_bridge_source"},{"doc":"aws_api/mediaconnect","title":"update_bridge_state","content":"pub fn update_bridge_state(\n  client: Client,\n  bridge_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.update_bridge_state\naws_api/mediaconnect update_bridge_state","url":"aws_api/mediaconnect.html#update_bridge_state"},{"doc":"aws_api/mediaconnect","title":"update_flow","content":"pub fn update_flow(\n  client: Client,\n  flow_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.update_flow\naws_api/mediaconnect update_flow","url":"aws_api/mediaconnect.html#update_flow"},{"doc":"aws_api/mediaconnect","title":"update_flow_entitlement","content":"pub fn update_flow_entitlement(\n  client: Client,\n  flow_arn: String,\n  entitlement_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.update_flow_entitlement\naws_api/mediaconnect update_flow_entitlement","url":"aws_api/mediaconnect.html#update_flow_entitlement"},{"doc":"aws_api/mediaconnect","title":"update_flow_media_stream","content":"pub fn update_flow_media_stream(\n  client: Client,\n  flow_arn: String,\n  media_stream_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.update_flow_media_stream\naws_api/mediaconnect update_flow_media_stream","url":"aws_api/mediaconnect.html#update_flow_media_stream"},{"doc":"aws_api/mediaconnect","title":"update_flow_output","content":"pub fn update_flow_output(\n  client: Client,\n  flow_arn: String,\n  output_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.update_flow_output\naws_api/mediaconnect update_flow_output","url":"aws_api/mediaconnect.html#update_flow_output"},{"doc":"aws_api/mediaconnect","title":"update_flow_source","content":"pub fn update_flow_source(\n  client: Client,\n  flow_arn: String,\n  source_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.update_flow_source\naws_api/mediaconnect update_flow_source","url":"aws_api/mediaconnect.html#update_flow_source"},{"doc":"aws_api/mediaconnect","title":"update_gateway_instance","content":"pub fn update_gateway_instance(\n  client: Client,\n  gateway_instance_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconnect.update_gateway_instance\naws_api/mediaconnect update_gateway_instance","url":"aws_api/mediaconnect.html#update_gateway_instance"},{"doc":"aws_api/mediaconnect","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/mediaconnect.with_custom_endpoint\naws_api/mediaconnect with_custom_endpoint","url":"aws_api/mediaconnect.html#with_custom_endpoint"},{"doc":"aws_api/mediaconnect","title":"aws_api/mediaconnect","content":"","url":"aws_api/mediaconnect.html"},{"doc":"aws_api/mediaconvert","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/mediaconvert.Client\naws_api/mediaconvert Client","url":"aws_api/mediaconvert.html#Client"},{"doc":"aws_api/mediaconvert","title":"associate_certificate","content":"pub fn associate_certificate(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconvert.associate_certificate\naws_api/mediaconvert associate_certificate","url":"aws_api/mediaconvert.html#associate_certificate"},{"doc":"aws_api/mediaconvert","title":"cancel_job","content":"pub fn cancel_job(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconvert.cancel_job\naws_api/mediaconvert cancel_job","url":"aws_api/mediaconvert.html#cancel_job"},{"doc":"aws_api/mediaconvert","title":"create_job","content":"pub fn create_job(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconvert.create_job\naws_api/mediaconvert create_job","url":"aws_api/mediaconvert.html#create_job"},{"doc":"aws_api/mediaconvert","title":"create_job_template","content":"pub fn create_job_template(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconvert.create_job_template\naws_api/mediaconvert create_job_template","url":"aws_api/mediaconvert.html#create_job_template"},{"doc":"aws_api/mediaconvert","title":"create_preset","content":"pub fn create_preset(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconvert.create_preset\naws_api/mediaconvert create_preset","url":"aws_api/mediaconvert.html#create_preset"},{"doc":"aws_api/mediaconvert","title":"create_queue","content":"pub fn create_queue(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconvert.create_queue\naws_api/mediaconvert create_queue","url":"aws_api/mediaconvert.html#create_queue"},{"doc":"aws_api/mediaconvert","title":"delete_job_template","content":"pub fn delete_job_template(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconvert.delete_job_template\naws_api/mediaconvert delete_job_template","url":"aws_api/mediaconvert.html#delete_job_template"},{"doc":"aws_api/mediaconvert","title":"delete_policy","content":"pub fn delete_policy(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconvert.delete_policy\naws_api/mediaconvert delete_policy","url":"aws_api/mediaconvert.html#delete_policy"},{"doc":"aws_api/mediaconvert","title":"delete_preset","content":"pub fn delete_preset(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconvert.delete_preset\naws_api/mediaconvert delete_preset","url":"aws_api/mediaconvert.html#delete_preset"},{"doc":"aws_api/mediaconvert","title":"delete_queue","content":"pub fn delete_queue(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconvert.delete_queue\naws_api/mediaconvert delete_queue","url":"aws_api/mediaconvert.html#delete_queue"},{"doc":"aws_api/mediaconvert","title":"describe_endpoints","content":"pub fn describe_endpoints(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconvert.describe_endpoints\naws_api/mediaconvert describe_endpoints","url":"aws_api/mediaconvert.html#describe_endpoints"},{"doc":"aws_api/mediaconvert","title":"disassociate_certificate","content":"pub fn disassociate_certificate(\n  client: Client,\n  arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconvert.disassociate_certificate\naws_api/mediaconvert disassociate_certificate","url":"aws_api/mediaconvert.html#disassociate_certificate"},{"doc":"aws_api/mediaconvert","title":"get_job","content":"pub fn get_job(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconvert.get_job\naws_api/mediaconvert get_job","url":"aws_api/mediaconvert.html#get_job"},{"doc":"aws_api/mediaconvert","title":"get_job_template","content":"pub fn get_job_template(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconvert.get_job_template\naws_api/mediaconvert get_job_template","url":"aws_api/mediaconvert.html#get_job_template"},{"doc":"aws_api/mediaconvert","title":"get_policy","content":"pub fn get_policy(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconvert.get_policy\naws_api/mediaconvert get_policy","url":"aws_api/mediaconvert.html#get_policy"},{"doc":"aws_api/mediaconvert","title":"get_preset","content":"pub fn get_preset(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconvert.get_preset\naws_api/mediaconvert get_preset","url":"aws_api/mediaconvert.html#get_preset"},{"doc":"aws_api/mediaconvert","title":"get_queue","content":"pub fn get_queue(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconvert.get_queue\naws_api/mediaconvert get_queue","url":"aws_api/mediaconvert.html#get_queue"},{"doc":"aws_api/mediaconvert","title":"list_job_templates","content":"pub fn list_job_templates(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconvert.list_job_templates\naws_api/mediaconvert list_job_templates","url":"aws_api/mediaconvert.html#list_job_templates"},{"doc":"aws_api/mediaconvert","title":"list_jobs","content":"pub fn list_jobs(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconvert.list_jobs\naws_api/mediaconvert list_jobs","url":"aws_api/mediaconvert.html#list_jobs"},{"doc":"aws_api/mediaconvert","title":"list_presets","content":"pub fn list_presets(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconvert.list_presets\naws_api/mediaconvert list_presets","url":"aws_api/mediaconvert.html#list_presets"},{"doc":"aws_api/mediaconvert","title":"list_queues","content":"pub fn list_queues(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconvert.list_queues\naws_api/mediaconvert list_queues","url":"aws_api/mediaconvert.html#list_queues"},{"doc":"aws_api/mediaconvert","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconvert.list_tags_for_resource\naws_api/mediaconvert list_tags_for_resource","url":"aws_api/mediaconvert.html#list_tags_for_resource"},{"doc":"aws_api/mediaconvert","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/mediaconvert.new\naws_api/mediaconvert new","url":"aws_api/mediaconvert.html#new"},{"doc":"aws_api/mediaconvert","title":"put_policy","content":"pub fn put_policy(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconvert.put_policy\naws_api/mediaconvert put_policy","url":"aws_api/mediaconvert.html#put_policy"},{"doc":"aws_api/mediaconvert","title":"search_jobs","content":"pub fn search_jobs(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconvert.search_jobs\naws_api/mediaconvert search_jobs","url":"aws_api/mediaconvert.html#search_jobs"},{"doc":"aws_api/mediaconvert","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconvert.tag_resource\naws_api/mediaconvert tag_resource","url":"aws_api/mediaconvert.html#tag_resource"},{"doc":"aws_api/mediaconvert","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconvert.untag_resource\naws_api/mediaconvert untag_resource","url":"aws_api/mediaconvert.html#untag_resource"},{"doc":"aws_api/mediaconvert","title":"update_job_template","content":"pub fn update_job_template(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconvert.update_job_template\naws_api/mediaconvert update_job_template","url":"aws_api/mediaconvert.html#update_job_template"},{"doc":"aws_api/mediaconvert","title":"update_preset","content":"pub fn update_preset(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconvert.update_preset\naws_api/mediaconvert update_preset","url":"aws_api/mediaconvert.html#update_preset"},{"doc":"aws_api/mediaconvert","title":"update_queue","content":"pub fn update_queue(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediaconvert.update_queue\naws_api/mediaconvert update_queue","url":"aws_api/mediaconvert.html#update_queue"},{"doc":"aws_api/mediaconvert","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/mediaconvert.with_custom_endpoint\naws_api/mediaconvert with_custom_endpoint","url":"aws_api/mediaconvert.html#with_custom_endpoint"},{"doc":"aws_api/mediaconvert","title":"aws_api/mediaconvert","content":"","url":"aws_api/mediaconvert.html"},{"doc":"aws_api/medialive","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/medialive.Client\naws_api/medialive Client","url":"aws_api/medialive.html#Client"},{"doc":"aws_api/medialive","title":"accept_input_device_transfer","content":"pub fn accept_input_device_transfer(\n  client: Client,\n  input_device_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.accept_input_device_transfer\naws_api/medialive accept_input_device_transfer","url":"aws_api/medialive.html#accept_input_device_transfer"},{"doc":"aws_api/medialive","title":"batch_delete","content":"pub fn batch_delete(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.batch_delete\naws_api/medialive batch_delete","url":"aws_api/medialive.html#batch_delete"},{"doc":"aws_api/medialive","title":"batch_start","content":"pub fn batch_start(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.batch_start\naws_api/medialive batch_start","url":"aws_api/medialive.html#batch_start"},{"doc":"aws_api/medialive","title":"batch_stop","content":"pub fn batch_stop(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.batch_stop\naws_api/medialive batch_stop","url":"aws_api/medialive.html#batch_stop"},{"doc":"aws_api/medialive","title":"batch_update_schedule","content":"pub fn batch_update_schedule(\n  client: Client,\n  channel_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.batch_update_schedule\naws_api/medialive batch_update_schedule","url":"aws_api/medialive.html#batch_update_schedule"},{"doc":"aws_api/medialive","title":"cancel_input_device_transfer","content":"pub fn cancel_input_device_transfer(\n  client: Client,\n  input_device_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.cancel_input_device_transfer\naws_api/medialive cancel_input_device_transfer","url":"aws_api/medialive.html#cancel_input_device_transfer"},{"doc":"aws_api/medialive","title":"claim_device","content":"pub fn claim_device(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.claim_device\naws_api/medialive claim_device","url":"aws_api/medialive.html#claim_device"},{"doc":"aws_api/medialive","title":"create_channel","content":"pub fn create_channel(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.create_channel\naws_api/medialive create_channel","url":"aws_api/medialive.html#create_channel"},{"doc":"aws_api/medialive","title":"create_cloud_watch_alarm_template","content":"pub fn create_cloud_watch_alarm_template(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.create_cloud_watch_alarm_template\naws_api/medialive create_cloud_watch_alarm_template","url":"aws_api/medialive.html#create_cloud_watch_alarm_template"},{"doc":"aws_api/medialive","title":"create_cloud_watch_alarm_template_group","content":"pub fn create_cloud_watch_alarm_template_group(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.create_cloud_watch_alarm_template_group\naws_api/medialive create_cloud_watch_alarm_template_group","url":"aws_api/medialive.html#create_cloud_watch_alarm_template_group"},{"doc":"aws_api/medialive","title":"create_event_bridge_rule_template","content":"pub fn create_event_bridge_rule_template(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.create_event_bridge_rule_template\naws_api/medialive create_event_bridge_rule_template","url":"aws_api/medialive.html#create_event_bridge_rule_template"},{"doc":"aws_api/medialive","title":"create_event_bridge_rule_template_group","content":"pub fn create_event_bridge_rule_template_group(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.create_event_bridge_rule_template_group\naws_api/medialive create_event_bridge_rule_template_group","url":"aws_api/medialive.html#create_event_bridge_rule_template_group"},{"doc":"aws_api/medialive","title":"create_input","content":"pub fn create_input(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.create_input\naws_api/medialive create_input","url":"aws_api/medialive.html#create_input"},{"doc":"aws_api/medialive","title":"create_input_security_group","content":"pub fn create_input_security_group(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.create_input_security_group\naws_api/medialive create_input_security_group","url":"aws_api/medialive.html#create_input_security_group"},{"doc":"aws_api/medialive","title":"create_multiplex","content":"pub fn create_multiplex(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.create_multiplex\naws_api/medialive create_multiplex","url":"aws_api/medialive.html#create_multiplex"},{"doc":"aws_api/medialive","title":"create_multiplex_program","content":"pub fn create_multiplex_program(\n  client: Client,\n  multiplex_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.create_multiplex_program\naws_api/medialive create_multiplex_program","url":"aws_api/medialive.html#create_multiplex_program"},{"doc":"aws_api/medialive","title":"create_partner_input","content":"pub fn create_partner_input(\n  client: Client,\n  input_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.create_partner_input\naws_api/medialive create_partner_input","url":"aws_api/medialive.html#create_partner_input"},{"doc":"aws_api/medialive","title":"create_signal_map","content":"pub fn create_signal_map(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.create_signal_map\naws_api/medialive create_signal_map","url":"aws_api/medialive.html#create_signal_map"},{"doc":"aws_api/medialive","title":"create_tags","content":"pub fn create_tags(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.create_tags\naws_api/medialive create_tags","url":"aws_api/medialive.html#create_tags"},{"doc":"aws_api/medialive","title":"delete_channel","content":"pub fn delete_channel(\n  client: Client,\n  channel_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.delete_channel\naws_api/medialive delete_channel","url":"aws_api/medialive.html#delete_channel"},{"doc":"aws_api/medialive","title":"delete_cloud_watch_alarm_template","content":"pub fn delete_cloud_watch_alarm_template(\n  client: Client,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.delete_cloud_watch_alarm_template\naws_api/medialive delete_cloud_watch_alarm_template","url":"aws_api/medialive.html#delete_cloud_watch_alarm_template"},{"doc":"aws_api/medialive","title":"delete_cloud_watch_alarm_template_group","content":"pub fn delete_cloud_watch_alarm_template_group(\n  client: Client,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.delete_cloud_watch_alarm_template_group\naws_api/medialive delete_cloud_watch_alarm_template_group","url":"aws_api/medialive.html#delete_cloud_watch_alarm_template_group"},{"doc":"aws_api/medialive","title":"delete_event_bridge_rule_template","content":"pub fn delete_event_bridge_rule_template(\n  client: Client,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.delete_event_bridge_rule_template\naws_api/medialive delete_event_bridge_rule_template","url":"aws_api/medialive.html#delete_event_bridge_rule_template"},{"doc":"aws_api/medialive","title":"delete_event_bridge_rule_template_group","content":"pub fn delete_event_bridge_rule_template_group(\n  client: Client,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.delete_event_bridge_rule_template_group\naws_api/medialive delete_event_bridge_rule_template_group","url":"aws_api/medialive.html#delete_event_bridge_rule_template_group"},{"doc":"aws_api/medialive","title":"delete_input","content":"pub fn delete_input(\n  client: Client,\n  input_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.delete_input\naws_api/medialive delete_input","url":"aws_api/medialive.html#delete_input"},{"doc":"aws_api/medialive","title":"delete_input_security_group","content":"pub fn delete_input_security_group(\n  client: Client,\n  input_security_group_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.delete_input_security_group\naws_api/medialive delete_input_security_group","url":"aws_api/medialive.html#delete_input_security_group"},{"doc":"aws_api/medialive","title":"delete_multiplex","content":"pub fn delete_multiplex(\n  client: Client,\n  multiplex_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.delete_multiplex\naws_api/medialive delete_multiplex","url":"aws_api/medialive.html#delete_multiplex"},{"doc":"aws_api/medialive","title":"delete_multiplex_program","content":"pub fn delete_multiplex_program(\n  client: Client,\n  multiplex_id: String,\n  program_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.delete_multiplex_program\naws_api/medialive delete_multiplex_program","url":"aws_api/medialive.html#delete_multiplex_program"},{"doc":"aws_api/medialive","title":"delete_reservation","content":"pub fn delete_reservation(\n  client: Client,\n  reservation_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.delete_reservation\naws_api/medialive delete_reservation","url":"aws_api/medialive.html#delete_reservation"},{"doc":"aws_api/medialive","title":"delete_schedule","content":"pub fn delete_schedule(\n  client: Client,\n  channel_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.delete_schedule\naws_api/medialive delete_schedule","url":"aws_api/medialive.html#delete_schedule"},{"doc":"aws_api/medialive","title":"delete_signal_map","content":"pub fn delete_signal_map(\n  client: Client,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.delete_signal_map\naws_api/medialive delete_signal_map","url":"aws_api/medialive.html#delete_signal_map"},{"doc":"aws_api/medialive","title":"delete_tags","content":"pub fn delete_tags(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.delete_tags\naws_api/medialive delete_tags","url":"aws_api/medialive.html#delete_tags"},{"doc":"aws_api/medialive","title":"describe_account_configuration","content":"pub fn describe_account_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.describe_account_configuration\naws_api/medialive describe_account_configuration","url":"aws_api/medialive.html#describe_account_configuration"},{"doc":"aws_api/medialive","title":"describe_channel","content":"pub fn describe_channel(\n  client: Client,\n  channel_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.describe_channel\naws_api/medialive describe_channel","url":"aws_api/medialive.html#describe_channel"},{"doc":"aws_api/medialive","title":"describe_input","content":"pub fn describe_input(\n  client: Client,\n  input_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.describe_input\naws_api/medialive describe_input","url":"aws_api/medialive.html#describe_input"},{"doc":"aws_api/medialive","title":"describe_input_device","content":"pub fn describe_input_device(\n  client: Client,\n  input_device_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.describe_input_device\naws_api/medialive describe_input_device","url":"aws_api/medialive.html#describe_input_device"},{"doc":"aws_api/medialive","title":"describe_input_device_thumbnail","content":"pub fn describe_input_device_thumbnail(\n  client: Client,\n  input_device_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.describe_input_device_thumbnail\naws_api/medialive describe_input_device_thumbnail","url":"aws_api/medialive.html#describe_input_device_thumbnail"},{"doc":"aws_api/medialive","title":"describe_input_security_group","content":"pub fn describe_input_security_group(\n  client: Client,\n  input_security_group_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.describe_input_security_group\naws_api/medialive describe_input_security_group","url":"aws_api/medialive.html#describe_input_security_group"},{"doc":"aws_api/medialive","title":"describe_multiplex","content":"pub fn describe_multiplex(\n  client: Client,\n  multiplex_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.describe_multiplex\naws_api/medialive describe_multiplex","url":"aws_api/medialive.html#describe_multiplex"},{"doc":"aws_api/medialive","title":"describe_multiplex_program","content":"pub fn describe_multiplex_program(\n  client: Client,\n  multiplex_id: String,\n  program_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.describe_multiplex_program\naws_api/medialive describe_multiplex_program","url":"aws_api/medialive.html#describe_multiplex_program"},{"doc":"aws_api/medialive","title":"describe_offering","content":"pub fn describe_offering(\n  client: Client,\n  offering_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.describe_offering\naws_api/medialive describe_offering","url":"aws_api/medialive.html#describe_offering"},{"doc":"aws_api/medialive","title":"describe_reservation","content":"pub fn describe_reservation(\n  client: Client,\n  reservation_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.describe_reservation\naws_api/medialive describe_reservation","url":"aws_api/medialive.html#describe_reservation"},{"doc":"aws_api/medialive","title":"describe_schedule","content":"pub fn describe_schedule(\n  client: Client,\n  channel_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.describe_schedule\naws_api/medialive describe_schedule","url":"aws_api/medialive.html#describe_schedule"},{"doc":"aws_api/medialive","title":"describe_thumbnails","content":"pub fn describe_thumbnails(\n  client: Client,\n  channel_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.describe_thumbnails\naws_api/medialive describe_thumbnails","url":"aws_api/medialive.html#describe_thumbnails"},{"doc":"aws_api/medialive","title":"get_cloud_watch_alarm_template","content":"pub fn get_cloud_watch_alarm_template(\n  client: Client,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.get_cloud_watch_alarm_template\naws_api/medialive get_cloud_watch_alarm_template","url":"aws_api/medialive.html#get_cloud_watch_alarm_template"},{"doc":"aws_api/medialive","title":"get_cloud_watch_alarm_template_group","content":"pub fn get_cloud_watch_alarm_template_group(\n  client: Client,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.get_cloud_watch_alarm_template_group\naws_api/medialive get_cloud_watch_alarm_template_group","url":"aws_api/medialive.html#get_cloud_watch_alarm_template_group"},{"doc":"aws_api/medialive","title":"get_event_bridge_rule_template","content":"pub fn get_event_bridge_rule_template(\n  client: Client,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.get_event_bridge_rule_template\naws_api/medialive get_event_bridge_rule_template","url":"aws_api/medialive.html#get_event_bridge_rule_template"},{"doc":"aws_api/medialive","title":"get_event_bridge_rule_template_group","content":"pub fn get_event_bridge_rule_template_group(\n  client: Client,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.get_event_bridge_rule_template_group\naws_api/medialive get_event_bridge_rule_template_group","url":"aws_api/medialive.html#get_event_bridge_rule_template_group"},{"doc":"aws_api/medialive","title":"get_signal_map","content":"pub fn get_signal_map(\n  client: Client,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.get_signal_map\naws_api/medialive get_signal_map","url":"aws_api/medialive.html#get_signal_map"},{"doc":"aws_api/medialive","title":"list_channels","content":"pub fn list_channels(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.list_channels\naws_api/medialive list_channels","url":"aws_api/medialive.html#list_channels"},{"doc":"aws_api/medialive","title":"list_cloud_watch_alarm_template_groups","content":"pub fn list_cloud_watch_alarm_template_groups(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.list_cloud_watch_alarm_template_groups\naws_api/medialive list_cloud_watch_alarm_template_groups","url":"aws_api/medialive.html#list_cloud_watch_alarm_template_groups"},{"doc":"aws_api/medialive","title":"list_cloud_watch_alarm_templates","content":"pub fn list_cloud_watch_alarm_templates(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.list_cloud_watch_alarm_templates\naws_api/medialive list_cloud_watch_alarm_templates","url":"aws_api/medialive.html#list_cloud_watch_alarm_templates"},{"doc":"aws_api/medialive","title":"list_event_bridge_rule_template_groups","content":"pub fn list_event_bridge_rule_template_groups(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.list_event_bridge_rule_template_groups\naws_api/medialive list_event_bridge_rule_template_groups","url":"aws_api/medialive.html#list_event_bridge_rule_template_groups"},{"doc":"aws_api/medialive","title":"list_event_bridge_rule_templates","content":"pub fn list_event_bridge_rule_templates(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.list_event_bridge_rule_templates\naws_api/medialive list_event_bridge_rule_templates","url":"aws_api/medialive.html#list_event_bridge_rule_templates"},{"doc":"aws_api/medialive","title":"list_input_device_transfers","content":"pub fn list_input_device_transfers(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.list_input_device_transfers\naws_api/medialive list_input_device_transfers","url":"aws_api/medialive.html#list_input_device_transfers"},{"doc":"aws_api/medialive","title":"list_input_devices","content":"pub fn list_input_devices(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.list_input_devices\naws_api/medialive list_input_devices","url":"aws_api/medialive.html#list_input_devices"},{"doc":"aws_api/medialive","title":"list_input_security_groups","content":"pub fn list_input_security_groups(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.list_input_security_groups\naws_api/medialive list_input_security_groups","url":"aws_api/medialive.html#list_input_security_groups"},{"doc":"aws_api/medialive","title":"list_inputs","content":"pub fn list_inputs(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.list_inputs\naws_api/medialive list_inputs","url":"aws_api/medialive.html#list_inputs"},{"doc":"aws_api/medialive","title":"list_multiplex_programs","content":"pub fn list_multiplex_programs(\n  client: Client,\n  multiplex_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.list_multiplex_programs\naws_api/medialive list_multiplex_programs","url":"aws_api/medialive.html#list_multiplex_programs"},{"doc":"aws_api/medialive","title":"list_multiplexes","content":"pub fn list_multiplexes(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.list_multiplexes\naws_api/medialive list_multiplexes","url":"aws_api/medialive.html#list_multiplexes"},{"doc":"aws_api/medialive","title":"list_offerings","content":"pub fn list_offerings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.list_offerings\naws_api/medialive list_offerings","url":"aws_api/medialive.html#list_offerings"},{"doc":"aws_api/medialive","title":"list_reservations","content":"pub fn list_reservations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.list_reservations\naws_api/medialive list_reservations","url":"aws_api/medialive.html#list_reservations"},{"doc":"aws_api/medialive","title":"list_signal_maps","content":"pub fn list_signal_maps(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.list_signal_maps\naws_api/medialive list_signal_maps","url":"aws_api/medialive.html#list_signal_maps"},{"doc":"aws_api/medialive","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.list_tags_for_resource\naws_api/medialive list_tags_for_resource","url":"aws_api/medialive.html#list_tags_for_resource"},{"doc":"aws_api/medialive","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/medialive.new\naws_api/medialive new","url":"aws_api/medialive.html#new"},{"doc":"aws_api/medialive","title":"purchase_offering","content":"pub fn purchase_offering(\n  client: Client,\n  offering_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.purchase_offering\naws_api/medialive purchase_offering","url":"aws_api/medialive.html#purchase_offering"},{"doc":"aws_api/medialive","title":"reboot_input_device","content":"pub fn reboot_input_device(\n  client: Client,\n  input_device_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.reboot_input_device\naws_api/medialive reboot_input_device","url":"aws_api/medialive.html#reboot_input_device"},{"doc":"aws_api/medialive","title":"reject_input_device_transfer","content":"pub fn reject_input_device_transfer(\n  client: Client,\n  input_device_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.reject_input_device_transfer\naws_api/medialive reject_input_device_transfer","url":"aws_api/medialive.html#reject_input_device_transfer"},{"doc":"aws_api/medialive","title":"restart_channel_pipelines","content":"pub fn restart_channel_pipelines(\n  client: Client,\n  channel_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.restart_channel_pipelines\naws_api/medialive restart_channel_pipelines","url":"aws_api/medialive.html#restart_channel_pipelines"},{"doc":"aws_api/medialive","title":"start_channel","content":"pub fn start_channel(\n  client: Client,\n  channel_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.start_channel\naws_api/medialive start_channel","url":"aws_api/medialive.html#start_channel"},{"doc":"aws_api/medialive","title":"start_delete_monitor_deployment","content":"pub fn start_delete_monitor_deployment(\n  client: Client,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.start_delete_monitor_deployment\naws_api/medialive start_delete_monitor_deployment","url":"aws_api/medialive.html#start_delete_monitor_deployment"},{"doc":"aws_api/medialive","title":"start_input_device","content":"pub fn start_input_device(\n  client: Client,\n  input_device_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.start_input_device\naws_api/medialive start_input_device","url":"aws_api/medialive.html#start_input_device"},{"doc":"aws_api/medialive","title":"start_input_device_maintenance_window","content":"pub fn start_input_device_maintenance_window(\n  client: Client,\n  input_device_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.start_input_device_maintenance_window\naws_api/medialive start_input_device_maintenance_window","url":"aws_api/medialive.html#start_input_device_maintenance_window"},{"doc":"aws_api/medialive","title":"start_monitor_deployment","content":"pub fn start_monitor_deployment(\n  client: Client,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.start_monitor_deployment\naws_api/medialive start_monitor_deployment","url":"aws_api/medialive.html#start_monitor_deployment"},{"doc":"aws_api/medialive","title":"start_multiplex","content":"pub fn start_multiplex(\n  client: Client,\n  multiplex_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.start_multiplex\naws_api/medialive start_multiplex","url":"aws_api/medialive.html#start_multiplex"},{"doc":"aws_api/medialive","title":"start_update_signal_map","content":"pub fn start_update_signal_map(\n  client: Client,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.start_update_signal_map\naws_api/medialive start_update_signal_map","url":"aws_api/medialive.html#start_update_signal_map"},{"doc":"aws_api/medialive","title":"stop_channel","content":"pub fn stop_channel(\n  client: Client,\n  channel_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.stop_channel\naws_api/medialive stop_channel","url":"aws_api/medialive.html#stop_channel"},{"doc":"aws_api/medialive","title":"stop_input_device","content":"pub fn stop_input_device(\n  client: Client,\n  input_device_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.stop_input_device\naws_api/medialive stop_input_device","url":"aws_api/medialive.html#stop_input_device"},{"doc":"aws_api/medialive","title":"stop_multiplex","content":"pub fn stop_multiplex(\n  client: Client,\n  multiplex_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.stop_multiplex\naws_api/medialive stop_multiplex","url":"aws_api/medialive.html#stop_multiplex"},{"doc":"aws_api/medialive","title":"transfer_input_device","content":"pub fn transfer_input_device(\n  client: Client,\n  input_device_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.transfer_input_device\naws_api/medialive transfer_input_device","url":"aws_api/medialive.html#transfer_input_device"},{"doc":"aws_api/medialive","title":"update_account_configuration","content":"pub fn update_account_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.update_account_configuration\naws_api/medialive update_account_configuration","url":"aws_api/medialive.html#update_account_configuration"},{"doc":"aws_api/medialive","title":"update_channel","content":"pub fn update_channel(\n  client: Client,\n  channel_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.update_channel\naws_api/medialive update_channel","url":"aws_api/medialive.html#update_channel"},{"doc":"aws_api/medialive","title":"update_channel_class","content":"pub fn update_channel_class(\n  client: Client,\n  channel_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.update_channel_class\naws_api/medialive update_channel_class","url":"aws_api/medialive.html#update_channel_class"},{"doc":"aws_api/medialive","title":"update_cloud_watch_alarm_template","content":"pub fn update_cloud_watch_alarm_template(\n  client: Client,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.update_cloud_watch_alarm_template\naws_api/medialive update_cloud_watch_alarm_template","url":"aws_api/medialive.html#update_cloud_watch_alarm_template"},{"doc":"aws_api/medialive","title":"update_cloud_watch_alarm_template_group","content":"pub fn update_cloud_watch_alarm_template_group(\n  client: Client,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.update_cloud_watch_alarm_template_group\naws_api/medialive update_cloud_watch_alarm_template_group","url":"aws_api/medialive.html#update_cloud_watch_alarm_template_group"},{"doc":"aws_api/medialive","title":"update_event_bridge_rule_template","content":"pub fn update_event_bridge_rule_template(\n  client: Client,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.update_event_bridge_rule_template\naws_api/medialive update_event_bridge_rule_template","url":"aws_api/medialive.html#update_event_bridge_rule_template"},{"doc":"aws_api/medialive","title":"update_event_bridge_rule_template_group","content":"pub fn update_event_bridge_rule_template_group(\n  client: Client,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.update_event_bridge_rule_template_group\naws_api/medialive update_event_bridge_rule_template_group","url":"aws_api/medialive.html#update_event_bridge_rule_template_group"},{"doc":"aws_api/medialive","title":"update_input","content":"pub fn update_input(\n  client: Client,\n  input_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.update_input\naws_api/medialive update_input","url":"aws_api/medialive.html#update_input"},{"doc":"aws_api/medialive","title":"update_input_device","content":"pub fn update_input_device(\n  client: Client,\n  input_device_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.update_input_device\naws_api/medialive update_input_device","url":"aws_api/medialive.html#update_input_device"},{"doc":"aws_api/medialive","title":"update_input_security_group","content":"pub fn update_input_security_group(\n  client: Client,\n  input_security_group_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.update_input_security_group\naws_api/medialive update_input_security_group","url":"aws_api/medialive.html#update_input_security_group"},{"doc":"aws_api/medialive","title":"update_multiplex","content":"pub fn update_multiplex(\n  client: Client,\n  multiplex_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.update_multiplex\naws_api/medialive update_multiplex","url":"aws_api/medialive.html#update_multiplex"},{"doc":"aws_api/medialive","title":"update_multiplex_program","content":"pub fn update_multiplex_program(\n  client: Client,\n  multiplex_id: String,\n  program_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.update_multiplex_program\naws_api/medialive update_multiplex_program","url":"aws_api/medialive.html#update_multiplex_program"},{"doc":"aws_api/medialive","title":"update_reservation","content":"pub fn update_reservation(\n  client: Client,\n  reservation_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/medialive.update_reservation\naws_api/medialive update_reservation","url":"aws_api/medialive.html#update_reservation"},{"doc":"aws_api/medialive","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/medialive.with_custom_endpoint\naws_api/medialive with_custom_endpoint","url":"aws_api/medialive.html#with_custom_endpoint"},{"doc":"aws_api/medialive","title":"aws_api/medialive","content":"","url":"aws_api/medialive.html"},{"doc":"aws_api/mediapackage","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/mediapackage.Client\naws_api/mediapackage Client","url":"aws_api/mediapackage.html#Client"},{"doc":"aws_api/mediapackage","title":"configure_logs","content":"pub fn configure_logs(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediapackage.configure_logs\naws_api/mediapackage configure_logs","url":"aws_api/mediapackage.html#configure_logs"},{"doc":"aws_api/mediapackage","title":"create_channel","content":"pub fn create_channel(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediapackage.create_channel\naws_api/mediapackage create_channel","url":"aws_api/mediapackage.html#create_channel"},{"doc":"aws_api/mediapackage","title":"create_harvest_job","content":"pub fn create_harvest_job(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediapackage.create_harvest_job\naws_api/mediapackage create_harvest_job","url":"aws_api/mediapackage.html#create_harvest_job"},{"doc":"aws_api/mediapackage","title":"create_origin_endpoint","content":"pub fn create_origin_endpoint(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediapackage.create_origin_endpoint\naws_api/mediapackage create_origin_endpoint","url":"aws_api/mediapackage.html#create_origin_endpoint"},{"doc":"aws_api/mediapackage","title":"delete_channel","content":"pub fn delete_channel(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediapackage.delete_channel\naws_api/mediapackage delete_channel","url":"aws_api/mediapackage.html#delete_channel"},{"doc":"aws_api/mediapackage","title":"delete_origin_endpoint","content":"pub fn delete_origin_endpoint(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediapackage.delete_origin_endpoint\naws_api/mediapackage delete_origin_endpoint","url":"aws_api/mediapackage.html#delete_origin_endpoint"},{"doc":"aws_api/mediapackage","title":"describe_channel","content":"pub fn describe_channel(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediapackage.describe_channel\naws_api/mediapackage describe_channel","url":"aws_api/mediapackage.html#describe_channel"},{"doc":"aws_api/mediapackage","title":"describe_harvest_job","content":"pub fn describe_harvest_job(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediapackage.describe_harvest_job\naws_api/mediapackage describe_harvest_job","url":"aws_api/mediapackage.html#describe_harvest_job"},{"doc":"aws_api/mediapackage","title":"describe_origin_endpoint","content":"pub fn describe_origin_endpoint(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediapackage.describe_origin_endpoint\naws_api/mediapackage describe_origin_endpoint","url":"aws_api/mediapackage.html#describe_origin_endpoint"},{"doc":"aws_api/mediapackage","title":"list_channels","content":"pub fn list_channels(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediapackage.list_channels\naws_api/mediapackage list_channels","url":"aws_api/mediapackage.html#list_channels"},{"doc":"aws_api/mediapackage","title":"list_harvest_jobs","content":"pub fn list_harvest_jobs(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediapackage.list_harvest_jobs\naws_api/mediapackage list_harvest_jobs","url":"aws_api/mediapackage.html#list_harvest_jobs"},{"doc":"aws_api/mediapackage","title":"list_origin_endpoints","content":"pub fn list_origin_endpoints(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediapackage.list_origin_endpoints\naws_api/mediapackage list_origin_endpoints","url":"aws_api/mediapackage.html#list_origin_endpoints"},{"doc":"aws_api/mediapackage","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediapackage.list_tags_for_resource\naws_api/mediapackage list_tags_for_resource","url":"aws_api/mediapackage.html#list_tags_for_resource"},{"doc":"aws_api/mediapackage","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/mediapackage.new\naws_api/mediapackage new","url":"aws_api/mediapackage.html#new"},{"doc":"aws_api/mediapackage","title":"rotate_channel_credentials","content":"pub fn rotate_channel_credentials(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediapackage.rotate_channel_credentials\naws_api/mediapackage rotate_channel_credentials","url":"aws_api/mediapackage.html#rotate_channel_credentials"},{"doc":"aws_api/mediapackage","title":"rotate_ingest_endpoint_credentials","content":"pub fn rotate_ingest_endpoint_credentials(\n  client: Client,\n  id: String,\n  ingest_endpoint_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediapackage.rotate_ingest_endpoint_credentials\naws_api/mediapackage rotate_ingest_endpoint_credentials","url":"aws_api/mediapackage.html#rotate_ingest_endpoint_credentials"},{"doc":"aws_api/mediapackage","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediapackage.tag_resource\naws_api/mediapackage tag_resource","url":"aws_api/mediapackage.html#tag_resource"},{"doc":"aws_api/mediapackage","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediapackage.untag_resource\naws_api/mediapackage untag_resource","url":"aws_api/mediapackage.html#untag_resource"},{"doc":"aws_api/mediapackage","title":"update_channel","content":"pub fn update_channel(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediapackage.update_channel\naws_api/mediapackage update_channel","url":"aws_api/mediapackage.html#update_channel"},{"doc":"aws_api/mediapackage","title":"update_origin_endpoint","content":"pub fn update_origin_endpoint(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediapackage.update_origin_endpoint\naws_api/mediapackage update_origin_endpoint","url":"aws_api/mediapackage.html#update_origin_endpoint"},{"doc":"aws_api/mediapackage","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/mediapackage.with_custom_endpoint\naws_api/mediapackage with_custom_endpoint","url":"aws_api/mediapackage.html#with_custom_endpoint"},{"doc":"aws_api/mediapackage","title":"aws_api/mediapackage","content":"","url":"aws_api/mediapackage.html"},{"doc":"aws_api/mediapackage_vod","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/mediapackage_vod.Client\naws_api/mediapackage_vod Client","url":"aws_api/mediapackage_vod.html#Client"},{"doc":"aws_api/mediapackage_vod","title":"configure_logs","content":"pub fn configure_logs(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediapackage_vod.configure_logs\naws_api/mediapackage_vod configure_logs","url":"aws_api/mediapackage_vod.html#configure_logs"},{"doc":"aws_api/mediapackage_vod","title":"create_asset","content":"pub fn create_asset(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediapackage_vod.create_asset\naws_api/mediapackage_vod create_asset","url":"aws_api/mediapackage_vod.html#create_asset"},{"doc":"aws_api/mediapackage_vod","title":"create_packaging_configuration","content":"pub fn create_packaging_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediapackage_vod.create_packaging_configuration\naws_api/mediapackage_vod create_packaging_configuration","url":"aws_api/mediapackage_vod.html#create_packaging_configuration"},{"doc":"aws_api/mediapackage_vod","title":"create_packaging_group","content":"pub fn create_packaging_group(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediapackage_vod.create_packaging_group\naws_api/mediapackage_vod create_packaging_group","url":"aws_api/mediapackage_vod.html#create_packaging_group"},{"doc":"aws_api/mediapackage_vod","title":"delete_asset","content":"pub fn delete_asset(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediapackage_vod.delete_asset\naws_api/mediapackage_vod delete_asset","url":"aws_api/mediapackage_vod.html#delete_asset"},{"doc":"aws_api/mediapackage_vod","title":"delete_packaging_configuration","content":"pub fn delete_packaging_configuration(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediapackage_vod.delete_packaging_configuration\naws_api/mediapackage_vod delete_packaging_configuration","url":"aws_api/mediapackage_vod.html#delete_packaging_configuration"},{"doc":"aws_api/mediapackage_vod","title":"delete_packaging_group","content":"pub fn delete_packaging_group(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediapackage_vod.delete_packaging_group\naws_api/mediapackage_vod delete_packaging_group","url":"aws_api/mediapackage_vod.html#delete_packaging_group"},{"doc":"aws_api/mediapackage_vod","title":"describe_asset","content":"pub fn describe_asset(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediapackage_vod.describe_asset\naws_api/mediapackage_vod describe_asset","url":"aws_api/mediapackage_vod.html#describe_asset"},{"doc":"aws_api/mediapackage_vod","title":"describe_packaging_configuration","content":"pub fn describe_packaging_configuration(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediapackage_vod.describe_packaging_configuration\naws_api/mediapackage_vod describe_packaging_configuration","url":"aws_api/mediapackage_vod.html#describe_packaging_configuration"},{"doc":"aws_api/mediapackage_vod","title":"describe_packaging_group","content":"pub fn describe_packaging_group(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediapackage_vod.describe_packaging_group\naws_api/mediapackage_vod describe_packaging_group","url":"aws_api/mediapackage_vod.html#describe_packaging_group"},{"doc":"aws_api/mediapackage_vod","title":"list_assets","content":"pub fn list_assets(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediapackage_vod.list_assets\naws_api/mediapackage_vod list_assets","url":"aws_api/mediapackage_vod.html#list_assets"},{"doc":"aws_api/mediapackage_vod","title":"list_packaging_configurations","content":"pub fn list_packaging_configurations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediapackage_vod.list_packaging_configurations\naws_api/mediapackage_vod list_packaging_configurations","url":"aws_api/mediapackage_vod.html#list_packaging_configurations"},{"doc":"aws_api/mediapackage_vod","title":"list_packaging_groups","content":"pub fn list_packaging_groups(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediapackage_vod.list_packaging_groups\naws_api/mediapackage_vod list_packaging_groups","url":"aws_api/mediapackage_vod.html#list_packaging_groups"},{"doc":"aws_api/mediapackage_vod","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediapackage_vod.list_tags_for_resource\naws_api/mediapackage_vod list_tags_for_resource","url":"aws_api/mediapackage_vod.html#list_tags_for_resource"},{"doc":"aws_api/mediapackage_vod","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/mediapackage_vod.new\naws_api/mediapackage_vod new","url":"aws_api/mediapackage_vod.html#new"},{"doc":"aws_api/mediapackage_vod","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediapackage_vod.tag_resource\naws_api/mediapackage_vod tag_resource","url":"aws_api/mediapackage_vod.html#tag_resource"},{"doc":"aws_api/mediapackage_vod","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediapackage_vod.untag_resource\naws_api/mediapackage_vod untag_resource","url":"aws_api/mediapackage_vod.html#untag_resource"},{"doc":"aws_api/mediapackage_vod","title":"update_packaging_group","content":"pub fn update_packaging_group(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediapackage_vod.update_packaging_group\naws_api/mediapackage_vod update_packaging_group","url":"aws_api/mediapackage_vod.html#update_packaging_group"},{"doc":"aws_api/mediapackage_vod","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/mediapackage_vod.with_custom_endpoint\naws_api/mediapackage_vod with_custom_endpoint","url":"aws_api/mediapackage_vod.html#with_custom_endpoint"},{"doc":"aws_api/mediapackage_vod","title":"aws_api/mediapackage_vod","content":"","url":"aws_api/mediapackage_vod.html"},{"doc":"aws_api/mediapackagev2","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/mediapackagev2.Client\naws_api/mediapackagev2 Client","url":"aws_api/mediapackagev2.html#Client"},{"doc":"aws_api/mediapackagev2","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediapackagev2.list_tags_for_resource\naws_api/mediapackagev2 list_tags_for_resource","url":"aws_api/mediapackagev2.html#list_tags_for_resource"},{"doc":"aws_api/mediapackagev2","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/mediapackagev2.new\naws_api/mediapackagev2 new","url":"aws_api/mediapackagev2.html#new"},{"doc":"aws_api/mediapackagev2","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediapackagev2.tag_resource\naws_api/mediapackagev2 tag_resource","url":"aws_api/mediapackagev2.html#tag_resource"},{"doc":"aws_api/mediapackagev2","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediapackagev2.untag_resource\naws_api/mediapackagev2 untag_resource","url":"aws_api/mediapackagev2.html#untag_resource"},{"doc":"aws_api/mediapackagev2","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/mediapackagev2.with_custom_endpoint\naws_api/mediapackagev2 with_custom_endpoint","url":"aws_api/mediapackagev2.html#with_custom_endpoint"},{"doc":"aws_api/mediapackagev2","title":"aws_api/mediapackagev2","content":"","url":"aws_api/mediapackagev2.html"},{"doc":"aws_api/mediastore","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/mediastore.Client\naws_api/mediastore Client","url":"aws_api/mediastore.html#Client"},{"doc":"aws_api/mediastore","title":"create_container","content":"pub fn create_container(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediastore.create_container\naws_api/mediastore create_container","url":"aws_api/mediastore.html#create_container"},{"doc":"aws_api/mediastore","title":"delete_container","content":"pub fn delete_container(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediastore.delete_container\naws_api/mediastore delete_container","url":"aws_api/mediastore.html#delete_container"},{"doc":"aws_api/mediastore","title":"delete_container_policy","content":"pub fn delete_container_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediastore.delete_container_policy\naws_api/mediastore delete_container_policy","url":"aws_api/mediastore.html#delete_container_policy"},{"doc":"aws_api/mediastore","title":"delete_cors_policy","content":"pub fn delete_cors_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediastore.delete_cors_policy\naws_api/mediastore delete_cors_policy","url":"aws_api/mediastore.html#delete_cors_policy"},{"doc":"aws_api/mediastore","title":"delete_lifecycle_policy","content":"pub fn delete_lifecycle_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediastore.delete_lifecycle_policy\naws_api/mediastore delete_lifecycle_policy","url":"aws_api/mediastore.html#delete_lifecycle_policy"},{"doc":"aws_api/mediastore","title":"delete_metric_policy","content":"pub fn delete_metric_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediastore.delete_metric_policy\naws_api/mediastore delete_metric_policy","url":"aws_api/mediastore.html#delete_metric_policy"},{"doc":"aws_api/mediastore","title":"describe_container","content":"pub fn describe_container(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediastore.describe_container\naws_api/mediastore describe_container","url":"aws_api/mediastore.html#describe_container"},{"doc":"aws_api/mediastore","title":"get_container_policy","content":"pub fn get_container_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediastore.get_container_policy\naws_api/mediastore get_container_policy","url":"aws_api/mediastore.html#get_container_policy"},{"doc":"aws_api/mediastore","title":"get_cors_policy","content":"pub fn get_cors_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediastore.get_cors_policy\naws_api/mediastore get_cors_policy","url":"aws_api/mediastore.html#get_cors_policy"},{"doc":"aws_api/mediastore","title":"get_lifecycle_policy","content":"pub fn get_lifecycle_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediastore.get_lifecycle_policy\naws_api/mediastore get_lifecycle_policy","url":"aws_api/mediastore.html#get_lifecycle_policy"},{"doc":"aws_api/mediastore","title":"get_metric_policy","content":"pub fn get_metric_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediastore.get_metric_policy\naws_api/mediastore get_metric_policy","url":"aws_api/mediastore.html#get_metric_policy"},{"doc":"aws_api/mediastore","title":"list_containers","content":"pub fn list_containers(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediastore.list_containers\naws_api/mediastore list_containers","url":"aws_api/mediastore.html#list_containers"},{"doc":"aws_api/mediastore","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediastore.list_tags_for_resource\naws_api/mediastore list_tags_for_resource","url":"aws_api/mediastore.html#list_tags_for_resource"},{"doc":"aws_api/mediastore","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/mediastore.new\naws_api/mediastore new","url":"aws_api/mediastore.html#new"},{"doc":"aws_api/mediastore","title":"put_container_policy","content":"pub fn put_container_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediastore.put_container_policy\naws_api/mediastore put_container_policy","url":"aws_api/mediastore.html#put_container_policy"},{"doc":"aws_api/mediastore","title":"put_cors_policy","content":"pub fn put_cors_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediastore.put_cors_policy\naws_api/mediastore put_cors_policy","url":"aws_api/mediastore.html#put_cors_policy"},{"doc":"aws_api/mediastore","title":"put_lifecycle_policy","content":"pub fn put_lifecycle_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediastore.put_lifecycle_policy\naws_api/mediastore put_lifecycle_policy","url":"aws_api/mediastore.html#put_lifecycle_policy"},{"doc":"aws_api/mediastore","title":"put_metric_policy","content":"pub fn put_metric_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediastore.put_metric_policy\naws_api/mediastore put_metric_policy","url":"aws_api/mediastore.html#put_metric_policy"},{"doc":"aws_api/mediastore","title":"start_access_logging","content":"pub fn start_access_logging(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediastore.start_access_logging\naws_api/mediastore start_access_logging","url":"aws_api/mediastore.html#start_access_logging"},{"doc":"aws_api/mediastore","title":"stop_access_logging","content":"pub fn stop_access_logging(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediastore.stop_access_logging\naws_api/mediastore stop_access_logging","url":"aws_api/mediastore.html#stop_access_logging"},{"doc":"aws_api/mediastore","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediastore.tag_resource\naws_api/mediastore tag_resource","url":"aws_api/mediastore.html#tag_resource"},{"doc":"aws_api/mediastore","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediastore.untag_resource\naws_api/mediastore untag_resource","url":"aws_api/mediastore.html#untag_resource"},{"doc":"aws_api/mediastore","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/mediastore.with_custom_endpoint\naws_api/mediastore with_custom_endpoint","url":"aws_api/mediastore.html#with_custom_endpoint"},{"doc":"aws_api/mediastore","title":"aws_api/mediastore","content":"","url":"aws_api/mediastore.html"},{"doc":"aws_api/mediastore_data","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/mediastore_data.Client\naws_api/mediastore_data Client","url":"aws_api/mediastore_data.html#Client"},{"doc":"aws_api/mediastore_data","title":"delete_object","content":"pub fn delete_object(\n  client: Client,\n  path: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediastore_data.delete_object\naws_api/mediastore_data delete_object","url":"aws_api/mediastore_data.html#delete_object"},{"doc":"aws_api/mediastore_data","title":"describe_object","content":"pub fn describe_object(\n  client: Client,\n  path: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediastore_data.describe_object\naws_api/mediastore_data describe_object","url":"aws_api/mediastore_data.html#describe_object"},{"doc":"aws_api/mediastore_data","title":"get_object","content":"pub fn get_object(\n  client: Client,\n  path: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediastore_data.get_object\naws_api/mediastore_data get_object","url":"aws_api/mediastore_data.html#get_object"},{"doc":"aws_api/mediastore_data","title":"list_items","content":"pub fn list_items(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediastore_data.list_items\naws_api/mediastore_data list_items","url":"aws_api/mediastore_data.html#list_items"},{"doc":"aws_api/mediastore_data","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/mediastore_data.new\naws_api/mediastore_data new","url":"aws_api/mediastore_data.html#new"},{"doc":"aws_api/mediastore_data","title":"put_object","content":"pub fn put_object(\n  client: Client,\n  path: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediastore_data.put_object\naws_api/mediastore_data put_object","url":"aws_api/mediastore_data.html#put_object"},{"doc":"aws_api/mediastore_data","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/mediastore_data.with_custom_endpoint\naws_api/mediastore_data with_custom_endpoint","url":"aws_api/mediastore_data.html#with_custom_endpoint"},{"doc":"aws_api/mediastore_data","title":"aws_api/mediastore_data","content":"","url":"aws_api/mediastore_data.html"},{"doc":"aws_api/mediatailor","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/mediatailor.Client\naws_api/mediatailor Client","url":"aws_api/mediatailor.html#Client"},{"doc":"aws_api/mediatailor","title":"configure_logs_for_playback_configuration","content":"pub fn configure_logs_for_playback_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediatailor.configure_logs_for_playback_configuration\naws_api/mediatailor configure_logs_for_playback_configuration","url":"aws_api/mediatailor.html#configure_logs_for_playback_configuration"},{"doc":"aws_api/mediatailor","title":"list_alerts","content":"pub fn list_alerts(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediatailor.list_alerts\naws_api/mediatailor list_alerts","url":"aws_api/mediatailor.html#list_alerts"},{"doc":"aws_api/mediatailor","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediatailor.list_tags_for_resource\naws_api/mediatailor list_tags_for_resource","url":"aws_api/mediatailor.html#list_tags_for_resource"},{"doc":"aws_api/mediatailor","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/mediatailor.new\naws_api/mediatailor new","url":"aws_api/mediatailor.html#new"},{"doc":"aws_api/mediatailor","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediatailor.tag_resource\naws_api/mediatailor tag_resource","url":"aws_api/mediatailor.html#tag_resource"},{"doc":"aws_api/mediatailor","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mediatailor.untag_resource\naws_api/mediatailor untag_resource","url":"aws_api/mediatailor.html#untag_resource"},{"doc":"aws_api/mediatailor","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/mediatailor.with_custom_endpoint\naws_api/mediatailor with_custom_endpoint","url":"aws_api/mediatailor.html#with_custom_endpoint"},{"doc":"aws_api/mediatailor","title":"aws_api/mediatailor","content":"","url":"aws_api/mediatailor.html"},{"doc":"aws_api/memorydb","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/memorydb.Client\naws_api/memorydb Client","url":"aws_api/memorydb.html#Client"},{"doc":"aws_api/memorydb","title":"batch_update_cluster","content":"pub fn batch_update_cluster(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/memorydb.batch_update_cluster\naws_api/memorydb batch_update_cluster","url":"aws_api/memorydb.html#batch_update_cluster"},{"doc":"aws_api/memorydb","title":"copy_snapshot","content":"pub fn copy_snapshot(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/memorydb.copy_snapshot\naws_api/memorydb copy_snapshot","url":"aws_api/memorydb.html#copy_snapshot"},{"doc":"aws_api/memorydb","title":"create_acl","content":"pub fn create_acl(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/memorydb.create_acl\naws_api/memorydb create_acl","url":"aws_api/memorydb.html#create_acl"},{"doc":"aws_api/memorydb","title":"create_cluster","content":"pub fn create_cluster(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/memorydb.create_cluster\naws_api/memorydb create_cluster","url":"aws_api/memorydb.html#create_cluster"},{"doc":"aws_api/memorydb","title":"create_parameter_group","content":"pub fn create_parameter_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/memorydb.create_parameter_group\naws_api/memorydb create_parameter_group","url":"aws_api/memorydb.html#create_parameter_group"},{"doc":"aws_api/memorydb","title":"create_snapshot","content":"pub fn create_snapshot(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/memorydb.create_snapshot\naws_api/memorydb create_snapshot","url":"aws_api/memorydb.html#create_snapshot"},{"doc":"aws_api/memorydb","title":"create_subnet_group","content":"pub fn create_subnet_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/memorydb.create_subnet_group\naws_api/memorydb create_subnet_group","url":"aws_api/memorydb.html#create_subnet_group"},{"doc":"aws_api/memorydb","title":"create_user","content":"pub fn create_user(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/memorydb.create_user\naws_api/memorydb create_user","url":"aws_api/memorydb.html#create_user"},{"doc":"aws_api/memorydb","title":"delete_acl","content":"pub fn delete_acl(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/memorydb.delete_acl\naws_api/memorydb delete_acl","url":"aws_api/memorydb.html#delete_acl"},{"doc":"aws_api/memorydb","title":"delete_cluster","content":"pub fn delete_cluster(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/memorydb.delete_cluster\naws_api/memorydb delete_cluster","url":"aws_api/memorydb.html#delete_cluster"},{"doc":"aws_api/memorydb","title":"delete_parameter_group","content":"pub fn delete_parameter_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/memorydb.delete_parameter_group\naws_api/memorydb delete_parameter_group","url":"aws_api/memorydb.html#delete_parameter_group"},{"doc":"aws_api/memorydb","title":"delete_snapshot","content":"pub fn delete_snapshot(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/memorydb.delete_snapshot\naws_api/memorydb delete_snapshot","url":"aws_api/memorydb.html#delete_snapshot"},{"doc":"aws_api/memorydb","title":"delete_subnet_group","content":"pub fn delete_subnet_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/memorydb.delete_subnet_group\naws_api/memorydb delete_subnet_group","url":"aws_api/memorydb.html#delete_subnet_group"},{"doc":"aws_api/memorydb","title":"delete_user","content":"pub fn delete_user(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/memorydb.delete_user\naws_api/memorydb delete_user","url":"aws_api/memorydb.html#delete_user"},{"doc":"aws_api/memorydb","title":"describe_ac_ls","content":"pub fn describe_ac_ls(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/memorydb.describe_ac_ls\naws_api/memorydb describe_ac_ls","url":"aws_api/memorydb.html#describe_ac_ls"},{"doc":"aws_api/memorydb","title":"describe_clusters","content":"pub fn describe_clusters(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/memorydb.describe_clusters\naws_api/memorydb describe_clusters","url":"aws_api/memorydb.html#describe_clusters"},{"doc":"aws_api/memorydb","title":"describe_engine_versions","content":"pub fn describe_engine_versions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/memorydb.describe_engine_versions\naws_api/memorydb describe_engine_versions","url":"aws_api/memorydb.html#describe_engine_versions"},{"doc":"aws_api/memorydb","title":"describe_events","content":"pub fn describe_events(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/memorydb.describe_events\naws_api/memorydb describe_events","url":"aws_api/memorydb.html#describe_events"},{"doc":"aws_api/memorydb","title":"describe_parameter_groups","content":"pub fn describe_parameter_groups(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/memorydb.describe_parameter_groups\naws_api/memorydb describe_parameter_groups","url":"aws_api/memorydb.html#describe_parameter_groups"},{"doc":"aws_api/memorydb","title":"describe_parameters","content":"pub fn describe_parameters(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/memorydb.describe_parameters\naws_api/memorydb describe_parameters","url":"aws_api/memorydb.html#describe_parameters"},{"doc":"aws_api/memorydb","title":"describe_reserved_nodes","content":"pub fn describe_reserved_nodes(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/memorydb.describe_reserved_nodes\naws_api/memorydb describe_reserved_nodes","url":"aws_api/memorydb.html#describe_reserved_nodes"},{"doc":"aws_api/memorydb","title":"describe_reserved_nodes_offerings","content":"pub fn describe_reserved_nodes_offerings(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/memorydb.describe_reserved_nodes_offerings\naws_api/memorydb describe_reserved_nodes_offerings","url":"aws_api/memorydb.html#describe_reserved_nodes_offerings"},{"doc":"aws_api/memorydb","title":"describe_service_updates","content":"pub fn describe_service_updates(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/memorydb.describe_service_updates\naws_api/memorydb describe_service_updates","url":"aws_api/memorydb.html#describe_service_updates"},{"doc":"aws_api/memorydb","title":"describe_snapshots","content":"pub fn describe_snapshots(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/memorydb.describe_snapshots\naws_api/memorydb describe_snapshots","url":"aws_api/memorydb.html#describe_snapshots"},{"doc":"aws_api/memorydb","title":"describe_subnet_groups","content":"pub fn describe_subnet_groups(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/memorydb.describe_subnet_groups\naws_api/memorydb describe_subnet_groups","url":"aws_api/memorydb.html#describe_subnet_groups"},{"doc":"aws_api/memorydb","title":"describe_users","content":"pub fn describe_users(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/memorydb.describe_users\naws_api/memorydb describe_users","url":"aws_api/memorydb.html#describe_users"},{"doc":"aws_api/memorydb","title":"failover_shard","content":"pub fn failover_shard(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/memorydb.failover_shard\naws_api/memorydb failover_shard","url":"aws_api/memorydb.html#failover_shard"},{"doc":"aws_api/memorydb","title":"list_allowed_node_type_updates","content":"pub fn list_allowed_node_type_updates(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/memorydb.list_allowed_node_type_updates\naws_api/memorydb list_allowed_node_type_updates","url":"aws_api/memorydb.html#list_allowed_node_type_updates"},{"doc":"aws_api/memorydb","title":"list_tags","content":"pub fn list_tags(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/memorydb.list_tags\naws_api/memorydb list_tags","url":"aws_api/memorydb.html#list_tags"},{"doc":"aws_api/memorydb","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/memorydb.new\naws_api/memorydb new","url":"aws_api/memorydb.html#new"},{"doc":"aws_api/memorydb","title":"purchase_reserved_nodes_offering","content":"pub fn purchase_reserved_nodes_offering(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/memorydb.purchase_reserved_nodes_offering\naws_api/memorydb purchase_reserved_nodes_offering","url":"aws_api/memorydb.html#purchase_reserved_nodes_offering"},{"doc":"aws_api/memorydb","title":"reset_parameter_group","content":"pub fn reset_parameter_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/memorydb.reset_parameter_group\naws_api/memorydb reset_parameter_group","url":"aws_api/memorydb.html#reset_parameter_group"},{"doc":"aws_api/memorydb","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/memorydb.tag_resource\naws_api/memorydb tag_resource","url":"aws_api/memorydb.html#tag_resource"},{"doc":"aws_api/memorydb","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/memorydb.untag_resource\naws_api/memorydb untag_resource","url":"aws_api/memorydb.html#untag_resource"},{"doc":"aws_api/memorydb","title":"update_acl","content":"pub fn update_acl(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/memorydb.update_acl\naws_api/memorydb update_acl","url":"aws_api/memorydb.html#update_acl"},{"doc":"aws_api/memorydb","title":"update_cluster","content":"pub fn update_cluster(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/memorydb.update_cluster\naws_api/memorydb update_cluster","url":"aws_api/memorydb.html#update_cluster"},{"doc":"aws_api/memorydb","title":"update_parameter_group","content":"pub fn update_parameter_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/memorydb.update_parameter_group\naws_api/memorydb update_parameter_group","url":"aws_api/memorydb.html#update_parameter_group"},{"doc":"aws_api/memorydb","title":"update_subnet_group","content":"pub fn update_subnet_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/memorydb.update_subnet_group\naws_api/memorydb update_subnet_group","url":"aws_api/memorydb.html#update_subnet_group"},{"doc":"aws_api/memorydb","title":"update_user","content":"pub fn update_user(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/memorydb.update_user\naws_api/memorydb update_user","url":"aws_api/memorydb.html#update_user"},{"doc":"aws_api/memorydb","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/memorydb.with_custom_endpoint\naws_api/memorydb with_custom_endpoint","url":"aws_api/memorydb.html#with_custom_endpoint"},{"doc":"aws_api/memorydb","title":"aws_api/memorydb","content":"","url":"aws_api/memorydb.html"},{"doc":"aws_api/mgn","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/mgn.Client\naws_api/mgn Client","url":"aws_api/mgn.html#Client"},{"doc":"aws_api/mgn","title":"initialize_service","content":"pub fn initialize_service(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mgn.initialize_service\naws_api/mgn initialize_service","url":"aws_api/mgn.html#initialize_service"},{"doc":"aws_api/mgn","title":"list_managed_accounts","content":"pub fn list_managed_accounts(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mgn.list_managed_accounts\naws_api/mgn list_managed_accounts","url":"aws_api/mgn.html#list_managed_accounts"},{"doc":"aws_api/mgn","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mgn.list_tags_for_resource\naws_api/mgn list_tags_for_resource","url":"aws_api/mgn.html#list_tags_for_resource"},{"doc":"aws_api/mgn","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/mgn.new\naws_api/mgn new","url":"aws_api/mgn.html#new"},{"doc":"aws_api/mgn","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mgn.tag_resource\naws_api/mgn tag_resource","url":"aws_api/mgn.html#tag_resource"},{"doc":"aws_api/mgn","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mgn.untag_resource\naws_api/mgn untag_resource","url":"aws_api/mgn.html#untag_resource"},{"doc":"aws_api/mgn","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/mgn.with_custom_endpoint\naws_api/mgn with_custom_endpoint","url":"aws_api/mgn.html#with_custom_endpoint"},{"doc":"aws_api/mgn","title":"aws_api/mgn","content":"","url":"aws_api/mgn.html"},{"doc":"aws_api/migration_hub","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/migration_hub.Client\naws_api/migration_hub Client","url":"aws_api/migration_hub.html#Client"},{"doc":"aws_api/migration_hub","title":"associate_created_artifact","content":"pub fn associate_created_artifact(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/migration_hub.associate_created_artifact\naws_api/migration_hub associate_created_artifact","url":"aws_api/migration_hub.html#associate_created_artifact"},{"doc":"aws_api/migration_hub","title":"associate_discovered_resource","content":"pub fn associate_discovered_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/migration_hub.associate_discovered_resource\naws_api/migration_hub associate_discovered_resource","url":"aws_api/migration_hub.html#associate_discovered_resource"},{"doc":"aws_api/migration_hub","title":"create_progress_update_stream","content":"pub fn create_progress_update_stream(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/migration_hub.create_progress_update_stream\naws_api/migration_hub create_progress_update_stream","url":"aws_api/migration_hub.html#create_progress_update_stream"},{"doc":"aws_api/migration_hub","title":"delete_progress_update_stream","content":"pub fn delete_progress_update_stream(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/migration_hub.delete_progress_update_stream\naws_api/migration_hub delete_progress_update_stream","url":"aws_api/migration_hub.html#delete_progress_update_stream"},{"doc":"aws_api/migration_hub","title":"describe_application_state","content":"pub fn describe_application_state(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/migration_hub.describe_application_state\naws_api/migration_hub describe_application_state","url":"aws_api/migration_hub.html#describe_application_state"},{"doc":"aws_api/migration_hub","title":"describe_migration_task","content":"pub fn describe_migration_task(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/migration_hub.describe_migration_task\naws_api/migration_hub describe_migration_task","url":"aws_api/migration_hub.html#describe_migration_task"},{"doc":"aws_api/migration_hub","title":"disassociate_created_artifact","content":"pub fn disassociate_created_artifact(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/migration_hub.disassociate_created_artifact\naws_api/migration_hub disassociate_created_artifact","url":"aws_api/migration_hub.html#disassociate_created_artifact"},{"doc":"aws_api/migration_hub","title":"disassociate_discovered_resource","content":"pub fn disassociate_discovered_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/migration_hub.disassociate_discovered_resource\naws_api/migration_hub disassociate_discovered_resource","url":"aws_api/migration_hub.html#disassociate_discovered_resource"},{"doc":"aws_api/migration_hub","title":"import_migration_task","content":"pub fn import_migration_task(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/migration_hub.import_migration_task\naws_api/migration_hub import_migration_task","url":"aws_api/migration_hub.html#import_migration_task"},{"doc":"aws_api/migration_hub","title":"list_application_states","content":"pub fn list_application_states(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/migration_hub.list_application_states\naws_api/migration_hub list_application_states","url":"aws_api/migration_hub.html#list_application_states"},{"doc":"aws_api/migration_hub","title":"list_created_artifacts","content":"pub fn list_created_artifacts(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/migration_hub.list_created_artifacts\naws_api/migration_hub list_created_artifacts","url":"aws_api/migration_hub.html#list_created_artifacts"},{"doc":"aws_api/migration_hub","title":"list_discovered_resources","content":"pub fn list_discovered_resources(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/migration_hub.list_discovered_resources\naws_api/migration_hub list_discovered_resources","url":"aws_api/migration_hub.html#list_discovered_resources"},{"doc":"aws_api/migration_hub","title":"list_migration_tasks","content":"pub fn list_migration_tasks(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/migration_hub.list_migration_tasks\naws_api/migration_hub list_migration_tasks","url":"aws_api/migration_hub.html#list_migration_tasks"},{"doc":"aws_api/migration_hub","title":"list_progress_update_streams","content":"pub fn list_progress_update_streams(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/migration_hub.list_progress_update_streams\naws_api/migration_hub list_progress_update_streams","url":"aws_api/migration_hub.html#list_progress_update_streams"},{"doc":"aws_api/migration_hub","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/migration_hub.new\naws_api/migration_hub new","url":"aws_api/migration_hub.html#new"},{"doc":"aws_api/migration_hub","title":"notify_application_state","content":"pub fn notify_application_state(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/migration_hub.notify_application_state\naws_api/migration_hub notify_application_state","url":"aws_api/migration_hub.html#notify_application_state"},{"doc":"aws_api/migration_hub","title":"notify_migration_task_state","content":"pub fn notify_migration_task_state(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/migration_hub.notify_migration_task_state\naws_api/migration_hub notify_migration_task_state","url":"aws_api/migration_hub.html#notify_migration_task_state"},{"doc":"aws_api/migration_hub","title":"put_resource_attributes","content":"pub fn put_resource_attributes(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/migration_hub.put_resource_attributes\naws_api/migration_hub put_resource_attributes","url":"aws_api/migration_hub.html#put_resource_attributes"},{"doc":"aws_api/migration_hub","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/migration_hub.with_custom_endpoint\naws_api/migration_hub with_custom_endpoint","url":"aws_api/migration_hub.html#with_custom_endpoint"},{"doc":"aws_api/migration_hub","title":"aws_api/migration_hub","content":"","url":"aws_api/migration_hub.html"},{"doc":"aws_api/migrationhuborchestrator","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/migrationhuborchestrator.Client\naws_api/migrationhuborchestrator Client","url":"aws_api/migrationhuborchestrator.html#Client"},{"doc":"aws_api/migrationhuborchestrator","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/migrationhuborchestrator.list_tags_for_resource\naws_api/migrationhuborchestrator list_tags_for_resource","url":"aws_api/migrationhuborchestrator.html#list_tags_for_resource"},{"doc":"aws_api/migrationhuborchestrator","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/migrationhuborchestrator.new\naws_api/migrationhuborchestrator new","url":"aws_api/migrationhuborchestrator.html#new"},{"doc":"aws_api/migrationhuborchestrator","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/migrationhuborchestrator.tag_resource\naws_api/migrationhuborchestrator tag_resource","url":"aws_api/migrationhuborchestrator.html#tag_resource"},{"doc":"aws_api/migrationhuborchestrator","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/migrationhuborchestrator.untag_resource\naws_api/migrationhuborchestrator untag_resource","url":"aws_api/migrationhuborchestrator.html#untag_resource"},{"doc":"aws_api/migrationhuborchestrator","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/migrationhuborchestrator.with_custom_endpoint\naws_api/migrationhuborchestrator with_custom_endpoint","url":"aws_api/migrationhuborchestrator.html#with_custom_endpoint"},{"doc":"aws_api/migrationhuborchestrator","title":"aws_api/migrationhuborchestrator","content":"","url":"aws_api/migrationhuborchestrator.html"},{"doc":"aws_api/migrationhubstrategy","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/migrationhubstrategy.Client\naws_api/migrationhubstrategy Client","url":"aws_api/migrationhubstrategy.html#Client"},{"doc":"aws_api/migrationhubstrategy","title":"get_application_component_details","content":"pub fn get_application_component_details(\n  client: Client,\n  application_component_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/migrationhubstrategy.get_application_component_details\naws_api/migrationhubstrategy get_application_component_details","url":"aws_api/migrationhubstrategy.html#get_application_component_details"},{"doc":"aws_api/migrationhubstrategy","title":"get_application_component_strategies","content":"pub fn get_application_component_strategies(\n  client: Client,\n  application_component_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/migrationhubstrategy.get_application_component_strategies\naws_api/migrationhubstrategy get_application_component_strategies","url":"aws_api/migrationhubstrategy.html#get_application_component_strategies"},{"doc":"aws_api/migrationhubstrategy","title":"get_assessment","content":"pub fn get_assessment(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/migrationhubstrategy.get_assessment\naws_api/migrationhubstrategy get_assessment","url":"aws_api/migrationhubstrategy.html#get_assessment"},{"doc":"aws_api/migrationhubstrategy","title":"get_import_file_task","content":"pub fn get_import_file_task(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/migrationhubstrategy.get_import_file_task\naws_api/migrationhubstrategy get_import_file_task","url":"aws_api/migrationhubstrategy.html#get_import_file_task"},{"doc":"aws_api/migrationhubstrategy","title":"get_latest_assessment_id","content":"pub fn get_latest_assessment_id(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/migrationhubstrategy.get_latest_assessment_id\naws_api/migrationhubstrategy get_latest_assessment_id","url":"aws_api/migrationhubstrategy.html#get_latest_assessment_id"},{"doc":"aws_api/migrationhubstrategy","title":"get_portfolio_preferences","content":"pub fn get_portfolio_preferences(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/migrationhubstrategy.get_portfolio_preferences\naws_api/migrationhubstrategy get_portfolio_preferences","url":"aws_api/migrationhubstrategy.html#get_portfolio_preferences"},{"doc":"aws_api/migrationhubstrategy","title":"get_portfolio_summary","content":"pub fn get_portfolio_summary(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/migrationhubstrategy.get_portfolio_summary\naws_api/migrationhubstrategy get_portfolio_summary","url":"aws_api/migrationhubstrategy.html#get_portfolio_summary"},{"doc":"aws_api/migrationhubstrategy","title":"get_recommendation_report_details","content":"pub fn get_recommendation_report_details(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/migrationhubstrategy.get_recommendation_report_details\naws_api/migrationhubstrategy get_recommendation_report_details","url":"aws_api/migrationhubstrategy.html#get_recommendation_report_details"},{"doc":"aws_api/migrationhubstrategy","title":"get_server_details","content":"pub fn get_server_details(\n  client: Client,\n  server_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/migrationhubstrategy.get_server_details\naws_api/migrationhubstrategy get_server_details","url":"aws_api/migrationhubstrategy.html#get_server_details"},{"doc":"aws_api/migrationhubstrategy","title":"get_server_strategies","content":"pub fn get_server_strategies(\n  client: Client,\n  server_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/migrationhubstrategy.get_server_strategies\naws_api/migrationhubstrategy get_server_strategies","url":"aws_api/migrationhubstrategy.html#get_server_strategies"},{"doc":"aws_api/migrationhubstrategy","title":"list_analyzable_servers","content":"pub fn list_analyzable_servers(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/migrationhubstrategy.list_analyzable_servers\naws_api/migrationhubstrategy list_analyzable_servers","url":"aws_api/migrationhubstrategy.html#list_analyzable_servers"},{"doc":"aws_api/migrationhubstrategy","title":"list_application_components","content":"pub fn list_application_components(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/migrationhubstrategy.list_application_components\naws_api/migrationhubstrategy list_application_components","url":"aws_api/migrationhubstrategy.html#list_application_components"},{"doc":"aws_api/migrationhubstrategy","title":"list_collectors","content":"pub fn list_collectors(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/migrationhubstrategy.list_collectors\naws_api/migrationhubstrategy list_collectors","url":"aws_api/migrationhubstrategy.html#list_collectors"},{"doc":"aws_api/migrationhubstrategy","title":"list_import_file_task","content":"pub fn list_import_file_task(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/migrationhubstrategy.list_import_file_task\naws_api/migrationhubstrategy list_import_file_task","url":"aws_api/migrationhubstrategy.html#list_import_file_task"},{"doc":"aws_api/migrationhubstrategy","title":"list_servers","content":"pub fn list_servers(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/migrationhubstrategy.list_servers\naws_api/migrationhubstrategy list_servers","url":"aws_api/migrationhubstrategy.html#list_servers"},{"doc":"aws_api/migrationhubstrategy","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/migrationhubstrategy.new\naws_api/migrationhubstrategy new","url":"aws_api/migrationhubstrategy.html#new"},{"doc":"aws_api/migrationhubstrategy","title":"put_portfolio_preferences","content":"pub fn put_portfolio_preferences(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/migrationhubstrategy.put_portfolio_preferences\naws_api/migrationhubstrategy put_portfolio_preferences","url":"aws_api/migrationhubstrategy.html#put_portfolio_preferences"},{"doc":"aws_api/migrationhubstrategy","title":"start_assessment","content":"pub fn start_assessment(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/migrationhubstrategy.start_assessment\naws_api/migrationhubstrategy start_assessment","url":"aws_api/migrationhubstrategy.html#start_assessment"},{"doc":"aws_api/migrationhubstrategy","title":"start_import_file_task","content":"pub fn start_import_file_task(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/migrationhubstrategy.start_import_file_task\naws_api/migrationhubstrategy start_import_file_task","url":"aws_api/migrationhubstrategy.html#start_import_file_task"},{"doc":"aws_api/migrationhubstrategy","title":"start_recommendation_report_generation","content":"pub fn start_recommendation_report_generation(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/migrationhubstrategy.start_recommendation_report_generation\naws_api/migrationhubstrategy start_recommendation_report_generation","url":"aws_api/migrationhubstrategy.html#start_recommendation_report_generation"},{"doc":"aws_api/migrationhubstrategy","title":"stop_assessment","content":"pub fn stop_assessment(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/migrationhubstrategy.stop_assessment\naws_api/migrationhubstrategy stop_assessment","url":"aws_api/migrationhubstrategy.html#stop_assessment"},{"doc":"aws_api/migrationhubstrategy","title":"update_application_component_config","content":"pub fn update_application_component_config(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/migrationhubstrategy.update_application_component_config\naws_api/migrationhubstrategy update_application_component_config","url":"aws_api/migrationhubstrategy.html#update_application_component_config"},{"doc":"aws_api/migrationhubstrategy","title":"update_server_config","content":"pub fn update_server_config(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/migrationhubstrategy.update_server_config\naws_api/migrationhubstrategy update_server_config","url":"aws_api/migrationhubstrategy.html#update_server_config"},{"doc":"aws_api/migrationhubstrategy","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/migrationhubstrategy.with_custom_endpoint\naws_api/migrationhubstrategy with_custom_endpoint","url":"aws_api/migrationhubstrategy.html#with_custom_endpoint"},{"doc":"aws_api/migrationhubstrategy","title":"aws_api/migrationhubstrategy","content":"","url":"aws_api/migrationhubstrategy.html"},{"doc":"aws_api/mq","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/mq.Client\naws_api/mq Client","url":"aws_api/mq.html#Client"},{"doc":"aws_api/mq","title":"create_broker","content":"pub fn create_broker(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mq.create_broker\naws_api/mq create_broker","url":"aws_api/mq.html#create_broker"},{"doc":"aws_api/mq","title":"create_configuration","content":"pub fn create_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mq.create_configuration\naws_api/mq create_configuration","url":"aws_api/mq.html#create_configuration"},{"doc":"aws_api/mq","title":"create_tags","content":"pub fn create_tags(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mq.create_tags\naws_api/mq create_tags","url":"aws_api/mq.html#create_tags"},{"doc":"aws_api/mq","title":"create_user","content":"pub fn create_user(\n  client: Client,\n  broker_id: String,\n  username: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mq.create_user\naws_api/mq create_user","url":"aws_api/mq.html#create_user"},{"doc":"aws_api/mq","title":"delete_broker","content":"pub fn delete_broker(\n  client: Client,\n  broker_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mq.delete_broker\naws_api/mq delete_broker","url":"aws_api/mq.html#delete_broker"},{"doc":"aws_api/mq","title":"delete_tags","content":"pub fn delete_tags(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mq.delete_tags\naws_api/mq delete_tags","url":"aws_api/mq.html#delete_tags"},{"doc":"aws_api/mq","title":"delete_user","content":"pub fn delete_user(\n  client: Client,\n  broker_id: String,\n  username: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mq.delete_user\naws_api/mq delete_user","url":"aws_api/mq.html#delete_user"},{"doc":"aws_api/mq","title":"describe_broker","content":"pub fn describe_broker(\n  client: Client,\n  broker_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mq.describe_broker\naws_api/mq describe_broker","url":"aws_api/mq.html#describe_broker"},{"doc":"aws_api/mq","title":"describe_broker_engine_types","content":"pub fn describe_broker_engine_types(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mq.describe_broker_engine_types\naws_api/mq describe_broker_engine_types","url":"aws_api/mq.html#describe_broker_engine_types"},{"doc":"aws_api/mq","title":"describe_broker_instance_options","content":"pub fn describe_broker_instance_options(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mq.describe_broker_instance_options\naws_api/mq describe_broker_instance_options","url":"aws_api/mq.html#describe_broker_instance_options"},{"doc":"aws_api/mq","title":"describe_configuration","content":"pub fn describe_configuration(\n  client: Client,\n  configuration_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mq.describe_configuration\naws_api/mq describe_configuration","url":"aws_api/mq.html#describe_configuration"},{"doc":"aws_api/mq","title":"describe_configuration_revision","content":"pub fn describe_configuration_revision(\n  client: Client,\n  configuration_id: String,\n  configuration_revision: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mq.describe_configuration_revision\naws_api/mq describe_configuration_revision","url":"aws_api/mq.html#describe_configuration_revision"},{"doc":"aws_api/mq","title":"describe_user","content":"pub fn describe_user(\n  client: Client,\n  broker_id: String,\n  username: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mq.describe_user\naws_api/mq describe_user","url":"aws_api/mq.html#describe_user"},{"doc":"aws_api/mq","title":"list_brokers","content":"pub fn list_brokers(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mq.list_brokers\naws_api/mq list_brokers","url":"aws_api/mq.html#list_brokers"},{"doc":"aws_api/mq","title":"list_configuration_revisions","content":"pub fn list_configuration_revisions(\n  client: Client,\n  configuration_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mq.list_configuration_revisions\naws_api/mq list_configuration_revisions","url":"aws_api/mq.html#list_configuration_revisions"},{"doc":"aws_api/mq","title":"list_configurations","content":"pub fn list_configurations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mq.list_configurations\naws_api/mq list_configurations","url":"aws_api/mq.html#list_configurations"},{"doc":"aws_api/mq","title":"list_tags","content":"pub fn list_tags(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mq.list_tags\naws_api/mq list_tags","url":"aws_api/mq.html#list_tags"},{"doc":"aws_api/mq","title":"list_users","content":"pub fn list_users(\n  client: Client,\n  broker_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mq.list_users\naws_api/mq list_users","url":"aws_api/mq.html#list_users"},{"doc":"aws_api/mq","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/mq.new\naws_api/mq new","url":"aws_api/mq.html#new"},{"doc":"aws_api/mq","title":"promote","content":"pub fn promote(\n  client: Client,\n  broker_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mq.promote\naws_api/mq promote","url":"aws_api/mq.html#promote"},{"doc":"aws_api/mq","title":"reboot_broker","content":"pub fn reboot_broker(\n  client: Client,\n  broker_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mq.reboot_broker\naws_api/mq reboot_broker","url":"aws_api/mq.html#reboot_broker"},{"doc":"aws_api/mq","title":"update_broker","content":"pub fn update_broker(\n  client: Client,\n  broker_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mq.update_broker\naws_api/mq update_broker","url":"aws_api/mq.html#update_broker"},{"doc":"aws_api/mq","title":"update_configuration","content":"pub fn update_configuration(\n  client: Client,\n  configuration_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mq.update_configuration\naws_api/mq update_configuration","url":"aws_api/mq.html#update_configuration"},{"doc":"aws_api/mq","title":"update_user","content":"pub fn update_user(\n  client: Client,\n  broker_id: String,\n  username: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mq.update_user\naws_api/mq update_user","url":"aws_api/mq.html#update_user"},{"doc":"aws_api/mq","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/mq.with_custom_endpoint\naws_api/mq with_custom_endpoint","url":"aws_api/mq.html#with_custom_endpoint"},{"doc":"aws_api/mq","title":"aws_api/mq","content":"","url":"aws_api/mq.html"},{"doc":"aws_api/mwaa","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/mwaa.Client\naws_api/mwaa Client","url":"aws_api/mwaa.html#Client"},{"doc":"aws_api/mwaa","title":"create_cli_token","content":"pub fn create_cli_token(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mwaa.create_cli_token\naws_api/mwaa create_cli_token","url":"aws_api/mwaa.html#create_cli_token"},{"doc":"aws_api/mwaa","title":"create_environment","content":"pub fn create_environment(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mwaa.create_environment\naws_api/mwaa create_environment","url":"aws_api/mwaa.html#create_environment"},{"doc":"aws_api/mwaa","title":"create_web_login_token","content":"pub fn create_web_login_token(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mwaa.create_web_login_token\naws_api/mwaa create_web_login_token","url":"aws_api/mwaa.html#create_web_login_token"},{"doc":"aws_api/mwaa","title":"delete_environment","content":"pub fn delete_environment(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mwaa.delete_environment\naws_api/mwaa delete_environment","url":"aws_api/mwaa.html#delete_environment"},{"doc":"aws_api/mwaa","title":"get_environment","content":"pub fn get_environment(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mwaa.get_environment\naws_api/mwaa get_environment","url":"aws_api/mwaa.html#get_environment"},{"doc":"aws_api/mwaa","title":"list_environments","content":"pub fn list_environments(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mwaa.list_environments\naws_api/mwaa list_environments","url":"aws_api/mwaa.html#list_environments"},{"doc":"aws_api/mwaa","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mwaa.list_tags_for_resource\naws_api/mwaa list_tags_for_resource","url":"aws_api/mwaa.html#list_tags_for_resource"},{"doc":"aws_api/mwaa","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/mwaa.new\naws_api/mwaa new","url":"aws_api/mwaa.html#new"},{"doc":"aws_api/mwaa","title":"publish_metrics","content":"pub fn publish_metrics(\n  client: Client,\n  environment_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mwaa.publish_metrics\naws_api/mwaa publish_metrics","url":"aws_api/mwaa.html#publish_metrics"},{"doc":"aws_api/mwaa","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mwaa.tag_resource\naws_api/mwaa tag_resource","url":"aws_api/mwaa.html#tag_resource"},{"doc":"aws_api/mwaa","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mwaa.untag_resource\naws_api/mwaa untag_resource","url":"aws_api/mwaa.html#untag_resource"},{"doc":"aws_api/mwaa","title":"update_environment","content":"pub fn update_environment(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/mwaa.update_environment\naws_api/mwaa update_environment","url":"aws_api/mwaa.html#update_environment"},{"doc":"aws_api/mwaa","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/mwaa.with_custom_endpoint\naws_api/mwaa with_custom_endpoint","url":"aws_api/mwaa.html#with_custom_endpoint"},{"doc":"aws_api/mwaa","title":"aws_api/mwaa","content":"","url":"aws_api/mwaa.html"},{"doc":"aws_api/neptune","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/neptune.Client\naws_api/neptune Client","url":"aws_api/neptune.html#Client"},{"doc":"aws_api/neptune","title":"add_role_to_db_cluster","content":"pub fn add_role_to_db_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.add_role_to_db_cluster\naws_api/neptune add_role_to_db_cluster","url":"aws_api/neptune.html#add_role_to_db_cluster"},{"doc":"aws_api/neptune","title":"add_source_identifier_to_subscription","content":"pub fn add_source_identifier_to_subscription(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.add_source_identifier_to_subscription\naws_api/neptune add_source_identifier_to_subscription","url":"aws_api/neptune.html#add_source_identifier_to_subscription"},{"doc":"aws_api/neptune","title":"add_tags_to_resource","content":"pub fn add_tags_to_resource(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.add_tags_to_resource\naws_api/neptune add_tags_to_resource","url":"aws_api/neptune.html#add_tags_to_resource"},{"doc":"aws_api/neptune","title":"apply_pending_maintenance_action","content":"pub fn apply_pending_maintenance_action(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.apply_pending_maintenance_action\naws_api/neptune apply_pending_maintenance_action","url":"aws_api/neptune.html#apply_pending_maintenance_action"},{"doc":"aws_api/neptune","title":"copy_db_cluster_parameter_group","content":"pub fn copy_db_cluster_parameter_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.copy_db_cluster_parameter_group\naws_api/neptune copy_db_cluster_parameter_group","url":"aws_api/neptune.html#copy_db_cluster_parameter_group"},{"doc":"aws_api/neptune","title":"copy_db_cluster_snapshot","content":"pub fn copy_db_cluster_snapshot(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.copy_db_cluster_snapshot\naws_api/neptune copy_db_cluster_snapshot","url":"aws_api/neptune.html#copy_db_cluster_snapshot"},{"doc":"aws_api/neptune","title":"copy_db_parameter_group","content":"pub fn copy_db_parameter_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.copy_db_parameter_group\naws_api/neptune copy_db_parameter_group","url":"aws_api/neptune.html#copy_db_parameter_group"},{"doc":"aws_api/neptune","title":"create_db_cluster","content":"pub fn create_db_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.create_db_cluster\naws_api/neptune create_db_cluster","url":"aws_api/neptune.html#create_db_cluster"},{"doc":"aws_api/neptune","title":"create_db_cluster_endpoint","content":"pub fn create_db_cluster_endpoint(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.create_db_cluster_endpoint\naws_api/neptune create_db_cluster_endpoint","url":"aws_api/neptune.html#create_db_cluster_endpoint"},{"doc":"aws_api/neptune","title":"create_db_cluster_parameter_group","content":"pub fn create_db_cluster_parameter_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.create_db_cluster_parameter_group\naws_api/neptune create_db_cluster_parameter_group","url":"aws_api/neptune.html#create_db_cluster_parameter_group"},{"doc":"aws_api/neptune","title":"create_db_cluster_snapshot","content":"pub fn create_db_cluster_snapshot(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.create_db_cluster_snapshot\naws_api/neptune create_db_cluster_snapshot","url":"aws_api/neptune.html#create_db_cluster_snapshot"},{"doc":"aws_api/neptune","title":"create_db_instance","content":"pub fn create_db_instance(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.create_db_instance\naws_api/neptune create_db_instance","url":"aws_api/neptune.html#create_db_instance"},{"doc":"aws_api/neptune","title":"create_db_parameter_group","content":"pub fn create_db_parameter_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.create_db_parameter_group\naws_api/neptune create_db_parameter_group","url":"aws_api/neptune.html#create_db_parameter_group"},{"doc":"aws_api/neptune","title":"create_db_subnet_group","content":"pub fn create_db_subnet_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.create_db_subnet_group\naws_api/neptune create_db_subnet_group","url":"aws_api/neptune.html#create_db_subnet_group"},{"doc":"aws_api/neptune","title":"create_event_subscription","content":"pub fn create_event_subscription(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.create_event_subscription\naws_api/neptune create_event_subscription","url":"aws_api/neptune.html#create_event_subscription"},{"doc":"aws_api/neptune","title":"create_global_cluster","content":"pub fn create_global_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.create_global_cluster\naws_api/neptune create_global_cluster","url":"aws_api/neptune.html#create_global_cluster"},{"doc":"aws_api/neptune","title":"delete_db_cluster","content":"pub fn delete_db_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.delete_db_cluster\naws_api/neptune delete_db_cluster","url":"aws_api/neptune.html#delete_db_cluster"},{"doc":"aws_api/neptune","title":"delete_db_cluster_endpoint","content":"pub fn delete_db_cluster_endpoint(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.delete_db_cluster_endpoint\naws_api/neptune delete_db_cluster_endpoint","url":"aws_api/neptune.html#delete_db_cluster_endpoint"},{"doc":"aws_api/neptune","title":"delete_db_cluster_parameter_group","content":"pub fn delete_db_cluster_parameter_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.delete_db_cluster_parameter_group\naws_api/neptune delete_db_cluster_parameter_group","url":"aws_api/neptune.html#delete_db_cluster_parameter_group"},{"doc":"aws_api/neptune","title":"delete_db_cluster_snapshot","content":"pub fn delete_db_cluster_snapshot(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.delete_db_cluster_snapshot\naws_api/neptune delete_db_cluster_snapshot","url":"aws_api/neptune.html#delete_db_cluster_snapshot"},{"doc":"aws_api/neptune","title":"delete_db_instance","content":"pub fn delete_db_instance(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.delete_db_instance\naws_api/neptune delete_db_instance","url":"aws_api/neptune.html#delete_db_instance"},{"doc":"aws_api/neptune","title":"delete_db_parameter_group","content":"pub fn delete_db_parameter_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.delete_db_parameter_group\naws_api/neptune delete_db_parameter_group","url":"aws_api/neptune.html#delete_db_parameter_group"},{"doc":"aws_api/neptune","title":"delete_db_subnet_group","content":"pub fn delete_db_subnet_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.delete_db_subnet_group\naws_api/neptune delete_db_subnet_group","url":"aws_api/neptune.html#delete_db_subnet_group"},{"doc":"aws_api/neptune","title":"delete_event_subscription","content":"pub fn delete_event_subscription(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.delete_event_subscription\naws_api/neptune delete_event_subscription","url":"aws_api/neptune.html#delete_event_subscription"},{"doc":"aws_api/neptune","title":"delete_global_cluster","content":"pub fn delete_global_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.delete_global_cluster\naws_api/neptune delete_global_cluster","url":"aws_api/neptune.html#delete_global_cluster"},{"doc":"aws_api/neptune","title":"describe_db_cluster_endpoints","content":"pub fn describe_db_cluster_endpoints(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.describe_db_cluster_endpoints\naws_api/neptune describe_db_cluster_endpoints","url":"aws_api/neptune.html#describe_db_cluster_endpoints"},{"doc":"aws_api/neptune","title":"describe_db_cluster_parameter_groups","content":"pub fn describe_db_cluster_parameter_groups(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.describe_db_cluster_parameter_groups\naws_api/neptune describe_db_cluster_parameter_groups","url":"aws_api/neptune.html#describe_db_cluster_parameter_groups"},{"doc":"aws_api/neptune","title":"describe_db_cluster_parameters","content":"pub fn describe_db_cluster_parameters(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.describe_db_cluster_parameters\naws_api/neptune describe_db_cluster_parameters","url":"aws_api/neptune.html#describe_db_cluster_parameters"},{"doc":"aws_api/neptune","title":"describe_db_cluster_snapshot_attributes","content":"pub fn describe_db_cluster_snapshot_attributes(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.describe_db_cluster_snapshot_attributes\naws_api/neptune describe_db_cluster_snapshot_attributes","url":"aws_api/neptune.html#describe_db_cluster_snapshot_attributes"},{"doc":"aws_api/neptune","title":"describe_db_cluster_snapshots","content":"pub fn describe_db_cluster_snapshots(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.describe_db_cluster_snapshots\naws_api/neptune describe_db_cluster_snapshots","url":"aws_api/neptune.html#describe_db_cluster_snapshots"},{"doc":"aws_api/neptune","title":"describe_db_clusters","content":"pub fn describe_db_clusters(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.describe_db_clusters\naws_api/neptune describe_db_clusters","url":"aws_api/neptune.html#describe_db_clusters"},{"doc":"aws_api/neptune","title":"describe_db_engine_versions","content":"pub fn describe_db_engine_versions(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.describe_db_engine_versions\naws_api/neptune describe_db_engine_versions","url":"aws_api/neptune.html#describe_db_engine_versions"},{"doc":"aws_api/neptune","title":"describe_db_instances","content":"pub fn describe_db_instances(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.describe_db_instances\naws_api/neptune describe_db_instances","url":"aws_api/neptune.html#describe_db_instances"},{"doc":"aws_api/neptune","title":"describe_db_parameter_groups","content":"pub fn describe_db_parameter_groups(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.describe_db_parameter_groups\naws_api/neptune describe_db_parameter_groups","url":"aws_api/neptune.html#describe_db_parameter_groups"},{"doc":"aws_api/neptune","title":"describe_db_parameters","content":"pub fn describe_db_parameters(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.describe_db_parameters\naws_api/neptune describe_db_parameters","url":"aws_api/neptune.html#describe_db_parameters"},{"doc":"aws_api/neptune","title":"describe_db_subnet_groups","content":"pub fn describe_db_subnet_groups(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.describe_db_subnet_groups\naws_api/neptune describe_db_subnet_groups","url":"aws_api/neptune.html#describe_db_subnet_groups"},{"doc":"aws_api/neptune","title":"describe_engine_default_cluster_parameters","content":"pub fn describe_engine_default_cluster_parameters(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.describe_engine_default_cluster_parameters\naws_api/neptune describe_engine_default_cluster_parameters","url":"aws_api/neptune.html#describe_engine_default_cluster_parameters"},{"doc":"aws_api/neptune","title":"describe_engine_default_parameters","content":"pub fn describe_engine_default_parameters(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.describe_engine_default_parameters\naws_api/neptune describe_engine_default_parameters","url":"aws_api/neptune.html#describe_engine_default_parameters"},{"doc":"aws_api/neptune","title":"describe_event_categories","content":"pub fn describe_event_categories(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.describe_event_categories\naws_api/neptune describe_event_categories","url":"aws_api/neptune.html#describe_event_categories"},{"doc":"aws_api/neptune","title":"describe_event_subscriptions","content":"pub fn describe_event_subscriptions(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.describe_event_subscriptions\naws_api/neptune describe_event_subscriptions","url":"aws_api/neptune.html#describe_event_subscriptions"},{"doc":"aws_api/neptune","title":"describe_events","content":"pub fn describe_events(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.describe_events\naws_api/neptune describe_events","url":"aws_api/neptune.html#describe_events"},{"doc":"aws_api/neptune","title":"describe_global_clusters","content":"pub fn describe_global_clusters(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.describe_global_clusters\naws_api/neptune describe_global_clusters","url":"aws_api/neptune.html#describe_global_clusters"},{"doc":"aws_api/neptune","title":"describe_orderable_db_instance_options","content":"pub fn describe_orderable_db_instance_options(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.describe_orderable_db_instance_options\naws_api/neptune describe_orderable_db_instance_options","url":"aws_api/neptune.html#describe_orderable_db_instance_options"},{"doc":"aws_api/neptune","title":"describe_pending_maintenance_actions","content":"pub fn describe_pending_maintenance_actions(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.describe_pending_maintenance_actions\naws_api/neptune describe_pending_maintenance_actions","url":"aws_api/neptune.html#describe_pending_maintenance_actions"},{"doc":"aws_api/neptune","title":"describe_valid_db_instance_modifications","content":"pub fn describe_valid_db_instance_modifications(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.describe_valid_db_instance_modifications\naws_api/neptune describe_valid_db_instance_modifications","url":"aws_api/neptune.html#describe_valid_db_instance_modifications"},{"doc":"aws_api/neptune","title":"failover_db_cluster","content":"pub fn failover_db_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.failover_db_cluster\naws_api/neptune failover_db_cluster","url":"aws_api/neptune.html#failover_db_cluster"},{"doc":"aws_api/neptune","title":"failover_global_cluster","content":"pub fn failover_global_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.failover_global_cluster\naws_api/neptune failover_global_cluster","url":"aws_api/neptune.html#failover_global_cluster"},{"doc":"aws_api/neptune","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.list_tags_for_resource\naws_api/neptune list_tags_for_resource","url":"aws_api/neptune.html#list_tags_for_resource"},{"doc":"aws_api/neptune","title":"modify_db_cluster","content":"pub fn modify_db_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.modify_db_cluster\naws_api/neptune modify_db_cluster","url":"aws_api/neptune.html#modify_db_cluster"},{"doc":"aws_api/neptune","title":"modify_db_cluster_endpoint","content":"pub fn modify_db_cluster_endpoint(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.modify_db_cluster_endpoint\naws_api/neptune modify_db_cluster_endpoint","url":"aws_api/neptune.html#modify_db_cluster_endpoint"},{"doc":"aws_api/neptune","title":"modify_db_cluster_parameter_group","content":"pub fn modify_db_cluster_parameter_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.modify_db_cluster_parameter_group\naws_api/neptune modify_db_cluster_parameter_group","url":"aws_api/neptune.html#modify_db_cluster_parameter_group"},{"doc":"aws_api/neptune","title":"modify_db_cluster_snapshot_attribute","content":"pub fn modify_db_cluster_snapshot_attribute(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.modify_db_cluster_snapshot_attribute\naws_api/neptune modify_db_cluster_snapshot_attribute","url":"aws_api/neptune.html#modify_db_cluster_snapshot_attribute"},{"doc":"aws_api/neptune","title":"modify_db_instance","content":"pub fn modify_db_instance(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.modify_db_instance\naws_api/neptune modify_db_instance","url":"aws_api/neptune.html#modify_db_instance"},{"doc":"aws_api/neptune","title":"modify_db_parameter_group","content":"pub fn modify_db_parameter_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.modify_db_parameter_group\naws_api/neptune modify_db_parameter_group","url":"aws_api/neptune.html#modify_db_parameter_group"},{"doc":"aws_api/neptune","title":"modify_db_subnet_group","content":"pub fn modify_db_subnet_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.modify_db_subnet_group\naws_api/neptune modify_db_subnet_group","url":"aws_api/neptune.html#modify_db_subnet_group"},{"doc":"aws_api/neptune","title":"modify_event_subscription","content":"pub fn modify_event_subscription(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.modify_event_subscription\naws_api/neptune modify_event_subscription","url":"aws_api/neptune.html#modify_event_subscription"},{"doc":"aws_api/neptune","title":"modify_global_cluster","content":"pub fn modify_global_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.modify_global_cluster\naws_api/neptune modify_global_cluster","url":"aws_api/neptune.html#modify_global_cluster"},{"doc":"aws_api/neptune","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/neptune.new\naws_api/neptune new","url":"aws_api/neptune.html#new"},{"doc":"aws_api/neptune","title":"promote_read_replica_db_cluster","content":"pub fn promote_read_replica_db_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.promote_read_replica_db_cluster\naws_api/neptune promote_read_replica_db_cluster","url":"aws_api/neptune.html#promote_read_replica_db_cluster"},{"doc":"aws_api/neptune","title":"reboot_db_instance","content":"pub fn reboot_db_instance(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.reboot_db_instance\naws_api/neptune reboot_db_instance","url":"aws_api/neptune.html#reboot_db_instance"},{"doc":"aws_api/neptune","title":"remove_from_global_cluster","content":"pub fn remove_from_global_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.remove_from_global_cluster\naws_api/neptune remove_from_global_cluster","url":"aws_api/neptune.html#remove_from_global_cluster"},{"doc":"aws_api/neptune","title":"remove_role_from_db_cluster","content":"pub fn remove_role_from_db_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.remove_role_from_db_cluster\naws_api/neptune remove_role_from_db_cluster","url":"aws_api/neptune.html#remove_role_from_db_cluster"},{"doc":"aws_api/neptune","title":"remove_source_identifier_from_subscription","content":"pub fn remove_source_identifier_from_subscription(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.remove_source_identifier_from_subscription\naws_api/neptune remove_source_identifier_from_subscription","url":"aws_api/neptune.html#remove_source_identifier_from_subscription"},{"doc":"aws_api/neptune","title":"remove_tags_from_resource","content":"pub fn remove_tags_from_resource(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.remove_tags_from_resource\naws_api/neptune remove_tags_from_resource","url":"aws_api/neptune.html#remove_tags_from_resource"},{"doc":"aws_api/neptune","title":"reset_db_cluster_parameter_group","content":"pub fn reset_db_cluster_parameter_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.reset_db_cluster_parameter_group\naws_api/neptune reset_db_cluster_parameter_group","url":"aws_api/neptune.html#reset_db_cluster_parameter_group"},{"doc":"aws_api/neptune","title":"reset_db_parameter_group","content":"pub fn reset_db_parameter_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.reset_db_parameter_group\naws_api/neptune reset_db_parameter_group","url":"aws_api/neptune.html#reset_db_parameter_group"},{"doc":"aws_api/neptune","title":"restore_db_cluster_from_snapshot","content":"pub fn restore_db_cluster_from_snapshot(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.restore_db_cluster_from_snapshot\naws_api/neptune restore_db_cluster_from_snapshot","url":"aws_api/neptune.html#restore_db_cluster_from_snapshot"},{"doc":"aws_api/neptune","title":"restore_db_cluster_to_point_in_time","content":"pub fn restore_db_cluster_to_point_in_time(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.restore_db_cluster_to_point_in_time\naws_api/neptune restore_db_cluster_to_point_in_time","url":"aws_api/neptune.html#restore_db_cluster_to_point_in_time"},{"doc":"aws_api/neptune","title":"start_db_cluster","content":"pub fn start_db_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.start_db_cluster\naws_api/neptune start_db_cluster","url":"aws_api/neptune.html#start_db_cluster"},{"doc":"aws_api/neptune","title":"stop_db_cluster","content":"pub fn stop_db_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/neptune.stop_db_cluster\naws_api/neptune stop_db_cluster","url":"aws_api/neptune.html#stop_db_cluster"},{"doc":"aws_api/neptune","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/neptune.with_custom_endpoint\naws_api/neptune with_custom_endpoint","url":"aws_api/neptune.html#with_custom_endpoint"},{"doc":"aws_api/neptune","title":"aws_api/neptune","content":"","url":"aws_api/neptune.html"},{"doc":"aws_api/network_firewall","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/network_firewall.Client\naws_api/network_firewall Client","url":"aws_api/network_firewall.html#Client"},{"doc":"aws_api/network_firewall","title":"associate_firewall_policy","content":"pub fn associate_firewall_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/network_firewall.associate_firewall_policy\naws_api/network_firewall associate_firewall_policy","url":"aws_api/network_firewall.html#associate_firewall_policy"},{"doc":"aws_api/network_firewall","title":"associate_subnets","content":"pub fn associate_subnets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/network_firewall.associate_subnets\naws_api/network_firewall associate_subnets","url":"aws_api/network_firewall.html#associate_subnets"},{"doc":"aws_api/network_firewall","title":"create_firewall","content":"pub fn create_firewall(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/network_firewall.create_firewall\naws_api/network_firewall create_firewall","url":"aws_api/network_firewall.html#create_firewall"},{"doc":"aws_api/network_firewall","title":"create_firewall_policy","content":"pub fn create_firewall_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/network_firewall.create_firewall_policy\naws_api/network_firewall create_firewall_policy","url":"aws_api/network_firewall.html#create_firewall_policy"},{"doc":"aws_api/network_firewall","title":"create_rule_group","content":"pub fn create_rule_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/network_firewall.create_rule_group\naws_api/network_firewall create_rule_group","url":"aws_api/network_firewall.html#create_rule_group"},{"doc":"aws_api/network_firewall","title":"create_tls_inspection_configuration","content":"pub fn create_tls_inspection_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/network_firewall.create_tls_inspection_configuration\naws_api/network_firewall create_tls_inspection_configuration","url":"aws_api/network_firewall.html#create_tls_inspection_configuration"},{"doc":"aws_api/network_firewall","title":"delete_firewall","content":"pub fn delete_firewall(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/network_firewall.delete_firewall\naws_api/network_firewall delete_firewall","url":"aws_api/network_firewall.html#delete_firewall"},{"doc":"aws_api/network_firewall","title":"delete_firewall_policy","content":"pub fn delete_firewall_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/network_firewall.delete_firewall_policy\naws_api/network_firewall delete_firewall_policy","url":"aws_api/network_firewall.html#delete_firewall_policy"},{"doc":"aws_api/network_firewall","title":"delete_resource_policy","content":"pub fn delete_resource_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/network_firewall.delete_resource_policy\naws_api/network_firewall delete_resource_policy","url":"aws_api/network_firewall.html#delete_resource_policy"},{"doc":"aws_api/network_firewall","title":"delete_rule_group","content":"pub fn delete_rule_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/network_firewall.delete_rule_group\naws_api/network_firewall delete_rule_group","url":"aws_api/network_firewall.html#delete_rule_group"},{"doc":"aws_api/network_firewall","title":"delete_tls_inspection_configuration","content":"pub fn delete_tls_inspection_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/network_firewall.delete_tls_inspection_configuration\naws_api/network_firewall delete_tls_inspection_configuration","url":"aws_api/network_firewall.html#delete_tls_inspection_configuration"},{"doc":"aws_api/network_firewall","title":"describe_firewall","content":"pub fn describe_firewall(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/network_firewall.describe_firewall\naws_api/network_firewall describe_firewall","url":"aws_api/network_firewall.html#describe_firewall"},{"doc":"aws_api/network_firewall","title":"describe_firewall_policy","content":"pub fn describe_firewall_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/network_firewall.describe_firewall_policy\naws_api/network_firewall describe_firewall_policy","url":"aws_api/network_firewall.html#describe_firewall_policy"},{"doc":"aws_api/network_firewall","title":"describe_logging_configuration","content":"pub fn describe_logging_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/network_firewall.describe_logging_configuration\naws_api/network_firewall describe_logging_configuration","url":"aws_api/network_firewall.html#describe_logging_configuration"},{"doc":"aws_api/network_firewall","title":"describe_resource_policy","content":"pub fn describe_resource_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/network_firewall.describe_resource_policy\naws_api/network_firewall describe_resource_policy","url":"aws_api/network_firewall.html#describe_resource_policy"},{"doc":"aws_api/network_firewall","title":"describe_rule_group","content":"pub fn describe_rule_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/network_firewall.describe_rule_group\naws_api/network_firewall describe_rule_group","url":"aws_api/network_firewall.html#describe_rule_group"},{"doc":"aws_api/network_firewall","title":"describe_rule_group_metadata","content":"pub fn describe_rule_group_metadata(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/network_firewall.describe_rule_group_metadata\naws_api/network_firewall describe_rule_group_metadata","url":"aws_api/network_firewall.html#describe_rule_group_metadata"},{"doc":"aws_api/network_firewall","title":"describe_tls_inspection_configuration","content":"pub fn describe_tls_inspection_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/network_firewall.describe_tls_inspection_configuration\naws_api/network_firewall describe_tls_inspection_configuration","url":"aws_api/network_firewall.html#describe_tls_inspection_configuration"},{"doc":"aws_api/network_firewall","title":"disassociate_subnets","content":"pub fn disassociate_subnets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/network_firewall.disassociate_subnets\naws_api/network_firewall disassociate_subnets","url":"aws_api/network_firewall.html#disassociate_subnets"},{"doc":"aws_api/network_firewall","title":"list_firewall_policies","content":"pub fn list_firewall_policies(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/network_firewall.list_firewall_policies\naws_api/network_firewall list_firewall_policies","url":"aws_api/network_firewall.html#list_firewall_policies"},{"doc":"aws_api/network_firewall","title":"list_firewalls","content":"pub fn list_firewalls(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/network_firewall.list_firewalls\naws_api/network_firewall list_firewalls","url":"aws_api/network_firewall.html#list_firewalls"},{"doc":"aws_api/network_firewall","title":"list_rule_groups","content":"pub fn list_rule_groups(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/network_firewall.list_rule_groups\naws_api/network_firewall list_rule_groups","url":"aws_api/network_firewall.html#list_rule_groups"},{"doc":"aws_api/network_firewall","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/network_firewall.list_tags_for_resource\naws_api/network_firewall list_tags_for_resource","url":"aws_api/network_firewall.html#list_tags_for_resource"},{"doc":"aws_api/network_firewall","title":"list_tls_inspection_configurations","content":"pub fn list_tls_inspection_configurations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/network_firewall.list_tls_inspection_configurations\naws_api/network_firewall list_tls_inspection_configurations","url":"aws_api/network_firewall.html#list_tls_inspection_configurations"},{"doc":"aws_api/network_firewall","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/network_firewall.new\naws_api/network_firewall new","url":"aws_api/network_firewall.html#new"},{"doc":"aws_api/network_firewall","title":"put_resource_policy","content":"pub fn put_resource_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/network_firewall.put_resource_policy\naws_api/network_firewall put_resource_policy","url":"aws_api/network_firewall.html#put_resource_policy"},{"doc":"aws_api/network_firewall","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/network_firewall.tag_resource\naws_api/network_firewall tag_resource","url":"aws_api/network_firewall.html#tag_resource"},{"doc":"aws_api/network_firewall","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/network_firewall.untag_resource\naws_api/network_firewall untag_resource","url":"aws_api/network_firewall.html#untag_resource"},{"doc":"aws_api/network_firewall","title":"update_firewall_delete_protection","content":"pub fn update_firewall_delete_protection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/network_firewall.update_firewall_delete_protection\naws_api/network_firewall update_firewall_delete_protection","url":"aws_api/network_firewall.html#update_firewall_delete_protection"},{"doc":"aws_api/network_firewall","title":"update_firewall_description","content":"pub fn update_firewall_description(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/network_firewall.update_firewall_description\naws_api/network_firewall update_firewall_description","url":"aws_api/network_firewall.html#update_firewall_description"},{"doc":"aws_api/network_firewall","title":"update_firewall_encryption_configuration","content":"pub fn update_firewall_encryption_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/network_firewall.update_firewall_encryption_configuration\naws_api/network_firewall update_firewall_encryption_configuration","url":"aws_api/network_firewall.html#update_firewall_encryption_configuration"},{"doc":"aws_api/network_firewall","title":"update_firewall_policy","content":"pub fn update_firewall_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/network_firewall.update_firewall_policy\naws_api/network_firewall update_firewall_policy","url":"aws_api/network_firewall.html#update_firewall_policy"},{"doc":"aws_api/network_firewall","title":"update_firewall_policy_change_protection","content":"pub fn update_firewall_policy_change_protection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/network_firewall.update_firewall_policy_change_protection\naws_api/network_firewall update_firewall_policy_change_protection","url":"aws_api/network_firewall.html#update_firewall_policy_change_protection"},{"doc":"aws_api/network_firewall","title":"update_logging_configuration","content":"pub fn update_logging_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/network_firewall.update_logging_configuration\naws_api/network_firewall update_logging_configuration","url":"aws_api/network_firewall.html#update_logging_configuration"},{"doc":"aws_api/network_firewall","title":"update_rule_group","content":"pub fn update_rule_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/network_firewall.update_rule_group\naws_api/network_firewall update_rule_group","url":"aws_api/network_firewall.html#update_rule_group"},{"doc":"aws_api/network_firewall","title":"update_subnet_change_protection","content":"pub fn update_subnet_change_protection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/network_firewall.update_subnet_change_protection\naws_api/network_firewall update_subnet_change_protection","url":"aws_api/network_firewall.html#update_subnet_change_protection"},{"doc":"aws_api/network_firewall","title":"update_tls_inspection_configuration","content":"pub fn update_tls_inspection_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/network_firewall.update_tls_inspection_configuration\naws_api/network_firewall update_tls_inspection_configuration","url":"aws_api/network_firewall.html#update_tls_inspection_configuration"},{"doc":"aws_api/network_firewall","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/network_firewall.with_custom_endpoint\naws_api/network_firewall with_custom_endpoint","url":"aws_api/network_firewall.html#with_custom_endpoint"},{"doc":"aws_api/network_firewall","title":"aws_api/network_firewall","content":"","url":"aws_api/network_firewall.html"},{"doc":"aws_api/networkmanager","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/networkmanager.Client\naws_api/networkmanager Client","url":"aws_api/networkmanager.html#Client"},{"doc":"aws_api/networkmanager","title":"accept_attachment","content":"pub fn accept_attachment(\n  client: Client,\n  attachment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.accept_attachment\naws_api/networkmanager accept_attachment","url":"aws_api/networkmanager.html#accept_attachment"},{"doc":"aws_api/networkmanager","title":"associate_connect_peer","content":"pub fn associate_connect_peer(\n  client: Client,\n  global_network_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.associate_connect_peer\naws_api/networkmanager associate_connect_peer","url":"aws_api/networkmanager.html#associate_connect_peer"},{"doc":"aws_api/networkmanager","title":"associate_customer_gateway","content":"pub fn associate_customer_gateway(\n  client: Client,\n  global_network_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.associate_customer_gateway\naws_api/networkmanager associate_customer_gateway","url":"aws_api/networkmanager.html#associate_customer_gateway"},{"doc":"aws_api/networkmanager","title":"associate_link","content":"pub fn associate_link(\n  client: Client,\n  global_network_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.associate_link\naws_api/networkmanager associate_link","url":"aws_api/networkmanager.html#associate_link"},{"doc":"aws_api/networkmanager","title":"associate_transit_gateway_connect_peer","content":"pub fn associate_transit_gateway_connect_peer(\n  client: Client,\n  global_network_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.associate_transit_gateway_connect_peer\naws_api/networkmanager associate_transit_gateway_connect_peer","url":"aws_api/networkmanager.html#associate_transit_gateway_connect_peer"},{"doc":"aws_api/networkmanager","title":"create_connect_attachment","content":"pub fn create_connect_attachment(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.create_connect_attachment\naws_api/networkmanager create_connect_attachment","url":"aws_api/networkmanager.html#create_connect_attachment"},{"doc":"aws_api/networkmanager","title":"create_connect_peer","content":"pub fn create_connect_peer(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.create_connect_peer\naws_api/networkmanager create_connect_peer","url":"aws_api/networkmanager.html#create_connect_peer"},{"doc":"aws_api/networkmanager","title":"create_connection","content":"pub fn create_connection(\n  client: Client,\n  global_network_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.create_connection\naws_api/networkmanager create_connection","url":"aws_api/networkmanager.html#create_connection"},{"doc":"aws_api/networkmanager","title":"create_core_network","content":"pub fn create_core_network(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.create_core_network\naws_api/networkmanager create_core_network","url":"aws_api/networkmanager.html#create_core_network"},{"doc":"aws_api/networkmanager","title":"create_device","content":"pub fn create_device(\n  client: Client,\n  global_network_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.create_device\naws_api/networkmanager create_device","url":"aws_api/networkmanager.html#create_device"},{"doc":"aws_api/networkmanager","title":"create_global_network","content":"pub fn create_global_network(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.create_global_network\naws_api/networkmanager create_global_network","url":"aws_api/networkmanager.html#create_global_network"},{"doc":"aws_api/networkmanager","title":"create_link","content":"pub fn create_link(\n  client: Client,\n  global_network_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.create_link\naws_api/networkmanager create_link","url":"aws_api/networkmanager.html#create_link"},{"doc":"aws_api/networkmanager","title":"create_site","content":"pub fn create_site(\n  client: Client,\n  global_network_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.create_site\naws_api/networkmanager create_site","url":"aws_api/networkmanager.html#create_site"},{"doc":"aws_api/networkmanager","title":"create_site_to_site_vpn_attachment","content":"pub fn create_site_to_site_vpn_attachment(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.create_site_to_site_vpn_attachment\naws_api/networkmanager create_site_to_site_vpn_attachment","url":"aws_api/networkmanager.html#create_site_to_site_vpn_attachment"},{"doc":"aws_api/networkmanager","title":"create_transit_gateway_peering","content":"pub fn create_transit_gateway_peering(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.create_transit_gateway_peering\naws_api/networkmanager create_transit_gateway_peering","url":"aws_api/networkmanager.html#create_transit_gateway_peering"},{"doc":"aws_api/networkmanager","title":"create_transit_gateway_route_table_attachment","content":"pub fn create_transit_gateway_route_table_attachment(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.create_transit_gateway_route_table_attachment\naws_api/networkmanager create_transit_gateway_route_table_attachment","url":"aws_api/networkmanager.html#create_transit_gateway_route_table_attachment"},{"doc":"aws_api/networkmanager","title":"create_vpc_attachment","content":"pub fn create_vpc_attachment(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.create_vpc_attachment\naws_api/networkmanager create_vpc_attachment","url":"aws_api/networkmanager.html#create_vpc_attachment"},{"doc":"aws_api/networkmanager","title":"delete_attachment","content":"pub fn delete_attachment(\n  client: Client,\n  attachment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.delete_attachment\naws_api/networkmanager delete_attachment","url":"aws_api/networkmanager.html#delete_attachment"},{"doc":"aws_api/networkmanager","title":"delete_connect_peer","content":"pub fn delete_connect_peer(\n  client: Client,\n  connect_peer_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.delete_connect_peer\naws_api/networkmanager delete_connect_peer","url":"aws_api/networkmanager.html#delete_connect_peer"},{"doc":"aws_api/networkmanager","title":"delete_connection","content":"pub fn delete_connection(\n  client: Client,\n  global_network_id: String,\n  connection_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.delete_connection\naws_api/networkmanager delete_connection","url":"aws_api/networkmanager.html#delete_connection"},{"doc":"aws_api/networkmanager","title":"delete_core_network","content":"pub fn delete_core_network(\n  client: Client,\n  core_network_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.delete_core_network\naws_api/networkmanager delete_core_network","url":"aws_api/networkmanager.html#delete_core_network"},{"doc":"aws_api/networkmanager","title":"delete_core_network_policy_version","content":"pub fn delete_core_network_policy_version(\n  client: Client,\n  core_network_id: String,\n  policy_version_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.delete_core_network_policy_version\naws_api/networkmanager delete_core_network_policy_version","url":"aws_api/networkmanager.html#delete_core_network_policy_version"},{"doc":"aws_api/networkmanager","title":"delete_device","content":"pub fn delete_device(\n  client: Client,\n  global_network_id: String,\n  device_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.delete_device\naws_api/networkmanager delete_device","url":"aws_api/networkmanager.html#delete_device"},{"doc":"aws_api/networkmanager","title":"delete_global_network","content":"pub fn delete_global_network(\n  client: Client,\n  global_network_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.delete_global_network\naws_api/networkmanager delete_global_network","url":"aws_api/networkmanager.html#delete_global_network"},{"doc":"aws_api/networkmanager","title":"delete_link","content":"pub fn delete_link(\n  client: Client,\n  global_network_id: String,\n  link_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.delete_link\naws_api/networkmanager delete_link","url":"aws_api/networkmanager.html#delete_link"},{"doc":"aws_api/networkmanager","title":"delete_peering","content":"pub fn delete_peering(\n  client: Client,\n  peering_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.delete_peering\naws_api/networkmanager delete_peering","url":"aws_api/networkmanager.html#delete_peering"},{"doc":"aws_api/networkmanager","title":"delete_resource_policy","content":"pub fn delete_resource_policy(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.delete_resource_policy\naws_api/networkmanager delete_resource_policy","url":"aws_api/networkmanager.html#delete_resource_policy"},{"doc":"aws_api/networkmanager","title":"delete_site","content":"pub fn delete_site(\n  client: Client,\n  global_network_id: String,\n  site_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.delete_site\naws_api/networkmanager delete_site","url":"aws_api/networkmanager.html#delete_site"},{"doc":"aws_api/networkmanager","title":"deregister_transit_gateway","content":"pub fn deregister_transit_gateway(\n  client: Client,\n  global_network_id: String,\n  transit_gateway_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.deregister_transit_gateway\naws_api/networkmanager deregister_transit_gateway","url":"aws_api/networkmanager.html#deregister_transit_gateway"},{"doc":"aws_api/networkmanager","title":"describe_global_networks","content":"pub fn describe_global_networks(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.describe_global_networks\naws_api/networkmanager describe_global_networks","url":"aws_api/networkmanager.html#describe_global_networks"},{"doc":"aws_api/networkmanager","title":"disassociate_connect_peer","content":"pub fn disassociate_connect_peer(\n  client: Client,\n  global_network_id: String,\n  connect_peer_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.disassociate_connect_peer\naws_api/networkmanager disassociate_connect_peer","url":"aws_api/networkmanager.html#disassociate_connect_peer"},{"doc":"aws_api/networkmanager","title":"disassociate_customer_gateway","content":"pub fn disassociate_customer_gateway(\n  client: Client,\n  global_network_id: String,\n  customer_gateway_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.disassociate_customer_gateway\naws_api/networkmanager disassociate_customer_gateway","url":"aws_api/networkmanager.html#disassociate_customer_gateway"},{"doc":"aws_api/networkmanager","title":"disassociate_link","content":"pub fn disassociate_link(\n  client: Client,\n  global_network_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.disassociate_link\naws_api/networkmanager disassociate_link","url":"aws_api/networkmanager.html#disassociate_link"},{"doc":"aws_api/networkmanager","title":"disassociate_transit_gateway_connect_peer","content":"pub fn disassociate_transit_gateway_connect_peer(\n  client: Client,\n  global_network_id: String,\n  transit_gateway_connect_peer_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.disassociate_transit_gateway_connect_peer\naws_api/networkmanager disassociate_transit_gateway_connect_peer","url":"aws_api/networkmanager.html#disassociate_transit_gateway_connect_peer"},{"doc":"aws_api/networkmanager","title":"execute_core_network_change_set","content":"pub fn execute_core_network_change_set(\n  client: Client,\n  core_network_id: String,\n  policy_version_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.execute_core_network_change_set\naws_api/networkmanager execute_core_network_change_set","url":"aws_api/networkmanager.html#execute_core_network_change_set"},{"doc":"aws_api/networkmanager","title":"get_connect_attachment","content":"pub fn get_connect_attachment(\n  client: Client,\n  attachment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.get_connect_attachment\naws_api/networkmanager get_connect_attachment","url":"aws_api/networkmanager.html#get_connect_attachment"},{"doc":"aws_api/networkmanager","title":"get_connect_peer","content":"pub fn get_connect_peer(\n  client: Client,\n  connect_peer_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.get_connect_peer\naws_api/networkmanager get_connect_peer","url":"aws_api/networkmanager.html#get_connect_peer"},{"doc":"aws_api/networkmanager","title":"get_connect_peer_associations","content":"pub fn get_connect_peer_associations(\n  client: Client,\n  global_network_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.get_connect_peer_associations\naws_api/networkmanager get_connect_peer_associations","url":"aws_api/networkmanager.html#get_connect_peer_associations"},{"doc":"aws_api/networkmanager","title":"get_connections","content":"pub fn get_connections(\n  client: Client,\n  global_network_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.get_connections\naws_api/networkmanager get_connections","url":"aws_api/networkmanager.html#get_connections"},{"doc":"aws_api/networkmanager","title":"get_core_network","content":"pub fn get_core_network(\n  client: Client,\n  core_network_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.get_core_network\naws_api/networkmanager get_core_network","url":"aws_api/networkmanager.html#get_core_network"},{"doc":"aws_api/networkmanager","title":"get_core_network_change_events","content":"pub fn get_core_network_change_events(\n  client: Client,\n  core_network_id: String,\n  policy_version_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.get_core_network_change_events\naws_api/networkmanager get_core_network_change_events","url":"aws_api/networkmanager.html#get_core_network_change_events"},{"doc":"aws_api/networkmanager","title":"get_core_network_change_set","content":"pub fn get_core_network_change_set(\n  client: Client,\n  core_network_id: String,\n  policy_version_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.get_core_network_change_set\naws_api/networkmanager get_core_network_change_set","url":"aws_api/networkmanager.html#get_core_network_change_set"},{"doc":"aws_api/networkmanager","title":"get_core_network_policy","content":"pub fn get_core_network_policy(\n  client: Client,\n  core_network_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.get_core_network_policy\naws_api/networkmanager get_core_network_policy","url":"aws_api/networkmanager.html#get_core_network_policy"},{"doc":"aws_api/networkmanager","title":"get_customer_gateway_associations","content":"pub fn get_customer_gateway_associations(\n  client: Client,\n  global_network_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.get_customer_gateway_associations\naws_api/networkmanager get_customer_gateway_associations","url":"aws_api/networkmanager.html#get_customer_gateway_associations"},{"doc":"aws_api/networkmanager","title":"get_devices","content":"pub fn get_devices(\n  client: Client,\n  global_network_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.get_devices\naws_api/networkmanager get_devices","url":"aws_api/networkmanager.html#get_devices"},{"doc":"aws_api/networkmanager","title":"get_link_associations","content":"pub fn get_link_associations(\n  client: Client,\n  global_network_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.get_link_associations\naws_api/networkmanager get_link_associations","url":"aws_api/networkmanager.html#get_link_associations"},{"doc":"aws_api/networkmanager","title":"get_links","content":"pub fn get_links(\n  client: Client,\n  global_network_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.get_links\naws_api/networkmanager get_links","url":"aws_api/networkmanager.html#get_links"},{"doc":"aws_api/networkmanager","title":"get_network_resource_counts","content":"pub fn get_network_resource_counts(\n  client: Client,\n  global_network_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.get_network_resource_counts\naws_api/networkmanager get_network_resource_counts","url":"aws_api/networkmanager.html#get_network_resource_counts"},{"doc":"aws_api/networkmanager","title":"get_network_resource_relationships","content":"pub fn get_network_resource_relationships(\n  client: Client,\n  global_network_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.get_network_resource_relationships\naws_api/networkmanager get_network_resource_relationships","url":"aws_api/networkmanager.html#get_network_resource_relationships"},{"doc":"aws_api/networkmanager","title":"get_network_resources","content":"pub fn get_network_resources(\n  client: Client,\n  global_network_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.get_network_resources\naws_api/networkmanager get_network_resources","url":"aws_api/networkmanager.html#get_network_resources"},{"doc":"aws_api/networkmanager","title":"get_network_routes","content":"pub fn get_network_routes(\n  client: Client,\n  global_network_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.get_network_routes\naws_api/networkmanager get_network_routes","url":"aws_api/networkmanager.html#get_network_routes"},{"doc":"aws_api/networkmanager","title":"get_network_telemetry","content":"pub fn get_network_telemetry(\n  client: Client,\n  global_network_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.get_network_telemetry\naws_api/networkmanager get_network_telemetry","url":"aws_api/networkmanager.html#get_network_telemetry"},{"doc":"aws_api/networkmanager","title":"get_resource_policy","content":"pub fn get_resource_policy(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.get_resource_policy\naws_api/networkmanager get_resource_policy","url":"aws_api/networkmanager.html#get_resource_policy"},{"doc":"aws_api/networkmanager","title":"get_route_analysis","content":"pub fn get_route_analysis(\n  client: Client,\n  global_network_id: String,\n  route_analysis_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.get_route_analysis\naws_api/networkmanager get_route_analysis","url":"aws_api/networkmanager.html#get_route_analysis"},{"doc":"aws_api/networkmanager","title":"get_site_to_site_vpn_attachment","content":"pub fn get_site_to_site_vpn_attachment(\n  client: Client,\n  attachment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.get_site_to_site_vpn_attachment\naws_api/networkmanager get_site_to_site_vpn_attachment","url":"aws_api/networkmanager.html#get_site_to_site_vpn_attachment"},{"doc":"aws_api/networkmanager","title":"get_sites","content":"pub fn get_sites(\n  client: Client,\n  global_network_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.get_sites\naws_api/networkmanager get_sites","url":"aws_api/networkmanager.html#get_sites"},{"doc":"aws_api/networkmanager","title":"get_transit_gateway_connect_peer_associations","content":"pub fn get_transit_gateway_connect_peer_associations(\n  client: Client,\n  global_network_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.get_transit_gateway_connect_peer_associations\naws_api/networkmanager get_transit_gateway_connect_peer_associations","url":"aws_api/networkmanager.html#get_transit_gateway_connect_peer_associations"},{"doc":"aws_api/networkmanager","title":"get_transit_gateway_peering","content":"pub fn get_transit_gateway_peering(\n  client: Client,\n  peering_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.get_transit_gateway_peering\naws_api/networkmanager get_transit_gateway_peering","url":"aws_api/networkmanager.html#get_transit_gateway_peering"},{"doc":"aws_api/networkmanager","title":"get_transit_gateway_registrations","content":"pub fn get_transit_gateway_registrations(\n  client: Client,\n  global_network_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.get_transit_gateway_registrations\naws_api/networkmanager get_transit_gateway_registrations","url":"aws_api/networkmanager.html#get_transit_gateway_registrations"},{"doc":"aws_api/networkmanager","title":"get_transit_gateway_route_table_attachment","content":"pub fn get_transit_gateway_route_table_attachment(\n  client: Client,\n  attachment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.get_transit_gateway_route_table_attachment\naws_api/networkmanager get_transit_gateway_route_table_attachment","url":"aws_api/networkmanager.html#get_transit_gateway_route_table_attachment"},{"doc":"aws_api/networkmanager","title":"get_vpc_attachment","content":"pub fn get_vpc_attachment(\n  client: Client,\n  attachment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.get_vpc_attachment\naws_api/networkmanager get_vpc_attachment","url":"aws_api/networkmanager.html#get_vpc_attachment"},{"doc":"aws_api/networkmanager","title":"list_attachments","content":"pub fn list_attachments(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.list_attachments\naws_api/networkmanager list_attachments","url":"aws_api/networkmanager.html#list_attachments"},{"doc":"aws_api/networkmanager","title":"list_connect_peers","content":"pub fn list_connect_peers(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.list_connect_peers\naws_api/networkmanager list_connect_peers","url":"aws_api/networkmanager.html#list_connect_peers"},{"doc":"aws_api/networkmanager","title":"list_core_network_policy_versions","content":"pub fn list_core_network_policy_versions(\n  client: Client,\n  core_network_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.list_core_network_policy_versions\naws_api/networkmanager list_core_network_policy_versions","url":"aws_api/networkmanager.html#list_core_network_policy_versions"},{"doc":"aws_api/networkmanager","title":"list_core_networks","content":"pub fn list_core_networks(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.list_core_networks\naws_api/networkmanager list_core_networks","url":"aws_api/networkmanager.html#list_core_networks"},{"doc":"aws_api/networkmanager","title":"list_organization_service_access_status","content":"pub fn list_organization_service_access_status(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.list_organization_service_access_status\naws_api/networkmanager list_organization_service_access_status","url":"aws_api/networkmanager.html#list_organization_service_access_status"},{"doc":"aws_api/networkmanager","title":"list_peerings","content":"pub fn list_peerings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.list_peerings\naws_api/networkmanager list_peerings","url":"aws_api/networkmanager.html#list_peerings"},{"doc":"aws_api/networkmanager","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.list_tags_for_resource\naws_api/networkmanager list_tags_for_resource","url":"aws_api/networkmanager.html#list_tags_for_resource"},{"doc":"aws_api/networkmanager","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/networkmanager.new\naws_api/networkmanager new","url":"aws_api/networkmanager.html#new"},{"doc":"aws_api/networkmanager","title":"put_core_network_policy","content":"pub fn put_core_network_policy(\n  client: Client,\n  core_network_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.put_core_network_policy\naws_api/networkmanager put_core_network_policy","url":"aws_api/networkmanager.html#put_core_network_policy"},{"doc":"aws_api/networkmanager","title":"put_resource_policy","content":"pub fn put_resource_policy(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.put_resource_policy\naws_api/networkmanager put_resource_policy","url":"aws_api/networkmanager.html#put_resource_policy"},{"doc":"aws_api/networkmanager","title":"register_transit_gateway","content":"pub fn register_transit_gateway(\n  client: Client,\n  global_network_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.register_transit_gateway\naws_api/networkmanager register_transit_gateway","url":"aws_api/networkmanager.html#register_transit_gateway"},{"doc":"aws_api/networkmanager","title":"reject_attachment","content":"pub fn reject_attachment(\n  client: Client,\n  attachment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.reject_attachment\naws_api/networkmanager reject_attachment","url":"aws_api/networkmanager.html#reject_attachment"},{"doc":"aws_api/networkmanager","title":"restore_core_network_policy_version","content":"pub fn restore_core_network_policy_version(\n  client: Client,\n  core_network_id: String,\n  policy_version_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.restore_core_network_policy_version\naws_api/networkmanager restore_core_network_policy_version","url":"aws_api/networkmanager.html#restore_core_network_policy_version"},{"doc":"aws_api/networkmanager","title":"start_organization_service_access_update","content":"pub fn start_organization_service_access_update(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.start_organization_service_access_update\naws_api/networkmanager start_organization_service_access_update","url":"aws_api/networkmanager.html#start_organization_service_access_update"},{"doc":"aws_api/networkmanager","title":"start_route_analysis","content":"pub fn start_route_analysis(\n  client: Client,\n  global_network_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.start_route_analysis\naws_api/networkmanager start_route_analysis","url":"aws_api/networkmanager.html#start_route_analysis"},{"doc":"aws_api/networkmanager","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.tag_resource\naws_api/networkmanager tag_resource","url":"aws_api/networkmanager.html#tag_resource"},{"doc":"aws_api/networkmanager","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.untag_resource\naws_api/networkmanager untag_resource","url":"aws_api/networkmanager.html#untag_resource"},{"doc":"aws_api/networkmanager","title":"update_connection","content":"pub fn update_connection(\n  client: Client,\n  global_network_id: String,\n  connection_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.update_connection\naws_api/networkmanager update_connection","url":"aws_api/networkmanager.html#update_connection"},{"doc":"aws_api/networkmanager","title":"update_core_network","content":"pub fn update_core_network(\n  client: Client,\n  core_network_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.update_core_network\naws_api/networkmanager update_core_network","url":"aws_api/networkmanager.html#update_core_network"},{"doc":"aws_api/networkmanager","title":"update_device","content":"pub fn update_device(\n  client: Client,\n  global_network_id: String,\n  device_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.update_device\naws_api/networkmanager update_device","url":"aws_api/networkmanager.html#update_device"},{"doc":"aws_api/networkmanager","title":"update_global_network","content":"pub fn update_global_network(\n  client: Client,\n  global_network_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.update_global_network\naws_api/networkmanager update_global_network","url":"aws_api/networkmanager.html#update_global_network"},{"doc":"aws_api/networkmanager","title":"update_link","content":"pub fn update_link(\n  client: Client,\n  global_network_id: String,\n  link_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.update_link\naws_api/networkmanager update_link","url":"aws_api/networkmanager.html#update_link"},{"doc":"aws_api/networkmanager","title":"update_network_resource_metadata","content":"pub fn update_network_resource_metadata(\n  client: Client,\n  global_network_id: String,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.update_network_resource_metadata\naws_api/networkmanager update_network_resource_metadata","url":"aws_api/networkmanager.html#update_network_resource_metadata"},{"doc":"aws_api/networkmanager","title":"update_site","content":"pub fn update_site(\n  client: Client,\n  global_network_id: String,\n  site_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.update_site\naws_api/networkmanager update_site","url":"aws_api/networkmanager.html#update_site"},{"doc":"aws_api/networkmanager","title":"update_vpc_attachment","content":"pub fn update_vpc_attachment(\n  client: Client,\n  attachment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/networkmanager.update_vpc_attachment\naws_api/networkmanager update_vpc_attachment","url":"aws_api/networkmanager.html#update_vpc_attachment"},{"doc":"aws_api/networkmanager","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/networkmanager.with_custom_endpoint\naws_api/networkmanager with_custom_endpoint","url":"aws_api/networkmanager.html#with_custom_endpoint"},{"doc":"aws_api/networkmanager","title":"aws_api/networkmanager","content":"","url":"aws_api/networkmanager.html"},{"doc":"aws_api/nimble","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/nimble.Client\naws_api/nimble Client","url":"aws_api/nimble.html#Client"},{"doc":"aws_api/nimble","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/nimble.list_tags_for_resource\naws_api/nimble list_tags_for_resource","url":"aws_api/nimble.html#list_tags_for_resource"},{"doc":"aws_api/nimble","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/nimble.new\naws_api/nimble new","url":"aws_api/nimble.html#new"},{"doc":"aws_api/nimble","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/nimble.tag_resource\naws_api/nimble tag_resource","url":"aws_api/nimble.html#tag_resource"},{"doc":"aws_api/nimble","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/nimble.untag_resource\naws_api/nimble untag_resource","url":"aws_api/nimble.html#untag_resource"},{"doc":"aws_api/nimble","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/nimble.with_custom_endpoint\naws_api/nimble with_custom_endpoint","url":"aws_api/nimble.html#with_custom_endpoint"},{"doc":"aws_api/nimble","title":"aws_api/nimble","content":"","url":"aws_api/nimble.html"},{"doc":"aws_api/oam","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/oam.Client\naws_api/oam Client","url":"aws_api/oam.html#Client"},{"doc":"aws_api/oam","title":"create_link","content":"pub fn create_link(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/oam.create_link\naws_api/oam create_link","url":"aws_api/oam.html#create_link"},{"doc":"aws_api/oam","title":"create_sink","content":"pub fn create_sink(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/oam.create_sink\naws_api/oam create_sink","url":"aws_api/oam.html#create_sink"},{"doc":"aws_api/oam","title":"delete_link","content":"pub fn delete_link(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/oam.delete_link\naws_api/oam delete_link","url":"aws_api/oam.html#delete_link"},{"doc":"aws_api/oam","title":"delete_sink","content":"pub fn delete_sink(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/oam.delete_sink\naws_api/oam delete_sink","url":"aws_api/oam.html#delete_sink"},{"doc":"aws_api/oam","title":"get_link","content":"pub fn get_link(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/oam.get_link\naws_api/oam get_link","url":"aws_api/oam.html#get_link"},{"doc":"aws_api/oam","title":"get_sink","content":"pub fn get_sink(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/oam.get_sink\naws_api/oam get_sink","url":"aws_api/oam.html#get_sink"},{"doc":"aws_api/oam","title":"get_sink_policy","content":"pub fn get_sink_policy(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/oam.get_sink_policy\naws_api/oam get_sink_policy","url":"aws_api/oam.html#get_sink_policy"},{"doc":"aws_api/oam","title":"list_attached_links","content":"pub fn list_attached_links(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/oam.list_attached_links\naws_api/oam list_attached_links","url":"aws_api/oam.html#list_attached_links"},{"doc":"aws_api/oam","title":"list_links","content":"pub fn list_links(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/oam.list_links\naws_api/oam list_links","url":"aws_api/oam.html#list_links"},{"doc":"aws_api/oam","title":"list_sinks","content":"pub fn list_sinks(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/oam.list_sinks\naws_api/oam list_sinks","url":"aws_api/oam.html#list_sinks"},{"doc":"aws_api/oam","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/oam.list_tags_for_resource\naws_api/oam list_tags_for_resource","url":"aws_api/oam.html#list_tags_for_resource"},{"doc":"aws_api/oam","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/oam.new\naws_api/oam new","url":"aws_api/oam.html#new"},{"doc":"aws_api/oam","title":"put_sink_policy","content":"pub fn put_sink_policy(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/oam.put_sink_policy\naws_api/oam put_sink_policy","url":"aws_api/oam.html#put_sink_policy"},{"doc":"aws_api/oam","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/oam.tag_resource\naws_api/oam tag_resource","url":"aws_api/oam.html#tag_resource"},{"doc":"aws_api/oam","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/oam.untag_resource\naws_api/oam untag_resource","url":"aws_api/oam.html#untag_resource"},{"doc":"aws_api/oam","title":"update_link","content":"pub fn update_link(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/oam.update_link\naws_api/oam update_link","url":"aws_api/oam.html#update_link"},{"doc":"aws_api/oam","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/oam.with_custom_endpoint\naws_api/oam with_custom_endpoint","url":"aws_api/oam.html#with_custom_endpoint"},{"doc":"aws_api/oam","title":"aws_api/oam","content":"","url":"aws_api/oam.html"},{"doc":"aws_api/opensearch","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/opensearch.Client\naws_api/opensearch Client","url":"aws_api/opensearch.html#Client"},{"doc":"aws_api/opensearch","title":"accept_inbound_connection","content":"pub fn accept_inbound_connection(\n  client: Client,\n  connection_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.accept_inbound_connection\naws_api/opensearch accept_inbound_connection","url":"aws_api/opensearch.html#accept_inbound_connection"},{"doc":"aws_api/opensearch","title":"add_data_source","content":"pub fn add_data_source(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.add_data_source\naws_api/opensearch add_data_source","url":"aws_api/opensearch.html#add_data_source"},{"doc":"aws_api/opensearch","title":"add_tags","content":"pub fn add_tags(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.add_tags\naws_api/opensearch add_tags","url":"aws_api/opensearch.html#add_tags"},{"doc":"aws_api/opensearch","title":"associate_package","content":"pub fn associate_package(\n  client: Client,\n  package_id: String,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.associate_package\naws_api/opensearch associate_package","url":"aws_api/opensearch.html#associate_package"},{"doc":"aws_api/opensearch","title":"authorize_vpc_endpoint_access","content":"pub fn authorize_vpc_endpoint_access(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.authorize_vpc_endpoint_access\naws_api/opensearch authorize_vpc_endpoint_access","url":"aws_api/opensearch.html#authorize_vpc_endpoint_access"},{"doc":"aws_api/opensearch","title":"cancel_domain_config_change","content":"pub fn cancel_domain_config_change(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.cancel_domain_config_change\naws_api/opensearch cancel_domain_config_change","url":"aws_api/opensearch.html#cancel_domain_config_change"},{"doc":"aws_api/opensearch","title":"cancel_service_software_update","content":"pub fn cancel_service_software_update(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.cancel_service_software_update\naws_api/opensearch cancel_service_software_update","url":"aws_api/opensearch.html#cancel_service_software_update"},{"doc":"aws_api/opensearch","title":"create_domain","content":"pub fn create_domain(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.create_domain\naws_api/opensearch create_domain","url":"aws_api/opensearch.html#create_domain"},{"doc":"aws_api/opensearch","title":"create_outbound_connection","content":"pub fn create_outbound_connection(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.create_outbound_connection\naws_api/opensearch create_outbound_connection","url":"aws_api/opensearch.html#create_outbound_connection"},{"doc":"aws_api/opensearch","title":"create_package","content":"pub fn create_package(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.create_package\naws_api/opensearch create_package","url":"aws_api/opensearch.html#create_package"},{"doc":"aws_api/opensearch","title":"create_vpc_endpoint","content":"pub fn create_vpc_endpoint(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.create_vpc_endpoint\naws_api/opensearch create_vpc_endpoint","url":"aws_api/opensearch.html#create_vpc_endpoint"},{"doc":"aws_api/opensearch","title":"delete_data_source","content":"pub fn delete_data_source(\n  client: Client,\n  domain_name: String,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.delete_data_source\naws_api/opensearch delete_data_source","url":"aws_api/opensearch.html#delete_data_source"},{"doc":"aws_api/opensearch","title":"delete_domain","content":"pub fn delete_domain(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.delete_domain\naws_api/opensearch delete_domain","url":"aws_api/opensearch.html#delete_domain"},{"doc":"aws_api/opensearch","title":"delete_inbound_connection","content":"pub fn delete_inbound_connection(\n  client: Client,\n  connection_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.delete_inbound_connection\naws_api/opensearch delete_inbound_connection","url":"aws_api/opensearch.html#delete_inbound_connection"},{"doc":"aws_api/opensearch","title":"delete_outbound_connection","content":"pub fn delete_outbound_connection(\n  client: Client,\n  connection_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.delete_outbound_connection\naws_api/opensearch delete_outbound_connection","url":"aws_api/opensearch.html#delete_outbound_connection"},{"doc":"aws_api/opensearch","title":"delete_package","content":"pub fn delete_package(\n  client: Client,\n  package_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.delete_package\naws_api/opensearch delete_package","url":"aws_api/opensearch.html#delete_package"},{"doc":"aws_api/opensearch","title":"delete_vpc_endpoint","content":"pub fn delete_vpc_endpoint(\n  client: Client,\n  vpc_endpoint_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.delete_vpc_endpoint\naws_api/opensearch delete_vpc_endpoint","url":"aws_api/opensearch.html#delete_vpc_endpoint"},{"doc":"aws_api/opensearch","title":"describe_domain","content":"pub fn describe_domain(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.describe_domain\naws_api/opensearch describe_domain","url":"aws_api/opensearch.html#describe_domain"},{"doc":"aws_api/opensearch","title":"describe_domain_auto_tunes","content":"pub fn describe_domain_auto_tunes(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.describe_domain_auto_tunes\naws_api/opensearch describe_domain_auto_tunes","url":"aws_api/opensearch.html#describe_domain_auto_tunes"},{"doc":"aws_api/opensearch","title":"describe_domain_change_progress","content":"pub fn describe_domain_change_progress(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.describe_domain_change_progress\naws_api/opensearch describe_domain_change_progress","url":"aws_api/opensearch.html#describe_domain_change_progress"},{"doc":"aws_api/opensearch","title":"describe_domain_config","content":"pub fn describe_domain_config(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.describe_domain_config\naws_api/opensearch describe_domain_config","url":"aws_api/opensearch.html#describe_domain_config"},{"doc":"aws_api/opensearch","title":"describe_domain_health","content":"pub fn describe_domain_health(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.describe_domain_health\naws_api/opensearch describe_domain_health","url":"aws_api/opensearch.html#describe_domain_health"},{"doc":"aws_api/opensearch","title":"describe_domain_nodes","content":"pub fn describe_domain_nodes(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.describe_domain_nodes\naws_api/opensearch describe_domain_nodes","url":"aws_api/opensearch.html#describe_domain_nodes"},{"doc":"aws_api/opensearch","title":"describe_domains","content":"pub fn describe_domains(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.describe_domains\naws_api/opensearch describe_domains","url":"aws_api/opensearch.html#describe_domains"},{"doc":"aws_api/opensearch","title":"describe_dry_run_progress","content":"pub fn describe_dry_run_progress(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.describe_dry_run_progress\naws_api/opensearch describe_dry_run_progress","url":"aws_api/opensearch.html#describe_dry_run_progress"},{"doc":"aws_api/opensearch","title":"describe_inbound_connections","content":"pub fn describe_inbound_connections(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.describe_inbound_connections\naws_api/opensearch describe_inbound_connections","url":"aws_api/opensearch.html#describe_inbound_connections"},{"doc":"aws_api/opensearch","title":"describe_instance_type_limits","content":"pub fn describe_instance_type_limits(\n  client: Client,\n  engine_version: String,\n  instance_type: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.describe_instance_type_limits\naws_api/opensearch describe_instance_type_limits","url":"aws_api/opensearch.html#describe_instance_type_limits"},{"doc":"aws_api/opensearch","title":"describe_outbound_connections","content":"pub fn describe_outbound_connections(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.describe_outbound_connections\naws_api/opensearch describe_outbound_connections","url":"aws_api/opensearch.html#describe_outbound_connections"},{"doc":"aws_api/opensearch","title":"describe_packages","content":"pub fn describe_packages(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.describe_packages\naws_api/opensearch describe_packages","url":"aws_api/opensearch.html#describe_packages"},{"doc":"aws_api/opensearch","title":"describe_reserved_instance_offerings","content":"pub fn describe_reserved_instance_offerings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.describe_reserved_instance_offerings\naws_api/opensearch describe_reserved_instance_offerings","url":"aws_api/opensearch.html#describe_reserved_instance_offerings"},{"doc":"aws_api/opensearch","title":"describe_reserved_instances","content":"pub fn describe_reserved_instances(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.describe_reserved_instances\naws_api/opensearch describe_reserved_instances","url":"aws_api/opensearch.html#describe_reserved_instances"},{"doc":"aws_api/opensearch","title":"describe_vpc_endpoints","content":"pub fn describe_vpc_endpoints(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.describe_vpc_endpoints\naws_api/opensearch describe_vpc_endpoints","url":"aws_api/opensearch.html#describe_vpc_endpoints"},{"doc":"aws_api/opensearch","title":"dissociate_package","content":"pub fn dissociate_package(\n  client: Client,\n  package_id: String,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.dissociate_package\naws_api/opensearch dissociate_package","url":"aws_api/opensearch.html#dissociate_package"},{"doc":"aws_api/opensearch","title":"get_compatible_versions","content":"pub fn get_compatible_versions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.get_compatible_versions\naws_api/opensearch get_compatible_versions","url":"aws_api/opensearch.html#get_compatible_versions"},{"doc":"aws_api/opensearch","title":"get_data_source","content":"pub fn get_data_source(\n  client: Client,\n  domain_name: String,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.get_data_source\naws_api/opensearch get_data_source","url":"aws_api/opensearch.html#get_data_source"},{"doc":"aws_api/opensearch","title":"get_domain_maintenance_status","content":"pub fn get_domain_maintenance_status(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.get_domain_maintenance_status\naws_api/opensearch get_domain_maintenance_status","url":"aws_api/opensearch.html#get_domain_maintenance_status"},{"doc":"aws_api/opensearch","title":"get_package_version_history","content":"pub fn get_package_version_history(\n  client: Client,\n  package_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.get_package_version_history\naws_api/opensearch get_package_version_history","url":"aws_api/opensearch.html#get_package_version_history"},{"doc":"aws_api/opensearch","title":"get_upgrade_history","content":"pub fn get_upgrade_history(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.get_upgrade_history\naws_api/opensearch get_upgrade_history","url":"aws_api/opensearch.html#get_upgrade_history"},{"doc":"aws_api/opensearch","title":"get_upgrade_status","content":"pub fn get_upgrade_status(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.get_upgrade_status\naws_api/opensearch get_upgrade_status","url":"aws_api/opensearch.html#get_upgrade_status"},{"doc":"aws_api/opensearch","title":"list_data_sources","content":"pub fn list_data_sources(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.list_data_sources\naws_api/opensearch list_data_sources","url":"aws_api/opensearch.html#list_data_sources"},{"doc":"aws_api/opensearch","title":"list_domain_maintenances","content":"pub fn list_domain_maintenances(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.list_domain_maintenances\naws_api/opensearch list_domain_maintenances","url":"aws_api/opensearch.html#list_domain_maintenances"},{"doc":"aws_api/opensearch","title":"list_domain_names","content":"pub fn list_domain_names(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.list_domain_names\naws_api/opensearch list_domain_names","url":"aws_api/opensearch.html#list_domain_names"},{"doc":"aws_api/opensearch","title":"list_domains_for_package","content":"pub fn list_domains_for_package(\n  client: Client,\n  package_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.list_domains_for_package\naws_api/opensearch list_domains_for_package","url":"aws_api/opensearch.html#list_domains_for_package"},{"doc":"aws_api/opensearch","title":"list_instance_type_details","content":"pub fn list_instance_type_details(\n  client: Client,\n  engine_version: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.list_instance_type_details\naws_api/opensearch list_instance_type_details","url":"aws_api/opensearch.html#list_instance_type_details"},{"doc":"aws_api/opensearch","title":"list_packages_for_domain","content":"pub fn list_packages_for_domain(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.list_packages_for_domain\naws_api/opensearch list_packages_for_domain","url":"aws_api/opensearch.html#list_packages_for_domain"},{"doc":"aws_api/opensearch","title":"list_scheduled_actions","content":"pub fn list_scheduled_actions(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.list_scheduled_actions\naws_api/opensearch list_scheduled_actions","url":"aws_api/opensearch.html#list_scheduled_actions"},{"doc":"aws_api/opensearch","title":"list_tags","content":"pub fn list_tags(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.list_tags\naws_api/opensearch list_tags","url":"aws_api/opensearch.html#list_tags"},{"doc":"aws_api/opensearch","title":"list_versions","content":"pub fn list_versions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.list_versions\naws_api/opensearch list_versions","url":"aws_api/opensearch.html#list_versions"},{"doc":"aws_api/opensearch","title":"list_vpc_endpoint_access","content":"pub fn list_vpc_endpoint_access(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.list_vpc_endpoint_access\naws_api/opensearch list_vpc_endpoint_access","url":"aws_api/opensearch.html#list_vpc_endpoint_access"},{"doc":"aws_api/opensearch","title":"list_vpc_endpoints","content":"pub fn list_vpc_endpoints(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.list_vpc_endpoints\naws_api/opensearch list_vpc_endpoints","url":"aws_api/opensearch.html#list_vpc_endpoints"},{"doc":"aws_api/opensearch","title":"list_vpc_endpoints_for_domain","content":"pub fn list_vpc_endpoints_for_domain(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.list_vpc_endpoints_for_domain\naws_api/opensearch list_vpc_endpoints_for_domain","url":"aws_api/opensearch.html#list_vpc_endpoints_for_domain"},{"doc":"aws_api/opensearch","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/opensearch.new\naws_api/opensearch new","url":"aws_api/opensearch.html#new"},{"doc":"aws_api/opensearch","title":"purchase_reserved_instance_offering","content":"pub fn purchase_reserved_instance_offering(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.purchase_reserved_instance_offering\naws_api/opensearch purchase_reserved_instance_offering","url":"aws_api/opensearch.html#purchase_reserved_instance_offering"},{"doc":"aws_api/opensearch","title":"reject_inbound_connection","content":"pub fn reject_inbound_connection(\n  client: Client,\n  connection_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.reject_inbound_connection\naws_api/opensearch reject_inbound_connection","url":"aws_api/opensearch.html#reject_inbound_connection"},{"doc":"aws_api/opensearch","title":"remove_tags","content":"pub fn remove_tags(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.remove_tags\naws_api/opensearch remove_tags","url":"aws_api/opensearch.html#remove_tags"},{"doc":"aws_api/opensearch","title":"revoke_vpc_endpoint_access","content":"pub fn revoke_vpc_endpoint_access(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.revoke_vpc_endpoint_access\naws_api/opensearch revoke_vpc_endpoint_access","url":"aws_api/opensearch.html#revoke_vpc_endpoint_access"},{"doc":"aws_api/opensearch","title":"start_domain_maintenance","content":"pub fn start_domain_maintenance(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.start_domain_maintenance\naws_api/opensearch start_domain_maintenance","url":"aws_api/opensearch.html#start_domain_maintenance"},{"doc":"aws_api/opensearch","title":"start_service_software_update","content":"pub fn start_service_software_update(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.start_service_software_update\naws_api/opensearch start_service_software_update","url":"aws_api/opensearch.html#start_service_software_update"},{"doc":"aws_api/opensearch","title":"update_data_source","content":"pub fn update_data_source(\n  client: Client,\n  domain_name: String,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.update_data_source\naws_api/opensearch update_data_source","url":"aws_api/opensearch.html#update_data_source"},{"doc":"aws_api/opensearch","title":"update_domain_config","content":"pub fn update_domain_config(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.update_domain_config\naws_api/opensearch update_domain_config","url":"aws_api/opensearch.html#update_domain_config"},{"doc":"aws_api/opensearch","title":"update_package","content":"pub fn update_package(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.update_package\naws_api/opensearch update_package","url":"aws_api/opensearch.html#update_package"},{"doc":"aws_api/opensearch","title":"update_scheduled_action","content":"pub fn update_scheduled_action(\n  client: Client,\n  domain_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.update_scheduled_action\naws_api/opensearch update_scheduled_action","url":"aws_api/opensearch.html#update_scheduled_action"},{"doc":"aws_api/opensearch","title":"update_vpc_endpoint","content":"pub fn update_vpc_endpoint(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.update_vpc_endpoint\naws_api/opensearch update_vpc_endpoint","url":"aws_api/opensearch.html#update_vpc_endpoint"},{"doc":"aws_api/opensearch","title":"upgrade_domain","content":"pub fn upgrade_domain(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearch.upgrade_domain\naws_api/opensearch upgrade_domain","url":"aws_api/opensearch.html#upgrade_domain"},{"doc":"aws_api/opensearch","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/opensearch.with_custom_endpoint\naws_api/opensearch with_custom_endpoint","url":"aws_api/opensearch.html#with_custom_endpoint"},{"doc":"aws_api/opensearch","title":"aws_api/opensearch","content":"","url":"aws_api/opensearch.html"},{"doc":"aws_api/opensearchserverless","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/opensearchserverless.Client\naws_api/opensearchserverless Client","url":"aws_api/opensearchserverless.html#Client"},{"doc":"aws_api/opensearchserverless","title":"batch_get_collection","content":"pub fn batch_get_collection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearchserverless.batch_get_collection\naws_api/opensearchserverless batch_get_collection","url":"aws_api/opensearchserverless.html#batch_get_collection"},{"doc":"aws_api/opensearchserverless","title":"batch_get_effective_lifecycle_policy","content":"pub fn batch_get_effective_lifecycle_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearchserverless.batch_get_effective_lifecycle_policy\naws_api/opensearchserverless batch_get_effective_lifecycle_policy","url":"aws_api/opensearchserverless.html#batch_get_effective_lifecycle_policy"},{"doc":"aws_api/opensearchserverless","title":"batch_get_lifecycle_policy","content":"pub fn batch_get_lifecycle_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearchserverless.batch_get_lifecycle_policy\naws_api/opensearchserverless batch_get_lifecycle_policy","url":"aws_api/opensearchserverless.html#batch_get_lifecycle_policy"},{"doc":"aws_api/opensearchserverless","title":"batch_get_vpc_endpoint","content":"pub fn batch_get_vpc_endpoint(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearchserverless.batch_get_vpc_endpoint\naws_api/opensearchserverless batch_get_vpc_endpoint","url":"aws_api/opensearchserverless.html#batch_get_vpc_endpoint"},{"doc":"aws_api/opensearchserverless","title":"create_lifecycle_policy","content":"pub fn create_lifecycle_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearchserverless.create_lifecycle_policy\naws_api/opensearchserverless create_lifecycle_policy","url":"aws_api/opensearchserverless.html#create_lifecycle_policy"},{"doc":"aws_api/opensearchserverless","title":"create_security_policy","content":"pub fn create_security_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearchserverless.create_security_policy\naws_api/opensearchserverless create_security_policy","url":"aws_api/opensearchserverless.html#create_security_policy"},{"doc":"aws_api/opensearchserverless","title":"get_account_settings","content":"pub fn get_account_settings(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearchserverless.get_account_settings\naws_api/opensearchserverless get_account_settings","url":"aws_api/opensearchserverless.html#get_account_settings"},{"doc":"aws_api/opensearchserverless","title":"get_policies_stats","content":"pub fn get_policies_stats(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearchserverless.get_policies_stats\naws_api/opensearchserverless get_policies_stats","url":"aws_api/opensearchserverless.html#get_policies_stats"},{"doc":"aws_api/opensearchserverless","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearchserverless.list_tags_for_resource\naws_api/opensearchserverless list_tags_for_resource","url":"aws_api/opensearchserverless.html#list_tags_for_resource"},{"doc":"aws_api/opensearchserverless","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/opensearchserverless.new\naws_api/opensearchserverless new","url":"aws_api/opensearchserverless.html#new"},{"doc":"aws_api/opensearchserverless","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearchserverless.tag_resource\naws_api/opensearchserverless tag_resource","url":"aws_api/opensearchserverless.html#tag_resource"},{"doc":"aws_api/opensearchserverless","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearchserverless.untag_resource\naws_api/opensearchserverless untag_resource","url":"aws_api/opensearchserverless.html#untag_resource"},{"doc":"aws_api/opensearchserverless","title":"update_account_settings","content":"pub fn update_account_settings(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearchserverless.update_account_settings\naws_api/opensearchserverless update_account_settings","url":"aws_api/opensearchserverless.html#update_account_settings"},{"doc":"aws_api/opensearchserverless","title":"update_vpc_endpoint","content":"pub fn update_vpc_endpoint(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opensearchserverless.update_vpc_endpoint\naws_api/opensearchserverless update_vpc_endpoint","url":"aws_api/opensearchserverless.html#update_vpc_endpoint"},{"doc":"aws_api/opensearchserverless","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/opensearchserverless.with_custom_endpoint\naws_api/opensearchserverless with_custom_endpoint","url":"aws_api/opensearchserverless.html#with_custom_endpoint"},{"doc":"aws_api/opensearchserverless","title":"aws_api/opensearchserverless","content":"","url":"aws_api/opensearchserverless.html"},{"doc":"aws_api/opsworks","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/opsworks.Client\naws_api/opsworks Client","url":"aws_api/opsworks.html#Client"},{"doc":"aws_api/opsworks","title":"assign_instance","content":"pub fn assign_instance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.assign_instance\naws_api/opsworks assign_instance","url":"aws_api/opsworks.html#assign_instance"},{"doc":"aws_api/opsworks","title":"assign_volume","content":"pub fn assign_volume(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.assign_volume\naws_api/opsworks assign_volume","url":"aws_api/opsworks.html#assign_volume"},{"doc":"aws_api/opsworks","title":"associate_elastic_ip","content":"pub fn associate_elastic_ip(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.associate_elastic_ip\naws_api/opsworks associate_elastic_ip","url":"aws_api/opsworks.html#associate_elastic_ip"},{"doc":"aws_api/opsworks","title":"attach_elastic_load_balancer","content":"pub fn attach_elastic_load_balancer(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.attach_elastic_load_balancer\naws_api/opsworks attach_elastic_load_balancer","url":"aws_api/opsworks.html#attach_elastic_load_balancer"},{"doc":"aws_api/opsworks","title":"clone_stack","content":"pub fn clone_stack(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.clone_stack\naws_api/opsworks clone_stack","url":"aws_api/opsworks.html#clone_stack"},{"doc":"aws_api/opsworks","title":"create_app","content":"pub fn create_app(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.create_app\naws_api/opsworks create_app","url":"aws_api/opsworks.html#create_app"},{"doc":"aws_api/opsworks","title":"create_deployment","content":"pub fn create_deployment(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.create_deployment\naws_api/opsworks create_deployment","url":"aws_api/opsworks.html#create_deployment"},{"doc":"aws_api/opsworks","title":"create_instance","content":"pub fn create_instance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.create_instance\naws_api/opsworks create_instance","url":"aws_api/opsworks.html#create_instance"},{"doc":"aws_api/opsworks","title":"create_layer","content":"pub fn create_layer(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.create_layer\naws_api/opsworks create_layer","url":"aws_api/opsworks.html#create_layer"},{"doc":"aws_api/opsworks","title":"create_stack","content":"pub fn create_stack(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.create_stack\naws_api/opsworks create_stack","url":"aws_api/opsworks.html#create_stack"},{"doc":"aws_api/opsworks","title":"create_user_profile","content":"pub fn create_user_profile(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.create_user_profile\naws_api/opsworks create_user_profile","url":"aws_api/opsworks.html#create_user_profile"},{"doc":"aws_api/opsworks","title":"delete_app","content":"pub fn delete_app(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.delete_app\naws_api/opsworks delete_app","url":"aws_api/opsworks.html#delete_app"},{"doc":"aws_api/opsworks","title":"delete_instance","content":"pub fn delete_instance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.delete_instance\naws_api/opsworks delete_instance","url":"aws_api/opsworks.html#delete_instance"},{"doc":"aws_api/opsworks","title":"delete_layer","content":"pub fn delete_layer(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.delete_layer\naws_api/opsworks delete_layer","url":"aws_api/opsworks.html#delete_layer"},{"doc":"aws_api/opsworks","title":"delete_stack","content":"pub fn delete_stack(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.delete_stack\naws_api/opsworks delete_stack","url":"aws_api/opsworks.html#delete_stack"},{"doc":"aws_api/opsworks","title":"delete_user_profile","content":"pub fn delete_user_profile(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.delete_user_profile\naws_api/opsworks delete_user_profile","url":"aws_api/opsworks.html#delete_user_profile"},{"doc":"aws_api/opsworks","title":"deregister_ecs_cluster","content":"pub fn deregister_ecs_cluster(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.deregister_ecs_cluster\naws_api/opsworks deregister_ecs_cluster","url":"aws_api/opsworks.html#deregister_ecs_cluster"},{"doc":"aws_api/opsworks","title":"deregister_elastic_ip","content":"pub fn deregister_elastic_ip(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.deregister_elastic_ip\naws_api/opsworks deregister_elastic_ip","url":"aws_api/opsworks.html#deregister_elastic_ip"},{"doc":"aws_api/opsworks","title":"deregister_instance","content":"pub fn deregister_instance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.deregister_instance\naws_api/opsworks deregister_instance","url":"aws_api/opsworks.html#deregister_instance"},{"doc":"aws_api/opsworks","title":"deregister_rds_db_instance","content":"pub fn deregister_rds_db_instance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.deregister_rds_db_instance\naws_api/opsworks deregister_rds_db_instance","url":"aws_api/opsworks.html#deregister_rds_db_instance"},{"doc":"aws_api/opsworks","title":"deregister_volume","content":"pub fn deregister_volume(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.deregister_volume\naws_api/opsworks deregister_volume","url":"aws_api/opsworks.html#deregister_volume"},{"doc":"aws_api/opsworks","title":"describe_agent_versions","content":"pub fn describe_agent_versions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.describe_agent_versions\naws_api/opsworks describe_agent_versions","url":"aws_api/opsworks.html#describe_agent_versions"},{"doc":"aws_api/opsworks","title":"describe_apps","content":"pub fn describe_apps(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.describe_apps\naws_api/opsworks describe_apps","url":"aws_api/opsworks.html#describe_apps"},{"doc":"aws_api/opsworks","title":"describe_commands","content":"pub fn describe_commands(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.describe_commands\naws_api/opsworks describe_commands","url":"aws_api/opsworks.html#describe_commands"},{"doc":"aws_api/opsworks","title":"describe_deployments","content":"pub fn describe_deployments(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.describe_deployments\naws_api/opsworks describe_deployments","url":"aws_api/opsworks.html#describe_deployments"},{"doc":"aws_api/opsworks","title":"describe_ecs_clusters","content":"pub fn describe_ecs_clusters(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.describe_ecs_clusters\naws_api/opsworks describe_ecs_clusters","url":"aws_api/opsworks.html#describe_ecs_clusters"},{"doc":"aws_api/opsworks","title":"describe_elastic_ips","content":"pub fn describe_elastic_ips(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.describe_elastic_ips\naws_api/opsworks describe_elastic_ips","url":"aws_api/opsworks.html#describe_elastic_ips"},{"doc":"aws_api/opsworks","title":"describe_elastic_load_balancers","content":"pub fn describe_elastic_load_balancers(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.describe_elastic_load_balancers\naws_api/opsworks describe_elastic_load_balancers","url":"aws_api/opsworks.html#describe_elastic_load_balancers"},{"doc":"aws_api/opsworks","title":"describe_instances","content":"pub fn describe_instances(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.describe_instances\naws_api/opsworks describe_instances","url":"aws_api/opsworks.html#describe_instances"},{"doc":"aws_api/opsworks","title":"describe_layers","content":"pub fn describe_layers(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.describe_layers\naws_api/opsworks describe_layers","url":"aws_api/opsworks.html#describe_layers"},{"doc":"aws_api/opsworks","title":"describe_load_based_auto_scaling","content":"pub fn describe_load_based_auto_scaling(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.describe_load_based_auto_scaling\naws_api/opsworks describe_load_based_auto_scaling","url":"aws_api/opsworks.html#describe_load_based_auto_scaling"},{"doc":"aws_api/opsworks","title":"describe_my_user_profile","content":"pub fn describe_my_user_profile(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.describe_my_user_profile\naws_api/opsworks describe_my_user_profile","url":"aws_api/opsworks.html#describe_my_user_profile"},{"doc":"aws_api/opsworks","title":"describe_operating_systems","content":"pub fn describe_operating_systems(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.describe_operating_systems\naws_api/opsworks describe_operating_systems","url":"aws_api/opsworks.html#describe_operating_systems"},{"doc":"aws_api/opsworks","title":"describe_permissions","content":"pub fn describe_permissions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.describe_permissions\naws_api/opsworks describe_permissions","url":"aws_api/opsworks.html#describe_permissions"},{"doc":"aws_api/opsworks","title":"describe_raid_arrays","content":"pub fn describe_raid_arrays(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.describe_raid_arrays\naws_api/opsworks describe_raid_arrays","url":"aws_api/opsworks.html#describe_raid_arrays"},{"doc":"aws_api/opsworks","title":"describe_rds_db_instances","content":"pub fn describe_rds_db_instances(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.describe_rds_db_instances\naws_api/opsworks describe_rds_db_instances","url":"aws_api/opsworks.html#describe_rds_db_instances"},{"doc":"aws_api/opsworks","title":"describe_service_errors","content":"pub fn describe_service_errors(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.describe_service_errors\naws_api/opsworks describe_service_errors","url":"aws_api/opsworks.html#describe_service_errors"},{"doc":"aws_api/opsworks","title":"describe_stack_provisioning_parameters","content":"pub fn describe_stack_provisioning_parameters(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.describe_stack_provisioning_parameters\naws_api/opsworks describe_stack_provisioning_parameters","url":"aws_api/opsworks.html#describe_stack_provisioning_parameters"},{"doc":"aws_api/opsworks","title":"describe_stack_summary","content":"pub fn describe_stack_summary(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.describe_stack_summary\naws_api/opsworks describe_stack_summary","url":"aws_api/opsworks.html#describe_stack_summary"},{"doc":"aws_api/opsworks","title":"describe_stacks","content":"pub fn describe_stacks(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.describe_stacks\naws_api/opsworks describe_stacks","url":"aws_api/opsworks.html#describe_stacks"},{"doc":"aws_api/opsworks","title":"describe_time_based_auto_scaling","content":"pub fn describe_time_based_auto_scaling(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.describe_time_based_auto_scaling\naws_api/opsworks describe_time_based_auto_scaling","url":"aws_api/opsworks.html#describe_time_based_auto_scaling"},{"doc":"aws_api/opsworks","title":"describe_user_profiles","content":"pub fn describe_user_profiles(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.describe_user_profiles\naws_api/opsworks describe_user_profiles","url":"aws_api/opsworks.html#describe_user_profiles"},{"doc":"aws_api/opsworks","title":"describe_volumes","content":"pub fn describe_volumes(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.describe_volumes\naws_api/opsworks describe_volumes","url":"aws_api/opsworks.html#describe_volumes"},{"doc":"aws_api/opsworks","title":"detach_elastic_load_balancer","content":"pub fn detach_elastic_load_balancer(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.detach_elastic_load_balancer\naws_api/opsworks detach_elastic_load_balancer","url":"aws_api/opsworks.html#detach_elastic_load_balancer"},{"doc":"aws_api/opsworks","title":"disassociate_elastic_ip","content":"pub fn disassociate_elastic_ip(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.disassociate_elastic_ip\naws_api/opsworks disassociate_elastic_ip","url":"aws_api/opsworks.html#disassociate_elastic_ip"},{"doc":"aws_api/opsworks","title":"get_hostname_suggestion","content":"pub fn get_hostname_suggestion(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.get_hostname_suggestion\naws_api/opsworks get_hostname_suggestion","url":"aws_api/opsworks.html#get_hostname_suggestion"},{"doc":"aws_api/opsworks","title":"grant_access","content":"pub fn grant_access(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.grant_access\naws_api/opsworks grant_access","url":"aws_api/opsworks.html#grant_access"},{"doc":"aws_api/opsworks","title":"list_tags","content":"pub fn list_tags(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.list_tags\naws_api/opsworks list_tags","url":"aws_api/opsworks.html#list_tags"},{"doc":"aws_api/opsworks","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/opsworks.new\naws_api/opsworks new","url":"aws_api/opsworks.html#new"},{"doc":"aws_api/opsworks","title":"reboot_instance","content":"pub fn reboot_instance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.reboot_instance\naws_api/opsworks reboot_instance","url":"aws_api/opsworks.html#reboot_instance"},{"doc":"aws_api/opsworks","title":"register_ecs_cluster","content":"pub fn register_ecs_cluster(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.register_ecs_cluster\naws_api/opsworks register_ecs_cluster","url":"aws_api/opsworks.html#register_ecs_cluster"},{"doc":"aws_api/opsworks","title":"register_elastic_ip","content":"pub fn register_elastic_ip(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.register_elastic_ip\naws_api/opsworks register_elastic_ip","url":"aws_api/opsworks.html#register_elastic_ip"},{"doc":"aws_api/opsworks","title":"register_instance","content":"pub fn register_instance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.register_instance\naws_api/opsworks register_instance","url":"aws_api/opsworks.html#register_instance"},{"doc":"aws_api/opsworks","title":"register_rds_db_instance","content":"pub fn register_rds_db_instance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.register_rds_db_instance\naws_api/opsworks register_rds_db_instance","url":"aws_api/opsworks.html#register_rds_db_instance"},{"doc":"aws_api/opsworks","title":"register_volume","content":"pub fn register_volume(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.register_volume\naws_api/opsworks register_volume","url":"aws_api/opsworks.html#register_volume"},{"doc":"aws_api/opsworks","title":"set_load_based_auto_scaling","content":"pub fn set_load_based_auto_scaling(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.set_load_based_auto_scaling\naws_api/opsworks set_load_based_auto_scaling","url":"aws_api/opsworks.html#set_load_based_auto_scaling"},{"doc":"aws_api/opsworks","title":"set_permission","content":"pub fn set_permission(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.set_permission\naws_api/opsworks set_permission","url":"aws_api/opsworks.html#set_permission"},{"doc":"aws_api/opsworks","title":"set_time_based_auto_scaling","content":"pub fn set_time_based_auto_scaling(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.set_time_based_auto_scaling\naws_api/opsworks set_time_based_auto_scaling","url":"aws_api/opsworks.html#set_time_based_auto_scaling"},{"doc":"aws_api/opsworks","title":"start_instance","content":"pub fn start_instance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.start_instance\naws_api/opsworks start_instance","url":"aws_api/opsworks.html#start_instance"},{"doc":"aws_api/opsworks","title":"start_stack","content":"pub fn start_stack(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.start_stack\naws_api/opsworks start_stack","url":"aws_api/opsworks.html#start_stack"},{"doc":"aws_api/opsworks","title":"stop_instance","content":"pub fn stop_instance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.stop_instance\naws_api/opsworks stop_instance","url":"aws_api/opsworks.html#stop_instance"},{"doc":"aws_api/opsworks","title":"stop_stack","content":"pub fn stop_stack(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.stop_stack\naws_api/opsworks stop_stack","url":"aws_api/opsworks.html#stop_stack"},{"doc":"aws_api/opsworks","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.tag_resource\naws_api/opsworks tag_resource","url":"aws_api/opsworks.html#tag_resource"},{"doc":"aws_api/opsworks","title":"unassign_instance","content":"pub fn unassign_instance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.unassign_instance\naws_api/opsworks unassign_instance","url":"aws_api/opsworks.html#unassign_instance"},{"doc":"aws_api/opsworks","title":"unassign_volume","content":"pub fn unassign_volume(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.unassign_volume\naws_api/opsworks unassign_volume","url":"aws_api/opsworks.html#unassign_volume"},{"doc":"aws_api/opsworks","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.untag_resource\naws_api/opsworks untag_resource","url":"aws_api/opsworks.html#untag_resource"},{"doc":"aws_api/opsworks","title":"update_app","content":"pub fn update_app(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.update_app\naws_api/opsworks update_app","url":"aws_api/opsworks.html#update_app"},{"doc":"aws_api/opsworks","title":"update_elastic_ip","content":"pub fn update_elastic_ip(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.update_elastic_ip\naws_api/opsworks update_elastic_ip","url":"aws_api/opsworks.html#update_elastic_ip"},{"doc":"aws_api/opsworks","title":"update_instance","content":"pub fn update_instance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.update_instance\naws_api/opsworks update_instance","url":"aws_api/opsworks.html#update_instance"},{"doc":"aws_api/opsworks","title":"update_layer","content":"pub fn update_layer(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.update_layer\naws_api/opsworks update_layer","url":"aws_api/opsworks.html#update_layer"},{"doc":"aws_api/opsworks","title":"update_my_user_profile","content":"pub fn update_my_user_profile(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.update_my_user_profile\naws_api/opsworks update_my_user_profile","url":"aws_api/opsworks.html#update_my_user_profile"},{"doc":"aws_api/opsworks","title":"update_rds_db_instance","content":"pub fn update_rds_db_instance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.update_rds_db_instance\naws_api/opsworks update_rds_db_instance","url":"aws_api/opsworks.html#update_rds_db_instance"},{"doc":"aws_api/opsworks","title":"update_stack","content":"pub fn update_stack(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.update_stack\naws_api/opsworks update_stack","url":"aws_api/opsworks.html#update_stack"},{"doc":"aws_api/opsworks","title":"update_user_profile","content":"pub fn update_user_profile(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.update_user_profile\naws_api/opsworks update_user_profile","url":"aws_api/opsworks.html#update_user_profile"},{"doc":"aws_api/opsworks","title":"update_volume","content":"pub fn update_volume(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworks.update_volume\naws_api/opsworks update_volume","url":"aws_api/opsworks.html#update_volume"},{"doc":"aws_api/opsworks","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/opsworks.with_custom_endpoint\naws_api/opsworks with_custom_endpoint","url":"aws_api/opsworks.html#with_custom_endpoint"},{"doc":"aws_api/opsworks","title":"aws_api/opsworks","content":"","url":"aws_api/opsworks.html"},{"doc":"aws_api/opsworkscm","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/opsworkscm.Client\naws_api/opsworkscm Client","url":"aws_api/opsworkscm.html#Client"},{"doc":"aws_api/opsworkscm","title":"associate_node","content":"pub fn associate_node(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworkscm.associate_node\naws_api/opsworkscm associate_node","url":"aws_api/opsworkscm.html#associate_node"},{"doc":"aws_api/opsworkscm","title":"create_backup","content":"pub fn create_backup(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworkscm.create_backup\naws_api/opsworkscm create_backup","url":"aws_api/opsworkscm.html#create_backup"},{"doc":"aws_api/opsworkscm","title":"create_server","content":"pub fn create_server(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworkscm.create_server\naws_api/opsworkscm create_server","url":"aws_api/opsworkscm.html#create_server"},{"doc":"aws_api/opsworkscm","title":"delete_backup","content":"pub fn delete_backup(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworkscm.delete_backup\naws_api/opsworkscm delete_backup","url":"aws_api/opsworkscm.html#delete_backup"},{"doc":"aws_api/opsworkscm","title":"delete_server","content":"pub fn delete_server(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworkscm.delete_server\naws_api/opsworkscm delete_server","url":"aws_api/opsworkscm.html#delete_server"},{"doc":"aws_api/opsworkscm","title":"describe_account_attributes","content":"pub fn describe_account_attributes(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworkscm.describe_account_attributes\naws_api/opsworkscm describe_account_attributes","url":"aws_api/opsworkscm.html#describe_account_attributes"},{"doc":"aws_api/opsworkscm","title":"describe_backups","content":"pub fn describe_backups(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworkscm.describe_backups\naws_api/opsworkscm describe_backups","url":"aws_api/opsworkscm.html#describe_backups"},{"doc":"aws_api/opsworkscm","title":"describe_events","content":"pub fn describe_events(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworkscm.describe_events\naws_api/opsworkscm describe_events","url":"aws_api/opsworkscm.html#describe_events"},{"doc":"aws_api/opsworkscm","title":"describe_node_association_status","content":"pub fn describe_node_association_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworkscm.describe_node_association_status\naws_api/opsworkscm describe_node_association_status","url":"aws_api/opsworkscm.html#describe_node_association_status"},{"doc":"aws_api/opsworkscm","title":"describe_servers","content":"pub fn describe_servers(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworkscm.describe_servers\naws_api/opsworkscm describe_servers","url":"aws_api/opsworkscm.html#describe_servers"},{"doc":"aws_api/opsworkscm","title":"disassociate_node","content":"pub fn disassociate_node(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworkscm.disassociate_node\naws_api/opsworkscm disassociate_node","url":"aws_api/opsworkscm.html#disassociate_node"},{"doc":"aws_api/opsworkscm","title":"export_server_engine_attribute","content":"pub fn export_server_engine_attribute(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworkscm.export_server_engine_attribute\naws_api/opsworkscm export_server_engine_attribute","url":"aws_api/opsworkscm.html#export_server_engine_attribute"},{"doc":"aws_api/opsworkscm","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworkscm.list_tags_for_resource\naws_api/opsworkscm list_tags_for_resource","url":"aws_api/opsworkscm.html#list_tags_for_resource"},{"doc":"aws_api/opsworkscm","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/opsworkscm.new\naws_api/opsworkscm new","url":"aws_api/opsworkscm.html#new"},{"doc":"aws_api/opsworkscm","title":"restore_server","content":"pub fn restore_server(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworkscm.restore_server\naws_api/opsworkscm restore_server","url":"aws_api/opsworkscm.html#restore_server"},{"doc":"aws_api/opsworkscm","title":"start_maintenance","content":"pub fn start_maintenance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworkscm.start_maintenance\naws_api/opsworkscm start_maintenance","url":"aws_api/opsworkscm.html#start_maintenance"},{"doc":"aws_api/opsworkscm","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworkscm.tag_resource\naws_api/opsworkscm tag_resource","url":"aws_api/opsworkscm.html#tag_resource"},{"doc":"aws_api/opsworkscm","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworkscm.untag_resource\naws_api/opsworkscm untag_resource","url":"aws_api/opsworkscm.html#untag_resource"},{"doc":"aws_api/opsworkscm","title":"update_server","content":"pub fn update_server(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworkscm.update_server\naws_api/opsworkscm update_server","url":"aws_api/opsworkscm.html#update_server"},{"doc":"aws_api/opsworkscm","title":"update_server_engine_attributes","content":"pub fn update_server_engine_attributes(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/opsworkscm.update_server_engine_attributes\naws_api/opsworkscm update_server_engine_attributes","url":"aws_api/opsworkscm.html#update_server_engine_attributes"},{"doc":"aws_api/opsworkscm","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/opsworkscm.with_custom_endpoint\naws_api/opsworkscm with_custom_endpoint","url":"aws_api/opsworkscm.html#with_custom_endpoint"},{"doc":"aws_api/opsworkscm","title":"aws_api/opsworkscm","content":"","url":"aws_api/opsworkscm.html"},{"doc":"aws_api/organizations","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/organizations.Client\naws_api/organizations Client","url":"aws_api/organizations.html#Client"},{"doc":"aws_api/organizations","title":"accept_handshake","content":"pub fn accept_handshake(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.accept_handshake\naws_api/organizations accept_handshake","url":"aws_api/organizations.html#accept_handshake"},{"doc":"aws_api/organizations","title":"attach_policy","content":"pub fn attach_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.attach_policy\naws_api/organizations attach_policy","url":"aws_api/organizations.html#attach_policy"},{"doc":"aws_api/organizations","title":"cancel_handshake","content":"pub fn cancel_handshake(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.cancel_handshake\naws_api/organizations cancel_handshake","url":"aws_api/organizations.html#cancel_handshake"},{"doc":"aws_api/organizations","title":"close_account","content":"pub fn close_account(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.close_account\naws_api/organizations close_account","url":"aws_api/organizations.html#close_account"},{"doc":"aws_api/organizations","title":"create_account","content":"pub fn create_account(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.create_account\naws_api/organizations create_account","url":"aws_api/organizations.html#create_account"},{"doc":"aws_api/organizations","title":"create_gov_cloud_account","content":"pub fn create_gov_cloud_account(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.create_gov_cloud_account\naws_api/organizations create_gov_cloud_account","url":"aws_api/organizations.html#create_gov_cloud_account"},{"doc":"aws_api/organizations","title":"create_organization","content":"pub fn create_organization(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.create_organization\naws_api/organizations create_organization","url":"aws_api/organizations.html#create_organization"},{"doc":"aws_api/organizations","title":"create_organizational_unit","content":"pub fn create_organizational_unit(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.create_organizational_unit\naws_api/organizations create_organizational_unit","url":"aws_api/organizations.html#create_organizational_unit"},{"doc":"aws_api/organizations","title":"create_policy","content":"pub fn create_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.create_policy\naws_api/organizations create_policy","url":"aws_api/organizations.html#create_policy"},{"doc":"aws_api/organizations","title":"decline_handshake","content":"pub fn decline_handshake(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.decline_handshake\naws_api/organizations decline_handshake","url":"aws_api/organizations.html#decline_handshake"},{"doc":"aws_api/organizations","title":"delete_organization","content":"pub fn delete_organization(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.delete_organization\naws_api/organizations delete_organization","url":"aws_api/organizations.html#delete_organization"},{"doc":"aws_api/organizations","title":"delete_organizational_unit","content":"pub fn delete_organizational_unit(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.delete_organizational_unit\naws_api/organizations delete_organizational_unit","url":"aws_api/organizations.html#delete_organizational_unit"},{"doc":"aws_api/organizations","title":"delete_policy","content":"pub fn delete_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.delete_policy\naws_api/organizations delete_policy","url":"aws_api/organizations.html#delete_policy"},{"doc":"aws_api/organizations","title":"delete_resource_policy","content":"pub fn delete_resource_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.delete_resource_policy\naws_api/organizations delete_resource_policy","url":"aws_api/organizations.html#delete_resource_policy"},{"doc":"aws_api/organizations","title":"deregister_delegated_administrator","content":"pub fn deregister_delegated_administrator(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.deregister_delegated_administrator\naws_api/organizations deregister_delegated_administrator","url":"aws_api/organizations.html#deregister_delegated_administrator"},{"doc":"aws_api/organizations","title":"describe_account","content":"pub fn describe_account(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.describe_account\naws_api/organizations describe_account","url":"aws_api/organizations.html#describe_account"},{"doc":"aws_api/organizations","title":"describe_create_account_status","content":"pub fn describe_create_account_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.describe_create_account_status\naws_api/organizations describe_create_account_status","url":"aws_api/organizations.html#describe_create_account_status"},{"doc":"aws_api/organizations","title":"describe_effective_policy","content":"pub fn describe_effective_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.describe_effective_policy\naws_api/organizations describe_effective_policy","url":"aws_api/organizations.html#describe_effective_policy"},{"doc":"aws_api/organizations","title":"describe_handshake","content":"pub fn describe_handshake(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.describe_handshake\naws_api/organizations describe_handshake","url":"aws_api/organizations.html#describe_handshake"},{"doc":"aws_api/organizations","title":"describe_organization","content":"pub fn describe_organization(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.describe_organization\naws_api/organizations describe_organization","url":"aws_api/organizations.html#describe_organization"},{"doc":"aws_api/organizations","title":"describe_organizational_unit","content":"pub fn describe_organizational_unit(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.describe_organizational_unit\naws_api/organizations describe_organizational_unit","url":"aws_api/organizations.html#describe_organizational_unit"},{"doc":"aws_api/organizations","title":"describe_policy","content":"pub fn describe_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.describe_policy\naws_api/organizations describe_policy","url":"aws_api/organizations.html#describe_policy"},{"doc":"aws_api/organizations","title":"describe_resource_policy","content":"pub fn describe_resource_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.describe_resource_policy\naws_api/organizations describe_resource_policy","url":"aws_api/organizations.html#describe_resource_policy"},{"doc":"aws_api/organizations","title":"detach_policy","content":"pub fn detach_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.detach_policy\naws_api/organizations detach_policy","url":"aws_api/organizations.html#detach_policy"},{"doc":"aws_api/organizations","title":"disable_aws_service_access","content":"pub fn disable_aws_service_access(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.disable_aws_service_access\naws_api/organizations disable_aws_service_access","url":"aws_api/organizations.html#disable_aws_service_access"},{"doc":"aws_api/organizations","title":"disable_policy_type","content":"pub fn disable_policy_type(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.disable_policy_type\naws_api/organizations disable_policy_type","url":"aws_api/organizations.html#disable_policy_type"},{"doc":"aws_api/organizations","title":"enable_all_features","content":"pub fn enable_all_features(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.enable_all_features\naws_api/organizations enable_all_features","url":"aws_api/organizations.html#enable_all_features"},{"doc":"aws_api/organizations","title":"enable_aws_service_access","content":"pub fn enable_aws_service_access(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.enable_aws_service_access\naws_api/organizations enable_aws_service_access","url":"aws_api/organizations.html#enable_aws_service_access"},{"doc":"aws_api/organizations","title":"enable_policy_type","content":"pub fn enable_policy_type(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.enable_policy_type\naws_api/organizations enable_policy_type","url":"aws_api/organizations.html#enable_policy_type"},{"doc":"aws_api/organizations","title":"invite_account_to_organization","content":"pub fn invite_account_to_organization(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.invite_account_to_organization\naws_api/organizations invite_account_to_organization","url":"aws_api/organizations.html#invite_account_to_organization"},{"doc":"aws_api/organizations","title":"leave_organization","content":"pub fn leave_organization(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.leave_organization\naws_api/organizations leave_organization","url":"aws_api/organizations.html#leave_organization"},{"doc":"aws_api/organizations","title":"list_accounts","content":"pub fn list_accounts(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.list_accounts\naws_api/organizations list_accounts","url":"aws_api/organizations.html#list_accounts"},{"doc":"aws_api/organizations","title":"list_accounts_for_parent","content":"pub fn list_accounts_for_parent(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.list_accounts_for_parent\naws_api/organizations list_accounts_for_parent","url":"aws_api/organizations.html#list_accounts_for_parent"},{"doc":"aws_api/organizations","title":"list_aws_service_access_for_organization","content":"pub fn list_aws_service_access_for_organization(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.list_aws_service_access_for_organization\naws_api/organizations list_aws_service_access_for_organization","url":"aws_api/organizations.html#list_aws_service_access_for_organization"},{"doc":"aws_api/organizations","title":"list_children","content":"pub fn list_children(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.list_children\naws_api/organizations list_children","url":"aws_api/organizations.html#list_children"},{"doc":"aws_api/organizations","title":"list_create_account_status","content":"pub fn list_create_account_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.list_create_account_status\naws_api/organizations list_create_account_status","url":"aws_api/organizations.html#list_create_account_status"},{"doc":"aws_api/organizations","title":"list_delegated_administrators","content":"pub fn list_delegated_administrators(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.list_delegated_administrators\naws_api/organizations list_delegated_administrators","url":"aws_api/organizations.html#list_delegated_administrators"},{"doc":"aws_api/organizations","title":"list_delegated_services_for_account","content":"pub fn list_delegated_services_for_account(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.list_delegated_services_for_account\naws_api/organizations list_delegated_services_for_account","url":"aws_api/organizations.html#list_delegated_services_for_account"},{"doc":"aws_api/organizations","title":"list_handshakes_for_account","content":"pub fn list_handshakes_for_account(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.list_handshakes_for_account\naws_api/organizations list_handshakes_for_account","url":"aws_api/organizations.html#list_handshakes_for_account"},{"doc":"aws_api/organizations","title":"list_handshakes_for_organization","content":"pub fn list_handshakes_for_organization(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.list_handshakes_for_organization\naws_api/organizations list_handshakes_for_organization","url":"aws_api/organizations.html#list_handshakes_for_organization"},{"doc":"aws_api/organizations","title":"list_organizational_units_for_parent","content":"pub fn list_organizational_units_for_parent(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.list_organizational_units_for_parent\naws_api/organizations list_organizational_units_for_parent","url":"aws_api/organizations.html#list_organizational_units_for_parent"},{"doc":"aws_api/organizations","title":"list_parents","content":"pub fn list_parents(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.list_parents\naws_api/organizations list_parents","url":"aws_api/organizations.html#list_parents"},{"doc":"aws_api/organizations","title":"list_policies","content":"pub fn list_policies(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.list_policies\naws_api/organizations list_policies","url":"aws_api/organizations.html#list_policies"},{"doc":"aws_api/organizations","title":"list_policies_for_target","content":"pub fn list_policies_for_target(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.list_policies_for_target\naws_api/organizations list_policies_for_target","url":"aws_api/organizations.html#list_policies_for_target"},{"doc":"aws_api/organizations","title":"list_roots","content":"pub fn list_roots(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.list_roots\naws_api/organizations list_roots","url":"aws_api/organizations.html#list_roots"},{"doc":"aws_api/organizations","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.list_tags_for_resource\naws_api/organizations list_tags_for_resource","url":"aws_api/organizations.html#list_tags_for_resource"},{"doc":"aws_api/organizations","title":"list_targets_for_policy","content":"pub fn list_targets_for_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.list_targets_for_policy\naws_api/organizations list_targets_for_policy","url":"aws_api/organizations.html#list_targets_for_policy"},{"doc":"aws_api/organizations","title":"move_account","content":"pub fn move_account(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.move_account\naws_api/organizations move_account","url":"aws_api/organizations.html#move_account"},{"doc":"aws_api/organizations","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/organizations.new\naws_api/organizations new","url":"aws_api/organizations.html#new"},{"doc":"aws_api/organizations","title":"put_resource_policy","content":"pub fn put_resource_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.put_resource_policy\naws_api/organizations put_resource_policy","url":"aws_api/organizations.html#put_resource_policy"},{"doc":"aws_api/organizations","title":"register_delegated_administrator","content":"pub fn register_delegated_administrator(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.register_delegated_administrator\naws_api/organizations register_delegated_administrator","url":"aws_api/organizations.html#register_delegated_administrator"},{"doc":"aws_api/organizations","title":"remove_account_from_organization","content":"pub fn remove_account_from_organization(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.remove_account_from_organization\naws_api/organizations remove_account_from_organization","url":"aws_api/organizations.html#remove_account_from_organization"},{"doc":"aws_api/organizations","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.tag_resource\naws_api/organizations tag_resource","url":"aws_api/organizations.html#tag_resource"},{"doc":"aws_api/organizations","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.untag_resource\naws_api/organizations untag_resource","url":"aws_api/organizations.html#untag_resource"},{"doc":"aws_api/organizations","title":"update_organizational_unit","content":"pub fn update_organizational_unit(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.update_organizational_unit\naws_api/organizations update_organizational_unit","url":"aws_api/organizations.html#update_organizational_unit"},{"doc":"aws_api/organizations","title":"update_policy","content":"pub fn update_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/organizations.update_policy\naws_api/organizations update_policy","url":"aws_api/organizations.html#update_policy"},{"doc":"aws_api/organizations","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/organizations.with_custom_endpoint\naws_api/organizations with_custom_endpoint","url":"aws_api/organizations.html#with_custom_endpoint"},{"doc":"aws_api/organizations","title":"aws_api/organizations","content":"","url":"aws_api/organizations.html"},{"doc":"aws_api/osis","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/osis.Client\naws_api/osis Client","url":"aws_api/osis.html#Client"},{"doc":"aws_api/osis","title":"create_pipeline","content":"pub fn create_pipeline(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/osis.create_pipeline\naws_api/osis create_pipeline","url":"aws_api/osis.html#create_pipeline"},{"doc":"aws_api/osis","title":"delete_pipeline","content":"pub fn delete_pipeline(\n  client: Client,\n  pipeline_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/osis.delete_pipeline\naws_api/osis delete_pipeline","url":"aws_api/osis.html#delete_pipeline"},{"doc":"aws_api/osis","title":"get_pipeline","content":"pub fn get_pipeline(\n  client: Client,\n  pipeline_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/osis.get_pipeline\naws_api/osis get_pipeline","url":"aws_api/osis.html#get_pipeline"},{"doc":"aws_api/osis","title":"get_pipeline_blueprint","content":"pub fn get_pipeline_blueprint(\n  client: Client,\n  blueprint_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/osis.get_pipeline_blueprint\naws_api/osis get_pipeline_blueprint","url":"aws_api/osis.html#get_pipeline_blueprint"},{"doc":"aws_api/osis","title":"get_pipeline_change_progress","content":"pub fn get_pipeline_change_progress(\n  client: Client,\n  pipeline_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/osis.get_pipeline_change_progress\naws_api/osis get_pipeline_change_progress","url":"aws_api/osis.html#get_pipeline_change_progress"},{"doc":"aws_api/osis","title":"list_pipeline_blueprints","content":"pub fn list_pipeline_blueprints(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/osis.list_pipeline_blueprints\naws_api/osis list_pipeline_blueprints","url":"aws_api/osis.html#list_pipeline_blueprints"},{"doc":"aws_api/osis","title":"list_pipelines","content":"pub fn list_pipelines(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/osis.list_pipelines\naws_api/osis list_pipelines","url":"aws_api/osis.html#list_pipelines"},{"doc":"aws_api/osis","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/osis.list_tags_for_resource\naws_api/osis list_tags_for_resource","url":"aws_api/osis.html#list_tags_for_resource"},{"doc":"aws_api/osis","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/osis.new\naws_api/osis new","url":"aws_api/osis.html#new"},{"doc":"aws_api/osis","title":"start_pipeline","content":"pub fn start_pipeline(\n  client: Client,\n  pipeline_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/osis.start_pipeline\naws_api/osis start_pipeline","url":"aws_api/osis.html#start_pipeline"},{"doc":"aws_api/osis","title":"stop_pipeline","content":"pub fn stop_pipeline(\n  client: Client,\n  pipeline_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/osis.stop_pipeline\naws_api/osis stop_pipeline","url":"aws_api/osis.html#stop_pipeline"},{"doc":"aws_api/osis","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/osis.tag_resource\naws_api/osis tag_resource","url":"aws_api/osis.html#tag_resource"},{"doc":"aws_api/osis","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/osis.untag_resource\naws_api/osis untag_resource","url":"aws_api/osis.html#untag_resource"},{"doc":"aws_api/osis","title":"update_pipeline","content":"pub fn update_pipeline(\n  client: Client,\n  pipeline_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/osis.update_pipeline\naws_api/osis update_pipeline","url":"aws_api/osis.html#update_pipeline"},{"doc":"aws_api/osis","title":"validate_pipeline","content":"pub fn validate_pipeline(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/osis.validate_pipeline\naws_api/osis validate_pipeline","url":"aws_api/osis.html#validate_pipeline"},{"doc":"aws_api/osis","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/osis.with_custom_endpoint\naws_api/osis with_custom_endpoint","url":"aws_api/osis.html#with_custom_endpoint"},{"doc":"aws_api/osis","title":"aws_api/osis","content":"","url":"aws_api/osis.html"},{"doc":"aws_api/outposts","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/outposts.Client\naws_api/outposts Client","url":"aws_api/outposts.html#Client"},{"doc":"aws_api/outposts","title":"cancel_capacity_task","content":"pub fn cancel_capacity_task(\n  client: Client,\n  outpost_identifier: String,\n  capacity_task_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/outposts.cancel_capacity_task\naws_api/outposts cancel_capacity_task","url":"aws_api/outposts.html#cancel_capacity_task"},{"doc":"aws_api/outposts","title":"cancel_order","content":"pub fn cancel_order(\n  client: Client,\n  order_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/outposts.cancel_order\naws_api/outposts cancel_order","url":"aws_api/outposts.html#cancel_order"},{"doc":"aws_api/outposts","title":"create_order","content":"pub fn create_order(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/outposts.create_order\naws_api/outposts create_order","url":"aws_api/outposts.html#create_order"},{"doc":"aws_api/outposts","title":"create_outpost","content":"pub fn create_outpost(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/outposts.create_outpost\naws_api/outposts create_outpost","url":"aws_api/outposts.html#create_outpost"},{"doc":"aws_api/outposts","title":"create_site","content":"pub fn create_site(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/outposts.create_site\naws_api/outposts create_site","url":"aws_api/outposts.html#create_site"},{"doc":"aws_api/outposts","title":"delete_outpost","content":"pub fn delete_outpost(\n  client: Client,\n  outpost_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/outposts.delete_outpost\naws_api/outposts delete_outpost","url":"aws_api/outposts.html#delete_outpost"},{"doc":"aws_api/outposts","title":"delete_site","content":"pub fn delete_site(\n  client: Client,\n  site_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/outposts.delete_site\naws_api/outposts delete_site","url":"aws_api/outposts.html#delete_site"},{"doc":"aws_api/outposts","title":"get_capacity_task","content":"pub fn get_capacity_task(\n  client: Client,\n  outpost_identifier: String,\n  capacity_task_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/outposts.get_capacity_task\naws_api/outposts get_capacity_task","url":"aws_api/outposts.html#get_capacity_task"},{"doc":"aws_api/outposts","title":"get_catalog_item","content":"pub fn get_catalog_item(\n  client: Client,\n  catalog_item_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/outposts.get_catalog_item\naws_api/outposts get_catalog_item","url":"aws_api/outposts.html#get_catalog_item"},{"doc":"aws_api/outposts","title":"get_connection","content":"pub fn get_connection(\n  client: Client,\n  connection_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/outposts.get_connection\naws_api/outposts get_connection","url":"aws_api/outposts.html#get_connection"},{"doc":"aws_api/outposts","title":"get_order","content":"pub fn get_order(\n  client: Client,\n  order_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/outposts.get_order\naws_api/outposts get_order","url":"aws_api/outposts.html#get_order"},{"doc":"aws_api/outposts","title":"get_outpost","content":"pub fn get_outpost(\n  client: Client,\n  outpost_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/outposts.get_outpost\naws_api/outposts get_outpost","url":"aws_api/outposts.html#get_outpost"},{"doc":"aws_api/outposts","title":"get_outpost_instance_types","content":"pub fn get_outpost_instance_types(\n  client: Client,\n  outpost_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/outposts.get_outpost_instance_types\naws_api/outposts get_outpost_instance_types","url":"aws_api/outposts.html#get_outpost_instance_types"},{"doc":"aws_api/outposts","title":"get_outpost_supported_instance_types","content":"pub fn get_outpost_supported_instance_types(\n  client: Client,\n  outpost_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/outposts.get_outpost_supported_instance_types\naws_api/outposts get_outpost_supported_instance_types","url":"aws_api/outposts.html#get_outpost_supported_instance_types"},{"doc":"aws_api/outposts","title":"get_site","content":"pub fn get_site(\n  client: Client,\n  site_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/outposts.get_site\naws_api/outposts get_site","url":"aws_api/outposts.html#get_site"},{"doc":"aws_api/outposts","title":"get_site_address","content":"pub fn get_site_address(\n  client: Client,\n  site_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/outposts.get_site_address\naws_api/outposts get_site_address","url":"aws_api/outposts.html#get_site_address"},{"doc":"aws_api/outposts","title":"list_assets","content":"pub fn list_assets(\n  client: Client,\n  outpost_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/outposts.list_assets\naws_api/outposts list_assets","url":"aws_api/outposts.html#list_assets"},{"doc":"aws_api/outposts","title":"list_capacity_tasks","content":"pub fn list_capacity_tasks(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/outposts.list_capacity_tasks\naws_api/outposts list_capacity_tasks","url":"aws_api/outposts.html#list_capacity_tasks"},{"doc":"aws_api/outposts","title":"list_catalog_items","content":"pub fn list_catalog_items(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/outposts.list_catalog_items\naws_api/outposts list_catalog_items","url":"aws_api/outposts.html#list_catalog_items"},{"doc":"aws_api/outposts","title":"list_orders","content":"pub fn list_orders(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/outposts.list_orders\naws_api/outposts list_orders","url":"aws_api/outposts.html#list_orders"},{"doc":"aws_api/outposts","title":"list_outposts","content":"pub fn list_outposts(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/outposts.list_outposts\naws_api/outposts list_outposts","url":"aws_api/outposts.html#list_outposts"},{"doc":"aws_api/outposts","title":"list_sites","content":"pub fn list_sites(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/outposts.list_sites\naws_api/outposts list_sites","url":"aws_api/outposts.html#list_sites"},{"doc":"aws_api/outposts","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/outposts.list_tags_for_resource\naws_api/outposts list_tags_for_resource","url":"aws_api/outposts.html#list_tags_for_resource"},{"doc":"aws_api/outposts","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/outposts.new\naws_api/outposts new","url":"aws_api/outposts.html#new"},{"doc":"aws_api/outposts","title":"start_capacity_task","content":"pub fn start_capacity_task(\n  client: Client,\n  outpost_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/outposts.start_capacity_task\naws_api/outposts start_capacity_task","url":"aws_api/outposts.html#start_capacity_task"},{"doc":"aws_api/outposts","title":"start_connection","content":"pub fn start_connection(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/outposts.start_connection\naws_api/outposts start_connection","url":"aws_api/outposts.html#start_connection"},{"doc":"aws_api/outposts","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/outposts.tag_resource\naws_api/outposts tag_resource","url":"aws_api/outposts.html#tag_resource"},{"doc":"aws_api/outposts","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/outposts.untag_resource\naws_api/outposts untag_resource","url":"aws_api/outposts.html#untag_resource"},{"doc":"aws_api/outposts","title":"update_outpost","content":"pub fn update_outpost(\n  client: Client,\n  outpost_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/outposts.update_outpost\naws_api/outposts update_outpost","url":"aws_api/outposts.html#update_outpost"},{"doc":"aws_api/outposts","title":"update_site","content":"pub fn update_site(\n  client: Client,\n  site_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/outposts.update_site\naws_api/outposts update_site","url":"aws_api/outposts.html#update_site"},{"doc":"aws_api/outposts","title":"update_site_address","content":"pub fn update_site_address(\n  client: Client,\n  site_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/outposts.update_site_address\naws_api/outposts update_site_address","url":"aws_api/outposts.html#update_site_address"},{"doc":"aws_api/outposts","title":"update_site_rack_physical_properties","content":"pub fn update_site_rack_physical_properties(\n  client: Client,\n  site_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/outposts.update_site_rack_physical_properties\naws_api/outposts update_site_rack_physical_properties","url":"aws_api/outposts.html#update_site_rack_physical_properties"},{"doc":"aws_api/outposts","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/outposts.with_custom_endpoint\naws_api/outposts with_custom_endpoint","url":"aws_api/outposts.html#with_custom_endpoint"},{"doc":"aws_api/outposts","title":"aws_api/outposts","content":"","url":"aws_api/outposts.html"},{"doc":"aws_api/personalize","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/personalize.Client\naws_api/personalize Client","url":"aws_api/personalize.html#Client"},{"doc":"aws_api/personalize","title":"create_batch_inference_job","content":"pub fn create_batch_inference_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.create_batch_inference_job\naws_api/personalize create_batch_inference_job","url":"aws_api/personalize.html#create_batch_inference_job"},{"doc":"aws_api/personalize","title":"create_batch_segment_job","content":"pub fn create_batch_segment_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.create_batch_segment_job\naws_api/personalize create_batch_segment_job","url":"aws_api/personalize.html#create_batch_segment_job"},{"doc":"aws_api/personalize","title":"create_campaign","content":"pub fn create_campaign(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.create_campaign\naws_api/personalize create_campaign","url":"aws_api/personalize.html#create_campaign"},{"doc":"aws_api/personalize","title":"create_data_deletion_job","content":"pub fn create_data_deletion_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.create_data_deletion_job\naws_api/personalize create_data_deletion_job","url":"aws_api/personalize.html#create_data_deletion_job"},{"doc":"aws_api/personalize","title":"create_dataset","content":"pub fn create_dataset(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.create_dataset\naws_api/personalize create_dataset","url":"aws_api/personalize.html#create_dataset"},{"doc":"aws_api/personalize","title":"create_dataset_export_job","content":"pub fn create_dataset_export_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.create_dataset_export_job\naws_api/personalize create_dataset_export_job","url":"aws_api/personalize.html#create_dataset_export_job"},{"doc":"aws_api/personalize","title":"create_dataset_group","content":"pub fn create_dataset_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.create_dataset_group\naws_api/personalize create_dataset_group","url":"aws_api/personalize.html#create_dataset_group"},{"doc":"aws_api/personalize","title":"create_dataset_import_job","content":"pub fn create_dataset_import_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.create_dataset_import_job\naws_api/personalize create_dataset_import_job","url":"aws_api/personalize.html#create_dataset_import_job"},{"doc":"aws_api/personalize","title":"create_event_tracker","content":"pub fn create_event_tracker(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.create_event_tracker\naws_api/personalize create_event_tracker","url":"aws_api/personalize.html#create_event_tracker"},{"doc":"aws_api/personalize","title":"create_filter","content":"pub fn create_filter(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.create_filter\naws_api/personalize create_filter","url":"aws_api/personalize.html#create_filter"},{"doc":"aws_api/personalize","title":"create_metric_attribution","content":"pub fn create_metric_attribution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.create_metric_attribution\naws_api/personalize create_metric_attribution","url":"aws_api/personalize.html#create_metric_attribution"},{"doc":"aws_api/personalize","title":"create_recommender","content":"pub fn create_recommender(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.create_recommender\naws_api/personalize create_recommender","url":"aws_api/personalize.html#create_recommender"},{"doc":"aws_api/personalize","title":"create_schema","content":"pub fn create_schema(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.create_schema\naws_api/personalize create_schema","url":"aws_api/personalize.html#create_schema"},{"doc":"aws_api/personalize","title":"create_solution","content":"pub fn create_solution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.create_solution\naws_api/personalize create_solution","url":"aws_api/personalize.html#create_solution"},{"doc":"aws_api/personalize","title":"create_solution_version","content":"pub fn create_solution_version(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.create_solution_version\naws_api/personalize create_solution_version","url":"aws_api/personalize.html#create_solution_version"},{"doc":"aws_api/personalize","title":"delete_campaign","content":"pub fn delete_campaign(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.delete_campaign\naws_api/personalize delete_campaign","url":"aws_api/personalize.html#delete_campaign"},{"doc":"aws_api/personalize","title":"delete_dataset","content":"pub fn delete_dataset(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.delete_dataset\naws_api/personalize delete_dataset","url":"aws_api/personalize.html#delete_dataset"},{"doc":"aws_api/personalize","title":"delete_dataset_group","content":"pub fn delete_dataset_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.delete_dataset_group\naws_api/personalize delete_dataset_group","url":"aws_api/personalize.html#delete_dataset_group"},{"doc":"aws_api/personalize","title":"delete_event_tracker","content":"pub fn delete_event_tracker(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.delete_event_tracker\naws_api/personalize delete_event_tracker","url":"aws_api/personalize.html#delete_event_tracker"},{"doc":"aws_api/personalize","title":"delete_filter","content":"pub fn delete_filter(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.delete_filter\naws_api/personalize delete_filter","url":"aws_api/personalize.html#delete_filter"},{"doc":"aws_api/personalize","title":"delete_metric_attribution","content":"pub fn delete_metric_attribution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.delete_metric_attribution\naws_api/personalize delete_metric_attribution","url":"aws_api/personalize.html#delete_metric_attribution"},{"doc":"aws_api/personalize","title":"delete_recommender","content":"pub fn delete_recommender(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.delete_recommender\naws_api/personalize delete_recommender","url":"aws_api/personalize.html#delete_recommender"},{"doc":"aws_api/personalize","title":"delete_schema","content":"pub fn delete_schema(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.delete_schema\naws_api/personalize delete_schema","url":"aws_api/personalize.html#delete_schema"},{"doc":"aws_api/personalize","title":"delete_solution","content":"pub fn delete_solution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.delete_solution\naws_api/personalize delete_solution","url":"aws_api/personalize.html#delete_solution"},{"doc":"aws_api/personalize","title":"describe_algorithm","content":"pub fn describe_algorithm(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.describe_algorithm\naws_api/personalize describe_algorithm","url":"aws_api/personalize.html#describe_algorithm"},{"doc":"aws_api/personalize","title":"describe_batch_inference_job","content":"pub fn describe_batch_inference_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.describe_batch_inference_job\naws_api/personalize describe_batch_inference_job","url":"aws_api/personalize.html#describe_batch_inference_job"},{"doc":"aws_api/personalize","title":"describe_batch_segment_job","content":"pub fn describe_batch_segment_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.describe_batch_segment_job\naws_api/personalize describe_batch_segment_job","url":"aws_api/personalize.html#describe_batch_segment_job"},{"doc":"aws_api/personalize","title":"describe_campaign","content":"pub fn describe_campaign(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.describe_campaign\naws_api/personalize describe_campaign","url":"aws_api/personalize.html#describe_campaign"},{"doc":"aws_api/personalize","title":"describe_data_deletion_job","content":"pub fn describe_data_deletion_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.describe_data_deletion_job\naws_api/personalize describe_data_deletion_job","url":"aws_api/personalize.html#describe_data_deletion_job"},{"doc":"aws_api/personalize","title":"describe_dataset","content":"pub fn describe_dataset(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.describe_dataset\naws_api/personalize describe_dataset","url":"aws_api/personalize.html#describe_dataset"},{"doc":"aws_api/personalize","title":"describe_dataset_export_job","content":"pub fn describe_dataset_export_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.describe_dataset_export_job\naws_api/personalize describe_dataset_export_job","url":"aws_api/personalize.html#describe_dataset_export_job"},{"doc":"aws_api/personalize","title":"describe_dataset_group","content":"pub fn describe_dataset_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.describe_dataset_group\naws_api/personalize describe_dataset_group","url":"aws_api/personalize.html#describe_dataset_group"},{"doc":"aws_api/personalize","title":"describe_dataset_import_job","content":"pub fn describe_dataset_import_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.describe_dataset_import_job\naws_api/personalize describe_dataset_import_job","url":"aws_api/personalize.html#describe_dataset_import_job"},{"doc":"aws_api/personalize","title":"describe_event_tracker","content":"pub fn describe_event_tracker(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.describe_event_tracker\naws_api/personalize describe_event_tracker","url":"aws_api/personalize.html#describe_event_tracker"},{"doc":"aws_api/personalize","title":"describe_feature_transformation","content":"pub fn describe_feature_transformation(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.describe_feature_transformation\naws_api/personalize describe_feature_transformation","url":"aws_api/personalize.html#describe_feature_transformation"},{"doc":"aws_api/personalize","title":"describe_filter","content":"pub fn describe_filter(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.describe_filter\naws_api/personalize describe_filter","url":"aws_api/personalize.html#describe_filter"},{"doc":"aws_api/personalize","title":"describe_metric_attribution","content":"pub fn describe_metric_attribution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.describe_metric_attribution\naws_api/personalize describe_metric_attribution","url":"aws_api/personalize.html#describe_metric_attribution"},{"doc":"aws_api/personalize","title":"describe_recipe","content":"pub fn describe_recipe(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.describe_recipe\naws_api/personalize describe_recipe","url":"aws_api/personalize.html#describe_recipe"},{"doc":"aws_api/personalize","title":"describe_recommender","content":"pub fn describe_recommender(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.describe_recommender\naws_api/personalize describe_recommender","url":"aws_api/personalize.html#describe_recommender"},{"doc":"aws_api/personalize","title":"describe_schema","content":"pub fn describe_schema(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.describe_schema\naws_api/personalize describe_schema","url":"aws_api/personalize.html#describe_schema"},{"doc":"aws_api/personalize","title":"describe_solution","content":"pub fn describe_solution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.describe_solution\naws_api/personalize describe_solution","url":"aws_api/personalize.html#describe_solution"},{"doc":"aws_api/personalize","title":"describe_solution_version","content":"pub fn describe_solution_version(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.describe_solution_version\naws_api/personalize describe_solution_version","url":"aws_api/personalize.html#describe_solution_version"},{"doc":"aws_api/personalize","title":"get_solution_metrics","content":"pub fn get_solution_metrics(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.get_solution_metrics\naws_api/personalize get_solution_metrics","url":"aws_api/personalize.html#get_solution_metrics"},{"doc":"aws_api/personalize","title":"list_batch_inference_jobs","content":"pub fn list_batch_inference_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.list_batch_inference_jobs\naws_api/personalize list_batch_inference_jobs","url":"aws_api/personalize.html#list_batch_inference_jobs"},{"doc":"aws_api/personalize","title":"list_batch_segment_jobs","content":"pub fn list_batch_segment_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.list_batch_segment_jobs\naws_api/personalize list_batch_segment_jobs","url":"aws_api/personalize.html#list_batch_segment_jobs"},{"doc":"aws_api/personalize","title":"list_campaigns","content":"pub fn list_campaigns(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.list_campaigns\naws_api/personalize list_campaigns","url":"aws_api/personalize.html#list_campaigns"},{"doc":"aws_api/personalize","title":"list_data_deletion_jobs","content":"pub fn list_data_deletion_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.list_data_deletion_jobs\naws_api/personalize list_data_deletion_jobs","url":"aws_api/personalize.html#list_data_deletion_jobs"},{"doc":"aws_api/personalize","title":"list_dataset_export_jobs","content":"pub fn list_dataset_export_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.list_dataset_export_jobs\naws_api/personalize list_dataset_export_jobs","url":"aws_api/personalize.html#list_dataset_export_jobs"},{"doc":"aws_api/personalize","title":"list_dataset_groups","content":"pub fn list_dataset_groups(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.list_dataset_groups\naws_api/personalize list_dataset_groups","url":"aws_api/personalize.html#list_dataset_groups"},{"doc":"aws_api/personalize","title":"list_dataset_import_jobs","content":"pub fn list_dataset_import_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.list_dataset_import_jobs\naws_api/personalize list_dataset_import_jobs","url":"aws_api/personalize.html#list_dataset_import_jobs"},{"doc":"aws_api/personalize","title":"list_datasets","content":"pub fn list_datasets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.list_datasets\naws_api/personalize list_datasets","url":"aws_api/personalize.html#list_datasets"},{"doc":"aws_api/personalize","title":"list_event_trackers","content":"pub fn list_event_trackers(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.list_event_trackers\naws_api/personalize list_event_trackers","url":"aws_api/personalize.html#list_event_trackers"},{"doc":"aws_api/personalize","title":"list_filters","content":"pub fn list_filters(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.list_filters\naws_api/personalize list_filters","url":"aws_api/personalize.html#list_filters"},{"doc":"aws_api/personalize","title":"list_metric_attribution_metrics","content":"pub fn list_metric_attribution_metrics(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.list_metric_attribution_metrics\naws_api/personalize list_metric_attribution_metrics","url":"aws_api/personalize.html#list_metric_attribution_metrics"},{"doc":"aws_api/personalize","title":"list_metric_attributions","content":"pub fn list_metric_attributions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.list_metric_attributions\naws_api/personalize list_metric_attributions","url":"aws_api/personalize.html#list_metric_attributions"},{"doc":"aws_api/personalize","title":"list_recipes","content":"pub fn list_recipes(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.list_recipes\naws_api/personalize list_recipes","url":"aws_api/personalize.html#list_recipes"},{"doc":"aws_api/personalize","title":"list_recommenders","content":"pub fn list_recommenders(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.list_recommenders\naws_api/personalize list_recommenders","url":"aws_api/personalize.html#list_recommenders"},{"doc":"aws_api/personalize","title":"list_schemas","content":"pub fn list_schemas(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.list_schemas\naws_api/personalize list_schemas","url":"aws_api/personalize.html#list_schemas"},{"doc":"aws_api/personalize","title":"list_solution_versions","content":"pub fn list_solution_versions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.list_solution_versions\naws_api/personalize list_solution_versions","url":"aws_api/personalize.html#list_solution_versions"},{"doc":"aws_api/personalize","title":"list_solutions","content":"pub fn list_solutions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.list_solutions\naws_api/personalize list_solutions","url":"aws_api/personalize.html#list_solutions"},{"doc":"aws_api/personalize","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.list_tags_for_resource\naws_api/personalize list_tags_for_resource","url":"aws_api/personalize.html#list_tags_for_resource"},{"doc":"aws_api/personalize","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/personalize.new\naws_api/personalize new","url":"aws_api/personalize.html#new"},{"doc":"aws_api/personalize","title":"start_recommender","content":"pub fn start_recommender(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.start_recommender\naws_api/personalize start_recommender","url":"aws_api/personalize.html#start_recommender"},{"doc":"aws_api/personalize","title":"stop_recommender","content":"pub fn stop_recommender(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.stop_recommender\naws_api/personalize stop_recommender","url":"aws_api/personalize.html#stop_recommender"},{"doc":"aws_api/personalize","title":"stop_solution_version_creation","content":"pub fn stop_solution_version_creation(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.stop_solution_version_creation\naws_api/personalize stop_solution_version_creation","url":"aws_api/personalize.html#stop_solution_version_creation"},{"doc":"aws_api/personalize","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.tag_resource\naws_api/personalize tag_resource","url":"aws_api/personalize.html#tag_resource"},{"doc":"aws_api/personalize","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.untag_resource\naws_api/personalize untag_resource","url":"aws_api/personalize.html#untag_resource"},{"doc":"aws_api/personalize","title":"update_campaign","content":"pub fn update_campaign(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.update_campaign\naws_api/personalize update_campaign","url":"aws_api/personalize.html#update_campaign"},{"doc":"aws_api/personalize","title":"update_dataset","content":"pub fn update_dataset(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.update_dataset\naws_api/personalize update_dataset","url":"aws_api/personalize.html#update_dataset"},{"doc":"aws_api/personalize","title":"update_metric_attribution","content":"pub fn update_metric_attribution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.update_metric_attribution\naws_api/personalize update_metric_attribution","url":"aws_api/personalize.html#update_metric_attribution"},{"doc":"aws_api/personalize","title":"update_recommender","content":"pub fn update_recommender(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/personalize.update_recommender\naws_api/personalize update_recommender","url":"aws_api/personalize.html#update_recommender"},{"doc":"aws_api/personalize","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/personalize.with_custom_endpoint\naws_api/personalize with_custom_endpoint","url":"aws_api/personalize.html#with_custom_endpoint"},{"doc":"aws_api/personalize","title":"aws_api/personalize","content":"","url":"aws_api/personalize.html"},{"doc":"aws_api/pi","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/pi.Client\naws_api/pi Client","url":"aws_api/pi.html#Client"},{"doc":"aws_api/pi","title":"create_performance_analysis_report","content":"pub fn create_performance_analysis_report(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pi.create_performance_analysis_report\naws_api/pi create_performance_analysis_report","url":"aws_api/pi.html#create_performance_analysis_report"},{"doc":"aws_api/pi","title":"delete_performance_analysis_report","content":"pub fn delete_performance_analysis_report(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pi.delete_performance_analysis_report\naws_api/pi delete_performance_analysis_report","url":"aws_api/pi.html#delete_performance_analysis_report"},{"doc":"aws_api/pi","title":"describe_dimension_keys","content":"pub fn describe_dimension_keys(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pi.describe_dimension_keys\naws_api/pi describe_dimension_keys","url":"aws_api/pi.html#describe_dimension_keys"},{"doc":"aws_api/pi","title":"get_dimension_key_details","content":"pub fn get_dimension_key_details(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pi.get_dimension_key_details\naws_api/pi get_dimension_key_details","url":"aws_api/pi.html#get_dimension_key_details"},{"doc":"aws_api/pi","title":"get_performance_analysis_report","content":"pub fn get_performance_analysis_report(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pi.get_performance_analysis_report\naws_api/pi get_performance_analysis_report","url":"aws_api/pi.html#get_performance_analysis_report"},{"doc":"aws_api/pi","title":"get_resource_metadata","content":"pub fn get_resource_metadata(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pi.get_resource_metadata\naws_api/pi get_resource_metadata","url":"aws_api/pi.html#get_resource_metadata"},{"doc":"aws_api/pi","title":"get_resource_metrics","content":"pub fn get_resource_metrics(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pi.get_resource_metrics\naws_api/pi get_resource_metrics","url":"aws_api/pi.html#get_resource_metrics"},{"doc":"aws_api/pi","title":"list_available_resource_dimensions","content":"pub fn list_available_resource_dimensions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pi.list_available_resource_dimensions\naws_api/pi list_available_resource_dimensions","url":"aws_api/pi.html#list_available_resource_dimensions"},{"doc":"aws_api/pi","title":"list_available_resource_metrics","content":"pub fn list_available_resource_metrics(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pi.list_available_resource_metrics\naws_api/pi list_available_resource_metrics","url":"aws_api/pi.html#list_available_resource_metrics"},{"doc":"aws_api/pi","title":"list_performance_analysis_reports","content":"pub fn list_performance_analysis_reports(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pi.list_performance_analysis_reports\naws_api/pi list_performance_analysis_reports","url":"aws_api/pi.html#list_performance_analysis_reports"},{"doc":"aws_api/pi","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pi.list_tags_for_resource\naws_api/pi list_tags_for_resource","url":"aws_api/pi.html#list_tags_for_resource"},{"doc":"aws_api/pi","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/pi.new\naws_api/pi new","url":"aws_api/pi.html#new"},{"doc":"aws_api/pi","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pi.tag_resource\naws_api/pi tag_resource","url":"aws_api/pi.html#tag_resource"},{"doc":"aws_api/pi","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pi.untag_resource\naws_api/pi untag_resource","url":"aws_api/pi.html#untag_resource"},{"doc":"aws_api/pi","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/pi.with_custom_endpoint\naws_api/pi with_custom_endpoint","url":"aws_api/pi.html#with_custom_endpoint"},{"doc":"aws_api/pi","title":"aws_api/pi","content":"","url":"aws_api/pi.html"},{"doc":"aws_api/pinpoint","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/pinpoint.Client\naws_api/pinpoint Client","url":"aws_api/pinpoint.html#Client"},{"doc":"aws_api/pinpoint","title":"create_app","content":"pub fn create_app(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.create_app\naws_api/pinpoint create_app","url":"aws_api/pinpoint.html#create_app"},{"doc":"aws_api/pinpoint","title":"create_campaign","content":"pub fn create_campaign(\n  client: Client,\n  application_id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.create_campaign\naws_api/pinpoint create_campaign","url":"aws_api/pinpoint.html#create_campaign"},{"doc":"aws_api/pinpoint","title":"create_email_template","content":"pub fn create_email_template(\n  client: Client,\n  template_name: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.create_email_template\naws_api/pinpoint create_email_template","url":"aws_api/pinpoint.html#create_email_template"},{"doc":"aws_api/pinpoint","title":"create_export_job","content":"pub fn create_export_job(\n  client: Client,\n  application_id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.create_export_job\naws_api/pinpoint create_export_job","url":"aws_api/pinpoint.html#create_export_job"},{"doc":"aws_api/pinpoint","title":"create_import_job","content":"pub fn create_import_job(\n  client: Client,\n  application_id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.create_import_job\naws_api/pinpoint create_import_job","url":"aws_api/pinpoint.html#create_import_job"},{"doc":"aws_api/pinpoint","title":"create_in_app_template","content":"pub fn create_in_app_template(\n  client: Client,\n  template_name: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.create_in_app_template\naws_api/pinpoint create_in_app_template","url":"aws_api/pinpoint.html#create_in_app_template"},{"doc":"aws_api/pinpoint","title":"create_journey","content":"pub fn create_journey(\n  client: Client,\n  application_id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.create_journey\naws_api/pinpoint create_journey","url":"aws_api/pinpoint.html#create_journey"},{"doc":"aws_api/pinpoint","title":"create_push_template","content":"pub fn create_push_template(\n  client: Client,\n  template_name: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.create_push_template\naws_api/pinpoint create_push_template","url":"aws_api/pinpoint.html#create_push_template"},{"doc":"aws_api/pinpoint","title":"create_recommender_configuration","content":"pub fn create_recommender_configuration(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.create_recommender_configuration\naws_api/pinpoint create_recommender_configuration","url":"aws_api/pinpoint.html#create_recommender_configuration"},{"doc":"aws_api/pinpoint","title":"create_segment","content":"pub fn create_segment(\n  client: Client,\n  application_id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.create_segment\naws_api/pinpoint create_segment","url":"aws_api/pinpoint.html#create_segment"},{"doc":"aws_api/pinpoint","title":"create_sms_template","content":"pub fn create_sms_template(\n  client: Client,\n  template_name: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.create_sms_template\naws_api/pinpoint create_sms_template","url":"aws_api/pinpoint.html#create_sms_template"},{"doc":"aws_api/pinpoint","title":"create_voice_template","content":"pub fn create_voice_template(\n  client: Client,\n  template_name: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.create_voice_template\naws_api/pinpoint create_voice_template","url":"aws_api/pinpoint.html#create_voice_template"},{"doc":"aws_api/pinpoint","title":"delete_adm_channel","content":"pub fn delete_adm_channel(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.delete_adm_channel\naws_api/pinpoint delete_adm_channel","url":"aws_api/pinpoint.html#delete_adm_channel"},{"doc":"aws_api/pinpoint","title":"delete_apns_channel","content":"pub fn delete_apns_channel(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.delete_apns_channel\naws_api/pinpoint delete_apns_channel","url":"aws_api/pinpoint.html#delete_apns_channel"},{"doc":"aws_api/pinpoint","title":"delete_apns_sandbox_channel","content":"pub fn delete_apns_sandbox_channel(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.delete_apns_sandbox_channel\naws_api/pinpoint delete_apns_sandbox_channel","url":"aws_api/pinpoint.html#delete_apns_sandbox_channel"},{"doc":"aws_api/pinpoint","title":"delete_apns_voip_channel","content":"pub fn delete_apns_voip_channel(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.delete_apns_voip_channel\naws_api/pinpoint delete_apns_voip_channel","url":"aws_api/pinpoint.html#delete_apns_voip_channel"},{"doc":"aws_api/pinpoint","title":"delete_apns_voip_sandbox_channel","content":"pub fn delete_apns_voip_sandbox_channel(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.delete_apns_voip_sandbox_channel\naws_api/pinpoint delete_apns_voip_sandbox_channel","url":"aws_api/pinpoint.html#delete_apns_voip_sandbox_channel"},{"doc":"aws_api/pinpoint","title":"delete_app","content":"pub fn delete_app(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.delete_app\naws_api/pinpoint delete_app","url":"aws_api/pinpoint.html#delete_app"},{"doc":"aws_api/pinpoint","title":"delete_baidu_channel","content":"pub fn delete_baidu_channel(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.delete_baidu_channel\naws_api/pinpoint delete_baidu_channel","url":"aws_api/pinpoint.html#delete_baidu_channel"},{"doc":"aws_api/pinpoint","title":"delete_campaign","content":"pub fn delete_campaign(\n  client: Client,\n  application_id: String,\n  campaign_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.delete_campaign\naws_api/pinpoint delete_campaign","url":"aws_api/pinpoint.html#delete_campaign"},{"doc":"aws_api/pinpoint","title":"delete_email_channel","content":"pub fn delete_email_channel(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.delete_email_channel\naws_api/pinpoint delete_email_channel","url":"aws_api/pinpoint.html#delete_email_channel"},{"doc":"aws_api/pinpoint","title":"delete_email_template","content":"pub fn delete_email_template(\n  client: Client,\n  template_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.delete_email_template\naws_api/pinpoint delete_email_template","url":"aws_api/pinpoint.html#delete_email_template"},{"doc":"aws_api/pinpoint","title":"delete_endpoint","content":"pub fn delete_endpoint(\n  client: Client,\n  application_id: String,\n  endpoint_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.delete_endpoint\naws_api/pinpoint delete_endpoint","url":"aws_api/pinpoint.html#delete_endpoint"},{"doc":"aws_api/pinpoint","title":"delete_event_stream","content":"pub fn delete_event_stream(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.delete_event_stream\naws_api/pinpoint delete_event_stream","url":"aws_api/pinpoint.html#delete_event_stream"},{"doc":"aws_api/pinpoint","title":"delete_gcm_channel","content":"pub fn delete_gcm_channel(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.delete_gcm_channel\naws_api/pinpoint delete_gcm_channel","url":"aws_api/pinpoint.html#delete_gcm_channel"},{"doc":"aws_api/pinpoint","title":"delete_in_app_template","content":"pub fn delete_in_app_template(\n  client: Client,\n  template_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.delete_in_app_template\naws_api/pinpoint delete_in_app_template","url":"aws_api/pinpoint.html#delete_in_app_template"},{"doc":"aws_api/pinpoint","title":"delete_journey","content":"pub fn delete_journey(\n  client: Client,\n  application_id: String,\n  journey_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.delete_journey\naws_api/pinpoint delete_journey","url":"aws_api/pinpoint.html#delete_journey"},{"doc":"aws_api/pinpoint","title":"delete_push_template","content":"pub fn delete_push_template(\n  client: Client,\n  template_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.delete_push_template\naws_api/pinpoint delete_push_template","url":"aws_api/pinpoint.html#delete_push_template"},{"doc":"aws_api/pinpoint","title":"delete_recommender_configuration","content":"pub fn delete_recommender_configuration(\n  client: Client,\n  recommender_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.delete_recommender_configuration\naws_api/pinpoint delete_recommender_configuration","url":"aws_api/pinpoint.html#delete_recommender_configuration"},{"doc":"aws_api/pinpoint","title":"delete_segment","content":"pub fn delete_segment(\n  client: Client,\n  application_id: String,\n  segment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.delete_segment\naws_api/pinpoint delete_segment","url":"aws_api/pinpoint.html#delete_segment"},{"doc":"aws_api/pinpoint","title":"delete_sms_channel","content":"pub fn delete_sms_channel(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.delete_sms_channel\naws_api/pinpoint delete_sms_channel","url":"aws_api/pinpoint.html#delete_sms_channel"},{"doc":"aws_api/pinpoint","title":"delete_sms_template","content":"pub fn delete_sms_template(\n  client: Client,\n  template_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.delete_sms_template\naws_api/pinpoint delete_sms_template","url":"aws_api/pinpoint.html#delete_sms_template"},{"doc":"aws_api/pinpoint","title":"delete_user_endpoints","content":"pub fn delete_user_endpoints(\n  client: Client,\n  application_id: String,\n  user_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.delete_user_endpoints\naws_api/pinpoint delete_user_endpoints","url":"aws_api/pinpoint.html#delete_user_endpoints"},{"doc":"aws_api/pinpoint","title":"delete_voice_channel","content":"pub fn delete_voice_channel(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.delete_voice_channel\naws_api/pinpoint delete_voice_channel","url":"aws_api/pinpoint.html#delete_voice_channel"},{"doc":"aws_api/pinpoint","title":"delete_voice_template","content":"pub fn delete_voice_template(\n  client: Client,\n  template_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.delete_voice_template\naws_api/pinpoint delete_voice_template","url":"aws_api/pinpoint.html#delete_voice_template"},{"doc":"aws_api/pinpoint","title":"get_adm_channel","content":"pub fn get_adm_channel(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.get_adm_channel\naws_api/pinpoint get_adm_channel","url":"aws_api/pinpoint.html#get_adm_channel"},{"doc":"aws_api/pinpoint","title":"get_apns_channel","content":"pub fn get_apns_channel(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.get_apns_channel\naws_api/pinpoint get_apns_channel","url":"aws_api/pinpoint.html#get_apns_channel"},{"doc":"aws_api/pinpoint","title":"get_apns_sandbox_channel","content":"pub fn get_apns_sandbox_channel(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.get_apns_sandbox_channel\naws_api/pinpoint get_apns_sandbox_channel","url":"aws_api/pinpoint.html#get_apns_sandbox_channel"},{"doc":"aws_api/pinpoint","title":"get_apns_voip_channel","content":"pub fn get_apns_voip_channel(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.get_apns_voip_channel\naws_api/pinpoint get_apns_voip_channel","url":"aws_api/pinpoint.html#get_apns_voip_channel"},{"doc":"aws_api/pinpoint","title":"get_apns_voip_sandbox_channel","content":"pub fn get_apns_voip_sandbox_channel(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.get_apns_voip_sandbox_channel\naws_api/pinpoint get_apns_voip_sandbox_channel","url":"aws_api/pinpoint.html#get_apns_voip_sandbox_channel"},{"doc":"aws_api/pinpoint","title":"get_app","content":"pub fn get_app(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.get_app\naws_api/pinpoint get_app","url":"aws_api/pinpoint.html#get_app"},{"doc":"aws_api/pinpoint","title":"get_application_date_range_kpi","content":"pub fn get_application_date_range_kpi(\n  client: Client,\n  application_id: String,\n  kpi_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.get_application_date_range_kpi\naws_api/pinpoint get_application_date_range_kpi","url":"aws_api/pinpoint.html#get_application_date_range_kpi"},{"doc":"aws_api/pinpoint","title":"get_application_settings","content":"pub fn get_application_settings(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.get_application_settings\naws_api/pinpoint get_application_settings","url":"aws_api/pinpoint.html#get_application_settings"},{"doc":"aws_api/pinpoint","title":"get_apps","content":"pub fn get_apps(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.get_apps\naws_api/pinpoint get_apps","url":"aws_api/pinpoint.html#get_apps"},{"doc":"aws_api/pinpoint","title":"get_baidu_channel","content":"pub fn get_baidu_channel(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.get_baidu_channel\naws_api/pinpoint get_baidu_channel","url":"aws_api/pinpoint.html#get_baidu_channel"},{"doc":"aws_api/pinpoint","title":"get_campaign","content":"pub fn get_campaign(\n  client: Client,\n  application_id: String,\n  campaign_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.get_campaign\naws_api/pinpoint get_campaign","url":"aws_api/pinpoint.html#get_campaign"},{"doc":"aws_api/pinpoint","title":"get_campaign_activities","content":"pub fn get_campaign_activities(\n  client: Client,\n  application_id: String,\n  campaign_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.get_campaign_activities\naws_api/pinpoint get_campaign_activities","url":"aws_api/pinpoint.html#get_campaign_activities"},{"doc":"aws_api/pinpoint","title":"get_campaign_date_range_kpi","content":"pub fn get_campaign_date_range_kpi(\n  client: Client,\n  application_id: String,\n  campaign_id: String,\n  kpi_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.get_campaign_date_range_kpi\naws_api/pinpoint get_campaign_date_range_kpi","url":"aws_api/pinpoint.html#get_campaign_date_range_kpi"},{"doc":"aws_api/pinpoint","title":"get_campaign_version","content":"pub fn get_campaign_version(\n  client: Client,\n  application_id: String,\n  campaign_id: String,\n  version: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.get_campaign_version\naws_api/pinpoint get_campaign_version","url":"aws_api/pinpoint.html#get_campaign_version"},{"doc":"aws_api/pinpoint","title":"get_campaign_versions","content":"pub fn get_campaign_versions(\n  client: Client,\n  application_id: String,\n  campaign_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.get_campaign_versions\naws_api/pinpoint get_campaign_versions","url":"aws_api/pinpoint.html#get_campaign_versions"},{"doc":"aws_api/pinpoint","title":"get_campaigns","content":"pub fn get_campaigns(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.get_campaigns\naws_api/pinpoint get_campaigns","url":"aws_api/pinpoint.html#get_campaigns"},{"doc":"aws_api/pinpoint","title":"get_channels","content":"pub fn get_channels(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.get_channels\naws_api/pinpoint get_channels","url":"aws_api/pinpoint.html#get_channels"},{"doc":"aws_api/pinpoint","title":"get_email_channel","content":"pub fn get_email_channel(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.get_email_channel\naws_api/pinpoint get_email_channel","url":"aws_api/pinpoint.html#get_email_channel"},{"doc":"aws_api/pinpoint","title":"get_email_template","content":"pub fn get_email_template(\n  client: Client,\n  template_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.get_email_template\naws_api/pinpoint get_email_template","url":"aws_api/pinpoint.html#get_email_template"},{"doc":"aws_api/pinpoint","title":"get_endpoint","content":"pub fn get_endpoint(\n  client: Client,\n  application_id: String,\n  endpoint_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.get_endpoint\naws_api/pinpoint get_endpoint","url":"aws_api/pinpoint.html#get_endpoint"},{"doc":"aws_api/pinpoint","title":"get_event_stream","content":"pub fn get_event_stream(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.get_event_stream\naws_api/pinpoint get_event_stream","url":"aws_api/pinpoint.html#get_event_stream"},{"doc":"aws_api/pinpoint","title":"get_export_job","content":"pub fn get_export_job(\n  client: Client,\n  application_id: String,\n  job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.get_export_job\naws_api/pinpoint get_export_job","url":"aws_api/pinpoint.html#get_export_job"},{"doc":"aws_api/pinpoint","title":"get_export_jobs","content":"pub fn get_export_jobs(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.get_export_jobs\naws_api/pinpoint get_export_jobs","url":"aws_api/pinpoint.html#get_export_jobs"},{"doc":"aws_api/pinpoint","title":"get_gcm_channel","content":"pub fn get_gcm_channel(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.get_gcm_channel\naws_api/pinpoint get_gcm_channel","url":"aws_api/pinpoint.html#get_gcm_channel"},{"doc":"aws_api/pinpoint","title":"get_import_job","content":"pub fn get_import_job(\n  client: Client,\n  application_id: String,\n  job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.get_import_job\naws_api/pinpoint get_import_job","url":"aws_api/pinpoint.html#get_import_job"},{"doc":"aws_api/pinpoint","title":"get_import_jobs","content":"pub fn get_import_jobs(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.get_import_jobs\naws_api/pinpoint get_import_jobs","url":"aws_api/pinpoint.html#get_import_jobs"},{"doc":"aws_api/pinpoint","title":"get_in_app_messages","content":"pub fn get_in_app_messages(\n  client: Client,\n  application_id: String,\n  endpoint_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.get_in_app_messages\naws_api/pinpoint get_in_app_messages","url":"aws_api/pinpoint.html#get_in_app_messages"},{"doc":"aws_api/pinpoint","title":"get_in_app_template","content":"pub fn get_in_app_template(\n  client: Client,\n  template_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.get_in_app_template\naws_api/pinpoint get_in_app_template","url":"aws_api/pinpoint.html#get_in_app_template"},{"doc":"aws_api/pinpoint","title":"get_journey","content":"pub fn get_journey(\n  client: Client,\n  application_id: String,\n  journey_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.get_journey\naws_api/pinpoint get_journey","url":"aws_api/pinpoint.html#get_journey"},{"doc":"aws_api/pinpoint","title":"get_journey_date_range_kpi","content":"pub fn get_journey_date_range_kpi(\n  client: Client,\n  application_id: String,\n  journey_id: String,\n  kpi_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.get_journey_date_range_kpi\naws_api/pinpoint get_journey_date_range_kpi","url":"aws_api/pinpoint.html#get_journey_date_range_kpi"},{"doc":"aws_api/pinpoint","title":"get_journey_execution_activity_metrics","content":"pub fn get_journey_execution_activity_metrics(\n  client: Client,\n  application_id: String,\n  journey_id: String,\n  journey_activity_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.get_journey_execution_activity_metrics\naws_api/pinpoint get_journey_execution_activity_metrics","url":"aws_api/pinpoint.html#get_journey_execution_activity_metrics"},{"doc":"aws_api/pinpoint","title":"get_journey_execution_metrics","content":"pub fn get_journey_execution_metrics(\n  client: Client,\n  application_id: String,\n  journey_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.get_journey_execution_metrics\naws_api/pinpoint get_journey_execution_metrics","url":"aws_api/pinpoint.html#get_journey_execution_metrics"},{"doc":"aws_api/pinpoint","title":"get_journey_run_execution_activity_metrics","content":"pub fn get_journey_run_execution_activity_metrics(\n  client: Client,\n  application_id: String,\n  journey_id: String,\n  run_id: String,\n  journey_activity_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.get_journey_run_execution_activity_metrics\naws_api/pinpoint get_journey_run_execution_activity_metrics","url":"aws_api/pinpoint.html#get_journey_run_execution_activity_metrics"},{"doc":"aws_api/pinpoint","title":"get_journey_run_execution_metrics","content":"pub fn get_journey_run_execution_metrics(\n  client: Client,\n  application_id: String,\n  journey_id: String,\n  run_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.get_journey_run_execution_metrics\naws_api/pinpoint get_journey_run_execution_metrics","url":"aws_api/pinpoint.html#get_journey_run_execution_metrics"},{"doc":"aws_api/pinpoint","title":"get_journey_runs","content":"pub fn get_journey_runs(\n  client: Client,\n  application_id: String,\n  journey_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.get_journey_runs\naws_api/pinpoint get_journey_runs","url":"aws_api/pinpoint.html#get_journey_runs"},{"doc":"aws_api/pinpoint","title":"get_push_template","content":"pub fn get_push_template(\n  client: Client,\n  template_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.get_push_template\naws_api/pinpoint get_push_template","url":"aws_api/pinpoint.html#get_push_template"},{"doc":"aws_api/pinpoint","title":"get_recommender_configuration","content":"pub fn get_recommender_configuration(\n  client: Client,\n  recommender_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.get_recommender_configuration\naws_api/pinpoint get_recommender_configuration","url":"aws_api/pinpoint.html#get_recommender_configuration"},{"doc":"aws_api/pinpoint","title":"get_recommender_configurations","content":"pub fn get_recommender_configurations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.get_recommender_configurations\naws_api/pinpoint get_recommender_configurations","url":"aws_api/pinpoint.html#get_recommender_configurations"},{"doc":"aws_api/pinpoint","title":"get_segment","content":"pub fn get_segment(\n  client: Client,\n  application_id: String,\n  segment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.get_segment\naws_api/pinpoint get_segment","url":"aws_api/pinpoint.html#get_segment"},{"doc":"aws_api/pinpoint","title":"get_segment_export_jobs","content":"pub fn get_segment_export_jobs(\n  client: Client,\n  application_id: String,\n  segment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.get_segment_export_jobs\naws_api/pinpoint get_segment_export_jobs","url":"aws_api/pinpoint.html#get_segment_export_jobs"},{"doc":"aws_api/pinpoint","title":"get_segment_import_jobs","content":"pub fn get_segment_import_jobs(\n  client: Client,\n  application_id: String,\n  segment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.get_segment_import_jobs\naws_api/pinpoint get_segment_import_jobs","url":"aws_api/pinpoint.html#get_segment_import_jobs"},{"doc":"aws_api/pinpoint","title":"get_segment_version","content":"pub fn get_segment_version(\n  client: Client,\n  application_id: String,\n  segment_id: String,\n  version: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.get_segment_version\naws_api/pinpoint get_segment_version","url":"aws_api/pinpoint.html#get_segment_version"},{"doc":"aws_api/pinpoint","title":"get_segment_versions","content":"pub fn get_segment_versions(\n  client: Client,\n  application_id: String,\n  segment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.get_segment_versions\naws_api/pinpoint get_segment_versions","url":"aws_api/pinpoint.html#get_segment_versions"},{"doc":"aws_api/pinpoint","title":"get_segments","content":"pub fn get_segments(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.get_segments\naws_api/pinpoint get_segments","url":"aws_api/pinpoint.html#get_segments"},{"doc":"aws_api/pinpoint","title":"get_sms_channel","content":"pub fn get_sms_channel(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.get_sms_channel\naws_api/pinpoint get_sms_channel","url":"aws_api/pinpoint.html#get_sms_channel"},{"doc":"aws_api/pinpoint","title":"get_sms_template","content":"pub fn get_sms_template(\n  client: Client,\n  template_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.get_sms_template\naws_api/pinpoint get_sms_template","url":"aws_api/pinpoint.html#get_sms_template"},{"doc":"aws_api/pinpoint","title":"get_user_endpoints","content":"pub fn get_user_endpoints(\n  client: Client,\n  application_id: String,\n  user_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.get_user_endpoints\naws_api/pinpoint get_user_endpoints","url":"aws_api/pinpoint.html#get_user_endpoints"},{"doc":"aws_api/pinpoint","title":"get_voice_channel","content":"pub fn get_voice_channel(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.get_voice_channel\naws_api/pinpoint get_voice_channel","url":"aws_api/pinpoint.html#get_voice_channel"},{"doc":"aws_api/pinpoint","title":"get_voice_template","content":"pub fn get_voice_template(\n  client: Client,\n  template_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.get_voice_template\naws_api/pinpoint get_voice_template","url":"aws_api/pinpoint.html#get_voice_template"},{"doc":"aws_api/pinpoint","title":"list_journeys","content":"pub fn list_journeys(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.list_journeys\naws_api/pinpoint list_journeys","url":"aws_api/pinpoint.html#list_journeys"},{"doc":"aws_api/pinpoint","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.list_tags_for_resource\naws_api/pinpoint list_tags_for_resource","url":"aws_api/pinpoint.html#list_tags_for_resource"},{"doc":"aws_api/pinpoint","title":"list_template_versions","content":"pub fn list_template_versions(\n  client: Client,\n  template_name: String,\n  template_type: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.list_template_versions\naws_api/pinpoint list_template_versions","url":"aws_api/pinpoint.html#list_template_versions"},{"doc":"aws_api/pinpoint","title":"list_templates","content":"pub fn list_templates(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.list_templates\naws_api/pinpoint list_templates","url":"aws_api/pinpoint.html#list_templates"},{"doc":"aws_api/pinpoint","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/pinpoint.new\naws_api/pinpoint new","url":"aws_api/pinpoint.html#new"},{"doc":"aws_api/pinpoint","title":"phone_number_validate","content":"pub fn phone_number_validate(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.phone_number_validate\naws_api/pinpoint phone_number_validate","url":"aws_api/pinpoint.html#phone_number_validate"},{"doc":"aws_api/pinpoint","title":"put_event_stream","content":"pub fn put_event_stream(\n  client: Client,\n  application_id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.put_event_stream\naws_api/pinpoint put_event_stream","url":"aws_api/pinpoint.html#put_event_stream"},{"doc":"aws_api/pinpoint","title":"put_events","content":"pub fn put_events(\n  client: Client,\n  application_id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.put_events\naws_api/pinpoint put_events","url":"aws_api/pinpoint.html#put_events"},{"doc":"aws_api/pinpoint","title":"remove_attributes","content":"pub fn remove_attributes(\n  client: Client,\n  application_id: String,\n  attribute_type: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.remove_attributes\naws_api/pinpoint remove_attributes","url":"aws_api/pinpoint.html#remove_attributes"},{"doc":"aws_api/pinpoint","title":"send_messages","content":"pub fn send_messages(\n  client: Client,\n  application_id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.send_messages\naws_api/pinpoint send_messages","url":"aws_api/pinpoint.html#send_messages"},{"doc":"aws_api/pinpoint","title":"send_otp_message","content":"pub fn send_otp_message(\n  client: Client,\n  application_id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.send_otp_message\naws_api/pinpoint send_otp_message","url":"aws_api/pinpoint.html#send_otp_message"},{"doc":"aws_api/pinpoint","title":"send_users_messages","content":"pub fn send_users_messages(\n  client: Client,\n  application_id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.send_users_messages\naws_api/pinpoint send_users_messages","url":"aws_api/pinpoint.html#send_users_messages"},{"doc":"aws_api/pinpoint","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.tag_resource\naws_api/pinpoint tag_resource","url":"aws_api/pinpoint.html#tag_resource"},{"doc":"aws_api/pinpoint","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.untag_resource\naws_api/pinpoint untag_resource","url":"aws_api/pinpoint.html#untag_resource"},{"doc":"aws_api/pinpoint","title":"update_adm_channel","content":"pub fn update_adm_channel(\n  client: Client,\n  application_id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.update_adm_channel\naws_api/pinpoint update_adm_channel","url":"aws_api/pinpoint.html#update_adm_channel"},{"doc":"aws_api/pinpoint","title":"update_apns_channel","content":"pub fn update_apns_channel(\n  client: Client,\n  application_id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.update_apns_channel\naws_api/pinpoint update_apns_channel","url":"aws_api/pinpoint.html#update_apns_channel"},{"doc":"aws_api/pinpoint","title":"update_apns_sandbox_channel","content":"pub fn update_apns_sandbox_channel(\n  client: Client,\n  application_id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.update_apns_sandbox_channel\naws_api/pinpoint update_apns_sandbox_channel","url":"aws_api/pinpoint.html#update_apns_sandbox_channel"},{"doc":"aws_api/pinpoint","title":"update_apns_voip_channel","content":"pub fn update_apns_voip_channel(\n  client: Client,\n  application_id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.update_apns_voip_channel\naws_api/pinpoint update_apns_voip_channel","url":"aws_api/pinpoint.html#update_apns_voip_channel"},{"doc":"aws_api/pinpoint","title":"update_apns_voip_sandbox_channel","content":"pub fn update_apns_voip_sandbox_channel(\n  client: Client,\n  application_id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.update_apns_voip_sandbox_channel\naws_api/pinpoint update_apns_voip_sandbox_channel","url":"aws_api/pinpoint.html#update_apns_voip_sandbox_channel"},{"doc":"aws_api/pinpoint","title":"update_application_settings","content":"pub fn update_application_settings(\n  client: Client,\n  application_id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.update_application_settings\naws_api/pinpoint update_application_settings","url":"aws_api/pinpoint.html#update_application_settings"},{"doc":"aws_api/pinpoint","title":"update_baidu_channel","content":"pub fn update_baidu_channel(\n  client: Client,\n  application_id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.update_baidu_channel\naws_api/pinpoint update_baidu_channel","url":"aws_api/pinpoint.html#update_baidu_channel"},{"doc":"aws_api/pinpoint","title":"update_campaign","content":"pub fn update_campaign(\n  client: Client,\n  application_id: String,\n  campaign_id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.update_campaign\naws_api/pinpoint update_campaign","url":"aws_api/pinpoint.html#update_campaign"},{"doc":"aws_api/pinpoint","title":"update_email_channel","content":"pub fn update_email_channel(\n  client: Client,\n  application_id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.update_email_channel\naws_api/pinpoint update_email_channel","url":"aws_api/pinpoint.html#update_email_channel"},{"doc":"aws_api/pinpoint","title":"update_email_template","content":"pub fn update_email_template(\n  client: Client,\n  template_name: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.update_email_template\naws_api/pinpoint update_email_template","url":"aws_api/pinpoint.html#update_email_template"},{"doc":"aws_api/pinpoint","title":"update_endpoint","content":"pub fn update_endpoint(\n  client: Client,\n  application_id: String,\n  endpoint_id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.update_endpoint\naws_api/pinpoint update_endpoint","url":"aws_api/pinpoint.html#update_endpoint"},{"doc":"aws_api/pinpoint","title":"update_endpoints_batch","content":"pub fn update_endpoints_batch(\n  client: Client,\n  application_id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.update_endpoints_batch\naws_api/pinpoint update_endpoints_batch","url":"aws_api/pinpoint.html#update_endpoints_batch"},{"doc":"aws_api/pinpoint","title":"update_gcm_channel","content":"pub fn update_gcm_channel(\n  client: Client,\n  application_id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.update_gcm_channel\naws_api/pinpoint update_gcm_channel","url":"aws_api/pinpoint.html#update_gcm_channel"},{"doc":"aws_api/pinpoint","title":"update_in_app_template","content":"pub fn update_in_app_template(\n  client: Client,\n  template_name: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.update_in_app_template\naws_api/pinpoint update_in_app_template","url":"aws_api/pinpoint.html#update_in_app_template"},{"doc":"aws_api/pinpoint","title":"update_journey","content":"pub fn update_journey(\n  client: Client,\n  application_id: String,\n  journey_id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.update_journey\naws_api/pinpoint update_journey","url":"aws_api/pinpoint.html#update_journey"},{"doc":"aws_api/pinpoint","title":"update_journey_state","content":"pub fn update_journey_state(\n  client: Client,\n  application_id: String,\n  journey_id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.update_journey_state\naws_api/pinpoint update_journey_state","url":"aws_api/pinpoint.html#update_journey_state"},{"doc":"aws_api/pinpoint","title":"update_push_template","content":"pub fn update_push_template(\n  client: Client,\n  template_name: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.update_push_template\naws_api/pinpoint update_push_template","url":"aws_api/pinpoint.html#update_push_template"},{"doc":"aws_api/pinpoint","title":"update_recommender_configuration","content":"pub fn update_recommender_configuration(\n  client: Client,\n  recommender_id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.update_recommender_configuration\naws_api/pinpoint update_recommender_configuration","url":"aws_api/pinpoint.html#update_recommender_configuration"},{"doc":"aws_api/pinpoint","title":"update_segment","content":"pub fn update_segment(\n  client: Client,\n  application_id: String,\n  segment_id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.update_segment\naws_api/pinpoint update_segment","url":"aws_api/pinpoint.html#update_segment"},{"doc":"aws_api/pinpoint","title":"update_sms_channel","content":"pub fn update_sms_channel(\n  client: Client,\n  application_id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.update_sms_channel\naws_api/pinpoint update_sms_channel","url":"aws_api/pinpoint.html#update_sms_channel"},{"doc":"aws_api/pinpoint","title":"update_sms_template","content":"pub fn update_sms_template(\n  client: Client,\n  template_name: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.update_sms_template\naws_api/pinpoint update_sms_template","url":"aws_api/pinpoint.html#update_sms_template"},{"doc":"aws_api/pinpoint","title":"update_template_active_version","content":"pub fn update_template_active_version(\n  client: Client,\n  template_name: String,\n  template_type: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.update_template_active_version\naws_api/pinpoint update_template_active_version","url":"aws_api/pinpoint.html#update_template_active_version"},{"doc":"aws_api/pinpoint","title":"update_voice_channel","content":"pub fn update_voice_channel(\n  client: Client,\n  application_id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.update_voice_channel\naws_api/pinpoint update_voice_channel","url":"aws_api/pinpoint.html#update_voice_channel"},{"doc":"aws_api/pinpoint","title":"update_voice_template","content":"pub fn update_voice_template(\n  client: Client,\n  template_name: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.update_voice_template\naws_api/pinpoint update_voice_template","url":"aws_api/pinpoint.html#update_voice_template"},{"doc":"aws_api/pinpoint","title":"verify_otp_message","content":"pub fn verify_otp_message(\n  client: Client,\n  application_id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint.verify_otp_message\naws_api/pinpoint verify_otp_message","url":"aws_api/pinpoint.html#verify_otp_message"},{"doc":"aws_api/pinpoint","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/pinpoint.with_custom_endpoint\naws_api/pinpoint with_custom_endpoint","url":"aws_api/pinpoint.html#with_custom_endpoint"},{"doc":"aws_api/pinpoint","title":"aws_api/pinpoint","content":"","url":"aws_api/pinpoint.html"},{"doc":"aws_api/pinpoint_email","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/pinpoint_email.Client\naws_api/pinpoint_email Client","url":"aws_api/pinpoint_email.html#Client"},{"doc":"aws_api/pinpoint_email","title":"create_configuration_set","content":"pub fn create_configuration_set(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_email.create_configuration_set\naws_api/pinpoint_email create_configuration_set","url":"aws_api/pinpoint_email.html#create_configuration_set"},{"doc":"aws_api/pinpoint_email","title":"create_configuration_set_event_destination","content":"pub fn create_configuration_set_event_destination(\n  client: Client,\n  configuration_set_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_email.create_configuration_set_event_destination\naws_api/pinpoint_email create_configuration_set_event_destination","url":"aws_api/pinpoint_email.html#create_configuration_set_event_destination"},{"doc":"aws_api/pinpoint_email","title":"create_dedicated_ip_pool","content":"pub fn create_dedicated_ip_pool(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_email.create_dedicated_ip_pool\naws_api/pinpoint_email create_dedicated_ip_pool","url":"aws_api/pinpoint_email.html#create_dedicated_ip_pool"},{"doc":"aws_api/pinpoint_email","title":"create_deliverability_test_report","content":"pub fn create_deliverability_test_report(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_email.create_deliverability_test_report\naws_api/pinpoint_email create_deliverability_test_report","url":"aws_api/pinpoint_email.html#create_deliverability_test_report"},{"doc":"aws_api/pinpoint_email","title":"create_email_identity","content":"pub fn create_email_identity(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_email.create_email_identity\naws_api/pinpoint_email create_email_identity","url":"aws_api/pinpoint_email.html#create_email_identity"},{"doc":"aws_api/pinpoint_email","title":"delete_configuration_set","content":"pub fn delete_configuration_set(\n  client: Client,\n  configuration_set_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_email.delete_configuration_set\naws_api/pinpoint_email delete_configuration_set","url":"aws_api/pinpoint_email.html#delete_configuration_set"},{"doc":"aws_api/pinpoint_email","title":"delete_configuration_set_event_destination","content":"pub fn delete_configuration_set_event_destination(\n  client: Client,\n  configuration_set_name: String,\n  event_destination_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_email.delete_configuration_set_event_destination\naws_api/pinpoint_email delete_configuration_set_event_destination","url":"aws_api/pinpoint_email.html#delete_configuration_set_event_destination"},{"doc":"aws_api/pinpoint_email","title":"delete_dedicated_ip_pool","content":"pub fn delete_dedicated_ip_pool(\n  client: Client,\n  pool_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_email.delete_dedicated_ip_pool\naws_api/pinpoint_email delete_dedicated_ip_pool","url":"aws_api/pinpoint_email.html#delete_dedicated_ip_pool"},{"doc":"aws_api/pinpoint_email","title":"delete_email_identity","content":"pub fn delete_email_identity(\n  client: Client,\n  email_identity: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_email.delete_email_identity\naws_api/pinpoint_email delete_email_identity","url":"aws_api/pinpoint_email.html#delete_email_identity"},{"doc":"aws_api/pinpoint_email","title":"get_account","content":"pub fn get_account(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_email.get_account\naws_api/pinpoint_email get_account","url":"aws_api/pinpoint_email.html#get_account"},{"doc":"aws_api/pinpoint_email","title":"get_blacklist_reports","content":"pub fn get_blacklist_reports(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_email.get_blacklist_reports\naws_api/pinpoint_email get_blacklist_reports","url":"aws_api/pinpoint_email.html#get_blacklist_reports"},{"doc":"aws_api/pinpoint_email","title":"get_configuration_set","content":"pub fn get_configuration_set(\n  client: Client,\n  configuration_set_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_email.get_configuration_set\naws_api/pinpoint_email get_configuration_set","url":"aws_api/pinpoint_email.html#get_configuration_set"},{"doc":"aws_api/pinpoint_email","title":"get_configuration_set_event_destinations","content":"pub fn get_configuration_set_event_destinations(\n  client: Client,\n  configuration_set_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_email.get_configuration_set_event_destinations\naws_api/pinpoint_email get_configuration_set_event_destinations","url":"aws_api/pinpoint_email.html#get_configuration_set_event_destinations"},{"doc":"aws_api/pinpoint_email","title":"get_dedicated_ip","content":"pub fn get_dedicated_ip(\n  client: Client,\n  ip: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_email.get_dedicated_ip\naws_api/pinpoint_email get_dedicated_ip","url":"aws_api/pinpoint_email.html#get_dedicated_ip"},{"doc":"aws_api/pinpoint_email","title":"get_dedicated_ips","content":"pub fn get_dedicated_ips(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_email.get_dedicated_ips\naws_api/pinpoint_email get_dedicated_ips","url":"aws_api/pinpoint_email.html#get_dedicated_ips"},{"doc":"aws_api/pinpoint_email","title":"get_deliverability_dashboard_options","content":"pub fn get_deliverability_dashboard_options(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_email.get_deliverability_dashboard_options\naws_api/pinpoint_email get_deliverability_dashboard_options","url":"aws_api/pinpoint_email.html#get_deliverability_dashboard_options"},{"doc":"aws_api/pinpoint_email","title":"get_deliverability_test_report","content":"pub fn get_deliverability_test_report(\n  client: Client,\n  report_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_email.get_deliverability_test_report\naws_api/pinpoint_email get_deliverability_test_report","url":"aws_api/pinpoint_email.html#get_deliverability_test_report"},{"doc":"aws_api/pinpoint_email","title":"get_domain_deliverability_campaign","content":"pub fn get_domain_deliverability_campaign(\n  client: Client,\n  campaign_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_email.get_domain_deliverability_campaign\naws_api/pinpoint_email get_domain_deliverability_campaign","url":"aws_api/pinpoint_email.html#get_domain_deliverability_campaign"},{"doc":"aws_api/pinpoint_email","title":"get_domain_statistics_report","content":"pub fn get_domain_statistics_report(\n  client: Client,\n  domain: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_email.get_domain_statistics_report\naws_api/pinpoint_email get_domain_statistics_report","url":"aws_api/pinpoint_email.html#get_domain_statistics_report"},{"doc":"aws_api/pinpoint_email","title":"get_email_identity","content":"pub fn get_email_identity(\n  client: Client,\n  email_identity: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_email.get_email_identity\naws_api/pinpoint_email get_email_identity","url":"aws_api/pinpoint_email.html#get_email_identity"},{"doc":"aws_api/pinpoint_email","title":"list_configuration_sets","content":"pub fn list_configuration_sets(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_email.list_configuration_sets\naws_api/pinpoint_email list_configuration_sets","url":"aws_api/pinpoint_email.html#list_configuration_sets"},{"doc":"aws_api/pinpoint_email","title":"list_dedicated_ip_pools","content":"pub fn list_dedicated_ip_pools(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_email.list_dedicated_ip_pools\naws_api/pinpoint_email list_dedicated_ip_pools","url":"aws_api/pinpoint_email.html#list_dedicated_ip_pools"},{"doc":"aws_api/pinpoint_email","title":"list_deliverability_test_reports","content":"pub fn list_deliverability_test_reports(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_email.list_deliverability_test_reports\naws_api/pinpoint_email list_deliverability_test_reports","url":"aws_api/pinpoint_email.html#list_deliverability_test_reports"},{"doc":"aws_api/pinpoint_email","title":"list_domain_deliverability_campaigns","content":"pub fn list_domain_deliverability_campaigns(\n  client: Client,\n  subscribed_domain: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_email.list_domain_deliverability_campaigns\naws_api/pinpoint_email list_domain_deliverability_campaigns","url":"aws_api/pinpoint_email.html#list_domain_deliverability_campaigns"},{"doc":"aws_api/pinpoint_email","title":"list_email_identities","content":"pub fn list_email_identities(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_email.list_email_identities\naws_api/pinpoint_email list_email_identities","url":"aws_api/pinpoint_email.html#list_email_identities"},{"doc":"aws_api/pinpoint_email","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_email.list_tags_for_resource\naws_api/pinpoint_email list_tags_for_resource","url":"aws_api/pinpoint_email.html#list_tags_for_resource"},{"doc":"aws_api/pinpoint_email","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/pinpoint_email.new\naws_api/pinpoint_email new","url":"aws_api/pinpoint_email.html#new"},{"doc":"aws_api/pinpoint_email","title":"put_account_dedicated_ip_warmup_attributes","content":"pub fn put_account_dedicated_ip_warmup_attributes(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_email.put_account_dedicated_ip_warmup_attributes\naws_api/pinpoint_email put_account_dedicated_ip_warmup_attributes","url":"aws_api/pinpoint_email.html#put_account_dedicated_ip_warmup_attributes"},{"doc":"aws_api/pinpoint_email","title":"put_account_sending_attributes","content":"pub fn put_account_sending_attributes(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_email.put_account_sending_attributes\naws_api/pinpoint_email put_account_sending_attributes","url":"aws_api/pinpoint_email.html#put_account_sending_attributes"},{"doc":"aws_api/pinpoint_email","title":"put_configuration_set_delivery_options","content":"pub fn put_configuration_set_delivery_options(\n  client: Client,\n  configuration_set_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_email.put_configuration_set_delivery_options\naws_api/pinpoint_email put_configuration_set_delivery_options","url":"aws_api/pinpoint_email.html#put_configuration_set_delivery_options"},{"doc":"aws_api/pinpoint_email","title":"put_configuration_set_reputation_options","content":"pub fn put_configuration_set_reputation_options(\n  client: Client,\n  configuration_set_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_email.put_configuration_set_reputation_options\naws_api/pinpoint_email put_configuration_set_reputation_options","url":"aws_api/pinpoint_email.html#put_configuration_set_reputation_options"},{"doc":"aws_api/pinpoint_email","title":"put_configuration_set_sending_options","content":"pub fn put_configuration_set_sending_options(\n  client: Client,\n  configuration_set_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_email.put_configuration_set_sending_options\naws_api/pinpoint_email put_configuration_set_sending_options","url":"aws_api/pinpoint_email.html#put_configuration_set_sending_options"},{"doc":"aws_api/pinpoint_email","title":"put_configuration_set_tracking_options","content":"pub fn put_configuration_set_tracking_options(\n  client: Client,\n  configuration_set_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_email.put_configuration_set_tracking_options\naws_api/pinpoint_email put_configuration_set_tracking_options","url":"aws_api/pinpoint_email.html#put_configuration_set_tracking_options"},{"doc":"aws_api/pinpoint_email","title":"put_dedicated_ip_in_pool","content":"pub fn put_dedicated_ip_in_pool(\n  client: Client,\n  ip: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_email.put_dedicated_ip_in_pool\naws_api/pinpoint_email put_dedicated_ip_in_pool","url":"aws_api/pinpoint_email.html#put_dedicated_ip_in_pool"},{"doc":"aws_api/pinpoint_email","title":"put_dedicated_ip_warmup_attributes","content":"pub fn put_dedicated_ip_warmup_attributes(\n  client: Client,\n  ip: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_email.put_dedicated_ip_warmup_attributes\naws_api/pinpoint_email put_dedicated_ip_warmup_attributes","url":"aws_api/pinpoint_email.html#put_dedicated_ip_warmup_attributes"},{"doc":"aws_api/pinpoint_email","title":"put_deliverability_dashboard_option","content":"pub fn put_deliverability_dashboard_option(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_email.put_deliverability_dashboard_option\naws_api/pinpoint_email put_deliverability_dashboard_option","url":"aws_api/pinpoint_email.html#put_deliverability_dashboard_option"},{"doc":"aws_api/pinpoint_email","title":"put_email_identity_dkim_attributes","content":"pub fn put_email_identity_dkim_attributes(\n  client: Client,\n  email_identity: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_email.put_email_identity_dkim_attributes\naws_api/pinpoint_email put_email_identity_dkim_attributes","url":"aws_api/pinpoint_email.html#put_email_identity_dkim_attributes"},{"doc":"aws_api/pinpoint_email","title":"put_email_identity_feedback_attributes","content":"pub fn put_email_identity_feedback_attributes(\n  client: Client,\n  email_identity: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_email.put_email_identity_feedback_attributes\naws_api/pinpoint_email put_email_identity_feedback_attributes","url":"aws_api/pinpoint_email.html#put_email_identity_feedback_attributes"},{"doc":"aws_api/pinpoint_email","title":"put_email_identity_mail_from_attributes","content":"pub fn put_email_identity_mail_from_attributes(\n  client: Client,\n  email_identity: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_email.put_email_identity_mail_from_attributes\naws_api/pinpoint_email put_email_identity_mail_from_attributes","url":"aws_api/pinpoint_email.html#put_email_identity_mail_from_attributes"},{"doc":"aws_api/pinpoint_email","title":"send_email","content":"pub fn send_email(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_email.send_email\naws_api/pinpoint_email send_email","url":"aws_api/pinpoint_email.html#send_email"},{"doc":"aws_api/pinpoint_email","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_email.tag_resource\naws_api/pinpoint_email tag_resource","url":"aws_api/pinpoint_email.html#tag_resource"},{"doc":"aws_api/pinpoint_email","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_email.untag_resource\naws_api/pinpoint_email untag_resource","url":"aws_api/pinpoint_email.html#untag_resource"},{"doc":"aws_api/pinpoint_email","title":"update_configuration_set_event_destination","content":"pub fn update_configuration_set_event_destination(\n  client: Client,\n  configuration_set_name: String,\n  event_destination_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_email.update_configuration_set_event_destination\naws_api/pinpoint_email update_configuration_set_event_destination","url":"aws_api/pinpoint_email.html#update_configuration_set_event_destination"},{"doc":"aws_api/pinpoint_email","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/pinpoint_email.with_custom_endpoint\naws_api/pinpoint_email with_custom_endpoint","url":"aws_api/pinpoint_email.html#with_custom_endpoint"},{"doc":"aws_api/pinpoint_email","title":"aws_api/pinpoint_email","content":"","url":"aws_api/pinpoint_email.html"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.Client\naws_api/pinpoint_sms_voice_v2 Client","url":"aws_api/pinpoint_sms_voice_v2.html#Client"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"associate_origination_identity","content":"pub fn associate_origination_identity(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.associate_origination_identity\naws_api/pinpoint_sms_voice_v2 associate_origination_identity","url":"aws_api/pinpoint_sms_voice_v2.html#associate_origination_identity"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"associate_protect_configuration","content":"pub fn associate_protect_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.associate_protect_configuration\naws_api/pinpoint_sms_voice_v2 associate_protect_configuration","url":"aws_api/pinpoint_sms_voice_v2.html#associate_protect_configuration"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"create_configuration_set","content":"pub fn create_configuration_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.create_configuration_set\naws_api/pinpoint_sms_voice_v2 create_configuration_set","url":"aws_api/pinpoint_sms_voice_v2.html#create_configuration_set"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"create_event_destination","content":"pub fn create_event_destination(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.create_event_destination\naws_api/pinpoint_sms_voice_v2 create_event_destination","url":"aws_api/pinpoint_sms_voice_v2.html#create_event_destination"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"create_opt_out_list","content":"pub fn create_opt_out_list(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.create_opt_out_list\naws_api/pinpoint_sms_voice_v2 create_opt_out_list","url":"aws_api/pinpoint_sms_voice_v2.html#create_opt_out_list"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"create_pool","content":"pub fn create_pool(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.create_pool\naws_api/pinpoint_sms_voice_v2 create_pool","url":"aws_api/pinpoint_sms_voice_v2.html#create_pool"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"create_protect_configuration","content":"pub fn create_protect_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.create_protect_configuration\naws_api/pinpoint_sms_voice_v2 create_protect_configuration","url":"aws_api/pinpoint_sms_voice_v2.html#create_protect_configuration"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"create_registration","content":"pub fn create_registration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.create_registration\naws_api/pinpoint_sms_voice_v2 create_registration","url":"aws_api/pinpoint_sms_voice_v2.html#create_registration"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"create_registration_association","content":"pub fn create_registration_association(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.create_registration_association\naws_api/pinpoint_sms_voice_v2 create_registration_association","url":"aws_api/pinpoint_sms_voice_v2.html#create_registration_association"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"create_registration_attachment","content":"pub fn create_registration_attachment(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.create_registration_attachment\naws_api/pinpoint_sms_voice_v2 create_registration_attachment","url":"aws_api/pinpoint_sms_voice_v2.html#create_registration_attachment"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"create_registration_version","content":"pub fn create_registration_version(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.create_registration_version\naws_api/pinpoint_sms_voice_v2 create_registration_version","url":"aws_api/pinpoint_sms_voice_v2.html#create_registration_version"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"create_verified_destination_number","content":"pub fn create_verified_destination_number(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.create_verified_destination_number\naws_api/pinpoint_sms_voice_v2 create_verified_destination_number","url":"aws_api/pinpoint_sms_voice_v2.html#create_verified_destination_number"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"delete_account_default_protect_configuration","content":"pub fn delete_account_default_protect_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.delete_account_default_protect_configuration\naws_api/pinpoint_sms_voice_v2 delete_account_default_protect_configuration","url":"aws_api/pinpoint_sms_voice_v2.html#delete_account_default_protect_configuration"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"delete_configuration_set","content":"pub fn delete_configuration_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.delete_configuration_set\naws_api/pinpoint_sms_voice_v2 delete_configuration_set","url":"aws_api/pinpoint_sms_voice_v2.html#delete_configuration_set"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"delete_default_message_type","content":"pub fn delete_default_message_type(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.delete_default_message_type\naws_api/pinpoint_sms_voice_v2 delete_default_message_type","url":"aws_api/pinpoint_sms_voice_v2.html#delete_default_message_type"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"delete_default_sender_id","content":"pub fn delete_default_sender_id(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.delete_default_sender_id\naws_api/pinpoint_sms_voice_v2 delete_default_sender_id","url":"aws_api/pinpoint_sms_voice_v2.html#delete_default_sender_id"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"delete_event_destination","content":"pub fn delete_event_destination(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.delete_event_destination\naws_api/pinpoint_sms_voice_v2 delete_event_destination","url":"aws_api/pinpoint_sms_voice_v2.html#delete_event_destination"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"delete_keyword","content":"pub fn delete_keyword(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.delete_keyword\naws_api/pinpoint_sms_voice_v2 delete_keyword","url":"aws_api/pinpoint_sms_voice_v2.html#delete_keyword"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"delete_media_message_spend_limit_override","content":"pub fn delete_media_message_spend_limit_override(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.delete_media_message_spend_limit_override\naws_api/pinpoint_sms_voice_v2 delete_media_message_spend_limit_override","url":"aws_api/pinpoint_sms_voice_v2.html#delete_media_message_spend_limit_override"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"delete_opt_out_list","content":"pub fn delete_opt_out_list(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.delete_opt_out_list\naws_api/pinpoint_sms_voice_v2 delete_opt_out_list","url":"aws_api/pinpoint_sms_voice_v2.html#delete_opt_out_list"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"delete_opted_out_number","content":"pub fn delete_opted_out_number(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.delete_opted_out_number\naws_api/pinpoint_sms_voice_v2 delete_opted_out_number","url":"aws_api/pinpoint_sms_voice_v2.html#delete_opted_out_number"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"delete_pool","content":"pub fn delete_pool(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.delete_pool\naws_api/pinpoint_sms_voice_v2 delete_pool","url":"aws_api/pinpoint_sms_voice_v2.html#delete_pool"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"delete_protect_configuration","content":"pub fn delete_protect_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.delete_protect_configuration\naws_api/pinpoint_sms_voice_v2 delete_protect_configuration","url":"aws_api/pinpoint_sms_voice_v2.html#delete_protect_configuration"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"delete_registration","content":"pub fn delete_registration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.delete_registration\naws_api/pinpoint_sms_voice_v2 delete_registration","url":"aws_api/pinpoint_sms_voice_v2.html#delete_registration"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"delete_registration_attachment","content":"pub fn delete_registration_attachment(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.delete_registration_attachment\naws_api/pinpoint_sms_voice_v2 delete_registration_attachment","url":"aws_api/pinpoint_sms_voice_v2.html#delete_registration_attachment"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"delete_registration_field_value","content":"pub fn delete_registration_field_value(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.delete_registration_field_value\naws_api/pinpoint_sms_voice_v2 delete_registration_field_value","url":"aws_api/pinpoint_sms_voice_v2.html#delete_registration_field_value"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"delete_text_message_spend_limit_override","content":"pub fn delete_text_message_spend_limit_override(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.delete_text_message_spend_limit_override\naws_api/pinpoint_sms_voice_v2 delete_text_message_spend_limit_override","url":"aws_api/pinpoint_sms_voice_v2.html#delete_text_message_spend_limit_override"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"delete_verified_destination_number","content":"pub fn delete_verified_destination_number(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.delete_verified_destination_number\naws_api/pinpoint_sms_voice_v2 delete_verified_destination_number","url":"aws_api/pinpoint_sms_voice_v2.html#delete_verified_destination_number"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"delete_voice_message_spend_limit_override","content":"pub fn delete_voice_message_spend_limit_override(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.delete_voice_message_spend_limit_override\naws_api/pinpoint_sms_voice_v2 delete_voice_message_spend_limit_override","url":"aws_api/pinpoint_sms_voice_v2.html#delete_voice_message_spend_limit_override"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"describe_account_attributes","content":"pub fn describe_account_attributes(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.describe_account_attributes\naws_api/pinpoint_sms_voice_v2 describe_account_attributes","url":"aws_api/pinpoint_sms_voice_v2.html#describe_account_attributes"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"describe_account_limits","content":"pub fn describe_account_limits(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.describe_account_limits\naws_api/pinpoint_sms_voice_v2 describe_account_limits","url":"aws_api/pinpoint_sms_voice_v2.html#describe_account_limits"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"describe_configuration_sets","content":"pub fn describe_configuration_sets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.describe_configuration_sets\naws_api/pinpoint_sms_voice_v2 describe_configuration_sets","url":"aws_api/pinpoint_sms_voice_v2.html#describe_configuration_sets"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"describe_keywords","content":"pub fn describe_keywords(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.describe_keywords\naws_api/pinpoint_sms_voice_v2 describe_keywords","url":"aws_api/pinpoint_sms_voice_v2.html#describe_keywords"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"describe_opt_out_lists","content":"pub fn describe_opt_out_lists(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.describe_opt_out_lists\naws_api/pinpoint_sms_voice_v2 describe_opt_out_lists","url":"aws_api/pinpoint_sms_voice_v2.html#describe_opt_out_lists"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"describe_opted_out_numbers","content":"pub fn describe_opted_out_numbers(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.describe_opted_out_numbers\naws_api/pinpoint_sms_voice_v2 describe_opted_out_numbers","url":"aws_api/pinpoint_sms_voice_v2.html#describe_opted_out_numbers"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"describe_phone_numbers","content":"pub fn describe_phone_numbers(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.describe_phone_numbers\naws_api/pinpoint_sms_voice_v2 describe_phone_numbers","url":"aws_api/pinpoint_sms_voice_v2.html#describe_phone_numbers"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"describe_pools","content":"pub fn describe_pools(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.describe_pools\naws_api/pinpoint_sms_voice_v2 describe_pools","url":"aws_api/pinpoint_sms_voice_v2.html#describe_pools"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"describe_protect_configurations","content":"pub fn describe_protect_configurations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.describe_protect_configurations\naws_api/pinpoint_sms_voice_v2 describe_protect_configurations","url":"aws_api/pinpoint_sms_voice_v2.html#describe_protect_configurations"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"describe_registration_attachments","content":"pub fn describe_registration_attachments(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.describe_registration_attachments\naws_api/pinpoint_sms_voice_v2 describe_registration_attachments","url":"aws_api/pinpoint_sms_voice_v2.html#describe_registration_attachments"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"describe_registration_field_definitions","content":"pub fn describe_registration_field_definitions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.describe_registration_field_definitions\naws_api/pinpoint_sms_voice_v2 describe_registration_field_definitions","url":"aws_api/pinpoint_sms_voice_v2.html#describe_registration_field_definitions"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"describe_registration_field_values","content":"pub fn describe_registration_field_values(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.describe_registration_field_values\naws_api/pinpoint_sms_voice_v2 describe_registration_field_values","url":"aws_api/pinpoint_sms_voice_v2.html#describe_registration_field_values"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"describe_registration_section_definitions","content":"pub fn describe_registration_section_definitions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.describe_registration_section_definitions\naws_api/pinpoint_sms_voice_v2 describe_registration_section_definitions","url":"aws_api/pinpoint_sms_voice_v2.html#describe_registration_section_definitions"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"describe_registration_type_definitions","content":"pub fn describe_registration_type_definitions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.describe_registration_type_definitions\naws_api/pinpoint_sms_voice_v2 describe_registration_type_definitions","url":"aws_api/pinpoint_sms_voice_v2.html#describe_registration_type_definitions"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"describe_registration_versions","content":"pub fn describe_registration_versions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.describe_registration_versions\naws_api/pinpoint_sms_voice_v2 describe_registration_versions","url":"aws_api/pinpoint_sms_voice_v2.html#describe_registration_versions"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"describe_registrations","content":"pub fn describe_registrations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.describe_registrations\naws_api/pinpoint_sms_voice_v2 describe_registrations","url":"aws_api/pinpoint_sms_voice_v2.html#describe_registrations"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"describe_sender_ids","content":"pub fn describe_sender_ids(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.describe_sender_ids\naws_api/pinpoint_sms_voice_v2 describe_sender_ids","url":"aws_api/pinpoint_sms_voice_v2.html#describe_sender_ids"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"describe_spend_limits","content":"pub fn describe_spend_limits(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.describe_spend_limits\naws_api/pinpoint_sms_voice_v2 describe_spend_limits","url":"aws_api/pinpoint_sms_voice_v2.html#describe_spend_limits"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"describe_verified_destination_numbers","content":"pub fn describe_verified_destination_numbers(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.describe_verified_destination_numbers\naws_api/pinpoint_sms_voice_v2 describe_verified_destination_numbers","url":"aws_api/pinpoint_sms_voice_v2.html#describe_verified_destination_numbers"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"disassociate_origination_identity","content":"pub fn disassociate_origination_identity(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.disassociate_origination_identity\naws_api/pinpoint_sms_voice_v2 disassociate_origination_identity","url":"aws_api/pinpoint_sms_voice_v2.html#disassociate_origination_identity"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"disassociate_protect_configuration","content":"pub fn disassociate_protect_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.disassociate_protect_configuration\naws_api/pinpoint_sms_voice_v2 disassociate_protect_configuration","url":"aws_api/pinpoint_sms_voice_v2.html#disassociate_protect_configuration"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"discard_registration_version","content":"pub fn discard_registration_version(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.discard_registration_version\naws_api/pinpoint_sms_voice_v2 discard_registration_version","url":"aws_api/pinpoint_sms_voice_v2.html#discard_registration_version"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"get_protect_configuration_country_rule_set","content":"pub fn get_protect_configuration_country_rule_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.get_protect_configuration_country_rule_set\naws_api/pinpoint_sms_voice_v2 get_protect_configuration_country_rule_set","url":"aws_api/pinpoint_sms_voice_v2.html#get_protect_configuration_country_rule_set"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"list_pool_origination_identities","content":"pub fn list_pool_origination_identities(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.list_pool_origination_identities\naws_api/pinpoint_sms_voice_v2 list_pool_origination_identities","url":"aws_api/pinpoint_sms_voice_v2.html#list_pool_origination_identities"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"list_registration_associations","content":"pub fn list_registration_associations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.list_registration_associations\naws_api/pinpoint_sms_voice_v2 list_registration_associations","url":"aws_api/pinpoint_sms_voice_v2.html#list_registration_associations"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.list_tags_for_resource\naws_api/pinpoint_sms_voice_v2 list_tags_for_resource","url":"aws_api/pinpoint_sms_voice_v2.html#list_tags_for_resource"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.new\naws_api/pinpoint_sms_voice_v2 new","url":"aws_api/pinpoint_sms_voice_v2.html#new"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"put_keyword","content":"pub fn put_keyword(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.put_keyword\naws_api/pinpoint_sms_voice_v2 put_keyword","url":"aws_api/pinpoint_sms_voice_v2.html#put_keyword"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"put_opted_out_number","content":"pub fn put_opted_out_number(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.put_opted_out_number\naws_api/pinpoint_sms_voice_v2 put_opted_out_number","url":"aws_api/pinpoint_sms_voice_v2.html#put_opted_out_number"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"put_registration_field_value","content":"pub fn put_registration_field_value(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.put_registration_field_value\naws_api/pinpoint_sms_voice_v2 put_registration_field_value","url":"aws_api/pinpoint_sms_voice_v2.html#put_registration_field_value"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"release_phone_number","content":"pub fn release_phone_number(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.release_phone_number\naws_api/pinpoint_sms_voice_v2 release_phone_number","url":"aws_api/pinpoint_sms_voice_v2.html#release_phone_number"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"release_sender_id","content":"pub fn release_sender_id(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.release_sender_id\naws_api/pinpoint_sms_voice_v2 release_sender_id","url":"aws_api/pinpoint_sms_voice_v2.html#release_sender_id"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"request_phone_number","content":"pub fn request_phone_number(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.request_phone_number\naws_api/pinpoint_sms_voice_v2 request_phone_number","url":"aws_api/pinpoint_sms_voice_v2.html#request_phone_number"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"request_sender_id","content":"pub fn request_sender_id(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.request_sender_id\naws_api/pinpoint_sms_voice_v2 request_sender_id","url":"aws_api/pinpoint_sms_voice_v2.html#request_sender_id"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"send_destination_number_verification_code","content":"pub fn send_destination_number_verification_code(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.send_destination_number_verification_code\naws_api/pinpoint_sms_voice_v2 send_destination_number_verification_code","url":"aws_api/pinpoint_sms_voice_v2.html#send_destination_number_verification_code"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"send_media_message","content":"pub fn send_media_message(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.send_media_message\naws_api/pinpoint_sms_voice_v2 send_media_message","url":"aws_api/pinpoint_sms_voice_v2.html#send_media_message"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"send_text_message","content":"pub fn send_text_message(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.send_text_message\naws_api/pinpoint_sms_voice_v2 send_text_message","url":"aws_api/pinpoint_sms_voice_v2.html#send_text_message"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"send_voice_message","content":"pub fn send_voice_message(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.send_voice_message\naws_api/pinpoint_sms_voice_v2 send_voice_message","url":"aws_api/pinpoint_sms_voice_v2.html#send_voice_message"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"set_account_default_protect_configuration","content":"pub fn set_account_default_protect_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.set_account_default_protect_configuration\naws_api/pinpoint_sms_voice_v2 set_account_default_protect_configuration","url":"aws_api/pinpoint_sms_voice_v2.html#set_account_default_protect_configuration"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"set_default_message_type","content":"pub fn set_default_message_type(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.set_default_message_type\naws_api/pinpoint_sms_voice_v2 set_default_message_type","url":"aws_api/pinpoint_sms_voice_v2.html#set_default_message_type"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"set_default_sender_id","content":"pub fn set_default_sender_id(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.set_default_sender_id\naws_api/pinpoint_sms_voice_v2 set_default_sender_id","url":"aws_api/pinpoint_sms_voice_v2.html#set_default_sender_id"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"set_media_message_spend_limit_override","content":"pub fn set_media_message_spend_limit_override(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.set_media_message_spend_limit_override\naws_api/pinpoint_sms_voice_v2 set_media_message_spend_limit_override","url":"aws_api/pinpoint_sms_voice_v2.html#set_media_message_spend_limit_override"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"set_text_message_spend_limit_override","content":"pub fn set_text_message_spend_limit_override(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.set_text_message_spend_limit_override\naws_api/pinpoint_sms_voice_v2 set_text_message_spend_limit_override","url":"aws_api/pinpoint_sms_voice_v2.html#set_text_message_spend_limit_override"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"set_voice_message_spend_limit_override","content":"pub fn set_voice_message_spend_limit_override(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.set_voice_message_spend_limit_override\naws_api/pinpoint_sms_voice_v2 set_voice_message_spend_limit_override","url":"aws_api/pinpoint_sms_voice_v2.html#set_voice_message_spend_limit_override"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"submit_registration_version","content":"pub fn submit_registration_version(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.submit_registration_version\naws_api/pinpoint_sms_voice_v2 submit_registration_version","url":"aws_api/pinpoint_sms_voice_v2.html#submit_registration_version"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.tag_resource\naws_api/pinpoint_sms_voice_v2 tag_resource","url":"aws_api/pinpoint_sms_voice_v2.html#tag_resource"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.untag_resource\naws_api/pinpoint_sms_voice_v2 untag_resource","url":"aws_api/pinpoint_sms_voice_v2.html#untag_resource"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"update_event_destination","content":"pub fn update_event_destination(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.update_event_destination\naws_api/pinpoint_sms_voice_v2 update_event_destination","url":"aws_api/pinpoint_sms_voice_v2.html#update_event_destination"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"update_phone_number","content":"pub fn update_phone_number(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.update_phone_number\naws_api/pinpoint_sms_voice_v2 update_phone_number","url":"aws_api/pinpoint_sms_voice_v2.html#update_phone_number"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"update_pool","content":"pub fn update_pool(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.update_pool\naws_api/pinpoint_sms_voice_v2 update_pool","url":"aws_api/pinpoint_sms_voice_v2.html#update_pool"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"update_protect_configuration","content":"pub fn update_protect_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.update_protect_configuration\naws_api/pinpoint_sms_voice_v2 update_protect_configuration","url":"aws_api/pinpoint_sms_voice_v2.html#update_protect_configuration"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"update_protect_configuration_country_rule_set","content":"pub fn update_protect_configuration_country_rule_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.update_protect_configuration_country_rule_set\naws_api/pinpoint_sms_voice_v2 update_protect_configuration_country_rule_set","url":"aws_api/pinpoint_sms_voice_v2.html#update_protect_configuration_country_rule_set"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"update_sender_id","content":"pub fn update_sender_id(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.update_sender_id\naws_api/pinpoint_sms_voice_v2 update_sender_id","url":"aws_api/pinpoint_sms_voice_v2.html#update_sender_id"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"verify_destination_number","content":"pub fn verify_destination_number(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.verify_destination_number\naws_api/pinpoint_sms_voice_v2 verify_destination_number","url":"aws_api/pinpoint_sms_voice_v2.html#verify_destination_number"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/pinpoint_sms_voice_v2.with_custom_endpoint\naws_api/pinpoint_sms_voice_v2 with_custom_endpoint","url":"aws_api/pinpoint_sms_voice_v2.html#with_custom_endpoint"},{"doc":"aws_api/pinpoint_sms_voice_v2","title":"aws_api/pinpoint_sms_voice_v2","content":"","url":"aws_api/pinpoint_sms_voice_v2.html"},{"doc":"aws_api/pipes","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/pipes.Client\naws_api/pipes Client","url":"aws_api/pipes.html#Client"},{"doc":"aws_api/pipes","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pipes.list_tags_for_resource\naws_api/pipes list_tags_for_resource","url":"aws_api/pipes.html#list_tags_for_resource"},{"doc":"aws_api/pipes","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/pipes.new\naws_api/pipes new","url":"aws_api/pipes.html#new"},{"doc":"aws_api/pipes","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pipes.tag_resource\naws_api/pipes tag_resource","url":"aws_api/pipes.html#tag_resource"},{"doc":"aws_api/pipes","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pipes.untag_resource\naws_api/pipes untag_resource","url":"aws_api/pipes.html#untag_resource"},{"doc":"aws_api/pipes","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/pipes.with_custom_endpoint\naws_api/pipes with_custom_endpoint","url":"aws_api/pipes.html#with_custom_endpoint"},{"doc":"aws_api/pipes","title":"aws_api/pipes","content":"","url":"aws_api/pipes.html"},{"doc":"aws_api/polly","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/polly.Client\naws_api/polly Client","url":"aws_api/polly.html#Client"},{"doc":"aws_api/polly","title":"delete_lexicon","content":"pub fn delete_lexicon(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/polly.delete_lexicon\naws_api/polly delete_lexicon","url":"aws_api/polly.html#delete_lexicon"},{"doc":"aws_api/polly","title":"describe_voices","content":"pub fn describe_voices(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/polly.describe_voices\naws_api/polly describe_voices","url":"aws_api/polly.html#describe_voices"},{"doc":"aws_api/polly","title":"get_lexicon","content":"pub fn get_lexicon(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/polly.get_lexicon\naws_api/polly get_lexicon","url":"aws_api/polly.html#get_lexicon"},{"doc":"aws_api/polly","title":"get_speech_synthesis_task","content":"pub fn get_speech_synthesis_task(\n  client: Client,\n  task_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/polly.get_speech_synthesis_task\naws_api/polly get_speech_synthesis_task","url":"aws_api/polly.html#get_speech_synthesis_task"},{"doc":"aws_api/polly","title":"list_lexicons","content":"pub fn list_lexicons(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/polly.list_lexicons\naws_api/polly list_lexicons","url":"aws_api/polly.html#list_lexicons"},{"doc":"aws_api/polly","title":"list_speech_synthesis_tasks","content":"pub fn list_speech_synthesis_tasks(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/polly.list_speech_synthesis_tasks\naws_api/polly list_speech_synthesis_tasks","url":"aws_api/polly.html#list_speech_synthesis_tasks"},{"doc":"aws_api/polly","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/polly.new\naws_api/polly new","url":"aws_api/polly.html#new"},{"doc":"aws_api/polly","title":"put_lexicon","content":"pub fn put_lexicon(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/polly.put_lexicon\naws_api/polly put_lexicon","url":"aws_api/polly.html#put_lexicon"},{"doc":"aws_api/polly","title":"start_speech_synthesis_task","content":"pub fn start_speech_synthesis_task(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/polly.start_speech_synthesis_task\naws_api/polly start_speech_synthesis_task","url":"aws_api/polly.html#start_speech_synthesis_task"},{"doc":"aws_api/polly","title":"synthesize_speech","content":"pub fn synthesize_speech(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/polly.synthesize_speech\naws_api/polly synthesize_speech","url":"aws_api/polly.html#synthesize_speech"},{"doc":"aws_api/polly","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/polly.with_custom_endpoint\naws_api/polly with_custom_endpoint","url":"aws_api/polly.html#with_custom_endpoint"},{"doc":"aws_api/polly","title":"aws_api/polly","content":"","url":"aws_api/polly.html"},{"doc":"aws_api/pricing","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/pricing.Client\naws_api/pricing Client","url":"aws_api/pricing.html#Client"},{"doc":"aws_api/pricing","title":"describe_services","content":"pub fn describe_services(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pricing.describe_services\naws_api/pricing describe_services","url":"aws_api/pricing.html#describe_services"},{"doc":"aws_api/pricing","title":"get_attribute_values","content":"pub fn get_attribute_values(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pricing.get_attribute_values\naws_api/pricing get_attribute_values","url":"aws_api/pricing.html#get_attribute_values"},{"doc":"aws_api/pricing","title":"get_price_list_file_url","content":"pub fn get_price_list_file_url(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pricing.get_price_list_file_url\naws_api/pricing get_price_list_file_url","url":"aws_api/pricing.html#get_price_list_file_url"},{"doc":"aws_api/pricing","title":"get_products","content":"pub fn get_products(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pricing.get_products\naws_api/pricing get_products","url":"aws_api/pricing.html#get_products"},{"doc":"aws_api/pricing","title":"list_price_lists","content":"pub fn list_price_lists(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/pricing.list_price_lists\naws_api/pricing list_price_lists","url":"aws_api/pricing.html#list_price_lists"},{"doc":"aws_api/pricing","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/pricing.new\naws_api/pricing new","url":"aws_api/pricing.html#new"},{"doc":"aws_api/pricing","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/pricing.with_custom_endpoint\naws_api/pricing with_custom_endpoint","url":"aws_api/pricing.html#with_custom_endpoint"},{"doc":"aws_api/pricing","title":"aws_api/pricing","content":"","url":"aws_api/pricing.html"},{"doc":"aws_api/privatenetworks","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/privatenetworks.Client\naws_api/privatenetworks Client","url":"aws_api/privatenetworks.html#Client"},{"doc":"aws_api/privatenetworks","title":"acknowledge_order_receipt","content":"pub fn acknowledge_order_receipt(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/privatenetworks.acknowledge_order_receipt\naws_api/privatenetworks acknowledge_order_receipt","url":"aws_api/privatenetworks.html#acknowledge_order_receipt"},{"doc":"aws_api/privatenetworks","title":"activate_device_identifier","content":"pub fn activate_device_identifier(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/privatenetworks.activate_device_identifier\naws_api/privatenetworks activate_device_identifier","url":"aws_api/privatenetworks.html#activate_device_identifier"},{"doc":"aws_api/privatenetworks","title":"activate_network_site","content":"pub fn activate_network_site(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/privatenetworks.activate_network_site\naws_api/privatenetworks activate_network_site","url":"aws_api/privatenetworks.html#activate_network_site"},{"doc":"aws_api/privatenetworks","title":"configure_access_point","content":"pub fn configure_access_point(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/privatenetworks.configure_access_point\naws_api/privatenetworks configure_access_point","url":"aws_api/privatenetworks.html#configure_access_point"},{"doc":"aws_api/privatenetworks","title":"create_network","content":"pub fn create_network(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/privatenetworks.create_network\naws_api/privatenetworks create_network","url":"aws_api/privatenetworks.html#create_network"},{"doc":"aws_api/privatenetworks","title":"create_network_site","content":"pub fn create_network_site(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/privatenetworks.create_network_site\naws_api/privatenetworks create_network_site","url":"aws_api/privatenetworks.html#create_network_site"},{"doc":"aws_api/privatenetworks","title":"deactivate_device_identifier","content":"pub fn deactivate_device_identifier(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/privatenetworks.deactivate_device_identifier\naws_api/privatenetworks deactivate_device_identifier","url":"aws_api/privatenetworks.html#deactivate_device_identifier"},{"doc":"aws_api/privatenetworks","title":"delete_network","content":"pub fn delete_network(\n  client: Client,\n  network_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/privatenetworks.delete_network\naws_api/privatenetworks delete_network","url":"aws_api/privatenetworks.html#delete_network"},{"doc":"aws_api/privatenetworks","title":"delete_network_site","content":"pub fn delete_network_site(\n  client: Client,\n  network_site_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/privatenetworks.delete_network_site\naws_api/privatenetworks delete_network_site","url":"aws_api/privatenetworks.html#delete_network_site"},{"doc":"aws_api/privatenetworks","title":"get_device_identifier","content":"pub fn get_device_identifier(\n  client: Client,\n  device_identifier_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/privatenetworks.get_device_identifier\naws_api/privatenetworks get_device_identifier","url":"aws_api/privatenetworks.html#get_device_identifier"},{"doc":"aws_api/privatenetworks","title":"get_network","content":"pub fn get_network(\n  client: Client,\n  network_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/privatenetworks.get_network\naws_api/privatenetworks get_network","url":"aws_api/privatenetworks.html#get_network"},{"doc":"aws_api/privatenetworks","title":"get_network_resource","content":"pub fn get_network_resource(\n  client: Client,\n  network_resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/privatenetworks.get_network_resource\naws_api/privatenetworks get_network_resource","url":"aws_api/privatenetworks.html#get_network_resource"},{"doc":"aws_api/privatenetworks","title":"get_network_site","content":"pub fn get_network_site(\n  client: Client,\n  network_site_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/privatenetworks.get_network_site\naws_api/privatenetworks get_network_site","url":"aws_api/privatenetworks.html#get_network_site"},{"doc":"aws_api/privatenetworks","title":"get_order","content":"pub fn get_order(\n  client: Client,\n  order_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/privatenetworks.get_order\naws_api/privatenetworks get_order","url":"aws_api/privatenetworks.html#get_order"},{"doc":"aws_api/privatenetworks","title":"list_device_identifiers","content":"pub fn list_device_identifiers(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/privatenetworks.list_device_identifiers\naws_api/privatenetworks list_device_identifiers","url":"aws_api/privatenetworks.html#list_device_identifiers"},{"doc":"aws_api/privatenetworks","title":"list_network_resources","content":"pub fn list_network_resources(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/privatenetworks.list_network_resources\naws_api/privatenetworks list_network_resources","url":"aws_api/privatenetworks.html#list_network_resources"},{"doc":"aws_api/privatenetworks","title":"list_network_sites","content":"pub fn list_network_sites(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/privatenetworks.list_network_sites\naws_api/privatenetworks list_network_sites","url":"aws_api/privatenetworks.html#list_network_sites"},{"doc":"aws_api/privatenetworks","title":"list_networks","content":"pub fn list_networks(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/privatenetworks.list_networks\naws_api/privatenetworks list_networks","url":"aws_api/privatenetworks.html#list_networks"},{"doc":"aws_api/privatenetworks","title":"list_orders","content":"pub fn list_orders(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/privatenetworks.list_orders\naws_api/privatenetworks list_orders","url":"aws_api/privatenetworks.html#list_orders"},{"doc":"aws_api/privatenetworks","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/privatenetworks.list_tags_for_resource\naws_api/privatenetworks list_tags_for_resource","url":"aws_api/privatenetworks.html#list_tags_for_resource"},{"doc":"aws_api/privatenetworks","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/privatenetworks.new\naws_api/privatenetworks new","url":"aws_api/privatenetworks.html#new"},{"doc":"aws_api/privatenetworks","title":"ping","content":"pub fn ping(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/privatenetworks.ping\naws_api/privatenetworks ping","url":"aws_api/privatenetworks.html#ping"},{"doc":"aws_api/privatenetworks","title":"start_network_resource_update","content":"pub fn start_network_resource_update(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/privatenetworks.start_network_resource_update\naws_api/privatenetworks start_network_resource_update","url":"aws_api/privatenetworks.html#start_network_resource_update"},{"doc":"aws_api/privatenetworks","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/privatenetworks.tag_resource\naws_api/privatenetworks tag_resource","url":"aws_api/privatenetworks.html#tag_resource"},{"doc":"aws_api/privatenetworks","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/privatenetworks.untag_resource\naws_api/privatenetworks untag_resource","url":"aws_api/privatenetworks.html#untag_resource"},{"doc":"aws_api/privatenetworks","title":"update_network_site","content":"pub fn update_network_site(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/privatenetworks.update_network_site\naws_api/privatenetworks update_network_site","url":"aws_api/privatenetworks.html#update_network_site"},{"doc":"aws_api/privatenetworks","title":"update_network_site_plan","content":"pub fn update_network_site_plan(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/privatenetworks.update_network_site_plan\naws_api/privatenetworks update_network_site_plan","url":"aws_api/privatenetworks.html#update_network_site_plan"},{"doc":"aws_api/privatenetworks","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/privatenetworks.with_custom_endpoint\naws_api/privatenetworks with_custom_endpoint","url":"aws_api/privatenetworks.html#with_custom_endpoint"},{"doc":"aws_api/privatenetworks","title":"aws_api/privatenetworks","content":"","url":"aws_api/privatenetworks.html"},{"doc":"aws_api/proton","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/proton.Client\naws_api/proton Client","url":"aws_api/proton.html#Client"},{"doc":"aws_api/proton","title":"cancel_component_deployment","content":"pub fn cancel_component_deployment(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/proton.cancel_component_deployment\naws_api/proton cancel_component_deployment","url":"aws_api/proton.html#cancel_component_deployment"},{"doc":"aws_api/proton","title":"cancel_environment_deployment","content":"pub fn cancel_environment_deployment(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/proton.cancel_environment_deployment\naws_api/proton cancel_environment_deployment","url":"aws_api/proton.html#cancel_environment_deployment"},{"doc":"aws_api/proton","title":"cancel_service_instance_deployment","content":"pub fn cancel_service_instance_deployment(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/proton.cancel_service_instance_deployment\naws_api/proton cancel_service_instance_deployment","url":"aws_api/proton.html#cancel_service_instance_deployment"},{"doc":"aws_api/proton","title":"cancel_service_pipeline_deployment","content":"pub fn cancel_service_pipeline_deployment(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/proton.cancel_service_pipeline_deployment\naws_api/proton cancel_service_pipeline_deployment","url":"aws_api/proton.html#cancel_service_pipeline_deployment"},{"doc":"aws_api/proton","title":"get_repository_sync_status","content":"pub fn get_repository_sync_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/proton.get_repository_sync_status\naws_api/proton get_repository_sync_status","url":"aws_api/proton.html#get_repository_sync_status"},{"doc":"aws_api/proton","title":"get_resources_summary","content":"pub fn get_resources_summary(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/proton.get_resources_summary\naws_api/proton get_resources_summary","url":"aws_api/proton.html#get_resources_summary"},{"doc":"aws_api/proton","title":"get_service_instance_sync_status","content":"pub fn get_service_instance_sync_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/proton.get_service_instance_sync_status\naws_api/proton get_service_instance_sync_status","url":"aws_api/proton.html#get_service_instance_sync_status"},{"doc":"aws_api/proton","title":"get_template_sync_status","content":"pub fn get_template_sync_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/proton.get_template_sync_status\naws_api/proton get_template_sync_status","url":"aws_api/proton.html#get_template_sync_status"},{"doc":"aws_api/proton","title":"list_repository_sync_definitions","content":"pub fn list_repository_sync_definitions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/proton.list_repository_sync_definitions\naws_api/proton list_repository_sync_definitions","url":"aws_api/proton.html#list_repository_sync_definitions"},{"doc":"aws_api/proton","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/proton.list_tags_for_resource\naws_api/proton list_tags_for_resource","url":"aws_api/proton.html#list_tags_for_resource"},{"doc":"aws_api/proton","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/proton.new\naws_api/proton new","url":"aws_api/proton.html#new"},{"doc":"aws_api/proton","title":"notify_resource_deployment_status_change","content":"pub fn notify_resource_deployment_status_change(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/proton.notify_resource_deployment_status_change\naws_api/proton notify_resource_deployment_status_change","url":"aws_api/proton.html#notify_resource_deployment_status_change"},{"doc":"aws_api/proton","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/proton.tag_resource\naws_api/proton tag_resource","url":"aws_api/proton.html#tag_resource"},{"doc":"aws_api/proton","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/proton.untag_resource\naws_api/proton untag_resource","url":"aws_api/proton.html#untag_resource"},{"doc":"aws_api/proton","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/proton.with_custom_endpoint\naws_api/proton with_custom_endpoint","url":"aws_api/proton.html#with_custom_endpoint"},{"doc":"aws_api/proton","title":"aws_api/proton","content":"","url":"aws_api/proton.html"},{"doc":"aws_api/qbusiness","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/qbusiness.Client\naws_api/qbusiness Client","url":"aws_api/qbusiness.html#Client"},{"doc":"aws_api/qbusiness","title":"batch_delete_document","content":"pub fn batch_delete_document(\n  client: Client,\n  application_id: String,\n  index_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/qbusiness.batch_delete_document\naws_api/qbusiness batch_delete_document","url":"aws_api/qbusiness.html#batch_delete_document"},{"doc":"aws_api/qbusiness","title":"batch_put_document","content":"pub fn batch_put_document(\n  client: Client,\n  application_id: String,\n  index_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/qbusiness.batch_put_document\naws_api/qbusiness batch_put_document","url":"aws_api/qbusiness.html#batch_put_document"},{"doc":"aws_api/qbusiness","title":"chat","content":"pub fn chat(\n  client: Client,\n  application_id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/qbusiness.chat\naws_api/qbusiness chat","url":"aws_api/qbusiness.html#chat"},{"doc":"aws_api/qbusiness","title":"chat_sync","content":"pub fn chat_sync(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/qbusiness.chat_sync\naws_api/qbusiness chat_sync","url":"aws_api/qbusiness.html#chat_sync"},{"doc":"aws_api/qbusiness","title":"create_user","content":"pub fn create_user(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/qbusiness.create_user\naws_api/qbusiness create_user","url":"aws_api/qbusiness.html#create_user"},{"doc":"aws_api/qbusiness","title":"delete_chat_controls_configuration","content":"pub fn delete_chat_controls_configuration(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/qbusiness.delete_chat_controls_configuration\naws_api/qbusiness delete_chat_controls_configuration","url":"aws_api/qbusiness.html#delete_chat_controls_configuration"},{"doc":"aws_api/qbusiness","title":"delete_conversation","content":"pub fn delete_conversation(\n  client: Client,\n  application_id: String,\n  conversation_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/qbusiness.delete_conversation\naws_api/qbusiness delete_conversation","url":"aws_api/qbusiness.html#delete_conversation"},{"doc":"aws_api/qbusiness","title":"delete_group","content":"pub fn delete_group(\n  client: Client,\n  application_id: String,\n  index_id: String,\n  group_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/qbusiness.delete_group\naws_api/qbusiness delete_group","url":"aws_api/qbusiness.html#delete_group"},{"doc":"aws_api/qbusiness","title":"delete_user","content":"pub fn delete_user(\n  client: Client,\n  application_id: String,\n  user_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/qbusiness.delete_user\naws_api/qbusiness delete_user","url":"aws_api/qbusiness.html#delete_user"},{"doc":"aws_api/qbusiness","title":"get_chat_controls_configuration","content":"pub fn get_chat_controls_configuration(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/qbusiness.get_chat_controls_configuration\naws_api/qbusiness get_chat_controls_configuration","url":"aws_api/qbusiness.html#get_chat_controls_configuration"},{"doc":"aws_api/qbusiness","title":"get_group","content":"pub fn get_group(\n  client: Client,\n  application_id: String,\n  index_id: String,\n  group_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/qbusiness.get_group\naws_api/qbusiness get_group","url":"aws_api/qbusiness.html#get_group"},{"doc":"aws_api/qbusiness","title":"get_user","content":"pub fn get_user(\n  client: Client,\n  application_id: String,\n  user_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/qbusiness.get_user\naws_api/qbusiness get_user","url":"aws_api/qbusiness.html#get_user"},{"doc":"aws_api/qbusiness","title":"list_conversations","content":"pub fn list_conversations(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/qbusiness.list_conversations\naws_api/qbusiness list_conversations","url":"aws_api/qbusiness.html#list_conversations"},{"doc":"aws_api/qbusiness","title":"list_data_source_sync_jobs","content":"pub fn list_data_source_sync_jobs(\n  client: Client,\n  application_id: String,\n  index_id: String,\n  data_source_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/qbusiness.list_data_source_sync_jobs\naws_api/qbusiness list_data_source_sync_jobs","url":"aws_api/qbusiness.html#list_data_source_sync_jobs"},{"doc":"aws_api/qbusiness","title":"list_documents","content":"pub fn list_documents(\n  client: Client,\n  application_id: String,\n  index_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/qbusiness.list_documents\naws_api/qbusiness list_documents","url":"aws_api/qbusiness.html#list_documents"},{"doc":"aws_api/qbusiness","title":"list_groups","content":"pub fn list_groups(\n  client: Client,\n  application_id: String,\n  index_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/qbusiness.list_groups\naws_api/qbusiness list_groups","url":"aws_api/qbusiness.html#list_groups"},{"doc":"aws_api/qbusiness","title":"list_messages","content":"pub fn list_messages(\n  client: Client,\n  application_id: String,\n  conversation_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/qbusiness.list_messages\naws_api/qbusiness list_messages","url":"aws_api/qbusiness.html#list_messages"},{"doc":"aws_api/qbusiness","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/qbusiness.list_tags_for_resource\naws_api/qbusiness list_tags_for_resource","url":"aws_api/qbusiness.html#list_tags_for_resource"},{"doc":"aws_api/qbusiness","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/qbusiness.new\naws_api/qbusiness new","url":"aws_api/qbusiness.html#new"},{"doc":"aws_api/qbusiness","title":"put_feedback","content":"pub fn put_feedback(\n  client: Client,\n  application_id: String,\n  conversation_id: String,\n  message_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/qbusiness.put_feedback\naws_api/qbusiness put_feedback","url":"aws_api/qbusiness.html#put_feedback"},{"doc":"aws_api/qbusiness","title":"put_group","content":"pub fn put_group(\n  client: Client,\n  application_id: String,\n  index_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/qbusiness.put_group\naws_api/qbusiness put_group","url":"aws_api/qbusiness.html#put_group"},{"doc":"aws_api/qbusiness","title":"start_data_source_sync_job","content":"pub fn start_data_source_sync_job(\n  client: Client,\n  application_id: String,\n  index_id: String,\n  data_source_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/qbusiness.start_data_source_sync_job\naws_api/qbusiness start_data_source_sync_job","url":"aws_api/qbusiness.html#start_data_source_sync_job"},{"doc":"aws_api/qbusiness","title":"stop_data_source_sync_job","content":"pub fn stop_data_source_sync_job(\n  client: Client,\n  application_id: String,\n  index_id: String,\n  data_source_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/qbusiness.stop_data_source_sync_job\naws_api/qbusiness stop_data_source_sync_job","url":"aws_api/qbusiness.html#stop_data_source_sync_job"},{"doc":"aws_api/qbusiness","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/qbusiness.tag_resource\naws_api/qbusiness tag_resource","url":"aws_api/qbusiness.html#tag_resource"},{"doc":"aws_api/qbusiness","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/qbusiness.untag_resource\naws_api/qbusiness untag_resource","url":"aws_api/qbusiness.html#untag_resource"},{"doc":"aws_api/qbusiness","title":"update_chat_controls_configuration","content":"pub fn update_chat_controls_configuration(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/qbusiness.update_chat_controls_configuration\naws_api/qbusiness update_chat_controls_configuration","url":"aws_api/qbusiness.html#update_chat_controls_configuration"},{"doc":"aws_api/qbusiness","title":"update_user","content":"pub fn update_user(\n  client: Client,\n  application_id: String,\n  user_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/qbusiness.update_user\naws_api/qbusiness update_user","url":"aws_api/qbusiness.html#update_user"},{"doc":"aws_api/qbusiness","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/qbusiness.with_custom_endpoint\naws_api/qbusiness with_custom_endpoint","url":"aws_api/qbusiness.html#with_custom_endpoint"},{"doc":"aws_api/qbusiness","title":"aws_api/qbusiness","content":"","url":"aws_api/qbusiness.html"},{"doc":"aws_api/qconnect","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/qconnect.Client\naws_api/qconnect Client","url":"aws_api/qconnect.html#Client"},{"doc":"aws_api/qconnect","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/qconnect.list_tags_for_resource\naws_api/qconnect list_tags_for_resource","url":"aws_api/qconnect.html#list_tags_for_resource"},{"doc":"aws_api/qconnect","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/qconnect.new\naws_api/qconnect new","url":"aws_api/qconnect.html#new"},{"doc":"aws_api/qconnect","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/qconnect.tag_resource\naws_api/qconnect tag_resource","url":"aws_api/qconnect.html#tag_resource"},{"doc":"aws_api/qconnect","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/qconnect.untag_resource\naws_api/qconnect untag_resource","url":"aws_api/qconnect.html#untag_resource"},{"doc":"aws_api/qconnect","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/qconnect.with_custom_endpoint\naws_api/qconnect with_custom_endpoint","url":"aws_api/qconnect.html#with_custom_endpoint"},{"doc":"aws_api/qconnect","title":"aws_api/qconnect","content":"","url":"aws_api/qconnect.html"},{"doc":"aws_api/qldb","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/qldb.Client\naws_api/qldb Client","url":"aws_api/qldb.html#Client"},{"doc":"aws_api/qldb","title":"cancel_journal_kinesis_stream","content":"pub fn cancel_journal_kinesis_stream(\n  client: Client,\n  ledger_name: String,\n  stream_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/qldb.cancel_journal_kinesis_stream\naws_api/qldb cancel_journal_kinesis_stream","url":"aws_api/qldb.html#cancel_journal_kinesis_stream"},{"doc":"aws_api/qldb","title":"create_ledger","content":"pub fn create_ledger(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/qldb.create_ledger\naws_api/qldb create_ledger","url":"aws_api/qldb.html#create_ledger"},{"doc":"aws_api/qldb","title":"delete_ledger","content":"pub fn delete_ledger(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/qldb.delete_ledger\naws_api/qldb delete_ledger","url":"aws_api/qldb.html#delete_ledger"},{"doc":"aws_api/qldb","title":"describe_journal_kinesis_stream","content":"pub fn describe_journal_kinesis_stream(\n  client: Client,\n  ledger_name: String,\n  stream_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/qldb.describe_journal_kinesis_stream\naws_api/qldb describe_journal_kinesis_stream","url":"aws_api/qldb.html#describe_journal_kinesis_stream"},{"doc":"aws_api/qldb","title":"describe_journal_s3_export","content":"pub fn describe_journal_s3_export(\n  client: Client,\n  name: String,\n  export_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/qldb.describe_journal_s3_export\naws_api/qldb describe_journal_s3_export","url":"aws_api/qldb.html#describe_journal_s3_export"},{"doc":"aws_api/qldb","title":"describe_ledger","content":"pub fn describe_ledger(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/qldb.describe_ledger\naws_api/qldb describe_ledger","url":"aws_api/qldb.html#describe_ledger"},{"doc":"aws_api/qldb","title":"export_journal_to_s3","content":"pub fn export_journal_to_s3(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/qldb.export_journal_to_s3\naws_api/qldb export_journal_to_s3","url":"aws_api/qldb.html#export_journal_to_s3"},{"doc":"aws_api/qldb","title":"get_block","content":"pub fn get_block(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/qldb.get_block\naws_api/qldb get_block","url":"aws_api/qldb.html#get_block"},{"doc":"aws_api/qldb","title":"get_digest","content":"pub fn get_digest(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/qldb.get_digest\naws_api/qldb get_digest","url":"aws_api/qldb.html#get_digest"},{"doc":"aws_api/qldb","title":"get_revision","content":"pub fn get_revision(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/qldb.get_revision\naws_api/qldb get_revision","url":"aws_api/qldb.html#get_revision"},{"doc":"aws_api/qldb","title":"list_journal_kinesis_streams_for_ledger","content":"pub fn list_journal_kinesis_streams_for_ledger(\n  client: Client,\n  ledger_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/qldb.list_journal_kinesis_streams_for_ledger\naws_api/qldb list_journal_kinesis_streams_for_ledger","url":"aws_api/qldb.html#list_journal_kinesis_streams_for_ledger"},{"doc":"aws_api/qldb","title":"list_journal_s3_exports","content":"pub fn list_journal_s3_exports(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/qldb.list_journal_s3_exports\naws_api/qldb list_journal_s3_exports","url":"aws_api/qldb.html#list_journal_s3_exports"},{"doc":"aws_api/qldb","title":"list_journal_s3_exports_for_ledger","content":"pub fn list_journal_s3_exports_for_ledger(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/qldb.list_journal_s3_exports_for_ledger\naws_api/qldb list_journal_s3_exports_for_ledger","url":"aws_api/qldb.html#list_journal_s3_exports_for_ledger"},{"doc":"aws_api/qldb","title":"list_ledgers","content":"pub fn list_ledgers(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/qldb.list_ledgers\naws_api/qldb list_ledgers","url":"aws_api/qldb.html#list_ledgers"},{"doc":"aws_api/qldb","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/qldb.list_tags_for_resource\naws_api/qldb list_tags_for_resource","url":"aws_api/qldb.html#list_tags_for_resource"},{"doc":"aws_api/qldb","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/qldb.new\naws_api/qldb new","url":"aws_api/qldb.html#new"},{"doc":"aws_api/qldb","title":"stream_journal_to_kinesis","content":"pub fn stream_journal_to_kinesis(\n  client: Client,\n  ledger_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/qldb.stream_journal_to_kinesis\naws_api/qldb stream_journal_to_kinesis","url":"aws_api/qldb.html#stream_journal_to_kinesis"},{"doc":"aws_api/qldb","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/qldb.tag_resource\naws_api/qldb tag_resource","url":"aws_api/qldb.html#tag_resource"},{"doc":"aws_api/qldb","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/qldb.untag_resource\naws_api/qldb untag_resource","url":"aws_api/qldb.html#untag_resource"},{"doc":"aws_api/qldb","title":"update_ledger","content":"pub fn update_ledger(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/qldb.update_ledger\naws_api/qldb update_ledger","url":"aws_api/qldb.html#update_ledger"},{"doc":"aws_api/qldb","title":"update_ledger_permissions_mode","content":"pub fn update_ledger_permissions_mode(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/qldb.update_ledger_permissions_mode\naws_api/qldb update_ledger_permissions_mode","url":"aws_api/qldb.html#update_ledger_permissions_mode"},{"doc":"aws_api/qldb","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/qldb.with_custom_endpoint\naws_api/qldb with_custom_endpoint","url":"aws_api/qldb.html#with_custom_endpoint"},{"doc":"aws_api/qldb","title":"aws_api/qldb","content":"","url":"aws_api/qldb.html"},{"doc":"aws_api/qldb_session","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/qldb_session.Client\naws_api/qldb_session Client","url":"aws_api/qldb_session.html#Client"},{"doc":"aws_api/qldb_session","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/qldb_session.new\naws_api/qldb_session new","url":"aws_api/qldb_session.html#new"},{"doc":"aws_api/qldb_session","title":"send_command","content":"pub fn send_command(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/qldb_session.send_command\naws_api/qldb_session send_command","url":"aws_api/qldb_session.html#send_command"},{"doc":"aws_api/qldb_session","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/qldb_session.with_custom_endpoint\naws_api/qldb_session with_custom_endpoint","url":"aws_api/qldb_session.html#with_custom_endpoint"},{"doc":"aws_api/qldb_session","title":"aws_api/qldb_session","content":"","url":"aws_api/qldb_session.html"},{"doc":"aws_api/quicksight","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/quicksight.Client\naws_api/quicksight Client","url":"aws_api/quicksight.html#Client"},{"doc":"aws_api/quicksight","title":"batch_create_topic_reviewed_answer","content":"pub fn batch_create_topic_reviewed_answer(\n  client: Client,\n  aws_account_id: String,\n  topic_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.batch_create_topic_reviewed_answer\naws_api/quicksight batch_create_topic_reviewed_answer","url":"aws_api/quicksight.html#batch_create_topic_reviewed_answer"},{"doc":"aws_api/quicksight","title":"batch_delete_topic_reviewed_answer","content":"pub fn batch_delete_topic_reviewed_answer(\n  client: Client,\n  aws_account_id: String,\n  topic_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.batch_delete_topic_reviewed_answer\naws_api/quicksight batch_delete_topic_reviewed_answer","url":"aws_api/quicksight.html#batch_delete_topic_reviewed_answer"},{"doc":"aws_api/quicksight","title":"cancel_ingestion","content":"pub fn cancel_ingestion(\n  client: Client,\n  aws_account_id: String,\n  data_set_id: String,\n  ingestion_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.cancel_ingestion\naws_api/quicksight cancel_ingestion","url":"aws_api/quicksight.html#cancel_ingestion"},{"doc":"aws_api/quicksight","title":"create_account_customization","content":"pub fn create_account_customization(\n  client: Client,\n  aws_account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.create_account_customization\naws_api/quicksight create_account_customization","url":"aws_api/quicksight.html#create_account_customization"},{"doc":"aws_api/quicksight","title":"create_account_subscription","content":"pub fn create_account_subscription(\n  client: Client,\n  aws_account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.create_account_subscription\naws_api/quicksight create_account_subscription","url":"aws_api/quicksight.html#create_account_subscription"},{"doc":"aws_api/quicksight","title":"create_analysis","content":"pub fn create_analysis(\n  client: Client,\n  aws_account_id: String,\n  analysis_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.create_analysis\naws_api/quicksight create_analysis","url":"aws_api/quicksight.html#create_analysis"},{"doc":"aws_api/quicksight","title":"create_dashboard","content":"pub fn create_dashboard(\n  client: Client,\n  aws_account_id: String,\n  dashboard_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.create_dashboard\naws_api/quicksight create_dashboard","url":"aws_api/quicksight.html#create_dashboard"},{"doc":"aws_api/quicksight","title":"create_data_set","content":"pub fn create_data_set(\n  client: Client,\n  aws_account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.create_data_set\naws_api/quicksight create_data_set","url":"aws_api/quicksight.html#create_data_set"},{"doc":"aws_api/quicksight","title":"create_data_source","content":"pub fn create_data_source(\n  client: Client,\n  aws_account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.create_data_source\naws_api/quicksight create_data_source","url":"aws_api/quicksight.html#create_data_source"},{"doc":"aws_api/quicksight","title":"create_folder","content":"pub fn create_folder(\n  client: Client,\n  aws_account_id: String,\n  folder_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.create_folder\naws_api/quicksight create_folder","url":"aws_api/quicksight.html#create_folder"},{"doc":"aws_api/quicksight","title":"create_folder_membership","content":"pub fn create_folder_membership(\n  client: Client,\n  aws_account_id: String,\n  folder_id: String,\n  member_type: String,\n  member_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.create_folder_membership\naws_api/quicksight create_folder_membership","url":"aws_api/quicksight.html#create_folder_membership"},{"doc":"aws_api/quicksight","title":"create_group","content":"pub fn create_group(\n  client: Client,\n  aws_account_id: String,\n  namespace: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.create_group\naws_api/quicksight create_group","url":"aws_api/quicksight.html#create_group"},{"doc":"aws_api/quicksight","title":"create_group_membership","content":"pub fn create_group_membership(\n  client: Client,\n  aws_account_id: String,\n  namespace: String,\n  group_name: String,\n  member_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.create_group_membership\naws_api/quicksight create_group_membership","url":"aws_api/quicksight.html#create_group_membership"},{"doc":"aws_api/quicksight","title":"create_iam_policy_assignment","content":"pub fn create_iam_policy_assignment(\n  client: Client,\n  aws_account_id: String,\n  namespace: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.create_iam_policy_assignment\naws_api/quicksight create_iam_policy_assignment","url":"aws_api/quicksight.html#create_iam_policy_assignment"},{"doc":"aws_api/quicksight","title":"create_ingestion","content":"pub fn create_ingestion(\n  client: Client,\n  aws_account_id: String,\n  data_set_id: String,\n  ingestion_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.create_ingestion\naws_api/quicksight create_ingestion","url":"aws_api/quicksight.html#create_ingestion"},{"doc":"aws_api/quicksight","title":"create_namespace","content":"pub fn create_namespace(\n  client: Client,\n  aws_account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.create_namespace\naws_api/quicksight create_namespace","url":"aws_api/quicksight.html#create_namespace"},{"doc":"aws_api/quicksight","title":"create_refresh_schedule","content":"pub fn create_refresh_schedule(\n  client: Client,\n  aws_account_id: String,\n  data_set_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.create_refresh_schedule\naws_api/quicksight create_refresh_schedule","url":"aws_api/quicksight.html#create_refresh_schedule"},{"doc":"aws_api/quicksight","title":"create_role_membership","content":"pub fn create_role_membership(\n  client: Client,\n  aws_account_id: String,\n  namespace: String,\n  role: String,\n  member_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.create_role_membership\naws_api/quicksight create_role_membership","url":"aws_api/quicksight.html#create_role_membership"},{"doc":"aws_api/quicksight","title":"create_template","content":"pub fn create_template(\n  client: Client,\n  aws_account_id: String,\n  template_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.create_template\naws_api/quicksight create_template","url":"aws_api/quicksight.html#create_template"},{"doc":"aws_api/quicksight","title":"create_template_alias","content":"pub fn create_template_alias(\n  client: Client,\n  aws_account_id: String,\n  template_id: String,\n  alias_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.create_template_alias\naws_api/quicksight create_template_alias","url":"aws_api/quicksight.html#create_template_alias"},{"doc":"aws_api/quicksight","title":"create_theme","content":"pub fn create_theme(\n  client: Client,\n  aws_account_id: String,\n  theme_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.create_theme\naws_api/quicksight create_theme","url":"aws_api/quicksight.html#create_theme"},{"doc":"aws_api/quicksight","title":"create_theme_alias","content":"pub fn create_theme_alias(\n  client: Client,\n  aws_account_id: String,\n  theme_id: String,\n  alias_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.create_theme_alias\naws_api/quicksight create_theme_alias","url":"aws_api/quicksight.html#create_theme_alias"},{"doc":"aws_api/quicksight","title":"create_topic","content":"pub fn create_topic(\n  client: Client,\n  aws_account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.create_topic\naws_api/quicksight create_topic","url":"aws_api/quicksight.html#create_topic"},{"doc":"aws_api/quicksight","title":"create_topic_refresh_schedule","content":"pub fn create_topic_refresh_schedule(\n  client: Client,\n  aws_account_id: String,\n  topic_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.create_topic_refresh_schedule\naws_api/quicksight create_topic_refresh_schedule","url":"aws_api/quicksight.html#create_topic_refresh_schedule"},{"doc":"aws_api/quicksight","title":"create_vpc_connection","content":"pub fn create_vpc_connection(\n  client: Client,\n  aws_account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.create_vpc_connection\naws_api/quicksight create_vpc_connection","url":"aws_api/quicksight.html#create_vpc_connection"},{"doc":"aws_api/quicksight","title":"delete_account_customization","content":"pub fn delete_account_customization(\n  client: Client,\n  aws_account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.delete_account_customization\naws_api/quicksight delete_account_customization","url":"aws_api/quicksight.html#delete_account_customization"},{"doc":"aws_api/quicksight","title":"delete_account_subscription","content":"pub fn delete_account_subscription(\n  client: Client,\n  aws_account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.delete_account_subscription\naws_api/quicksight delete_account_subscription","url":"aws_api/quicksight.html#delete_account_subscription"},{"doc":"aws_api/quicksight","title":"delete_analysis","content":"pub fn delete_analysis(\n  client: Client,\n  aws_account_id: String,\n  analysis_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.delete_analysis\naws_api/quicksight delete_analysis","url":"aws_api/quicksight.html#delete_analysis"},{"doc":"aws_api/quicksight","title":"delete_dashboard","content":"pub fn delete_dashboard(\n  client: Client,\n  aws_account_id: String,\n  dashboard_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.delete_dashboard\naws_api/quicksight delete_dashboard","url":"aws_api/quicksight.html#delete_dashboard"},{"doc":"aws_api/quicksight","title":"delete_data_set","content":"pub fn delete_data_set(\n  client: Client,\n  aws_account_id: String,\n  data_set_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.delete_data_set\naws_api/quicksight delete_data_set","url":"aws_api/quicksight.html#delete_data_set"},{"doc":"aws_api/quicksight","title":"delete_data_set_refresh_properties","content":"pub fn delete_data_set_refresh_properties(\n  client: Client,\n  aws_account_id: String,\n  data_set_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.delete_data_set_refresh_properties\naws_api/quicksight delete_data_set_refresh_properties","url":"aws_api/quicksight.html#delete_data_set_refresh_properties"},{"doc":"aws_api/quicksight","title":"delete_data_source","content":"pub fn delete_data_source(\n  client: Client,\n  aws_account_id: String,\n  data_source_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.delete_data_source\naws_api/quicksight delete_data_source","url":"aws_api/quicksight.html#delete_data_source"},{"doc":"aws_api/quicksight","title":"delete_folder","content":"pub fn delete_folder(\n  client: Client,\n  aws_account_id: String,\n  folder_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.delete_folder\naws_api/quicksight delete_folder","url":"aws_api/quicksight.html#delete_folder"},{"doc":"aws_api/quicksight","title":"delete_folder_membership","content":"pub fn delete_folder_membership(\n  client: Client,\n  aws_account_id: String,\n  folder_id: String,\n  member_type: String,\n  member_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.delete_folder_membership\naws_api/quicksight delete_folder_membership","url":"aws_api/quicksight.html#delete_folder_membership"},{"doc":"aws_api/quicksight","title":"delete_group","content":"pub fn delete_group(\n  client: Client,\n  aws_account_id: String,\n  namespace: String,\n  group_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.delete_group\naws_api/quicksight delete_group","url":"aws_api/quicksight.html#delete_group"},{"doc":"aws_api/quicksight","title":"delete_group_membership","content":"pub fn delete_group_membership(\n  client: Client,\n  aws_account_id: String,\n  namespace: String,\n  group_name: String,\n  member_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.delete_group_membership\naws_api/quicksight delete_group_membership","url":"aws_api/quicksight.html#delete_group_membership"},{"doc":"aws_api/quicksight","title":"delete_iam_policy_assignment","content":"pub fn delete_iam_policy_assignment(\n  client: Client,\n  aws_account_id: String,\n  namespace: String,\n  assignment_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.delete_iam_policy_assignment\naws_api/quicksight delete_iam_policy_assignment","url":"aws_api/quicksight.html#delete_iam_policy_assignment"},{"doc":"aws_api/quicksight","title":"delete_identity_propagation_config","content":"pub fn delete_identity_propagation_config(\n  client: Client,\n  aws_account_id: String,\n  service: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.delete_identity_propagation_config\naws_api/quicksight delete_identity_propagation_config","url":"aws_api/quicksight.html#delete_identity_propagation_config"},{"doc":"aws_api/quicksight","title":"delete_namespace","content":"pub fn delete_namespace(\n  client: Client,\n  aws_account_id: String,\n  namespace: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.delete_namespace\naws_api/quicksight delete_namespace","url":"aws_api/quicksight.html#delete_namespace"},{"doc":"aws_api/quicksight","title":"delete_refresh_schedule","content":"pub fn delete_refresh_schedule(\n  client: Client,\n  aws_account_id: String,\n  data_set_id: String,\n  schedule_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.delete_refresh_schedule\naws_api/quicksight delete_refresh_schedule","url":"aws_api/quicksight.html#delete_refresh_schedule"},{"doc":"aws_api/quicksight","title":"delete_role_custom_permission","content":"pub fn delete_role_custom_permission(\n  client: Client,\n  aws_account_id: String,\n  namespace: String,\n  role: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.delete_role_custom_permission\naws_api/quicksight delete_role_custom_permission","url":"aws_api/quicksight.html#delete_role_custom_permission"},{"doc":"aws_api/quicksight","title":"delete_role_membership","content":"pub fn delete_role_membership(\n  client: Client,\n  aws_account_id: String,\n  namespace: String,\n  role: String,\n  member_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.delete_role_membership\naws_api/quicksight delete_role_membership","url":"aws_api/quicksight.html#delete_role_membership"},{"doc":"aws_api/quicksight","title":"delete_template","content":"pub fn delete_template(\n  client: Client,\n  aws_account_id: String,\n  template_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.delete_template\naws_api/quicksight delete_template","url":"aws_api/quicksight.html#delete_template"},{"doc":"aws_api/quicksight","title":"delete_template_alias","content":"pub fn delete_template_alias(\n  client: Client,\n  aws_account_id: String,\n  template_id: String,\n  alias_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.delete_template_alias\naws_api/quicksight delete_template_alias","url":"aws_api/quicksight.html#delete_template_alias"},{"doc":"aws_api/quicksight","title":"delete_theme","content":"pub fn delete_theme(\n  client: Client,\n  aws_account_id: String,\n  theme_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.delete_theme\naws_api/quicksight delete_theme","url":"aws_api/quicksight.html#delete_theme"},{"doc":"aws_api/quicksight","title":"delete_theme_alias","content":"pub fn delete_theme_alias(\n  client: Client,\n  aws_account_id: String,\n  theme_id: String,\n  alias_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.delete_theme_alias\naws_api/quicksight delete_theme_alias","url":"aws_api/quicksight.html#delete_theme_alias"},{"doc":"aws_api/quicksight","title":"delete_topic","content":"pub fn delete_topic(\n  client: Client,\n  aws_account_id: String,\n  topic_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.delete_topic\naws_api/quicksight delete_topic","url":"aws_api/quicksight.html#delete_topic"},{"doc":"aws_api/quicksight","title":"delete_topic_refresh_schedule","content":"pub fn delete_topic_refresh_schedule(\n  client: Client,\n  aws_account_id: String,\n  topic_id: String,\n  dataset_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.delete_topic_refresh_schedule\naws_api/quicksight delete_topic_refresh_schedule","url":"aws_api/quicksight.html#delete_topic_refresh_schedule"},{"doc":"aws_api/quicksight","title":"delete_user","content":"pub fn delete_user(\n  client: Client,\n  aws_account_id: String,\n  namespace: String,\n  user_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.delete_user\naws_api/quicksight delete_user","url":"aws_api/quicksight.html#delete_user"},{"doc":"aws_api/quicksight","title":"delete_user_by_principal_id","content":"pub fn delete_user_by_principal_id(\n  client: Client,\n  aws_account_id: String,\n  namespace: String,\n  principal_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.delete_user_by_principal_id\naws_api/quicksight delete_user_by_principal_id","url":"aws_api/quicksight.html#delete_user_by_principal_id"},{"doc":"aws_api/quicksight","title":"delete_vpc_connection","content":"pub fn delete_vpc_connection(\n  client: Client,\n  aws_account_id: String,\n  vpc_connection_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.delete_vpc_connection\naws_api/quicksight delete_vpc_connection","url":"aws_api/quicksight.html#delete_vpc_connection"},{"doc":"aws_api/quicksight","title":"describe_account_customization","content":"pub fn describe_account_customization(\n  client: Client,\n  aws_account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.describe_account_customization\naws_api/quicksight describe_account_customization","url":"aws_api/quicksight.html#describe_account_customization"},{"doc":"aws_api/quicksight","title":"describe_account_settings","content":"pub fn describe_account_settings(\n  client: Client,\n  aws_account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.describe_account_settings\naws_api/quicksight describe_account_settings","url":"aws_api/quicksight.html#describe_account_settings"},{"doc":"aws_api/quicksight","title":"describe_account_subscription","content":"pub fn describe_account_subscription(\n  client: Client,\n  aws_account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.describe_account_subscription\naws_api/quicksight describe_account_subscription","url":"aws_api/quicksight.html#describe_account_subscription"},{"doc":"aws_api/quicksight","title":"describe_analysis","content":"pub fn describe_analysis(\n  client: Client,\n  aws_account_id: String,\n  analysis_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.describe_analysis\naws_api/quicksight describe_analysis","url":"aws_api/quicksight.html#describe_analysis"},{"doc":"aws_api/quicksight","title":"describe_analysis_definition","content":"pub fn describe_analysis_definition(\n  client: Client,\n  aws_account_id: String,\n  analysis_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.describe_analysis_definition\naws_api/quicksight describe_analysis_definition","url":"aws_api/quicksight.html#describe_analysis_definition"},{"doc":"aws_api/quicksight","title":"describe_analysis_permissions","content":"pub fn describe_analysis_permissions(\n  client: Client,\n  aws_account_id: String,\n  analysis_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.describe_analysis_permissions\naws_api/quicksight describe_analysis_permissions","url":"aws_api/quicksight.html#describe_analysis_permissions"},{"doc":"aws_api/quicksight","title":"describe_asset_bundle_export_job","content":"pub fn describe_asset_bundle_export_job(\n  client: Client,\n  aws_account_id: String,\n  asset_bundle_export_job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.describe_asset_bundle_export_job\naws_api/quicksight describe_asset_bundle_export_job","url":"aws_api/quicksight.html#describe_asset_bundle_export_job"},{"doc":"aws_api/quicksight","title":"describe_asset_bundle_import_job","content":"pub fn describe_asset_bundle_import_job(\n  client: Client,\n  aws_account_id: String,\n  asset_bundle_import_job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.describe_asset_bundle_import_job\naws_api/quicksight describe_asset_bundle_import_job","url":"aws_api/quicksight.html#describe_asset_bundle_import_job"},{"doc":"aws_api/quicksight","title":"describe_dashboard","content":"pub fn describe_dashboard(\n  client: Client,\n  aws_account_id: String,\n  dashboard_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.describe_dashboard\naws_api/quicksight describe_dashboard","url":"aws_api/quicksight.html#describe_dashboard"},{"doc":"aws_api/quicksight","title":"describe_dashboard_definition","content":"pub fn describe_dashboard_definition(\n  client: Client,\n  aws_account_id: String,\n  dashboard_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.describe_dashboard_definition\naws_api/quicksight describe_dashboard_definition","url":"aws_api/quicksight.html#describe_dashboard_definition"},{"doc":"aws_api/quicksight","title":"describe_dashboard_permissions","content":"pub fn describe_dashboard_permissions(\n  client: Client,\n  aws_account_id: String,\n  dashboard_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.describe_dashboard_permissions\naws_api/quicksight describe_dashboard_permissions","url":"aws_api/quicksight.html#describe_dashboard_permissions"},{"doc":"aws_api/quicksight","title":"describe_dashboard_snapshot_job","content":"pub fn describe_dashboard_snapshot_job(\n  client: Client,\n  aws_account_id: String,\n  dashboard_id: String,\n  snapshot_job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.describe_dashboard_snapshot_job\naws_api/quicksight describe_dashboard_snapshot_job","url":"aws_api/quicksight.html#describe_dashboard_snapshot_job"},{"doc":"aws_api/quicksight","title":"describe_dashboard_snapshot_job_result","content":"pub fn describe_dashboard_snapshot_job_result(\n  client: Client,\n  aws_account_id: String,\n  dashboard_id: String,\n  snapshot_job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.describe_dashboard_snapshot_job_result\naws_api/quicksight describe_dashboard_snapshot_job_result","url":"aws_api/quicksight.html#describe_dashboard_snapshot_job_result"},{"doc":"aws_api/quicksight","title":"describe_data_set","content":"pub fn describe_data_set(\n  client: Client,\n  aws_account_id: String,\n  data_set_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.describe_data_set\naws_api/quicksight describe_data_set","url":"aws_api/quicksight.html#describe_data_set"},{"doc":"aws_api/quicksight","title":"describe_data_set_permissions","content":"pub fn describe_data_set_permissions(\n  client: Client,\n  aws_account_id: String,\n  data_set_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.describe_data_set_permissions\naws_api/quicksight describe_data_set_permissions","url":"aws_api/quicksight.html#describe_data_set_permissions"},{"doc":"aws_api/quicksight","title":"describe_data_set_refresh_properties","content":"pub fn describe_data_set_refresh_properties(\n  client: Client,\n  aws_account_id: String,\n  data_set_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.describe_data_set_refresh_properties\naws_api/quicksight describe_data_set_refresh_properties","url":"aws_api/quicksight.html#describe_data_set_refresh_properties"},{"doc":"aws_api/quicksight","title":"describe_data_source","content":"pub fn describe_data_source(\n  client: Client,\n  aws_account_id: String,\n  data_source_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.describe_data_source\naws_api/quicksight describe_data_source","url":"aws_api/quicksight.html#describe_data_source"},{"doc":"aws_api/quicksight","title":"describe_data_source_permissions","content":"pub fn describe_data_source_permissions(\n  client: Client,\n  aws_account_id: String,\n  data_source_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.describe_data_source_permissions\naws_api/quicksight describe_data_source_permissions","url":"aws_api/quicksight.html#describe_data_source_permissions"},{"doc":"aws_api/quicksight","title":"describe_folder","content":"pub fn describe_folder(\n  client: Client,\n  aws_account_id: String,\n  folder_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.describe_folder\naws_api/quicksight describe_folder","url":"aws_api/quicksight.html#describe_folder"},{"doc":"aws_api/quicksight","title":"describe_folder_permissions","content":"pub fn describe_folder_permissions(\n  client: Client,\n  aws_account_id: String,\n  folder_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.describe_folder_permissions\naws_api/quicksight describe_folder_permissions","url":"aws_api/quicksight.html#describe_folder_permissions"},{"doc":"aws_api/quicksight","title":"describe_folder_resolved_permissions","content":"pub fn describe_folder_resolved_permissions(\n  client: Client,\n  aws_account_id: String,\n  folder_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.describe_folder_resolved_permissions\naws_api/quicksight describe_folder_resolved_permissions","url":"aws_api/quicksight.html#describe_folder_resolved_permissions"},{"doc":"aws_api/quicksight","title":"describe_group","content":"pub fn describe_group(\n  client: Client,\n  aws_account_id: String,\n  namespace: String,\n  group_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.describe_group\naws_api/quicksight describe_group","url":"aws_api/quicksight.html#describe_group"},{"doc":"aws_api/quicksight","title":"describe_group_membership","content":"pub fn describe_group_membership(\n  client: Client,\n  aws_account_id: String,\n  namespace: String,\n  group_name: String,\n  member_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.describe_group_membership\naws_api/quicksight describe_group_membership","url":"aws_api/quicksight.html#describe_group_membership"},{"doc":"aws_api/quicksight","title":"describe_iam_policy_assignment","content":"pub fn describe_iam_policy_assignment(\n  client: Client,\n  aws_account_id: String,\n  namespace: String,\n  assignment_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.describe_iam_policy_assignment\naws_api/quicksight describe_iam_policy_assignment","url":"aws_api/quicksight.html#describe_iam_policy_assignment"},{"doc":"aws_api/quicksight","title":"describe_ingestion","content":"pub fn describe_ingestion(\n  client: Client,\n  aws_account_id: String,\n  data_set_id: String,\n  ingestion_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.describe_ingestion\naws_api/quicksight describe_ingestion","url":"aws_api/quicksight.html#describe_ingestion"},{"doc":"aws_api/quicksight","title":"describe_ip_restriction","content":"pub fn describe_ip_restriction(\n  client: Client,\n  aws_account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.describe_ip_restriction\naws_api/quicksight describe_ip_restriction","url":"aws_api/quicksight.html#describe_ip_restriction"},{"doc":"aws_api/quicksight","title":"describe_key_registration","content":"pub fn describe_key_registration(\n  client: Client,\n  aws_account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.describe_key_registration\naws_api/quicksight describe_key_registration","url":"aws_api/quicksight.html#describe_key_registration"},{"doc":"aws_api/quicksight","title":"describe_namespace","content":"pub fn describe_namespace(\n  client: Client,\n  aws_account_id: String,\n  namespace: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.describe_namespace\naws_api/quicksight describe_namespace","url":"aws_api/quicksight.html#describe_namespace"},{"doc":"aws_api/quicksight","title":"describe_refresh_schedule","content":"pub fn describe_refresh_schedule(\n  client: Client,\n  aws_account_id: String,\n  data_set_id: String,\n  schedule_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.describe_refresh_schedule\naws_api/quicksight describe_refresh_schedule","url":"aws_api/quicksight.html#describe_refresh_schedule"},{"doc":"aws_api/quicksight","title":"describe_role_custom_permission","content":"pub fn describe_role_custom_permission(\n  client: Client,\n  aws_account_id: String,\n  namespace: String,\n  role: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.describe_role_custom_permission\naws_api/quicksight describe_role_custom_permission","url":"aws_api/quicksight.html#describe_role_custom_permission"},{"doc":"aws_api/quicksight","title":"describe_template","content":"pub fn describe_template(\n  client: Client,\n  aws_account_id: String,\n  template_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.describe_template\naws_api/quicksight describe_template","url":"aws_api/quicksight.html#describe_template"},{"doc":"aws_api/quicksight","title":"describe_template_alias","content":"pub fn describe_template_alias(\n  client: Client,\n  aws_account_id: String,\n  template_id: String,\n  alias_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.describe_template_alias\naws_api/quicksight describe_template_alias","url":"aws_api/quicksight.html#describe_template_alias"},{"doc":"aws_api/quicksight","title":"describe_template_definition","content":"pub fn describe_template_definition(\n  client: Client,\n  aws_account_id: String,\n  template_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.describe_template_definition\naws_api/quicksight describe_template_definition","url":"aws_api/quicksight.html#describe_template_definition"},{"doc":"aws_api/quicksight","title":"describe_template_permissions","content":"pub fn describe_template_permissions(\n  client: Client,\n  aws_account_id: String,\n  template_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.describe_template_permissions\naws_api/quicksight describe_template_permissions","url":"aws_api/quicksight.html#describe_template_permissions"},{"doc":"aws_api/quicksight","title":"describe_theme","content":"pub fn describe_theme(\n  client: Client,\n  aws_account_id: String,\n  theme_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.describe_theme\naws_api/quicksight describe_theme","url":"aws_api/quicksight.html#describe_theme"},{"doc":"aws_api/quicksight","title":"describe_theme_alias","content":"pub fn describe_theme_alias(\n  client: Client,\n  aws_account_id: String,\n  theme_id: String,\n  alias_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.describe_theme_alias\naws_api/quicksight describe_theme_alias","url":"aws_api/quicksight.html#describe_theme_alias"},{"doc":"aws_api/quicksight","title":"describe_theme_permissions","content":"pub fn describe_theme_permissions(\n  client: Client,\n  aws_account_id: String,\n  theme_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.describe_theme_permissions\naws_api/quicksight describe_theme_permissions","url":"aws_api/quicksight.html#describe_theme_permissions"},{"doc":"aws_api/quicksight","title":"describe_topic","content":"pub fn describe_topic(\n  client: Client,\n  aws_account_id: String,\n  topic_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.describe_topic\naws_api/quicksight describe_topic","url":"aws_api/quicksight.html#describe_topic"},{"doc":"aws_api/quicksight","title":"describe_topic_permissions","content":"pub fn describe_topic_permissions(\n  client: Client,\n  aws_account_id: String,\n  topic_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.describe_topic_permissions\naws_api/quicksight describe_topic_permissions","url":"aws_api/quicksight.html#describe_topic_permissions"},{"doc":"aws_api/quicksight","title":"describe_topic_refresh","content":"pub fn describe_topic_refresh(\n  client: Client,\n  aws_account_id: String,\n  topic_id: String,\n  refresh_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.describe_topic_refresh\naws_api/quicksight describe_topic_refresh","url":"aws_api/quicksight.html#describe_topic_refresh"},{"doc":"aws_api/quicksight","title":"describe_topic_refresh_schedule","content":"pub fn describe_topic_refresh_schedule(\n  client: Client,\n  aws_account_id: String,\n  topic_id: String,\n  dataset_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.describe_topic_refresh_schedule\naws_api/quicksight describe_topic_refresh_schedule","url":"aws_api/quicksight.html#describe_topic_refresh_schedule"},{"doc":"aws_api/quicksight","title":"describe_user","content":"pub fn describe_user(\n  client: Client,\n  aws_account_id: String,\n  namespace: String,\n  user_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.describe_user\naws_api/quicksight describe_user","url":"aws_api/quicksight.html#describe_user"},{"doc":"aws_api/quicksight","title":"describe_vpc_connection","content":"pub fn describe_vpc_connection(\n  client: Client,\n  aws_account_id: String,\n  vpc_connection_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.describe_vpc_connection\naws_api/quicksight describe_vpc_connection","url":"aws_api/quicksight.html#describe_vpc_connection"},{"doc":"aws_api/quicksight","title":"generate_embed_url_for_anonymous_user","content":"pub fn generate_embed_url_for_anonymous_user(\n  client: Client,\n  aws_account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.generate_embed_url_for_anonymous_user\naws_api/quicksight generate_embed_url_for_anonymous_user","url":"aws_api/quicksight.html#generate_embed_url_for_anonymous_user"},{"doc":"aws_api/quicksight","title":"generate_embed_url_for_registered_user","content":"pub fn generate_embed_url_for_registered_user(\n  client: Client,\n  aws_account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.generate_embed_url_for_registered_user\naws_api/quicksight generate_embed_url_for_registered_user","url":"aws_api/quicksight.html#generate_embed_url_for_registered_user"},{"doc":"aws_api/quicksight","title":"get_dashboard_embed_url","content":"pub fn get_dashboard_embed_url(\n  client: Client,\n  aws_account_id: String,\n  dashboard_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.get_dashboard_embed_url\naws_api/quicksight get_dashboard_embed_url","url":"aws_api/quicksight.html#get_dashboard_embed_url"},{"doc":"aws_api/quicksight","title":"get_session_embed_url","content":"pub fn get_session_embed_url(\n  client: Client,\n  aws_account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.get_session_embed_url\naws_api/quicksight get_session_embed_url","url":"aws_api/quicksight.html#get_session_embed_url"},{"doc":"aws_api/quicksight","title":"list_analyses","content":"pub fn list_analyses(\n  client: Client,\n  aws_account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.list_analyses\naws_api/quicksight list_analyses","url":"aws_api/quicksight.html#list_analyses"},{"doc":"aws_api/quicksight","title":"list_asset_bundle_export_jobs","content":"pub fn list_asset_bundle_export_jobs(\n  client: Client,\n  aws_account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.list_asset_bundle_export_jobs\naws_api/quicksight list_asset_bundle_export_jobs","url":"aws_api/quicksight.html#list_asset_bundle_export_jobs"},{"doc":"aws_api/quicksight","title":"list_asset_bundle_import_jobs","content":"pub fn list_asset_bundle_import_jobs(\n  client: Client,\n  aws_account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.list_asset_bundle_import_jobs\naws_api/quicksight list_asset_bundle_import_jobs","url":"aws_api/quicksight.html#list_asset_bundle_import_jobs"},{"doc":"aws_api/quicksight","title":"list_dashboard_versions","content":"pub fn list_dashboard_versions(\n  client: Client,\n  aws_account_id: String,\n  dashboard_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.list_dashboard_versions\naws_api/quicksight list_dashboard_versions","url":"aws_api/quicksight.html#list_dashboard_versions"},{"doc":"aws_api/quicksight","title":"list_dashboards","content":"pub fn list_dashboards(\n  client: Client,\n  aws_account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.list_dashboards\naws_api/quicksight list_dashboards","url":"aws_api/quicksight.html#list_dashboards"},{"doc":"aws_api/quicksight","title":"list_data_sets","content":"pub fn list_data_sets(\n  client: Client,\n  aws_account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.list_data_sets\naws_api/quicksight list_data_sets","url":"aws_api/quicksight.html#list_data_sets"},{"doc":"aws_api/quicksight","title":"list_data_sources","content":"pub fn list_data_sources(\n  client: Client,\n  aws_account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.list_data_sources\naws_api/quicksight list_data_sources","url":"aws_api/quicksight.html#list_data_sources"},{"doc":"aws_api/quicksight","title":"list_folder_members","content":"pub fn list_folder_members(\n  client: Client,\n  aws_account_id: String,\n  folder_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.list_folder_members\naws_api/quicksight list_folder_members","url":"aws_api/quicksight.html#list_folder_members"},{"doc":"aws_api/quicksight","title":"list_folders","content":"pub fn list_folders(\n  client: Client,\n  aws_account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.list_folders\naws_api/quicksight list_folders","url":"aws_api/quicksight.html#list_folders"},{"doc":"aws_api/quicksight","title":"list_group_memberships","content":"pub fn list_group_memberships(\n  client: Client,\n  aws_account_id: String,\n  namespace: String,\n  group_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.list_group_memberships\naws_api/quicksight list_group_memberships","url":"aws_api/quicksight.html#list_group_memberships"},{"doc":"aws_api/quicksight","title":"list_groups","content":"pub fn list_groups(\n  client: Client,\n  aws_account_id: String,\n  namespace: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.list_groups\naws_api/quicksight list_groups","url":"aws_api/quicksight.html#list_groups"},{"doc":"aws_api/quicksight","title":"list_iam_policy_assignments","content":"pub fn list_iam_policy_assignments(\n  client: Client,\n  aws_account_id: String,\n  namespace: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.list_iam_policy_assignments\naws_api/quicksight list_iam_policy_assignments","url":"aws_api/quicksight.html#list_iam_policy_assignments"},{"doc":"aws_api/quicksight","title":"list_iam_policy_assignments_for_user","content":"pub fn list_iam_policy_assignments_for_user(\n  client: Client,\n  aws_account_id: String,\n  namespace: String,\n  user_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.list_iam_policy_assignments_for_user\naws_api/quicksight list_iam_policy_assignments_for_user","url":"aws_api/quicksight.html#list_iam_policy_assignments_for_user"},{"doc":"aws_api/quicksight","title":"list_identity_propagation_configs","content":"pub fn list_identity_propagation_configs(\n  client: Client,\n  aws_account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.list_identity_propagation_configs\naws_api/quicksight list_identity_propagation_configs","url":"aws_api/quicksight.html#list_identity_propagation_configs"},{"doc":"aws_api/quicksight","title":"list_ingestions","content":"pub fn list_ingestions(\n  client: Client,\n  aws_account_id: String,\n  data_set_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.list_ingestions\naws_api/quicksight list_ingestions","url":"aws_api/quicksight.html#list_ingestions"},{"doc":"aws_api/quicksight","title":"list_namespaces","content":"pub fn list_namespaces(\n  client: Client,\n  aws_account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.list_namespaces\naws_api/quicksight list_namespaces","url":"aws_api/quicksight.html#list_namespaces"},{"doc":"aws_api/quicksight","title":"list_refresh_schedules","content":"pub fn list_refresh_schedules(\n  client: Client,\n  aws_account_id: String,\n  data_set_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.list_refresh_schedules\naws_api/quicksight list_refresh_schedules","url":"aws_api/quicksight.html#list_refresh_schedules"},{"doc":"aws_api/quicksight","title":"list_role_memberships","content":"pub fn list_role_memberships(\n  client: Client,\n  aws_account_id: String,\n  namespace: String,\n  role: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.list_role_memberships\naws_api/quicksight list_role_memberships","url":"aws_api/quicksight.html#list_role_memberships"},{"doc":"aws_api/quicksight","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.list_tags_for_resource\naws_api/quicksight list_tags_for_resource","url":"aws_api/quicksight.html#list_tags_for_resource"},{"doc":"aws_api/quicksight","title":"list_template_aliases","content":"pub fn list_template_aliases(\n  client: Client,\n  aws_account_id: String,\n  template_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.list_template_aliases\naws_api/quicksight list_template_aliases","url":"aws_api/quicksight.html#list_template_aliases"},{"doc":"aws_api/quicksight","title":"list_template_versions","content":"pub fn list_template_versions(\n  client: Client,\n  aws_account_id: String,\n  template_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.list_template_versions\naws_api/quicksight list_template_versions","url":"aws_api/quicksight.html#list_template_versions"},{"doc":"aws_api/quicksight","title":"list_templates","content":"pub fn list_templates(\n  client: Client,\n  aws_account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.list_templates\naws_api/quicksight list_templates","url":"aws_api/quicksight.html#list_templates"},{"doc":"aws_api/quicksight","title":"list_theme_aliases","content":"pub fn list_theme_aliases(\n  client: Client,\n  aws_account_id: String,\n  theme_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.list_theme_aliases\naws_api/quicksight list_theme_aliases","url":"aws_api/quicksight.html#list_theme_aliases"},{"doc":"aws_api/quicksight","title":"list_theme_versions","content":"pub fn list_theme_versions(\n  client: Client,\n  aws_account_id: String,\n  theme_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.list_theme_versions\naws_api/quicksight list_theme_versions","url":"aws_api/quicksight.html#list_theme_versions"},{"doc":"aws_api/quicksight","title":"list_themes","content":"pub fn list_themes(\n  client: Client,\n  aws_account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.list_themes\naws_api/quicksight list_themes","url":"aws_api/quicksight.html#list_themes"},{"doc":"aws_api/quicksight","title":"list_topic_refresh_schedules","content":"pub fn list_topic_refresh_schedules(\n  client: Client,\n  aws_account_id: String,\n  topic_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.list_topic_refresh_schedules\naws_api/quicksight list_topic_refresh_schedules","url":"aws_api/quicksight.html#list_topic_refresh_schedules"},{"doc":"aws_api/quicksight","title":"list_topic_reviewed_answers","content":"pub fn list_topic_reviewed_answers(\n  client: Client,\n  aws_account_id: String,\n  topic_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.list_topic_reviewed_answers\naws_api/quicksight list_topic_reviewed_answers","url":"aws_api/quicksight.html#list_topic_reviewed_answers"},{"doc":"aws_api/quicksight","title":"list_topics","content":"pub fn list_topics(\n  client: Client,\n  aws_account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.list_topics\naws_api/quicksight list_topics","url":"aws_api/quicksight.html#list_topics"},{"doc":"aws_api/quicksight","title":"list_user_groups","content":"pub fn list_user_groups(\n  client: Client,\n  aws_account_id: String,\n  namespace: String,\n  user_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.list_user_groups\naws_api/quicksight list_user_groups","url":"aws_api/quicksight.html#list_user_groups"},{"doc":"aws_api/quicksight","title":"list_users","content":"pub fn list_users(\n  client: Client,\n  aws_account_id: String,\n  namespace: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.list_users\naws_api/quicksight list_users","url":"aws_api/quicksight.html#list_users"},{"doc":"aws_api/quicksight","title":"list_vpc_connections","content":"pub fn list_vpc_connections(\n  client: Client,\n  aws_account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.list_vpc_connections\naws_api/quicksight list_vpc_connections","url":"aws_api/quicksight.html#list_vpc_connections"},{"doc":"aws_api/quicksight","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/quicksight.new\naws_api/quicksight new","url":"aws_api/quicksight.html#new"},{"doc":"aws_api/quicksight","title":"put_data_set_refresh_properties","content":"pub fn put_data_set_refresh_properties(\n  client: Client,\n  aws_account_id: String,\n  data_set_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.put_data_set_refresh_properties\naws_api/quicksight put_data_set_refresh_properties","url":"aws_api/quicksight.html#put_data_set_refresh_properties"},{"doc":"aws_api/quicksight","title":"register_user","content":"pub fn register_user(\n  client: Client,\n  aws_account_id: String,\n  namespace: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.register_user\naws_api/quicksight register_user","url":"aws_api/quicksight.html#register_user"},{"doc":"aws_api/quicksight","title":"restore_analysis","content":"pub fn restore_analysis(\n  client: Client,\n  aws_account_id: String,\n  analysis_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.restore_analysis\naws_api/quicksight restore_analysis","url":"aws_api/quicksight.html#restore_analysis"},{"doc":"aws_api/quicksight","title":"search_analyses","content":"pub fn search_analyses(\n  client: Client,\n  aws_account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.search_analyses\naws_api/quicksight search_analyses","url":"aws_api/quicksight.html#search_analyses"},{"doc":"aws_api/quicksight","title":"search_dashboards","content":"pub fn search_dashboards(\n  client: Client,\n  aws_account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.search_dashboards\naws_api/quicksight search_dashboards","url":"aws_api/quicksight.html#search_dashboards"},{"doc":"aws_api/quicksight","title":"search_data_sets","content":"pub fn search_data_sets(\n  client: Client,\n  aws_account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.search_data_sets\naws_api/quicksight search_data_sets","url":"aws_api/quicksight.html#search_data_sets"},{"doc":"aws_api/quicksight","title":"search_data_sources","content":"pub fn search_data_sources(\n  client: Client,\n  aws_account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.search_data_sources\naws_api/quicksight search_data_sources","url":"aws_api/quicksight.html#search_data_sources"},{"doc":"aws_api/quicksight","title":"search_folders","content":"pub fn search_folders(\n  client: Client,\n  aws_account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.search_folders\naws_api/quicksight search_folders","url":"aws_api/quicksight.html#search_folders"},{"doc":"aws_api/quicksight","title":"search_groups","content":"pub fn search_groups(\n  client: Client,\n  aws_account_id: String,\n  namespace: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.search_groups\naws_api/quicksight search_groups","url":"aws_api/quicksight.html#search_groups"},{"doc":"aws_api/quicksight","title":"start_asset_bundle_export_job","content":"pub fn start_asset_bundle_export_job(\n  client: Client,\n  aws_account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.start_asset_bundle_export_job\naws_api/quicksight start_asset_bundle_export_job","url":"aws_api/quicksight.html#start_asset_bundle_export_job"},{"doc":"aws_api/quicksight","title":"start_asset_bundle_import_job","content":"pub fn start_asset_bundle_import_job(\n  client: Client,\n  aws_account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.start_asset_bundle_import_job\naws_api/quicksight start_asset_bundle_import_job","url":"aws_api/quicksight.html#start_asset_bundle_import_job"},{"doc":"aws_api/quicksight","title":"start_dashboard_snapshot_job","content":"pub fn start_dashboard_snapshot_job(\n  client: Client,\n  aws_account_id: String,\n  dashboard_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.start_dashboard_snapshot_job\naws_api/quicksight start_dashboard_snapshot_job","url":"aws_api/quicksight.html#start_dashboard_snapshot_job"},{"doc":"aws_api/quicksight","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.tag_resource\naws_api/quicksight tag_resource","url":"aws_api/quicksight.html#tag_resource"},{"doc":"aws_api/quicksight","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.untag_resource\naws_api/quicksight untag_resource","url":"aws_api/quicksight.html#untag_resource"},{"doc":"aws_api/quicksight","title":"update_account_customization","content":"pub fn update_account_customization(\n  client: Client,\n  aws_account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.update_account_customization\naws_api/quicksight update_account_customization","url":"aws_api/quicksight.html#update_account_customization"},{"doc":"aws_api/quicksight","title":"update_account_settings","content":"pub fn update_account_settings(\n  client: Client,\n  aws_account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.update_account_settings\naws_api/quicksight update_account_settings","url":"aws_api/quicksight.html#update_account_settings"},{"doc":"aws_api/quicksight","title":"update_analysis","content":"pub fn update_analysis(\n  client: Client,\n  aws_account_id: String,\n  analysis_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.update_analysis\naws_api/quicksight update_analysis","url":"aws_api/quicksight.html#update_analysis"},{"doc":"aws_api/quicksight","title":"update_analysis_permissions","content":"pub fn update_analysis_permissions(\n  client: Client,\n  aws_account_id: String,\n  analysis_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.update_analysis_permissions\naws_api/quicksight update_analysis_permissions","url":"aws_api/quicksight.html#update_analysis_permissions"},{"doc":"aws_api/quicksight","title":"update_dashboard","content":"pub fn update_dashboard(\n  client: Client,\n  aws_account_id: String,\n  dashboard_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.update_dashboard\naws_api/quicksight update_dashboard","url":"aws_api/quicksight.html#update_dashboard"},{"doc":"aws_api/quicksight","title":"update_dashboard_links","content":"pub fn update_dashboard_links(\n  client: Client,\n  aws_account_id: String,\n  dashboard_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.update_dashboard_links\naws_api/quicksight update_dashboard_links","url":"aws_api/quicksight.html#update_dashboard_links"},{"doc":"aws_api/quicksight","title":"update_dashboard_permissions","content":"pub fn update_dashboard_permissions(\n  client: Client,\n  aws_account_id: String,\n  dashboard_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.update_dashboard_permissions\naws_api/quicksight update_dashboard_permissions","url":"aws_api/quicksight.html#update_dashboard_permissions"},{"doc":"aws_api/quicksight","title":"update_dashboard_published_version","content":"pub fn update_dashboard_published_version(\n  client: Client,\n  aws_account_id: String,\n  dashboard_id: String,\n  version_number: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.update_dashboard_published_version\naws_api/quicksight update_dashboard_published_version","url":"aws_api/quicksight.html#update_dashboard_published_version"},{"doc":"aws_api/quicksight","title":"update_data_set","content":"pub fn update_data_set(\n  client: Client,\n  aws_account_id: String,\n  data_set_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.update_data_set\naws_api/quicksight update_data_set","url":"aws_api/quicksight.html#update_data_set"},{"doc":"aws_api/quicksight","title":"update_data_set_permissions","content":"pub fn update_data_set_permissions(\n  client: Client,\n  aws_account_id: String,\n  data_set_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.update_data_set_permissions\naws_api/quicksight update_data_set_permissions","url":"aws_api/quicksight.html#update_data_set_permissions"},{"doc":"aws_api/quicksight","title":"update_data_source","content":"pub fn update_data_source(\n  client: Client,\n  aws_account_id: String,\n  data_source_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.update_data_source\naws_api/quicksight update_data_source","url":"aws_api/quicksight.html#update_data_source"},{"doc":"aws_api/quicksight","title":"update_data_source_permissions","content":"pub fn update_data_source_permissions(\n  client: Client,\n  aws_account_id: String,\n  data_source_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.update_data_source_permissions\naws_api/quicksight update_data_source_permissions","url":"aws_api/quicksight.html#update_data_source_permissions"},{"doc":"aws_api/quicksight","title":"update_folder","content":"pub fn update_folder(\n  client: Client,\n  aws_account_id: String,\n  folder_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.update_folder\naws_api/quicksight update_folder","url":"aws_api/quicksight.html#update_folder"},{"doc":"aws_api/quicksight","title":"update_folder_permissions","content":"pub fn update_folder_permissions(\n  client: Client,\n  aws_account_id: String,\n  folder_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.update_folder_permissions\naws_api/quicksight update_folder_permissions","url":"aws_api/quicksight.html#update_folder_permissions"},{"doc":"aws_api/quicksight","title":"update_group","content":"pub fn update_group(\n  client: Client,\n  aws_account_id: String,\n  namespace: String,\n  group_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.update_group\naws_api/quicksight update_group","url":"aws_api/quicksight.html#update_group"},{"doc":"aws_api/quicksight","title":"update_iam_policy_assignment","content":"pub fn update_iam_policy_assignment(\n  client: Client,\n  aws_account_id: String,\n  namespace: String,\n  assignment_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.update_iam_policy_assignment\naws_api/quicksight update_iam_policy_assignment","url":"aws_api/quicksight.html#update_iam_policy_assignment"},{"doc":"aws_api/quicksight","title":"update_identity_propagation_config","content":"pub fn update_identity_propagation_config(\n  client: Client,\n  aws_account_id: String,\n  service: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.update_identity_propagation_config\naws_api/quicksight update_identity_propagation_config","url":"aws_api/quicksight.html#update_identity_propagation_config"},{"doc":"aws_api/quicksight","title":"update_ip_restriction","content":"pub fn update_ip_restriction(\n  client: Client,\n  aws_account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.update_ip_restriction\naws_api/quicksight update_ip_restriction","url":"aws_api/quicksight.html#update_ip_restriction"},{"doc":"aws_api/quicksight","title":"update_key_registration","content":"pub fn update_key_registration(\n  client: Client,\n  aws_account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.update_key_registration\naws_api/quicksight update_key_registration","url":"aws_api/quicksight.html#update_key_registration"},{"doc":"aws_api/quicksight","title":"update_public_sharing_settings","content":"pub fn update_public_sharing_settings(\n  client: Client,\n  aws_account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.update_public_sharing_settings\naws_api/quicksight update_public_sharing_settings","url":"aws_api/quicksight.html#update_public_sharing_settings"},{"doc":"aws_api/quicksight","title":"update_refresh_schedule","content":"pub fn update_refresh_schedule(\n  client: Client,\n  aws_account_id: String,\n  data_set_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.update_refresh_schedule\naws_api/quicksight update_refresh_schedule","url":"aws_api/quicksight.html#update_refresh_schedule"},{"doc":"aws_api/quicksight","title":"update_role_custom_permission","content":"pub fn update_role_custom_permission(\n  client: Client,\n  aws_account_id: String,\n  namespace: String,\n  role: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.update_role_custom_permission\naws_api/quicksight update_role_custom_permission","url":"aws_api/quicksight.html#update_role_custom_permission"},{"doc":"aws_api/quicksight","title":"update_spice_capacity_configuration","content":"pub fn update_spice_capacity_configuration(\n  client: Client,\n  aws_account_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.update_spice_capacity_configuration\naws_api/quicksight update_spice_capacity_configuration","url":"aws_api/quicksight.html#update_spice_capacity_configuration"},{"doc":"aws_api/quicksight","title":"update_template","content":"pub fn update_template(\n  client: Client,\n  aws_account_id: String,\n  template_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.update_template\naws_api/quicksight update_template","url":"aws_api/quicksight.html#update_template"},{"doc":"aws_api/quicksight","title":"update_template_alias","content":"pub fn update_template_alias(\n  client: Client,\n  aws_account_id: String,\n  template_id: String,\n  alias_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.update_template_alias\naws_api/quicksight update_template_alias","url":"aws_api/quicksight.html#update_template_alias"},{"doc":"aws_api/quicksight","title":"update_template_permissions","content":"pub fn update_template_permissions(\n  client: Client,\n  aws_account_id: String,\n  template_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.update_template_permissions\naws_api/quicksight update_template_permissions","url":"aws_api/quicksight.html#update_template_permissions"},{"doc":"aws_api/quicksight","title":"update_theme","content":"pub fn update_theme(\n  client: Client,\n  aws_account_id: String,\n  theme_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.update_theme\naws_api/quicksight update_theme","url":"aws_api/quicksight.html#update_theme"},{"doc":"aws_api/quicksight","title":"update_theme_alias","content":"pub fn update_theme_alias(\n  client: Client,\n  aws_account_id: String,\n  theme_id: String,\n  alias_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.update_theme_alias\naws_api/quicksight update_theme_alias","url":"aws_api/quicksight.html#update_theme_alias"},{"doc":"aws_api/quicksight","title":"update_theme_permissions","content":"pub fn update_theme_permissions(\n  client: Client,\n  aws_account_id: String,\n  theme_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.update_theme_permissions\naws_api/quicksight update_theme_permissions","url":"aws_api/quicksight.html#update_theme_permissions"},{"doc":"aws_api/quicksight","title":"update_topic","content":"pub fn update_topic(\n  client: Client,\n  aws_account_id: String,\n  topic_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.update_topic\naws_api/quicksight update_topic","url":"aws_api/quicksight.html#update_topic"},{"doc":"aws_api/quicksight","title":"update_topic_permissions","content":"pub fn update_topic_permissions(\n  client: Client,\n  aws_account_id: String,\n  topic_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.update_topic_permissions\naws_api/quicksight update_topic_permissions","url":"aws_api/quicksight.html#update_topic_permissions"},{"doc":"aws_api/quicksight","title":"update_topic_refresh_schedule","content":"pub fn update_topic_refresh_schedule(\n  client: Client,\n  aws_account_id: String,\n  topic_id: String,\n  dataset_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.update_topic_refresh_schedule\naws_api/quicksight update_topic_refresh_schedule","url":"aws_api/quicksight.html#update_topic_refresh_schedule"},{"doc":"aws_api/quicksight","title":"update_user","content":"pub fn update_user(\n  client: Client,\n  aws_account_id: String,\n  namespace: String,\n  user_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.update_user\naws_api/quicksight update_user","url":"aws_api/quicksight.html#update_user"},{"doc":"aws_api/quicksight","title":"update_vpc_connection","content":"pub fn update_vpc_connection(\n  client: Client,\n  aws_account_id: String,\n  vpc_connection_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/quicksight.update_vpc_connection\naws_api/quicksight update_vpc_connection","url":"aws_api/quicksight.html#update_vpc_connection"},{"doc":"aws_api/quicksight","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/quicksight.with_custom_endpoint\naws_api/quicksight with_custom_endpoint","url":"aws_api/quicksight.html#with_custom_endpoint"},{"doc":"aws_api/quicksight","title":"aws_api/quicksight","content":"","url":"aws_api/quicksight.html"},{"doc":"aws_api/ram","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/ram.Client\naws_api/ram Client","url":"aws_api/ram.html#Client"},{"doc":"aws_api/ram","title":"accept_resource_share_invitation","content":"pub fn accept_resource_share_invitation(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ram.accept_resource_share_invitation\naws_api/ram accept_resource_share_invitation","url":"aws_api/ram.html#accept_resource_share_invitation"},{"doc":"aws_api/ram","title":"associate_resource_share","content":"pub fn associate_resource_share(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ram.associate_resource_share\naws_api/ram associate_resource_share","url":"aws_api/ram.html#associate_resource_share"},{"doc":"aws_api/ram","title":"associate_resource_share_permission","content":"pub fn associate_resource_share_permission(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ram.associate_resource_share_permission\naws_api/ram associate_resource_share_permission","url":"aws_api/ram.html#associate_resource_share_permission"},{"doc":"aws_api/ram","title":"create_permission","content":"pub fn create_permission(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ram.create_permission\naws_api/ram create_permission","url":"aws_api/ram.html#create_permission"},{"doc":"aws_api/ram","title":"create_permission_version","content":"pub fn create_permission_version(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ram.create_permission_version\naws_api/ram create_permission_version","url":"aws_api/ram.html#create_permission_version"},{"doc":"aws_api/ram","title":"create_resource_share","content":"pub fn create_resource_share(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ram.create_resource_share\naws_api/ram create_resource_share","url":"aws_api/ram.html#create_resource_share"},{"doc":"aws_api/ram","title":"delete_permission","content":"pub fn delete_permission(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ram.delete_permission\naws_api/ram delete_permission","url":"aws_api/ram.html#delete_permission"},{"doc":"aws_api/ram","title":"delete_permission_version","content":"pub fn delete_permission_version(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ram.delete_permission_version\naws_api/ram delete_permission_version","url":"aws_api/ram.html#delete_permission_version"},{"doc":"aws_api/ram","title":"delete_resource_share","content":"pub fn delete_resource_share(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ram.delete_resource_share\naws_api/ram delete_resource_share","url":"aws_api/ram.html#delete_resource_share"},{"doc":"aws_api/ram","title":"disassociate_resource_share","content":"pub fn disassociate_resource_share(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ram.disassociate_resource_share\naws_api/ram disassociate_resource_share","url":"aws_api/ram.html#disassociate_resource_share"},{"doc":"aws_api/ram","title":"disassociate_resource_share_permission","content":"pub fn disassociate_resource_share_permission(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ram.disassociate_resource_share_permission\naws_api/ram disassociate_resource_share_permission","url":"aws_api/ram.html#disassociate_resource_share_permission"},{"doc":"aws_api/ram","title":"enable_sharing_with_aws_organization","content":"pub fn enable_sharing_with_aws_organization(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ram.enable_sharing_with_aws_organization\naws_api/ram enable_sharing_with_aws_organization","url":"aws_api/ram.html#enable_sharing_with_aws_organization"},{"doc":"aws_api/ram","title":"get_permission","content":"pub fn get_permission(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ram.get_permission\naws_api/ram get_permission","url":"aws_api/ram.html#get_permission"},{"doc":"aws_api/ram","title":"get_resource_policies","content":"pub fn get_resource_policies(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ram.get_resource_policies\naws_api/ram get_resource_policies","url":"aws_api/ram.html#get_resource_policies"},{"doc":"aws_api/ram","title":"get_resource_share_associations","content":"pub fn get_resource_share_associations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ram.get_resource_share_associations\naws_api/ram get_resource_share_associations","url":"aws_api/ram.html#get_resource_share_associations"},{"doc":"aws_api/ram","title":"get_resource_share_invitations","content":"pub fn get_resource_share_invitations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ram.get_resource_share_invitations\naws_api/ram get_resource_share_invitations","url":"aws_api/ram.html#get_resource_share_invitations"},{"doc":"aws_api/ram","title":"get_resource_shares","content":"pub fn get_resource_shares(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ram.get_resource_shares\naws_api/ram get_resource_shares","url":"aws_api/ram.html#get_resource_shares"},{"doc":"aws_api/ram","title":"list_pending_invitation_resources","content":"pub fn list_pending_invitation_resources(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ram.list_pending_invitation_resources\naws_api/ram list_pending_invitation_resources","url":"aws_api/ram.html#list_pending_invitation_resources"},{"doc":"aws_api/ram","title":"list_permission_associations","content":"pub fn list_permission_associations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ram.list_permission_associations\naws_api/ram list_permission_associations","url":"aws_api/ram.html#list_permission_associations"},{"doc":"aws_api/ram","title":"list_permission_versions","content":"pub fn list_permission_versions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ram.list_permission_versions\naws_api/ram list_permission_versions","url":"aws_api/ram.html#list_permission_versions"},{"doc":"aws_api/ram","title":"list_permissions","content":"pub fn list_permissions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ram.list_permissions\naws_api/ram list_permissions","url":"aws_api/ram.html#list_permissions"},{"doc":"aws_api/ram","title":"list_principals","content":"pub fn list_principals(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ram.list_principals\naws_api/ram list_principals","url":"aws_api/ram.html#list_principals"},{"doc":"aws_api/ram","title":"list_replace_permission_associations_work","content":"pub fn list_replace_permission_associations_work(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ram.list_replace_permission_associations_work\naws_api/ram list_replace_permission_associations_work","url":"aws_api/ram.html#list_replace_permission_associations_work"},{"doc":"aws_api/ram","title":"list_resource_share_permissions","content":"pub fn list_resource_share_permissions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ram.list_resource_share_permissions\naws_api/ram list_resource_share_permissions","url":"aws_api/ram.html#list_resource_share_permissions"},{"doc":"aws_api/ram","title":"list_resource_types","content":"pub fn list_resource_types(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ram.list_resource_types\naws_api/ram list_resource_types","url":"aws_api/ram.html#list_resource_types"},{"doc":"aws_api/ram","title":"list_resources","content":"pub fn list_resources(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ram.list_resources\naws_api/ram list_resources","url":"aws_api/ram.html#list_resources"},{"doc":"aws_api/ram","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/ram.new\naws_api/ram new","url":"aws_api/ram.html#new"},{"doc":"aws_api/ram","title":"promote_permission_created_from_policy","content":"pub fn promote_permission_created_from_policy(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ram.promote_permission_created_from_policy\naws_api/ram promote_permission_created_from_policy","url":"aws_api/ram.html#promote_permission_created_from_policy"},{"doc":"aws_api/ram","title":"promote_resource_share_created_from_policy","content":"pub fn promote_resource_share_created_from_policy(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ram.promote_resource_share_created_from_policy\naws_api/ram promote_resource_share_created_from_policy","url":"aws_api/ram.html#promote_resource_share_created_from_policy"},{"doc":"aws_api/ram","title":"reject_resource_share_invitation","content":"pub fn reject_resource_share_invitation(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ram.reject_resource_share_invitation\naws_api/ram reject_resource_share_invitation","url":"aws_api/ram.html#reject_resource_share_invitation"},{"doc":"aws_api/ram","title":"replace_permission_associations","content":"pub fn replace_permission_associations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ram.replace_permission_associations\naws_api/ram replace_permission_associations","url":"aws_api/ram.html#replace_permission_associations"},{"doc":"aws_api/ram","title":"set_default_permission_version","content":"pub fn set_default_permission_version(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ram.set_default_permission_version\naws_api/ram set_default_permission_version","url":"aws_api/ram.html#set_default_permission_version"},{"doc":"aws_api/ram","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ram.tag_resource\naws_api/ram tag_resource","url":"aws_api/ram.html#tag_resource"},{"doc":"aws_api/ram","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ram.untag_resource\naws_api/ram untag_resource","url":"aws_api/ram.html#untag_resource"},{"doc":"aws_api/ram","title":"update_resource_share","content":"pub fn update_resource_share(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ram.update_resource_share\naws_api/ram update_resource_share","url":"aws_api/ram.html#update_resource_share"},{"doc":"aws_api/ram","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/ram.with_custom_endpoint\naws_api/ram with_custom_endpoint","url":"aws_api/ram.html#with_custom_endpoint"},{"doc":"aws_api/ram","title":"aws_api/ram","content":"","url":"aws_api/ram.html"},{"doc":"aws_api/rbin","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/rbin.Client\naws_api/rbin Client","url":"aws_api/rbin.html#Client"},{"doc":"aws_api/rbin","title":"create_rule","content":"pub fn create_rule(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rbin.create_rule\naws_api/rbin create_rule","url":"aws_api/rbin.html#create_rule"},{"doc":"aws_api/rbin","title":"delete_rule","content":"pub fn delete_rule(\n  client: Client,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rbin.delete_rule\naws_api/rbin delete_rule","url":"aws_api/rbin.html#delete_rule"},{"doc":"aws_api/rbin","title":"get_rule","content":"pub fn get_rule(\n  client: Client,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rbin.get_rule\naws_api/rbin get_rule","url":"aws_api/rbin.html#get_rule"},{"doc":"aws_api/rbin","title":"list_rules","content":"pub fn list_rules(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rbin.list_rules\naws_api/rbin list_rules","url":"aws_api/rbin.html#list_rules"},{"doc":"aws_api/rbin","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rbin.list_tags_for_resource\naws_api/rbin list_tags_for_resource","url":"aws_api/rbin.html#list_tags_for_resource"},{"doc":"aws_api/rbin","title":"lock_rule","content":"pub fn lock_rule(\n  client: Client,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rbin.lock_rule\naws_api/rbin lock_rule","url":"aws_api/rbin.html#lock_rule"},{"doc":"aws_api/rbin","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/rbin.new\naws_api/rbin new","url":"aws_api/rbin.html#new"},{"doc":"aws_api/rbin","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rbin.tag_resource\naws_api/rbin tag_resource","url":"aws_api/rbin.html#tag_resource"},{"doc":"aws_api/rbin","title":"unlock_rule","content":"pub fn unlock_rule(\n  client: Client,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rbin.unlock_rule\naws_api/rbin unlock_rule","url":"aws_api/rbin.html#unlock_rule"},{"doc":"aws_api/rbin","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rbin.untag_resource\naws_api/rbin untag_resource","url":"aws_api/rbin.html#untag_resource"},{"doc":"aws_api/rbin","title":"update_rule","content":"pub fn update_rule(\n  client: Client,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rbin.update_rule\naws_api/rbin update_rule","url":"aws_api/rbin.html#update_rule"},{"doc":"aws_api/rbin","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/rbin.with_custom_endpoint\naws_api/rbin with_custom_endpoint","url":"aws_api/rbin.html#with_custom_endpoint"},{"doc":"aws_api/rbin","title":"aws_api/rbin","content":"","url":"aws_api/rbin.html"},{"doc":"aws_api/rds","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/rds.Client\naws_api/rds Client","url":"aws_api/rds.html#Client"},{"doc":"aws_api/rds","title":"add_role_to_db_cluster","content":"pub fn add_role_to_db_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.add_role_to_db_cluster\naws_api/rds add_role_to_db_cluster","url":"aws_api/rds.html#add_role_to_db_cluster"},{"doc":"aws_api/rds","title":"add_role_to_db_instance","content":"pub fn add_role_to_db_instance(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.add_role_to_db_instance\naws_api/rds add_role_to_db_instance","url":"aws_api/rds.html#add_role_to_db_instance"},{"doc":"aws_api/rds","title":"add_source_identifier_to_subscription","content":"pub fn add_source_identifier_to_subscription(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.add_source_identifier_to_subscription\naws_api/rds add_source_identifier_to_subscription","url":"aws_api/rds.html#add_source_identifier_to_subscription"},{"doc":"aws_api/rds","title":"add_tags_to_resource","content":"pub fn add_tags_to_resource(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.add_tags_to_resource\naws_api/rds add_tags_to_resource","url":"aws_api/rds.html#add_tags_to_resource"},{"doc":"aws_api/rds","title":"apply_pending_maintenance_action","content":"pub fn apply_pending_maintenance_action(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.apply_pending_maintenance_action\naws_api/rds apply_pending_maintenance_action","url":"aws_api/rds.html#apply_pending_maintenance_action"},{"doc":"aws_api/rds","title":"authorize_db_security_group_ingress","content":"pub fn authorize_db_security_group_ingress(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.authorize_db_security_group_ingress\naws_api/rds authorize_db_security_group_ingress","url":"aws_api/rds.html#authorize_db_security_group_ingress"},{"doc":"aws_api/rds","title":"backtrack_db_cluster","content":"pub fn backtrack_db_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.backtrack_db_cluster\naws_api/rds backtrack_db_cluster","url":"aws_api/rds.html#backtrack_db_cluster"},{"doc":"aws_api/rds","title":"cancel_export_task","content":"pub fn cancel_export_task(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.cancel_export_task\naws_api/rds cancel_export_task","url":"aws_api/rds.html#cancel_export_task"},{"doc":"aws_api/rds","title":"copy_db_cluster_parameter_group","content":"pub fn copy_db_cluster_parameter_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.copy_db_cluster_parameter_group\naws_api/rds copy_db_cluster_parameter_group","url":"aws_api/rds.html#copy_db_cluster_parameter_group"},{"doc":"aws_api/rds","title":"copy_db_cluster_snapshot","content":"pub fn copy_db_cluster_snapshot(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.copy_db_cluster_snapshot\naws_api/rds copy_db_cluster_snapshot","url":"aws_api/rds.html#copy_db_cluster_snapshot"},{"doc":"aws_api/rds","title":"copy_db_parameter_group","content":"pub fn copy_db_parameter_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.copy_db_parameter_group\naws_api/rds copy_db_parameter_group","url":"aws_api/rds.html#copy_db_parameter_group"},{"doc":"aws_api/rds","title":"copy_db_snapshot","content":"pub fn copy_db_snapshot(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.copy_db_snapshot\naws_api/rds copy_db_snapshot","url":"aws_api/rds.html#copy_db_snapshot"},{"doc":"aws_api/rds","title":"copy_option_group","content":"pub fn copy_option_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.copy_option_group\naws_api/rds copy_option_group","url":"aws_api/rds.html#copy_option_group"},{"doc":"aws_api/rds","title":"create_blue_green_deployment","content":"pub fn create_blue_green_deployment(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.create_blue_green_deployment\naws_api/rds create_blue_green_deployment","url":"aws_api/rds.html#create_blue_green_deployment"},{"doc":"aws_api/rds","title":"create_custom_db_engine_version","content":"pub fn create_custom_db_engine_version(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.create_custom_db_engine_version\naws_api/rds create_custom_db_engine_version","url":"aws_api/rds.html#create_custom_db_engine_version"},{"doc":"aws_api/rds","title":"create_db_cluster","content":"pub fn create_db_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.create_db_cluster\naws_api/rds create_db_cluster","url":"aws_api/rds.html#create_db_cluster"},{"doc":"aws_api/rds","title":"create_db_cluster_endpoint","content":"pub fn create_db_cluster_endpoint(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.create_db_cluster_endpoint\naws_api/rds create_db_cluster_endpoint","url":"aws_api/rds.html#create_db_cluster_endpoint"},{"doc":"aws_api/rds","title":"create_db_cluster_parameter_group","content":"pub fn create_db_cluster_parameter_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.create_db_cluster_parameter_group\naws_api/rds create_db_cluster_parameter_group","url":"aws_api/rds.html#create_db_cluster_parameter_group"},{"doc":"aws_api/rds","title":"create_db_cluster_snapshot","content":"pub fn create_db_cluster_snapshot(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.create_db_cluster_snapshot\naws_api/rds create_db_cluster_snapshot","url":"aws_api/rds.html#create_db_cluster_snapshot"},{"doc":"aws_api/rds","title":"create_db_instance","content":"pub fn create_db_instance(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.create_db_instance\naws_api/rds create_db_instance","url":"aws_api/rds.html#create_db_instance"},{"doc":"aws_api/rds","title":"create_db_instance_read_replica","content":"pub fn create_db_instance_read_replica(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.create_db_instance_read_replica\naws_api/rds create_db_instance_read_replica","url":"aws_api/rds.html#create_db_instance_read_replica"},{"doc":"aws_api/rds","title":"create_db_parameter_group","content":"pub fn create_db_parameter_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.create_db_parameter_group\naws_api/rds create_db_parameter_group","url":"aws_api/rds.html#create_db_parameter_group"},{"doc":"aws_api/rds","title":"create_db_proxy","content":"pub fn create_db_proxy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.create_db_proxy\naws_api/rds create_db_proxy","url":"aws_api/rds.html#create_db_proxy"},{"doc":"aws_api/rds","title":"create_db_proxy_endpoint","content":"pub fn create_db_proxy_endpoint(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.create_db_proxy_endpoint\naws_api/rds create_db_proxy_endpoint","url":"aws_api/rds.html#create_db_proxy_endpoint"},{"doc":"aws_api/rds","title":"create_db_security_group","content":"pub fn create_db_security_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.create_db_security_group\naws_api/rds create_db_security_group","url":"aws_api/rds.html#create_db_security_group"},{"doc":"aws_api/rds","title":"create_db_shard_group","content":"pub fn create_db_shard_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.create_db_shard_group\naws_api/rds create_db_shard_group","url":"aws_api/rds.html#create_db_shard_group"},{"doc":"aws_api/rds","title":"create_db_snapshot","content":"pub fn create_db_snapshot(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.create_db_snapshot\naws_api/rds create_db_snapshot","url":"aws_api/rds.html#create_db_snapshot"},{"doc":"aws_api/rds","title":"create_db_subnet_group","content":"pub fn create_db_subnet_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.create_db_subnet_group\naws_api/rds create_db_subnet_group","url":"aws_api/rds.html#create_db_subnet_group"},{"doc":"aws_api/rds","title":"create_event_subscription","content":"pub fn create_event_subscription(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.create_event_subscription\naws_api/rds create_event_subscription","url":"aws_api/rds.html#create_event_subscription"},{"doc":"aws_api/rds","title":"create_global_cluster","content":"pub fn create_global_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.create_global_cluster\naws_api/rds create_global_cluster","url":"aws_api/rds.html#create_global_cluster"},{"doc":"aws_api/rds","title":"create_integration","content":"pub fn create_integration(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.create_integration\naws_api/rds create_integration","url":"aws_api/rds.html#create_integration"},{"doc":"aws_api/rds","title":"create_option_group","content":"pub fn create_option_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.create_option_group\naws_api/rds create_option_group","url":"aws_api/rds.html#create_option_group"},{"doc":"aws_api/rds","title":"create_tenant_database","content":"pub fn create_tenant_database(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.create_tenant_database\naws_api/rds create_tenant_database","url":"aws_api/rds.html#create_tenant_database"},{"doc":"aws_api/rds","title":"delete_blue_green_deployment","content":"pub fn delete_blue_green_deployment(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.delete_blue_green_deployment\naws_api/rds delete_blue_green_deployment","url":"aws_api/rds.html#delete_blue_green_deployment"},{"doc":"aws_api/rds","title":"delete_custom_db_engine_version","content":"pub fn delete_custom_db_engine_version(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.delete_custom_db_engine_version\naws_api/rds delete_custom_db_engine_version","url":"aws_api/rds.html#delete_custom_db_engine_version"},{"doc":"aws_api/rds","title":"delete_db_cluster","content":"pub fn delete_db_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.delete_db_cluster\naws_api/rds delete_db_cluster","url":"aws_api/rds.html#delete_db_cluster"},{"doc":"aws_api/rds","title":"delete_db_cluster_automated_backup","content":"pub fn delete_db_cluster_automated_backup(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.delete_db_cluster_automated_backup\naws_api/rds delete_db_cluster_automated_backup","url":"aws_api/rds.html#delete_db_cluster_automated_backup"},{"doc":"aws_api/rds","title":"delete_db_cluster_endpoint","content":"pub fn delete_db_cluster_endpoint(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.delete_db_cluster_endpoint\naws_api/rds delete_db_cluster_endpoint","url":"aws_api/rds.html#delete_db_cluster_endpoint"},{"doc":"aws_api/rds","title":"delete_db_cluster_parameter_group","content":"pub fn delete_db_cluster_parameter_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.delete_db_cluster_parameter_group\naws_api/rds delete_db_cluster_parameter_group","url":"aws_api/rds.html#delete_db_cluster_parameter_group"},{"doc":"aws_api/rds","title":"delete_db_cluster_snapshot","content":"pub fn delete_db_cluster_snapshot(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.delete_db_cluster_snapshot\naws_api/rds delete_db_cluster_snapshot","url":"aws_api/rds.html#delete_db_cluster_snapshot"},{"doc":"aws_api/rds","title":"delete_db_instance","content":"pub fn delete_db_instance(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.delete_db_instance\naws_api/rds delete_db_instance","url":"aws_api/rds.html#delete_db_instance"},{"doc":"aws_api/rds","title":"delete_db_instance_automated_backup","content":"pub fn delete_db_instance_automated_backup(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.delete_db_instance_automated_backup\naws_api/rds delete_db_instance_automated_backup","url":"aws_api/rds.html#delete_db_instance_automated_backup"},{"doc":"aws_api/rds","title":"delete_db_parameter_group","content":"pub fn delete_db_parameter_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.delete_db_parameter_group\naws_api/rds delete_db_parameter_group","url":"aws_api/rds.html#delete_db_parameter_group"},{"doc":"aws_api/rds","title":"delete_db_proxy","content":"pub fn delete_db_proxy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.delete_db_proxy\naws_api/rds delete_db_proxy","url":"aws_api/rds.html#delete_db_proxy"},{"doc":"aws_api/rds","title":"delete_db_proxy_endpoint","content":"pub fn delete_db_proxy_endpoint(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.delete_db_proxy_endpoint\naws_api/rds delete_db_proxy_endpoint","url":"aws_api/rds.html#delete_db_proxy_endpoint"},{"doc":"aws_api/rds","title":"delete_db_security_group","content":"pub fn delete_db_security_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.delete_db_security_group\naws_api/rds delete_db_security_group","url":"aws_api/rds.html#delete_db_security_group"},{"doc":"aws_api/rds","title":"delete_db_shard_group","content":"pub fn delete_db_shard_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.delete_db_shard_group\naws_api/rds delete_db_shard_group","url":"aws_api/rds.html#delete_db_shard_group"},{"doc":"aws_api/rds","title":"delete_db_snapshot","content":"pub fn delete_db_snapshot(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.delete_db_snapshot\naws_api/rds delete_db_snapshot","url":"aws_api/rds.html#delete_db_snapshot"},{"doc":"aws_api/rds","title":"delete_db_subnet_group","content":"pub fn delete_db_subnet_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.delete_db_subnet_group\naws_api/rds delete_db_subnet_group","url":"aws_api/rds.html#delete_db_subnet_group"},{"doc":"aws_api/rds","title":"delete_event_subscription","content":"pub fn delete_event_subscription(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.delete_event_subscription\naws_api/rds delete_event_subscription","url":"aws_api/rds.html#delete_event_subscription"},{"doc":"aws_api/rds","title":"delete_global_cluster","content":"pub fn delete_global_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.delete_global_cluster\naws_api/rds delete_global_cluster","url":"aws_api/rds.html#delete_global_cluster"},{"doc":"aws_api/rds","title":"delete_integration","content":"pub fn delete_integration(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.delete_integration\naws_api/rds delete_integration","url":"aws_api/rds.html#delete_integration"},{"doc":"aws_api/rds","title":"delete_option_group","content":"pub fn delete_option_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.delete_option_group\naws_api/rds delete_option_group","url":"aws_api/rds.html#delete_option_group"},{"doc":"aws_api/rds","title":"delete_tenant_database","content":"pub fn delete_tenant_database(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.delete_tenant_database\naws_api/rds delete_tenant_database","url":"aws_api/rds.html#delete_tenant_database"},{"doc":"aws_api/rds","title":"deregister_db_proxy_targets","content":"pub fn deregister_db_proxy_targets(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.deregister_db_proxy_targets\naws_api/rds deregister_db_proxy_targets","url":"aws_api/rds.html#deregister_db_proxy_targets"},{"doc":"aws_api/rds","title":"describe_account_attributes","content":"pub fn describe_account_attributes(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.describe_account_attributes\naws_api/rds describe_account_attributes","url":"aws_api/rds.html#describe_account_attributes"},{"doc":"aws_api/rds","title":"describe_blue_green_deployments","content":"pub fn describe_blue_green_deployments(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.describe_blue_green_deployments\naws_api/rds describe_blue_green_deployments","url":"aws_api/rds.html#describe_blue_green_deployments"},{"doc":"aws_api/rds","title":"describe_certificates","content":"pub fn describe_certificates(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.describe_certificates\naws_api/rds describe_certificates","url":"aws_api/rds.html#describe_certificates"},{"doc":"aws_api/rds","title":"describe_db_cluster_automated_backups","content":"pub fn describe_db_cluster_automated_backups(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.describe_db_cluster_automated_backups\naws_api/rds describe_db_cluster_automated_backups","url":"aws_api/rds.html#describe_db_cluster_automated_backups"},{"doc":"aws_api/rds","title":"describe_db_cluster_backtracks","content":"pub fn describe_db_cluster_backtracks(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.describe_db_cluster_backtracks\naws_api/rds describe_db_cluster_backtracks","url":"aws_api/rds.html#describe_db_cluster_backtracks"},{"doc":"aws_api/rds","title":"describe_db_cluster_endpoints","content":"pub fn describe_db_cluster_endpoints(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.describe_db_cluster_endpoints\naws_api/rds describe_db_cluster_endpoints","url":"aws_api/rds.html#describe_db_cluster_endpoints"},{"doc":"aws_api/rds","title":"describe_db_cluster_parameter_groups","content":"pub fn describe_db_cluster_parameter_groups(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.describe_db_cluster_parameter_groups\naws_api/rds describe_db_cluster_parameter_groups","url":"aws_api/rds.html#describe_db_cluster_parameter_groups"},{"doc":"aws_api/rds","title":"describe_db_cluster_parameters","content":"pub fn describe_db_cluster_parameters(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.describe_db_cluster_parameters\naws_api/rds describe_db_cluster_parameters","url":"aws_api/rds.html#describe_db_cluster_parameters"},{"doc":"aws_api/rds","title":"describe_db_cluster_snapshot_attributes","content":"pub fn describe_db_cluster_snapshot_attributes(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.describe_db_cluster_snapshot_attributes\naws_api/rds describe_db_cluster_snapshot_attributes","url":"aws_api/rds.html#describe_db_cluster_snapshot_attributes"},{"doc":"aws_api/rds","title":"describe_db_cluster_snapshots","content":"pub fn describe_db_cluster_snapshots(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.describe_db_cluster_snapshots\naws_api/rds describe_db_cluster_snapshots","url":"aws_api/rds.html#describe_db_cluster_snapshots"},{"doc":"aws_api/rds","title":"describe_db_clusters","content":"pub fn describe_db_clusters(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.describe_db_clusters\naws_api/rds describe_db_clusters","url":"aws_api/rds.html#describe_db_clusters"},{"doc":"aws_api/rds","title":"describe_db_engine_versions","content":"pub fn describe_db_engine_versions(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.describe_db_engine_versions\naws_api/rds describe_db_engine_versions","url":"aws_api/rds.html#describe_db_engine_versions"},{"doc":"aws_api/rds","title":"describe_db_instance_automated_backups","content":"pub fn describe_db_instance_automated_backups(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.describe_db_instance_automated_backups\naws_api/rds describe_db_instance_automated_backups","url":"aws_api/rds.html#describe_db_instance_automated_backups"},{"doc":"aws_api/rds","title":"describe_db_instances","content":"pub fn describe_db_instances(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.describe_db_instances\naws_api/rds describe_db_instances","url":"aws_api/rds.html#describe_db_instances"},{"doc":"aws_api/rds","title":"describe_db_log_files","content":"pub fn describe_db_log_files(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.describe_db_log_files\naws_api/rds describe_db_log_files","url":"aws_api/rds.html#describe_db_log_files"},{"doc":"aws_api/rds","title":"describe_db_parameter_groups","content":"pub fn describe_db_parameter_groups(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.describe_db_parameter_groups\naws_api/rds describe_db_parameter_groups","url":"aws_api/rds.html#describe_db_parameter_groups"},{"doc":"aws_api/rds","title":"describe_db_parameters","content":"pub fn describe_db_parameters(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.describe_db_parameters\naws_api/rds describe_db_parameters","url":"aws_api/rds.html#describe_db_parameters"},{"doc":"aws_api/rds","title":"describe_db_proxies","content":"pub fn describe_db_proxies(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.describe_db_proxies\naws_api/rds describe_db_proxies","url":"aws_api/rds.html#describe_db_proxies"},{"doc":"aws_api/rds","title":"describe_db_proxy_endpoints","content":"pub fn describe_db_proxy_endpoints(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.describe_db_proxy_endpoints\naws_api/rds describe_db_proxy_endpoints","url":"aws_api/rds.html#describe_db_proxy_endpoints"},{"doc":"aws_api/rds","title":"describe_db_proxy_target_groups","content":"pub fn describe_db_proxy_target_groups(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.describe_db_proxy_target_groups\naws_api/rds describe_db_proxy_target_groups","url":"aws_api/rds.html#describe_db_proxy_target_groups"},{"doc":"aws_api/rds","title":"describe_db_proxy_targets","content":"pub fn describe_db_proxy_targets(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.describe_db_proxy_targets\naws_api/rds describe_db_proxy_targets","url":"aws_api/rds.html#describe_db_proxy_targets"},{"doc":"aws_api/rds","title":"describe_db_recommendations","content":"pub fn describe_db_recommendations(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.describe_db_recommendations\naws_api/rds describe_db_recommendations","url":"aws_api/rds.html#describe_db_recommendations"},{"doc":"aws_api/rds","title":"describe_db_security_groups","content":"pub fn describe_db_security_groups(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.describe_db_security_groups\naws_api/rds describe_db_security_groups","url":"aws_api/rds.html#describe_db_security_groups"},{"doc":"aws_api/rds","title":"describe_db_shard_groups","content":"pub fn describe_db_shard_groups(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.describe_db_shard_groups\naws_api/rds describe_db_shard_groups","url":"aws_api/rds.html#describe_db_shard_groups"},{"doc":"aws_api/rds","title":"describe_db_snapshot_attributes","content":"pub fn describe_db_snapshot_attributes(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.describe_db_snapshot_attributes\naws_api/rds describe_db_snapshot_attributes","url":"aws_api/rds.html#describe_db_snapshot_attributes"},{"doc":"aws_api/rds","title":"describe_db_snapshot_tenant_databases","content":"pub fn describe_db_snapshot_tenant_databases(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.describe_db_snapshot_tenant_databases\naws_api/rds describe_db_snapshot_tenant_databases","url":"aws_api/rds.html#describe_db_snapshot_tenant_databases"},{"doc":"aws_api/rds","title":"describe_db_snapshots","content":"pub fn describe_db_snapshots(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.describe_db_snapshots\naws_api/rds describe_db_snapshots","url":"aws_api/rds.html#describe_db_snapshots"},{"doc":"aws_api/rds","title":"describe_db_subnet_groups","content":"pub fn describe_db_subnet_groups(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.describe_db_subnet_groups\naws_api/rds describe_db_subnet_groups","url":"aws_api/rds.html#describe_db_subnet_groups"},{"doc":"aws_api/rds","title":"describe_engine_default_cluster_parameters","content":"pub fn describe_engine_default_cluster_parameters(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.describe_engine_default_cluster_parameters\naws_api/rds describe_engine_default_cluster_parameters","url":"aws_api/rds.html#describe_engine_default_cluster_parameters"},{"doc":"aws_api/rds","title":"describe_engine_default_parameters","content":"pub fn describe_engine_default_parameters(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.describe_engine_default_parameters\naws_api/rds describe_engine_default_parameters","url":"aws_api/rds.html#describe_engine_default_parameters"},{"doc":"aws_api/rds","title":"describe_event_categories","content":"pub fn describe_event_categories(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.describe_event_categories\naws_api/rds describe_event_categories","url":"aws_api/rds.html#describe_event_categories"},{"doc":"aws_api/rds","title":"describe_event_subscriptions","content":"pub fn describe_event_subscriptions(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.describe_event_subscriptions\naws_api/rds describe_event_subscriptions","url":"aws_api/rds.html#describe_event_subscriptions"},{"doc":"aws_api/rds","title":"describe_events","content":"pub fn describe_events(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.describe_events\naws_api/rds describe_events","url":"aws_api/rds.html#describe_events"},{"doc":"aws_api/rds","title":"describe_export_tasks","content":"pub fn describe_export_tasks(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.describe_export_tasks\naws_api/rds describe_export_tasks","url":"aws_api/rds.html#describe_export_tasks"},{"doc":"aws_api/rds","title":"describe_global_clusters","content":"pub fn describe_global_clusters(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.describe_global_clusters\naws_api/rds describe_global_clusters","url":"aws_api/rds.html#describe_global_clusters"},{"doc":"aws_api/rds","title":"describe_integrations","content":"pub fn describe_integrations(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.describe_integrations\naws_api/rds describe_integrations","url":"aws_api/rds.html#describe_integrations"},{"doc":"aws_api/rds","title":"describe_option_group_options","content":"pub fn describe_option_group_options(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.describe_option_group_options\naws_api/rds describe_option_group_options","url":"aws_api/rds.html#describe_option_group_options"},{"doc":"aws_api/rds","title":"describe_option_groups","content":"pub fn describe_option_groups(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.describe_option_groups\naws_api/rds describe_option_groups","url":"aws_api/rds.html#describe_option_groups"},{"doc":"aws_api/rds","title":"describe_orderable_db_instance_options","content":"pub fn describe_orderable_db_instance_options(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.describe_orderable_db_instance_options\naws_api/rds describe_orderable_db_instance_options","url":"aws_api/rds.html#describe_orderable_db_instance_options"},{"doc":"aws_api/rds","title":"describe_pending_maintenance_actions","content":"pub fn describe_pending_maintenance_actions(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.describe_pending_maintenance_actions\naws_api/rds describe_pending_maintenance_actions","url":"aws_api/rds.html#describe_pending_maintenance_actions"},{"doc":"aws_api/rds","title":"describe_reserved_db_instances","content":"pub fn describe_reserved_db_instances(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.describe_reserved_db_instances\naws_api/rds describe_reserved_db_instances","url":"aws_api/rds.html#describe_reserved_db_instances"},{"doc":"aws_api/rds","title":"describe_reserved_db_instances_offerings","content":"pub fn describe_reserved_db_instances_offerings(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.describe_reserved_db_instances_offerings\naws_api/rds describe_reserved_db_instances_offerings","url":"aws_api/rds.html#describe_reserved_db_instances_offerings"},{"doc":"aws_api/rds","title":"describe_source_regions","content":"pub fn describe_source_regions(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.describe_source_regions\naws_api/rds describe_source_regions","url":"aws_api/rds.html#describe_source_regions"},{"doc":"aws_api/rds","title":"describe_tenant_databases","content":"pub fn describe_tenant_databases(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.describe_tenant_databases\naws_api/rds describe_tenant_databases","url":"aws_api/rds.html#describe_tenant_databases"},{"doc":"aws_api/rds","title":"describe_valid_db_instance_modifications","content":"pub fn describe_valid_db_instance_modifications(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.describe_valid_db_instance_modifications\naws_api/rds describe_valid_db_instance_modifications","url":"aws_api/rds.html#describe_valid_db_instance_modifications"},{"doc":"aws_api/rds","title":"disable_http_endpoint","content":"pub fn disable_http_endpoint(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.disable_http_endpoint\naws_api/rds disable_http_endpoint","url":"aws_api/rds.html#disable_http_endpoint"},{"doc":"aws_api/rds","title":"download_db_log_file_portion","content":"pub fn download_db_log_file_portion(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.download_db_log_file_portion\naws_api/rds download_db_log_file_portion","url":"aws_api/rds.html#download_db_log_file_portion"},{"doc":"aws_api/rds","title":"enable_http_endpoint","content":"pub fn enable_http_endpoint(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.enable_http_endpoint\naws_api/rds enable_http_endpoint","url":"aws_api/rds.html#enable_http_endpoint"},{"doc":"aws_api/rds","title":"failover_db_cluster","content":"pub fn failover_db_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.failover_db_cluster\naws_api/rds failover_db_cluster","url":"aws_api/rds.html#failover_db_cluster"},{"doc":"aws_api/rds","title":"failover_global_cluster","content":"pub fn failover_global_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.failover_global_cluster\naws_api/rds failover_global_cluster","url":"aws_api/rds.html#failover_global_cluster"},{"doc":"aws_api/rds","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.list_tags_for_resource\naws_api/rds list_tags_for_resource","url":"aws_api/rds.html#list_tags_for_resource"},{"doc":"aws_api/rds","title":"modify_activity_stream","content":"pub fn modify_activity_stream(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.modify_activity_stream\naws_api/rds modify_activity_stream","url":"aws_api/rds.html#modify_activity_stream"},{"doc":"aws_api/rds","title":"modify_certificates","content":"pub fn modify_certificates(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.modify_certificates\naws_api/rds modify_certificates","url":"aws_api/rds.html#modify_certificates"},{"doc":"aws_api/rds","title":"modify_current_db_cluster_capacity","content":"pub fn modify_current_db_cluster_capacity(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.modify_current_db_cluster_capacity\naws_api/rds modify_current_db_cluster_capacity","url":"aws_api/rds.html#modify_current_db_cluster_capacity"},{"doc":"aws_api/rds","title":"modify_custom_db_engine_version","content":"pub fn modify_custom_db_engine_version(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.modify_custom_db_engine_version\naws_api/rds modify_custom_db_engine_version","url":"aws_api/rds.html#modify_custom_db_engine_version"},{"doc":"aws_api/rds","title":"modify_db_cluster","content":"pub fn modify_db_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.modify_db_cluster\naws_api/rds modify_db_cluster","url":"aws_api/rds.html#modify_db_cluster"},{"doc":"aws_api/rds","title":"modify_db_cluster_endpoint","content":"pub fn modify_db_cluster_endpoint(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.modify_db_cluster_endpoint\naws_api/rds modify_db_cluster_endpoint","url":"aws_api/rds.html#modify_db_cluster_endpoint"},{"doc":"aws_api/rds","title":"modify_db_cluster_parameter_group","content":"pub fn modify_db_cluster_parameter_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.modify_db_cluster_parameter_group\naws_api/rds modify_db_cluster_parameter_group","url":"aws_api/rds.html#modify_db_cluster_parameter_group"},{"doc":"aws_api/rds","title":"modify_db_cluster_snapshot_attribute","content":"pub fn modify_db_cluster_snapshot_attribute(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.modify_db_cluster_snapshot_attribute\naws_api/rds modify_db_cluster_snapshot_attribute","url":"aws_api/rds.html#modify_db_cluster_snapshot_attribute"},{"doc":"aws_api/rds","title":"modify_db_instance","content":"pub fn modify_db_instance(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.modify_db_instance\naws_api/rds modify_db_instance","url":"aws_api/rds.html#modify_db_instance"},{"doc":"aws_api/rds","title":"modify_db_parameter_group","content":"pub fn modify_db_parameter_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.modify_db_parameter_group\naws_api/rds modify_db_parameter_group","url":"aws_api/rds.html#modify_db_parameter_group"},{"doc":"aws_api/rds","title":"modify_db_proxy","content":"pub fn modify_db_proxy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.modify_db_proxy\naws_api/rds modify_db_proxy","url":"aws_api/rds.html#modify_db_proxy"},{"doc":"aws_api/rds","title":"modify_db_proxy_endpoint","content":"pub fn modify_db_proxy_endpoint(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.modify_db_proxy_endpoint\naws_api/rds modify_db_proxy_endpoint","url":"aws_api/rds.html#modify_db_proxy_endpoint"},{"doc":"aws_api/rds","title":"modify_db_proxy_target_group","content":"pub fn modify_db_proxy_target_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.modify_db_proxy_target_group\naws_api/rds modify_db_proxy_target_group","url":"aws_api/rds.html#modify_db_proxy_target_group"},{"doc":"aws_api/rds","title":"modify_db_recommendation","content":"pub fn modify_db_recommendation(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.modify_db_recommendation\naws_api/rds modify_db_recommendation","url":"aws_api/rds.html#modify_db_recommendation"},{"doc":"aws_api/rds","title":"modify_db_shard_group","content":"pub fn modify_db_shard_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.modify_db_shard_group\naws_api/rds modify_db_shard_group","url":"aws_api/rds.html#modify_db_shard_group"},{"doc":"aws_api/rds","title":"modify_db_snapshot","content":"pub fn modify_db_snapshot(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.modify_db_snapshot\naws_api/rds modify_db_snapshot","url":"aws_api/rds.html#modify_db_snapshot"},{"doc":"aws_api/rds","title":"modify_db_snapshot_attribute","content":"pub fn modify_db_snapshot_attribute(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.modify_db_snapshot_attribute\naws_api/rds modify_db_snapshot_attribute","url":"aws_api/rds.html#modify_db_snapshot_attribute"},{"doc":"aws_api/rds","title":"modify_db_subnet_group","content":"pub fn modify_db_subnet_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.modify_db_subnet_group\naws_api/rds modify_db_subnet_group","url":"aws_api/rds.html#modify_db_subnet_group"},{"doc":"aws_api/rds","title":"modify_event_subscription","content":"pub fn modify_event_subscription(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.modify_event_subscription\naws_api/rds modify_event_subscription","url":"aws_api/rds.html#modify_event_subscription"},{"doc":"aws_api/rds","title":"modify_global_cluster","content":"pub fn modify_global_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.modify_global_cluster\naws_api/rds modify_global_cluster","url":"aws_api/rds.html#modify_global_cluster"},{"doc":"aws_api/rds","title":"modify_integration","content":"pub fn modify_integration(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.modify_integration\naws_api/rds modify_integration","url":"aws_api/rds.html#modify_integration"},{"doc":"aws_api/rds","title":"modify_option_group","content":"pub fn modify_option_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.modify_option_group\naws_api/rds modify_option_group","url":"aws_api/rds.html#modify_option_group"},{"doc":"aws_api/rds","title":"modify_tenant_database","content":"pub fn modify_tenant_database(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.modify_tenant_database\naws_api/rds modify_tenant_database","url":"aws_api/rds.html#modify_tenant_database"},{"doc":"aws_api/rds","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/rds.new\naws_api/rds new","url":"aws_api/rds.html#new"},{"doc":"aws_api/rds","title":"promote_read_replica","content":"pub fn promote_read_replica(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.promote_read_replica\naws_api/rds promote_read_replica","url":"aws_api/rds.html#promote_read_replica"},{"doc":"aws_api/rds","title":"promote_read_replica_db_cluster","content":"pub fn promote_read_replica_db_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.promote_read_replica_db_cluster\naws_api/rds promote_read_replica_db_cluster","url":"aws_api/rds.html#promote_read_replica_db_cluster"},{"doc":"aws_api/rds","title":"purchase_reserved_db_instances_offering","content":"pub fn purchase_reserved_db_instances_offering(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.purchase_reserved_db_instances_offering\naws_api/rds purchase_reserved_db_instances_offering","url":"aws_api/rds.html#purchase_reserved_db_instances_offering"},{"doc":"aws_api/rds","title":"reboot_db_cluster","content":"pub fn reboot_db_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.reboot_db_cluster\naws_api/rds reboot_db_cluster","url":"aws_api/rds.html#reboot_db_cluster"},{"doc":"aws_api/rds","title":"reboot_db_instance","content":"pub fn reboot_db_instance(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.reboot_db_instance\naws_api/rds reboot_db_instance","url":"aws_api/rds.html#reboot_db_instance"},{"doc":"aws_api/rds","title":"reboot_db_shard_group","content":"pub fn reboot_db_shard_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.reboot_db_shard_group\naws_api/rds reboot_db_shard_group","url":"aws_api/rds.html#reboot_db_shard_group"},{"doc":"aws_api/rds","title":"register_db_proxy_targets","content":"pub fn register_db_proxy_targets(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.register_db_proxy_targets\naws_api/rds register_db_proxy_targets","url":"aws_api/rds.html#register_db_proxy_targets"},{"doc":"aws_api/rds","title":"remove_from_global_cluster","content":"pub fn remove_from_global_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.remove_from_global_cluster\naws_api/rds remove_from_global_cluster","url":"aws_api/rds.html#remove_from_global_cluster"},{"doc":"aws_api/rds","title":"remove_role_from_db_cluster","content":"pub fn remove_role_from_db_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.remove_role_from_db_cluster\naws_api/rds remove_role_from_db_cluster","url":"aws_api/rds.html#remove_role_from_db_cluster"},{"doc":"aws_api/rds","title":"remove_role_from_db_instance","content":"pub fn remove_role_from_db_instance(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.remove_role_from_db_instance\naws_api/rds remove_role_from_db_instance","url":"aws_api/rds.html#remove_role_from_db_instance"},{"doc":"aws_api/rds","title":"remove_source_identifier_from_subscription","content":"pub fn remove_source_identifier_from_subscription(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.remove_source_identifier_from_subscription\naws_api/rds remove_source_identifier_from_subscription","url":"aws_api/rds.html#remove_source_identifier_from_subscription"},{"doc":"aws_api/rds","title":"remove_tags_from_resource","content":"pub fn remove_tags_from_resource(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.remove_tags_from_resource\naws_api/rds remove_tags_from_resource","url":"aws_api/rds.html#remove_tags_from_resource"},{"doc":"aws_api/rds","title":"reset_db_cluster_parameter_group","content":"pub fn reset_db_cluster_parameter_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.reset_db_cluster_parameter_group\naws_api/rds reset_db_cluster_parameter_group","url":"aws_api/rds.html#reset_db_cluster_parameter_group"},{"doc":"aws_api/rds","title":"reset_db_parameter_group","content":"pub fn reset_db_parameter_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.reset_db_parameter_group\naws_api/rds reset_db_parameter_group","url":"aws_api/rds.html#reset_db_parameter_group"},{"doc":"aws_api/rds","title":"restore_db_cluster_from_s3","content":"pub fn restore_db_cluster_from_s3(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.restore_db_cluster_from_s3\naws_api/rds restore_db_cluster_from_s3","url":"aws_api/rds.html#restore_db_cluster_from_s3"},{"doc":"aws_api/rds","title":"restore_db_cluster_from_snapshot","content":"pub fn restore_db_cluster_from_snapshot(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.restore_db_cluster_from_snapshot\naws_api/rds restore_db_cluster_from_snapshot","url":"aws_api/rds.html#restore_db_cluster_from_snapshot"},{"doc":"aws_api/rds","title":"restore_db_cluster_to_point_in_time","content":"pub fn restore_db_cluster_to_point_in_time(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.restore_db_cluster_to_point_in_time\naws_api/rds restore_db_cluster_to_point_in_time","url":"aws_api/rds.html#restore_db_cluster_to_point_in_time"},{"doc":"aws_api/rds","title":"restore_db_instance_from_db_snapshot","content":"pub fn restore_db_instance_from_db_snapshot(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.restore_db_instance_from_db_snapshot\naws_api/rds restore_db_instance_from_db_snapshot","url":"aws_api/rds.html#restore_db_instance_from_db_snapshot"},{"doc":"aws_api/rds","title":"restore_db_instance_from_s3","content":"pub fn restore_db_instance_from_s3(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.restore_db_instance_from_s3\naws_api/rds restore_db_instance_from_s3","url":"aws_api/rds.html#restore_db_instance_from_s3"},{"doc":"aws_api/rds","title":"restore_db_instance_to_point_in_time","content":"pub fn restore_db_instance_to_point_in_time(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.restore_db_instance_to_point_in_time\naws_api/rds restore_db_instance_to_point_in_time","url":"aws_api/rds.html#restore_db_instance_to_point_in_time"},{"doc":"aws_api/rds","title":"revoke_db_security_group_ingress","content":"pub fn revoke_db_security_group_ingress(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.revoke_db_security_group_ingress\naws_api/rds revoke_db_security_group_ingress","url":"aws_api/rds.html#revoke_db_security_group_ingress"},{"doc":"aws_api/rds","title":"start_activity_stream","content":"pub fn start_activity_stream(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.start_activity_stream\naws_api/rds start_activity_stream","url":"aws_api/rds.html#start_activity_stream"},{"doc":"aws_api/rds","title":"start_db_cluster","content":"pub fn start_db_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.start_db_cluster\naws_api/rds start_db_cluster","url":"aws_api/rds.html#start_db_cluster"},{"doc":"aws_api/rds","title":"start_db_instance","content":"pub fn start_db_instance(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.start_db_instance\naws_api/rds start_db_instance","url":"aws_api/rds.html#start_db_instance"},{"doc":"aws_api/rds","title":"start_db_instance_automated_backups_replication","content":"pub fn start_db_instance_automated_backups_replication(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.start_db_instance_automated_backups_replication\naws_api/rds start_db_instance_automated_backups_replication","url":"aws_api/rds.html#start_db_instance_automated_backups_replication"},{"doc":"aws_api/rds","title":"start_export_task","content":"pub fn start_export_task(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.start_export_task\naws_api/rds start_export_task","url":"aws_api/rds.html#start_export_task"},{"doc":"aws_api/rds","title":"stop_activity_stream","content":"pub fn stop_activity_stream(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.stop_activity_stream\naws_api/rds stop_activity_stream","url":"aws_api/rds.html#stop_activity_stream"},{"doc":"aws_api/rds","title":"stop_db_cluster","content":"pub fn stop_db_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.stop_db_cluster\naws_api/rds stop_db_cluster","url":"aws_api/rds.html#stop_db_cluster"},{"doc":"aws_api/rds","title":"stop_db_instance","content":"pub fn stop_db_instance(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.stop_db_instance\naws_api/rds stop_db_instance","url":"aws_api/rds.html#stop_db_instance"},{"doc":"aws_api/rds","title":"stop_db_instance_automated_backups_replication","content":"pub fn stop_db_instance_automated_backups_replication(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.stop_db_instance_automated_backups_replication\naws_api/rds stop_db_instance_automated_backups_replication","url":"aws_api/rds.html#stop_db_instance_automated_backups_replication"},{"doc":"aws_api/rds","title":"switchover_blue_green_deployment","content":"pub fn switchover_blue_green_deployment(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.switchover_blue_green_deployment\naws_api/rds switchover_blue_green_deployment","url":"aws_api/rds.html#switchover_blue_green_deployment"},{"doc":"aws_api/rds","title":"switchover_global_cluster","content":"pub fn switchover_global_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.switchover_global_cluster\naws_api/rds switchover_global_cluster","url":"aws_api/rds.html#switchover_global_cluster"},{"doc":"aws_api/rds","title":"switchover_read_replica","content":"pub fn switchover_read_replica(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds.switchover_read_replica\naws_api/rds switchover_read_replica","url":"aws_api/rds.html#switchover_read_replica"},{"doc":"aws_api/rds","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/rds.with_custom_endpoint\naws_api/rds with_custom_endpoint","url":"aws_api/rds.html#with_custom_endpoint"},{"doc":"aws_api/rds","title":"aws_api/rds","content":"","url":"aws_api/rds.html"},{"doc":"aws_api/rds_data","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/rds_data.Client\naws_api/rds_data Client","url":"aws_api/rds_data.html#Client"},{"doc":"aws_api/rds_data","title":"batch_execute_statement","content":"pub fn batch_execute_statement(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds_data.batch_execute_statement\naws_api/rds_data batch_execute_statement","url":"aws_api/rds_data.html#batch_execute_statement"},{"doc":"aws_api/rds_data","title":"begin_transaction","content":"pub fn begin_transaction(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds_data.begin_transaction\naws_api/rds_data begin_transaction","url":"aws_api/rds_data.html#begin_transaction"},{"doc":"aws_api/rds_data","title":"commit_transaction","content":"pub fn commit_transaction(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds_data.commit_transaction\naws_api/rds_data commit_transaction","url":"aws_api/rds_data.html#commit_transaction"},{"doc":"aws_api/rds_data","title":"execute_sql","content":"pub fn execute_sql(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds_data.execute_sql\naws_api/rds_data execute_sql","url":"aws_api/rds_data.html#execute_sql"},{"doc":"aws_api/rds_data","title":"execute_statement","content":"pub fn execute_statement(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds_data.execute_statement\naws_api/rds_data execute_statement","url":"aws_api/rds_data.html#execute_statement"},{"doc":"aws_api/rds_data","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/rds_data.new\naws_api/rds_data new","url":"aws_api/rds_data.html#new"},{"doc":"aws_api/rds_data","title":"rollback_transaction","content":"pub fn rollback_transaction(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rds_data.rollback_transaction\naws_api/rds_data rollback_transaction","url":"aws_api/rds_data.html#rollback_transaction"},{"doc":"aws_api/rds_data","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/rds_data.with_custom_endpoint\naws_api/rds_data with_custom_endpoint","url":"aws_api/rds_data.html#with_custom_endpoint"},{"doc":"aws_api/rds_data","title":"aws_api/rds_data","content":"","url":"aws_api/rds_data.html"},{"doc":"aws_api/redshift","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/redshift.Client\naws_api/redshift Client","url":"aws_api/redshift.html#Client"},{"doc":"aws_api/redshift","title":"accept_reserved_node_exchange","content":"pub fn accept_reserved_node_exchange(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.accept_reserved_node_exchange\naws_api/redshift accept_reserved_node_exchange","url":"aws_api/redshift.html#accept_reserved_node_exchange"},{"doc":"aws_api/redshift","title":"add_partner","content":"pub fn add_partner(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.add_partner\naws_api/redshift add_partner","url":"aws_api/redshift.html#add_partner"},{"doc":"aws_api/redshift","title":"associate_data_share_consumer","content":"pub fn associate_data_share_consumer(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.associate_data_share_consumer\naws_api/redshift associate_data_share_consumer","url":"aws_api/redshift.html#associate_data_share_consumer"},{"doc":"aws_api/redshift","title":"authorize_cluster_security_group_ingress","content":"pub fn authorize_cluster_security_group_ingress(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.authorize_cluster_security_group_ingress\naws_api/redshift authorize_cluster_security_group_ingress","url":"aws_api/redshift.html#authorize_cluster_security_group_ingress"},{"doc":"aws_api/redshift","title":"authorize_data_share","content":"pub fn authorize_data_share(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.authorize_data_share\naws_api/redshift authorize_data_share","url":"aws_api/redshift.html#authorize_data_share"},{"doc":"aws_api/redshift","title":"authorize_endpoint_access","content":"pub fn authorize_endpoint_access(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.authorize_endpoint_access\naws_api/redshift authorize_endpoint_access","url":"aws_api/redshift.html#authorize_endpoint_access"},{"doc":"aws_api/redshift","title":"authorize_snapshot_access","content":"pub fn authorize_snapshot_access(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.authorize_snapshot_access\naws_api/redshift authorize_snapshot_access","url":"aws_api/redshift.html#authorize_snapshot_access"},{"doc":"aws_api/redshift","title":"batch_delete_cluster_snapshots","content":"pub fn batch_delete_cluster_snapshots(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.batch_delete_cluster_snapshots\naws_api/redshift batch_delete_cluster_snapshots","url":"aws_api/redshift.html#batch_delete_cluster_snapshots"},{"doc":"aws_api/redshift","title":"batch_modify_cluster_snapshots","content":"pub fn batch_modify_cluster_snapshots(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.batch_modify_cluster_snapshots\naws_api/redshift batch_modify_cluster_snapshots","url":"aws_api/redshift.html#batch_modify_cluster_snapshots"},{"doc":"aws_api/redshift","title":"cancel_resize","content":"pub fn cancel_resize(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.cancel_resize\naws_api/redshift cancel_resize","url":"aws_api/redshift.html#cancel_resize"},{"doc":"aws_api/redshift","title":"copy_cluster_snapshot","content":"pub fn copy_cluster_snapshot(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.copy_cluster_snapshot\naws_api/redshift copy_cluster_snapshot","url":"aws_api/redshift.html#copy_cluster_snapshot"},{"doc":"aws_api/redshift","title":"create_authentication_profile","content":"pub fn create_authentication_profile(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.create_authentication_profile\naws_api/redshift create_authentication_profile","url":"aws_api/redshift.html#create_authentication_profile"},{"doc":"aws_api/redshift","title":"create_cluster","content":"pub fn create_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.create_cluster\naws_api/redshift create_cluster","url":"aws_api/redshift.html#create_cluster"},{"doc":"aws_api/redshift","title":"create_cluster_parameter_group","content":"pub fn create_cluster_parameter_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.create_cluster_parameter_group\naws_api/redshift create_cluster_parameter_group","url":"aws_api/redshift.html#create_cluster_parameter_group"},{"doc":"aws_api/redshift","title":"create_cluster_security_group","content":"pub fn create_cluster_security_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.create_cluster_security_group\naws_api/redshift create_cluster_security_group","url":"aws_api/redshift.html#create_cluster_security_group"},{"doc":"aws_api/redshift","title":"create_cluster_snapshot","content":"pub fn create_cluster_snapshot(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.create_cluster_snapshot\naws_api/redshift create_cluster_snapshot","url":"aws_api/redshift.html#create_cluster_snapshot"},{"doc":"aws_api/redshift","title":"create_cluster_subnet_group","content":"pub fn create_cluster_subnet_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.create_cluster_subnet_group\naws_api/redshift create_cluster_subnet_group","url":"aws_api/redshift.html#create_cluster_subnet_group"},{"doc":"aws_api/redshift","title":"create_custom_domain_association","content":"pub fn create_custom_domain_association(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.create_custom_domain_association\naws_api/redshift create_custom_domain_association","url":"aws_api/redshift.html#create_custom_domain_association"},{"doc":"aws_api/redshift","title":"create_endpoint_access","content":"pub fn create_endpoint_access(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.create_endpoint_access\naws_api/redshift create_endpoint_access","url":"aws_api/redshift.html#create_endpoint_access"},{"doc":"aws_api/redshift","title":"create_event_subscription","content":"pub fn create_event_subscription(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.create_event_subscription\naws_api/redshift create_event_subscription","url":"aws_api/redshift.html#create_event_subscription"},{"doc":"aws_api/redshift","title":"create_hsm_client_certificate","content":"pub fn create_hsm_client_certificate(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.create_hsm_client_certificate\naws_api/redshift create_hsm_client_certificate","url":"aws_api/redshift.html#create_hsm_client_certificate"},{"doc":"aws_api/redshift","title":"create_hsm_configuration","content":"pub fn create_hsm_configuration(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.create_hsm_configuration\naws_api/redshift create_hsm_configuration","url":"aws_api/redshift.html#create_hsm_configuration"},{"doc":"aws_api/redshift","title":"create_redshift_idc_application","content":"pub fn create_redshift_idc_application(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.create_redshift_idc_application\naws_api/redshift create_redshift_idc_application","url":"aws_api/redshift.html#create_redshift_idc_application"},{"doc":"aws_api/redshift","title":"create_scheduled_action","content":"pub fn create_scheduled_action(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.create_scheduled_action\naws_api/redshift create_scheduled_action","url":"aws_api/redshift.html#create_scheduled_action"},{"doc":"aws_api/redshift","title":"create_snapshot_copy_grant","content":"pub fn create_snapshot_copy_grant(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.create_snapshot_copy_grant\naws_api/redshift create_snapshot_copy_grant","url":"aws_api/redshift.html#create_snapshot_copy_grant"},{"doc":"aws_api/redshift","title":"create_snapshot_schedule","content":"pub fn create_snapshot_schedule(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.create_snapshot_schedule\naws_api/redshift create_snapshot_schedule","url":"aws_api/redshift.html#create_snapshot_schedule"},{"doc":"aws_api/redshift","title":"create_tags","content":"pub fn create_tags(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.create_tags\naws_api/redshift create_tags","url":"aws_api/redshift.html#create_tags"},{"doc":"aws_api/redshift","title":"create_usage_limit","content":"pub fn create_usage_limit(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.create_usage_limit\naws_api/redshift create_usage_limit","url":"aws_api/redshift.html#create_usage_limit"},{"doc":"aws_api/redshift","title":"deauthorize_data_share","content":"pub fn deauthorize_data_share(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.deauthorize_data_share\naws_api/redshift deauthorize_data_share","url":"aws_api/redshift.html#deauthorize_data_share"},{"doc":"aws_api/redshift","title":"delete_authentication_profile","content":"pub fn delete_authentication_profile(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.delete_authentication_profile\naws_api/redshift delete_authentication_profile","url":"aws_api/redshift.html#delete_authentication_profile"},{"doc":"aws_api/redshift","title":"delete_cluster","content":"pub fn delete_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.delete_cluster\naws_api/redshift delete_cluster","url":"aws_api/redshift.html#delete_cluster"},{"doc":"aws_api/redshift","title":"delete_cluster_parameter_group","content":"pub fn delete_cluster_parameter_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.delete_cluster_parameter_group\naws_api/redshift delete_cluster_parameter_group","url":"aws_api/redshift.html#delete_cluster_parameter_group"},{"doc":"aws_api/redshift","title":"delete_cluster_security_group","content":"pub fn delete_cluster_security_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.delete_cluster_security_group\naws_api/redshift delete_cluster_security_group","url":"aws_api/redshift.html#delete_cluster_security_group"},{"doc":"aws_api/redshift","title":"delete_cluster_snapshot","content":"pub fn delete_cluster_snapshot(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.delete_cluster_snapshot\naws_api/redshift delete_cluster_snapshot","url":"aws_api/redshift.html#delete_cluster_snapshot"},{"doc":"aws_api/redshift","title":"delete_cluster_subnet_group","content":"pub fn delete_cluster_subnet_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.delete_cluster_subnet_group\naws_api/redshift delete_cluster_subnet_group","url":"aws_api/redshift.html#delete_cluster_subnet_group"},{"doc":"aws_api/redshift","title":"delete_custom_domain_association","content":"pub fn delete_custom_domain_association(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.delete_custom_domain_association\naws_api/redshift delete_custom_domain_association","url":"aws_api/redshift.html#delete_custom_domain_association"},{"doc":"aws_api/redshift","title":"delete_endpoint_access","content":"pub fn delete_endpoint_access(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.delete_endpoint_access\naws_api/redshift delete_endpoint_access","url":"aws_api/redshift.html#delete_endpoint_access"},{"doc":"aws_api/redshift","title":"delete_event_subscription","content":"pub fn delete_event_subscription(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.delete_event_subscription\naws_api/redshift delete_event_subscription","url":"aws_api/redshift.html#delete_event_subscription"},{"doc":"aws_api/redshift","title":"delete_hsm_client_certificate","content":"pub fn delete_hsm_client_certificate(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.delete_hsm_client_certificate\naws_api/redshift delete_hsm_client_certificate","url":"aws_api/redshift.html#delete_hsm_client_certificate"},{"doc":"aws_api/redshift","title":"delete_hsm_configuration","content":"pub fn delete_hsm_configuration(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.delete_hsm_configuration\naws_api/redshift delete_hsm_configuration","url":"aws_api/redshift.html#delete_hsm_configuration"},{"doc":"aws_api/redshift","title":"delete_partner","content":"pub fn delete_partner(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.delete_partner\naws_api/redshift delete_partner","url":"aws_api/redshift.html#delete_partner"},{"doc":"aws_api/redshift","title":"delete_redshift_idc_application","content":"pub fn delete_redshift_idc_application(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.delete_redshift_idc_application\naws_api/redshift delete_redshift_idc_application","url":"aws_api/redshift.html#delete_redshift_idc_application"},{"doc":"aws_api/redshift","title":"delete_resource_policy","content":"pub fn delete_resource_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.delete_resource_policy\naws_api/redshift delete_resource_policy","url":"aws_api/redshift.html#delete_resource_policy"},{"doc":"aws_api/redshift","title":"delete_scheduled_action","content":"pub fn delete_scheduled_action(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.delete_scheduled_action\naws_api/redshift delete_scheduled_action","url":"aws_api/redshift.html#delete_scheduled_action"},{"doc":"aws_api/redshift","title":"delete_snapshot_copy_grant","content":"pub fn delete_snapshot_copy_grant(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.delete_snapshot_copy_grant\naws_api/redshift delete_snapshot_copy_grant","url":"aws_api/redshift.html#delete_snapshot_copy_grant"},{"doc":"aws_api/redshift","title":"delete_snapshot_schedule","content":"pub fn delete_snapshot_schedule(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.delete_snapshot_schedule\naws_api/redshift delete_snapshot_schedule","url":"aws_api/redshift.html#delete_snapshot_schedule"},{"doc":"aws_api/redshift","title":"delete_tags","content":"pub fn delete_tags(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.delete_tags\naws_api/redshift delete_tags","url":"aws_api/redshift.html#delete_tags"},{"doc":"aws_api/redshift","title":"delete_usage_limit","content":"pub fn delete_usage_limit(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.delete_usage_limit\naws_api/redshift delete_usage_limit","url":"aws_api/redshift.html#delete_usage_limit"},{"doc":"aws_api/redshift","title":"describe_account_attributes","content":"pub fn describe_account_attributes(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.describe_account_attributes\naws_api/redshift describe_account_attributes","url":"aws_api/redshift.html#describe_account_attributes"},{"doc":"aws_api/redshift","title":"describe_authentication_profiles","content":"pub fn describe_authentication_profiles(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.describe_authentication_profiles\naws_api/redshift describe_authentication_profiles","url":"aws_api/redshift.html#describe_authentication_profiles"},{"doc":"aws_api/redshift","title":"describe_cluster_db_revisions","content":"pub fn describe_cluster_db_revisions(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.describe_cluster_db_revisions\naws_api/redshift describe_cluster_db_revisions","url":"aws_api/redshift.html#describe_cluster_db_revisions"},{"doc":"aws_api/redshift","title":"describe_cluster_parameter_groups","content":"pub fn describe_cluster_parameter_groups(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.describe_cluster_parameter_groups\naws_api/redshift describe_cluster_parameter_groups","url":"aws_api/redshift.html#describe_cluster_parameter_groups"},{"doc":"aws_api/redshift","title":"describe_cluster_parameters","content":"pub fn describe_cluster_parameters(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.describe_cluster_parameters\naws_api/redshift describe_cluster_parameters","url":"aws_api/redshift.html#describe_cluster_parameters"},{"doc":"aws_api/redshift","title":"describe_cluster_security_groups","content":"pub fn describe_cluster_security_groups(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.describe_cluster_security_groups\naws_api/redshift describe_cluster_security_groups","url":"aws_api/redshift.html#describe_cluster_security_groups"},{"doc":"aws_api/redshift","title":"describe_cluster_snapshots","content":"pub fn describe_cluster_snapshots(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.describe_cluster_snapshots\naws_api/redshift describe_cluster_snapshots","url":"aws_api/redshift.html#describe_cluster_snapshots"},{"doc":"aws_api/redshift","title":"describe_cluster_subnet_groups","content":"pub fn describe_cluster_subnet_groups(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.describe_cluster_subnet_groups\naws_api/redshift describe_cluster_subnet_groups","url":"aws_api/redshift.html#describe_cluster_subnet_groups"},{"doc":"aws_api/redshift","title":"describe_cluster_tracks","content":"pub fn describe_cluster_tracks(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.describe_cluster_tracks\naws_api/redshift describe_cluster_tracks","url":"aws_api/redshift.html#describe_cluster_tracks"},{"doc":"aws_api/redshift","title":"describe_cluster_versions","content":"pub fn describe_cluster_versions(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.describe_cluster_versions\naws_api/redshift describe_cluster_versions","url":"aws_api/redshift.html#describe_cluster_versions"},{"doc":"aws_api/redshift","title":"describe_clusters","content":"pub fn describe_clusters(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.describe_clusters\naws_api/redshift describe_clusters","url":"aws_api/redshift.html#describe_clusters"},{"doc":"aws_api/redshift","title":"describe_custom_domain_associations","content":"pub fn describe_custom_domain_associations(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.describe_custom_domain_associations\naws_api/redshift describe_custom_domain_associations","url":"aws_api/redshift.html#describe_custom_domain_associations"},{"doc":"aws_api/redshift","title":"describe_data_shares","content":"pub fn describe_data_shares(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.describe_data_shares\naws_api/redshift describe_data_shares","url":"aws_api/redshift.html#describe_data_shares"},{"doc":"aws_api/redshift","title":"describe_data_shares_for_consumer","content":"pub fn describe_data_shares_for_consumer(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.describe_data_shares_for_consumer\naws_api/redshift describe_data_shares_for_consumer","url":"aws_api/redshift.html#describe_data_shares_for_consumer"},{"doc":"aws_api/redshift","title":"describe_data_shares_for_producer","content":"pub fn describe_data_shares_for_producer(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.describe_data_shares_for_producer\naws_api/redshift describe_data_shares_for_producer","url":"aws_api/redshift.html#describe_data_shares_for_producer"},{"doc":"aws_api/redshift","title":"describe_default_cluster_parameters","content":"pub fn describe_default_cluster_parameters(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.describe_default_cluster_parameters\naws_api/redshift describe_default_cluster_parameters","url":"aws_api/redshift.html#describe_default_cluster_parameters"},{"doc":"aws_api/redshift","title":"describe_endpoint_access","content":"pub fn describe_endpoint_access(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.describe_endpoint_access\naws_api/redshift describe_endpoint_access","url":"aws_api/redshift.html#describe_endpoint_access"},{"doc":"aws_api/redshift","title":"describe_endpoint_authorization","content":"pub fn describe_endpoint_authorization(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.describe_endpoint_authorization\naws_api/redshift describe_endpoint_authorization","url":"aws_api/redshift.html#describe_endpoint_authorization"},{"doc":"aws_api/redshift","title":"describe_event_categories","content":"pub fn describe_event_categories(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.describe_event_categories\naws_api/redshift describe_event_categories","url":"aws_api/redshift.html#describe_event_categories"},{"doc":"aws_api/redshift","title":"describe_event_subscriptions","content":"pub fn describe_event_subscriptions(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.describe_event_subscriptions\naws_api/redshift describe_event_subscriptions","url":"aws_api/redshift.html#describe_event_subscriptions"},{"doc":"aws_api/redshift","title":"describe_events","content":"pub fn describe_events(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.describe_events\naws_api/redshift describe_events","url":"aws_api/redshift.html#describe_events"},{"doc":"aws_api/redshift","title":"describe_hsm_client_certificates","content":"pub fn describe_hsm_client_certificates(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.describe_hsm_client_certificates\naws_api/redshift describe_hsm_client_certificates","url":"aws_api/redshift.html#describe_hsm_client_certificates"},{"doc":"aws_api/redshift","title":"describe_hsm_configurations","content":"pub fn describe_hsm_configurations(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.describe_hsm_configurations\naws_api/redshift describe_hsm_configurations","url":"aws_api/redshift.html#describe_hsm_configurations"},{"doc":"aws_api/redshift","title":"describe_inbound_integrations","content":"pub fn describe_inbound_integrations(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.describe_inbound_integrations\naws_api/redshift describe_inbound_integrations","url":"aws_api/redshift.html#describe_inbound_integrations"},{"doc":"aws_api/redshift","title":"describe_logging_status","content":"pub fn describe_logging_status(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.describe_logging_status\naws_api/redshift describe_logging_status","url":"aws_api/redshift.html#describe_logging_status"},{"doc":"aws_api/redshift","title":"describe_node_configuration_options","content":"pub fn describe_node_configuration_options(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.describe_node_configuration_options\naws_api/redshift describe_node_configuration_options","url":"aws_api/redshift.html#describe_node_configuration_options"},{"doc":"aws_api/redshift","title":"describe_orderable_cluster_options","content":"pub fn describe_orderable_cluster_options(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.describe_orderable_cluster_options\naws_api/redshift describe_orderable_cluster_options","url":"aws_api/redshift.html#describe_orderable_cluster_options"},{"doc":"aws_api/redshift","title":"describe_partners","content":"pub fn describe_partners(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.describe_partners\naws_api/redshift describe_partners","url":"aws_api/redshift.html#describe_partners"},{"doc":"aws_api/redshift","title":"describe_redshift_idc_applications","content":"pub fn describe_redshift_idc_applications(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.describe_redshift_idc_applications\naws_api/redshift describe_redshift_idc_applications","url":"aws_api/redshift.html#describe_redshift_idc_applications"},{"doc":"aws_api/redshift","title":"describe_reserved_node_exchange_status","content":"pub fn describe_reserved_node_exchange_status(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.describe_reserved_node_exchange_status\naws_api/redshift describe_reserved_node_exchange_status","url":"aws_api/redshift.html#describe_reserved_node_exchange_status"},{"doc":"aws_api/redshift","title":"describe_reserved_node_offerings","content":"pub fn describe_reserved_node_offerings(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.describe_reserved_node_offerings\naws_api/redshift describe_reserved_node_offerings","url":"aws_api/redshift.html#describe_reserved_node_offerings"},{"doc":"aws_api/redshift","title":"describe_reserved_nodes","content":"pub fn describe_reserved_nodes(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.describe_reserved_nodes\naws_api/redshift describe_reserved_nodes","url":"aws_api/redshift.html#describe_reserved_nodes"},{"doc":"aws_api/redshift","title":"describe_resize","content":"pub fn describe_resize(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.describe_resize\naws_api/redshift describe_resize","url":"aws_api/redshift.html#describe_resize"},{"doc":"aws_api/redshift","title":"describe_scheduled_actions","content":"pub fn describe_scheduled_actions(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.describe_scheduled_actions\naws_api/redshift describe_scheduled_actions","url":"aws_api/redshift.html#describe_scheduled_actions"},{"doc":"aws_api/redshift","title":"describe_snapshot_copy_grants","content":"pub fn describe_snapshot_copy_grants(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.describe_snapshot_copy_grants\naws_api/redshift describe_snapshot_copy_grants","url":"aws_api/redshift.html#describe_snapshot_copy_grants"},{"doc":"aws_api/redshift","title":"describe_snapshot_schedules","content":"pub fn describe_snapshot_schedules(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.describe_snapshot_schedules\naws_api/redshift describe_snapshot_schedules","url":"aws_api/redshift.html#describe_snapshot_schedules"},{"doc":"aws_api/redshift","title":"describe_storage","content":"pub fn describe_storage(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.describe_storage\naws_api/redshift describe_storage","url":"aws_api/redshift.html#describe_storage"},{"doc":"aws_api/redshift","title":"describe_table_restore_status","content":"pub fn describe_table_restore_status(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.describe_table_restore_status\naws_api/redshift describe_table_restore_status","url":"aws_api/redshift.html#describe_table_restore_status"},{"doc":"aws_api/redshift","title":"describe_tags","content":"pub fn describe_tags(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.describe_tags\naws_api/redshift describe_tags","url":"aws_api/redshift.html#describe_tags"},{"doc":"aws_api/redshift","title":"describe_usage_limits","content":"pub fn describe_usage_limits(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.describe_usage_limits\naws_api/redshift describe_usage_limits","url":"aws_api/redshift.html#describe_usage_limits"},{"doc":"aws_api/redshift","title":"disable_logging","content":"pub fn disable_logging(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.disable_logging\naws_api/redshift disable_logging","url":"aws_api/redshift.html#disable_logging"},{"doc":"aws_api/redshift","title":"disable_snapshot_copy","content":"pub fn disable_snapshot_copy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.disable_snapshot_copy\naws_api/redshift disable_snapshot_copy","url":"aws_api/redshift.html#disable_snapshot_copy"},{"doc":"aws_api/redshift","title":"disassociate_data_share_consumer","content":"pub fn disassociate_data_share_consumer(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.disassociate_data_share_consumer\naws_api/redshift disassociate_data_share_consumer","url":"aws_api/redshift.html#disassociate_data_share_consumer"},{"doc":"aws_api/redshift","title":"enable_logging","content":"pub fn enable_logging(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.enable_logging\naws_api/redshift enable_logging","url":"aws_api/redshift.html#enable_logging"},{"doc":"aws_api/redshift","title":"enable_snapshot_copy","content":"pub fn enable_snapshot_copy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.enable_snapshot_copy\naws_api/redshift enable_snapshot_copy","url":"aws_api/redshift.html#enable_snapshot_copy"},{"doc":"aws_api/redshift","title":"failover_primary_compute","content":"pub fn failover_primary_compute(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.failover_primary_compute\naws_api/redshift failover_primary_compute","url":"aws_api/redshift.html#failover_primary_compute"},{"doc":"aws_api/redshift","title":"get_cluster_credentials","content":"pub fn get_cluster_credentials(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.get_cluster_credentials\naws_api/redshift get_cluster_credentials","url":"aws_api/redshift.html#get_cluster_credentials"},{"doc":"aws_api/redshift","title":"get_cluster_credentials_with_iam","content":"pub fn get_cluster_credentials_with_iam(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.get_cluster_credentials_with_iam\naws_api/redshift get_cluster_credentials_with_iam","url":"aws_api/redshift.html#get_cluster_credentials_with_iam"},{"doc":"aws_api/redshift","title":"get_reserved_node_exchange_configuration_options","content":"pub fn get_reserved_node_exchange_configuration_options(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.get_reserved_node_exchange_configuration_options\naws_api/redshift get_reserved_node_exchange_configuration_options","url":"aws_api/redshift.html#get_reserved_node_exchange_configuration_options"},{"doc":"aws_api/redshift","title":"get_reserved_node_exchange_offerings","content":"pub fn get_reserved_node_exchange_offerings(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.get_reserved_node_exchange_offerings\naws_api/redshift get_reserved_node_exchange_offerings","url":"aws_api/redshift.html#get_reserved_node_exchange_offerings"},{"doc":"aws_api/redshift","title":"get_resource_policy","content":"pub fn get_resource_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.get_resource_policy\naws_api/redshift get_resource_policy","url":"aws_api/redshift.html#get_resource_policy"},{"doc":"aws_api/redshift","title":"list_recommendations","content":"pub fn list_recommendations(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.list_recommendations\naws_api/redshift list_recommendations","url":"aws_api/redshift.html#list_recommendations"},{"doc":"aws_api/redshift","title":"modify_aqua_configuration","content":"pub fn modify_aqua_configuration(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.modify_aqua_configuration\naws_api/redshift modify_aqua_configuration","url":"aws_api/redshift.html#modify_aqua_configuration"},{"doc":"aws_api/redshift","title":"modify_authentication_profile","content":"pub fn modify_authentication_profile(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.modify_authentication_profile\naws_api/redshift modify_authentication_profile","url":"aws_api/redshift.html#modify_authentication_profile"},{"doc":"aws_api/redshift","title":"modify_cluster","content":"pub fn modify_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.modify_cluster\naws_api/redshift modify_cluster","url":"aws_api/redshift.html#modify_cluster"},{"doc":"aws_api/redshift","title":"modify_cluster_db_revision","content":"pub fn modify_cluster_db_revision(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.modify_cluster_db_revision\naws_api/redshift modify_cluster_db_revision","url":"aws_api/redshift.html#modify_cluster_db_revision"},{"doc":"aws_api/redshift","title":"modify_cluster_iam_roles","content":"pub fn modify_cluster_iam_roles(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.modify_cluster_iam_roles\naws_api/redshift modify_cluster_iam_roles","url":"aws_api/redshift.html#modify_cluster_iam_roles"},{"doc":"aws_api/redshift","title":"modify_cluster_maintenance","content":"pub fn modify_cluster_maintenance(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.modify_cluster_maintenance\naws_api/redshift modify_cluster_maintenance","url":"aws_api/redshift.html#modify_cluster_maintenance"},{"doc":"aws_api/redshift","title":"modify_cluster_parameter_group","content":"pub fn modify_cluster_parameter_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.modify_cluster_parameter_group\naws_api/redshift modify_cluster_parameter_group","url":"aws_api/redshift.html#modify_cluster_parameter_group"},{"doc":"aws_api/redshift","title":"modify_cluster_snapshot","content":"pub fn modify_cluster_snapshot(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.modify_cluster_snapshot\naws_api/redshift modify_cluster_snapshot","url":"aws_api/redshift.html#modify_cluster_snapshot"},{"doc":"aws_api/redshift","title":"modify_cluster_snapshot_schedule","content":"pub fn modify_cluster_snapshot_schedule(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.modify_cluster_snapshot_schedule\naws_api/redshift modify_cluster_snapshot_schedule","url":"aws_api/redshift.html#modify_cluster_snapshot_schedule"},{"doc":"aws_api/redshift","title":"modify_cluster_subnet_group","content":"pub fn modify_cluster_subnet_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.modify_cluster_subnet_group\naws_api/redshift modify_cluster_subnet_group","url":"aws_api/redshift.html#modify_cluster_subnet_group"},{"doc":"aws_api/redshift","title":"modify_custom_domain_association","content":"pub fn modify_custom_domain_association(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.modify_custom_domain_association\naws_api/redshift modify_custom_domain_association","url":"aws_api/redshift.html#modify_custom_domain_association"},{"doc":"aws_api/redshift","title":"modify_endpoint_access","content":"pub fn modify_endpoint_access(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.modify_endpoint_access\naws_api/redshift modify_endpoint_access","url":"aws_api/redshift.html#modify_endpoint_access"},{"doc":"aws_api/redshift","title":"modify_event_subscription","content":"pub fn modify_event_subscription(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.modify_event_subscription\naws_api/redshift modify_event_subscription","url":"aws_api/redshift.html#modify_event_subscription"},{"doc":"aws_api/redshift","title":"modify_redshift_idc_application","content":"pub fn modify_redshift_idc_application(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.modify_redshift_idc_application\naws_api/redshift modify_redshift_idc_application","url":"aws_api/redshift.html#modify_redshift_idc_application"},{"doc":"aws_api/redshift","title":"modify_scheduled_action","content":"pub fn modify_scheduled_action(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.modify_scheduled_action\naws_api/redshift modify_scheduled_action","url":"aws_api/redshift.html#modify_scheduled_action"},{"doc":"aws_api/redshift","title":"modify_snapshot_copy_retention_period","content":"pub fn modify_snapshot_copy_retention_period(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.modify_snapshot_copy_retention_period\naws_api/redshift modify_snapshot_copy_retention_period","url":"aws_api/redshift.html#modify_snapshot_copy_retention_period"},{"doc":"aws_api/redshift","title":"modify_snapshot_schedule","content":"pub fn modify_snapshot_schedule(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.modify_snapshot_schedule\naws_api/redshift modify_snapshot_schedule","url":"aws_api/redshift.html#modify_snapshot_schedule"},{"doc":"aws_api/redshift","title":"modify_usage_limit","content":"pub fn modify_usage_limit(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.modify_usage_limit\naws_api/redshift modify_usage_limit","url":"aws_api/redshift.html#modify_usage_limit"},{"doc":"aws_api/redshift","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/redshift.new\naws_api/redshift new","url":"aws_api/redshift.html#new"},{"doc":"aws_api/redshift","title":"pause_cluster","content":"pub fn pause_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.pause_cluster\naws_api/redshift pause_cluster","url":"aws_api/redshift.html#pause_cluster"},{"doc":"aws_api/redshift","title":"purchase_reserved_node_offering","content":"pub fn purchase_reserved_node_offering(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.purchase_reserved_node_offering\naws_api/redshift purchase_reserved_node_offering","url":"aws_api/redshift.html#purchase_reserved_node_offering"},{"doc":"aws_api/redshift","title":"put_resource_policy","content":"pub fn put_resource_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.put_resource_policy\naws_api/redshift put_resource_policy","url":"aws_api/redshift.html#put_resource_policy"},{"doc":"aws_api/redshift","title":"reboot_cluster","content":"pub fn reboot_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.reboot_cluster\naws_api/redshift reboot_cluster","url":"aws_api/redshift.html#reboot_cluster"},{"doc":"aws_api/redshift","title":"reject_data_share","content":"pub fn reject_data_share(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.reject_data_share\naws_api/redshift reject_data_share","url":"aws_api/redshift.html#reject_data_share"},{"doc":"aws_api/redshift","title":"reset_cluster_parameter_group","content":"pub fn reset_cluster_parameter_group(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.reset_cluster_parameter_group\naws_api/redshift reset_cluster_parameter_group","url":"aws_api/redshift.html#reset_cluster_parameter_group"},{"doc":"aws_api/redshift","title":"resize_cluster","content":"pub fn resize_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.resize_cluster\naws_api/redshift resize_cluster","url":"aws_api/redshift.html#resize_cluster"},{"doc":"aws_api/redshift","title":"restore_from_cluster_snapshot","content":"pub fn restore_from_cluster_snapshot(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.restore_from_cluster_snapshot\naws_api/redshift restore_from_cluster_snapshot","url":"aws_api/redshift.html#restore_from_cluster_snapshot"},{"doc":"aws_api/redshift","title":"restore_table_from_cluster_snapshot","content":"pub fn restore_table_from_cluster_snapshot(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.restore_table_from_cluster_snapshot\naws_api/redshift restore_table_from_cluster_snapshot","url":"aws_api/redshift.html#restore_table_from_cluster_snapshot"},{"doc":"aws_api/redshift","title":"resume_cluster","content":"pub fn resume_cluster(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.resume_cluster\naws_api/redshift resume_cluster","url":"aws_api/redshift.html#resume_cluster"},{"doc":"aws_api/redshift","title":"revoke_cluster_security_group_ingress","content":"pub fn revoke_cluster_security_group_ingress(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.revoke_cluster_security_group_ingress\naws_api/redshift revoke_cluster_security_group_ingress","url":"aws_api/redshift.html#revoke_cluster_security_group_ingress"},{"doc":"aws_api/redshift","title":"revoke_endpoint_access","content":"pub fn revoke_endpoint_access(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.revoke_endpoint_access\naws_api/redshift revoke_endpoint_access","url":"aws_api/redshift.html#revoke_endpoint_access"},{"doc":"aws_api/redshift","title":"revoke_snapshot_access","content":"pub fn revoke_snapshot_access(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.revoke_snapshot_access\naws_api/redshift revoke_snapshot_access","url":"aws_api/redshift.html#revoke_snapshot_access"},{"doc":"aws_api/redshift","title":"rotate_encryption_key","content":"pub fn rotate_encryption_key(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.rotate_encryption_key\naws_api/redshift rotate_encryption_key","url":"aws_api/redshift.html#rotate_encryption_key"},{"doc":"aws_api/redshift","title":"update_partner_status","content":"pub fn update_partner_status(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift.update_partner_status\naws_api/redshift update_partner_status","url":"aws_api/redshift.html#update_partner_status"},{"doc":"aws_api/redshift","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/redshift.with_custom_endpoint\naws_api/redshift with_custom_endpoint","url":"aws_api/redshift.html#with_custom_endpoint"},{"doc":"aws_api/redshift","title":"aws_api/redshift","content":"","url":"aws_api/redshift.html"},{"doc":"aws_api/redshift_serverless","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/redshift_serverless.Client\naws_api/redshift_serverless Client","url":"aws_api/redshift_serverless.html#Client"},{"doc":"aws_api/redshift_serverless","title":"create_custom_domain_association","content":"pub fn create_custom_domain_association(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift_serverless.create_custom_domain_association\naws_api/redshift_serverless create_custom_domain_association","url":"aws_api/redshift_serverless.html#create_custom_domain_association"},{"doc":"aws_api/redshift_serverless","title":"delete_custom_domain_association","content":"pub fn delete_custom_domain_association(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift_serverless.delete_custom_domain_association\naws_api/redshift_serverless delete_custom_domain_association","url":"aws_api/redshift_serverless.html#delete_custom_domain_association"},{"doc":"aws_api/redshift_serverless","title":"delete_resource_policy","content":"pub fn delete_resource_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift_serverless.delete_resource_policy\naws_api/redshift_serverless delete_resource_policy","url":"aws_api/redshift_serverless.html#delete_resource_policy"},{"doc":"aws_api/redshift_serverless","title":"get_credentials","content":"pub fn get_credentials(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift_serverless.get_credentials\naws_api/redshift_serverless get_credentials","url":"aws_api/redshift_serverless.html#get_credentials"},{"doc":"aws_api/redshift_serverless","title":"get_custom_domain_association","content":"pub fn get_custom_domain_association(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift_serverless.get_custom_domain_association\naws_api/redshift_serverless get_custom_domain_association","url":"aws_api/redshift_serverless.html#get_custom_domain_association"},{"doc":"aws_api/redshift_serverless","title":"get_resource_policy","content":"pub fn get_resource_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift_serverless.get_resource_policy\naws_api/redshift_serverless get_resource_policy","url":"aws_api/redshift_serverless.html#get_resource_policy"},{"doc":"aws_api/redshift_serverless","title":"list_custom_domain_associations","content":"pub fn list_custom_domain_associations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift_serverless.list_custom_domain_associations\naws_api/redshift_serverless list_custom_domain_associations","url":"aws_api/redshift_serverless.html#list_custom_domain_associations"},{"doc":"aws_api/redshift_serverless","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift_serverless.list_tags_for_resource\naws_api/redshift_serverless list_tags_for_resource","url":"aws_api/redshift_serverless.html#list_tags_for_resource"},{"doc":"aws_api/redshift_serverless","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/redshift_serverless.new\naws_api/redshift_serverless new","url":"aws_api/redshift_serverless.html#new"},{"doc":"aws_api/redshift_serverless","title":"put_resource_policy","content":"pub fn put_resource_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift_serverless.put_resource_policy\naws_api/redshift_serverless put_resource_policy","url":"aws_api/redshift_serverless.html#put_resource_policy"},{"doc":"aws_api/redshift_serverless","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift_serverless.tag_resource\naws_api/redshift_serverless tag_resource","url":"aws_api/redshift_serverless.html#tag_resource"},{"doc":"aws_api/redshift_serverless","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift_serverless.untag_resource\naws_api/redshift_serverless untag_resource","url":"aws_api/redshift_serverless.html#untag_resource"},{"doc":"aws_api/redshift_serverless","title":"update_custom_domain_association","content":"pub fn update_custom_domain_association(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/redshift_serverless.update_custom_domain_association\naws_api/redshift_serverless update_custom_domain_association","url":"aws_api/redshift_serverless.html#update_custom_domain_association"},{"doc":"aws_api/redshift_serverless","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/redshift_serverless.with_custom_endpoint\naws_api/redshift_serverless with_custom_endpoint","url":"aws_api/redshift_serverless.html#with_custom_endpoint"},{"doc":"aws_api/redshift_serverless","title":"aws_api/redshift_serverless","content":"","url":"aws_api/redshift_serverless.html"},{"doc":"aws_api/rekognition","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/rekognition.Client\naws_api/rekognition Client","url":"aws_api/rekognition.html#Client"},{"doc":"aws_api/rekognition","title":"associate_faces","content":"pub fn associate_faces(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.associate_faces\naws_api/rekognition associate_faces","url":"aws_api/rekognition.html#associate_faces"},{"doc":"aws_api/rekognition","title":"compare_faces","content":"pub fn compare_faces(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.compare_faces\naws_api/rekognition compare_faces","url":"aws_api/rekognition.html#compare_faces"},{"doc":"aws_api/rekognition","title":"copy_project_version","content":"pub fn copy_project_version(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.copy_project_version\naws_api/rekognition copy_project_version","url":"aws_api/rekognition.html#copy_project_version"},{"doc":"aws_api/rekognition","title":"create_collection","content":"pub fn create_collection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.create_collection\naws_api/rekognition create_collection","url":"aws_api/rekognition.html#create_collection"},{"doc":"aws_api/rekognition","title":"create_dataset","content":"pub fn create_dataset(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.create_dataset\naws_api/rekognition create_dataset","url":"aws_api/rekognition.html#create_dataset"},{"doc":"aws_api/rekognition","title":"create_face_liveness_session","content":"pub fn create_face_liveness_session(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.create_face_liveness_session\naws_api/rekognition create_face_liveness_session","url":"aws_api/rekognition.html#create_face_liveness_session"},{"doc":"aws_api/rekognition","title":"create_project","content":"pub fn create_project(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.create_project\naws_api/rekognition create_project","url":"aws_api/rekognition.html#create_project"},{"doc":"aws_api/rekognition","title":"create_project_version","content":"pub fn create_project_version(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.create_project_version\naws_api/rekognition create_project_version","url":"aws_api/rekognition.html#create_project_version"},{"doc":"aws_api/rekognition","title":"create_stream_processor","content":"pub fn create_stream_processor(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.create_stream_processor\naws_api/rekognition create_stream_processor","url":"aws_api/rekognition.html#create_stream_processor"},{"doc":"aws_api/rekognition","title":"create_user","content":"pub fn create_user(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.create_user\naws_api/rekognition create_user","url":"aws_api/rekognition.html#create_user"},{"doc":"aws_api/rekognition","title":"delete_collection","content":"pub fn delete_collection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.delete_collection\naws_api/rekognition delete_collection","url":"aws_api/rekognition.html#delete_collection"},{"doc":"aws_api/rekognition","title":"delete_dataset","content":"pub fn delete_dataset(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.delete_dataset\naws_api/rekognition delete_dataset","url":"aws_api/rekognition.html#delete_dataset"},{"doc":"aws_api/rekognition","title":"delete_faces","content":"pub fn delete_faces(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.delete_faces\naws_api/rekognition delete_faces","url":"aws_api/rekognition.html#delete_faces"},{"doc":"aws_api/rekognition","title":"delete_project","content":"pub fn delete_project(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.delete_project\naws_api/rekognition delete_project","url":"aws_api/rekognition.html#delete_project"},{"doc":"aws_api/rekognition","title":"delete_project_policy","content":"pub fn delete_project_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.delete_project_policy\naws_api/rekognition delete_project_policy","url":"aws_api/rekognition.html#delete_project_policy"},{"doc":"aws_api/rekognition","title":"delete_project_version","content":"pub fn delete_project_version(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.delete_project_version\naws_api/rekognition delete_project_version","url":"aws_api/rekognition.html#delete_project_version"},{"doc":"aws_api/rekognition","title":"delete_stream_processor","content":"pub fn delete_stream_processor(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.delete_stream_processor\naws_api/rekognition delete_stream_processor","url":"aws_api/rekognition.html#delete_stream_processor"},{"doc":"aws_api/rekognition","title":"delete_user","content":"pub fn delete_user(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.delete_user\naws_api/rekognition delete_user","url":"aws_api/rekognition.html#delete_user"},{"doc":"aws_api/rekognition","title":"describe_collection","content":"pub fn describe_collection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.describe_collection\naws_api/rekognition describe_collection","url":"aws_api/rekognition.html#describe_collection"},{"doc":"aws_api/rekognition","title":"describe_dataset","content":"pub fn describe_dataset(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.describe_dataset\naws_api/rekognition describe_dataset","url":"aws_api/rekognition.html#describe_dataset"},{"doc":"aws_api/rekognition","title":"describe_project_versions","content":"pub fn describe_project_versions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.describe_project_versions\naws_api/rekognition describe_project_versions","url":"aws_api/rekognition.html#describe_project_versions"},{"doc":"aws_api/rekognition","title":"describe_projects","content":"pub fn describe_projects(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.describe_projects\naws_api/rekognition describe_projects","url":"aws_api/rekognition.html#describe_projects"},{"doc":"aws_api/rekognition","title":"describe_stream_processor","content":"pub fn describe_stream_processor(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.describe_stream_processor\naws_api/rekognition describe_stream_processor","url":"aws_api/rekognition.html#describe_stream_processor"},{"doc":"aws_api/rekognition","title":"detect_custom_labels","content":"pub fn detect_custom_labels(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.detect_custom_labels\naws_api/rekognition detect_custom_labels","url":"aws_api/rekognition.html#detect_custom_labels"},{"doc":"aws_api/rekognition","title":"detect_faces","content":"pub fn detect_faces(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.detect_faces\naws_api/rekognition detect_faces","url":"aws_api/rekognition.html#detect_faces"},{"doc":"aws_api/rekognition","title":"detect_labels","content":"pub fn detect_labels(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.detect_labels\naws_api/rekognition detect_labels","url":"aws_api/rekognition.html#detect_labels"},{"doc":"aws_api/rekognition","title":"detect_moderation_labels","content":"pub fn detect_moderation_labels(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.detect_moderation_labels\naws_api/rekognition detect_moderation_labels","url":"aws_api/rekognition.html#detect_moderation_labels"},{"doc":"aws_api/rekognition","title":"detect_protective_equipment","content":"pub fn detect_protective_equipment(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.detect_protective_equipment\naws_api/rekognition detect_protective_equipment","url":"aws_api/rekognition.html#detect_protective_equipment"},{"doc":"aws_api/rekognition","title":"detect_text","content":"pub fn detect_text(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.detect_text\naws_api/rekognition detect_text","url":"aws_api/rekognition.html#detect_text"},{"doc":"aws_api/rekognition","title":"disassociate_faces","content":"pub fn disassociate_faces(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.disassociate_faces\naws_api/rekognition disassociate_faces","url":"aws_api/rekognition.html#disassociate_faces"},{"doc":"aws_api/rekognition","title":"distribute_dataset_entries","content":"pub fn distribute_dataset_entries(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.distribute_dataset_entries\naws_api/rekognition distribute_dataset_entries","url":"aws_api/rekognition.html#distribute_dataset_entries"},{"doc":"aws_api/rekognition","title":"get_celebrity_info","content":"pub fn get_celebrity_info(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.get_celebrity_info\naws_api/rekognition get_celebrity_info","url":"aws_api/rekognition.html#get_celebrity_info"},{"doc":"aws_api/rekognition","title":"get_celebrity_recognition","content":"pub fn get_celebrity_recognition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.get_celebrity_recognition\naws_api/rekognition get_celebrity_recognition","url":"aws_api/rekognition.html#get_celebrity_recognition"},{"doc":"aws_api/rekognition","title":"get_content_moderation","content":"pub fn get_content_moderation(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.get_content_moderation\naws_api/rekognition get_content_moderation","url":"aws_api/rekognition.html#get_content_moderation"},{"doc":"aws_api/rekognition","title":"get_face_detection","content":"pub fn get_face_detection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.get_face_detection\naws_api/rekognition get_face_detection","url":"aws_api/rekognition.html#get_face_detection"},{"doc":"aws_api/rekognition","title":"get_face_liveness_session_results","content":"pub fn get_face_liveness_session_results(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.get_face_liveness_session_results\naws_api/rekognition get_face_liveness_session_results","url":"aws_api/rekognition.html#get_face_liveness_session_results"},{"doc":"aws_api/rekognition","title":"get_face_search","content":"pub fn get_face_search(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.get_face_search\naws_api/rekognition get_face_search","url":"aws_api/rekognition.html#get_face_search"},{"doc":"aws_api/rekognition","title":"get_label_detection","content":"pub fn get_label_detection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.get_label_detection\naws_api/rekognition get_label_detection","url":"aws_api/rekognition.html#get_label_detection"},{"doc":"aws_api/rekognition","title":"get_media_analysis_job","content":"pub fn get_media_analysis_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.get_media_analysis_job\naws_api/rekognition get_media_analysis_job","url":"aws_api/rekognition.html#get_media_analysis_job"},{"doc":"aws_api/rekognition","title":"get_person_tracking","content":"pub fn get_person_tracking(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.get_person_tracking\naws_api/rekognition get_person_tracking","url":"aws_api/rekognition.html#get_person_tracking"},{"doc":"aws_api/rekognition","title":"get_segment_detection","content":"pub fn get_segment_detection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.get_segment_detection\naws_api/rekognition get_segment_detection","url":"aws_api/rekognition.html#get_segment_detection"},{"doc":"aws_api/rekognition","title":"get_text_detection","content":"pub fn get_text_detection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.get_text_detection\naws_api/rekognition get_text_detection","url":"aws_api/rekognition.html#get_text_detection"},{"doc":"aws_api/rekognition","title":"index_faces","content":"pub fn index_faces(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.index_faces\naws_api/rekognition index_faces","url":"aws_api/rekognition.html#index_faces"},{"doc":"aws_api/rekognition","title":"list_collections","content":"pub fn list_collections(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.list_collections\naws_api/rekognition list_collections","url":"aws_api/rekognition.html#list_collections"},{"doc":"aws_api/rekognition","title":"list_dataset_entries","content":"pub fn list_dataset_entries(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.list_dataset_entries\naws_api/rekognition list_dataset_entries","url":"aws_api/rekognition.html#list_dataset_entries"},{"doc":"aws_api/rekognition","title":"list_dataset_labels","content":"pub fn list_dataset_labels(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.list_dataset_labels\naws_api/rekognition list_dataset_labels","url":"aws_api/rekognition.html#list_dataset_labels"},{"doc":"aws_api/rekognition","title":"list_faces","content":"pub fn list_faces(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.list_faces\naws_api/rekognition list_faces","url":"aws_api/rekognition.html#list_faces"},{"doc":"aws_api/rekognition","title":"list_media_analysis_jobs","content":"pub fn list_media_analysis_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.list_media_analysis_jobs\naws_api/rekognition list_media_analysis_jobs","url":"aws_api/rekognition.html#list_media_analysis_jobs"},{"doc":"aws_api/rekognition","title":"list_project_policies","content":"pub fn list_project_policies(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.list_project_policies\naws_api/rekognition list_project_policies","url":"aws_api/rekognition.html#list_project_policies"},{"doc":"aws_api/rekognition","title":"list_stream_processors","content":"pub fn list_stream_processors(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.list_stream_processors\naws_api/rekognition list_stream_processors","url":"aws_api/rekognition.html#list_stream_processors"},{"doc":"aws_api/rekognition","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.list_tags_for_resource\naws_api/rekognition list_tags_for_resource","url":"aws_api/rekognition.html#list_tags_for_resource"},{"doc":"aws_api/rekognition","title":"list_users","content":"pub fn list_users(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.list_users\naws_api/rekognition list_users","url":"aws_api/rekognition.html#list_users"},{"doc":"aws_api/rekognition","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/rekognition.new\naws_api/rekognition new","url":"aws_api/rekognition.html#new"},{"doc":"aws_api/rekognition","title":"put_project_policy","content":"pub fn put_project_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.put_project_policy\naws_api/rekognition put_project_policy","url":"aws_api/rekognition.html#put_project_policy"},{"doc":"aws_api/rekognition","title":"recognize_celebrities","content":"pub fn recognize_celebrities(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.recognize_celebrities\naws_api/rekognition recognize_celebrities","url":"aws_api/rekognition.html#recognize_celebrities"},{"doc":"aws_api/rekognition","title":"search_faces","content":"pub fn search_faces(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.search_faces\naws_api/rekognition search_faces","url":"aws_api/rekognition.html#search_faces"},{"doc":"aws_api/rekognition","title":"search_faces_by_image","content":"pub fn search_faces_by_image(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.search_faces_by_image\naws_api/rekognition search_faces_by_image","url":"aws_api/rekognition.html#search_faces_by_image"},{"doc":"aws_api/rekognition","title":"search_users","content":"pub fn search_users(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.search_users\naws_api/rekognition search_users","url":"aws_api/rekognition.html#search_users"},{"doc":"aws_api/rekognition","title":"search_users_by_image","content":"pub fn search_users_by_image(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.search_users_by_image\naws_api/rekognition search_users_by_image","url":"aws_api/rekognition.html#search_users_by_image"},{"doc":"aws_api/rekognition","title":"start_celebrity_recognition","content":"pub fn start_celebrity_recognition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.start_celebrity_recognition\naws_api/rekognition start_celebrity_recognition","url":"aws_api/rekognition.html#start_celebrity_recognition"},{"doc":"aws_api/rekognition","title":"start_content_moderation","content":"pub fn start_content_moderation(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.start_content_moderation\naws_api/rekognition start_content_moderation","url":"aws_api/rekognition.html#start_content_moderation"},{"doc":"aws_api/rekognition","title":"start_face_detection","content":"pub fn start_face_detection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.start_face_detection\naws_api/rekognition start_face_detection","url":"aws_api/rekognition.html#start_face_detection"},{"doc":"aws_api/rekognition","title":"start_face_search","content":"pub fn start_face_search(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.start_face_search\naws_api/rekognition start_face_search","url":"aws_api/rekognition.html#start_face_search"},{"doc":"aws_api/rekognition","title":"start_label_detection","content":"pub fn start_label_detection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.start_label_detection\naws_api/rekognition start_label_detection","url":"aws_api/rekognition.html#start_label_detection"},{"doc":"aws_api/rekognition","title":"start_media_analysis_job","content":"pub fn start_media_analysis_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.start_media_analysis_job\naws_api/rekognition start_media_analysis_job","url":"aws_api/rekognition.html#start_media_analysis_job"},{"doc":"aws_api/rekognition","title":"start_person_tracking","content":"pub fn start_person_tracking(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.start_person_tracking\naws_api/rekognition start_person_tracking","url":"aws_api/rekognition.html#start_person_tracking"},{"doc":"aws_api/rekognition","title":"start_project_version","content":"pub fn start_project_version(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.start_project_version\naws_api/rekognition start_project_version","url":"aws_api/rekognition.html#start_project_version"},{"doc":"aws_api/rekognition","title":"start_segment_detection","content":"pub fn start_segment_detection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.start_segment_detection\naws_api/rekognition start_segment_detection","url":"aws_api/rekognition.html#start_segment_detection"},{"doc":"aws_api/rekognition","title":"start_stream_processor","content":"pub fn start_stream_processor(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.start_stream_processor\naws_api/rekognition start_stream_processor","url":"aws_api/rekognition.html#start_stream_processor"},{"doc":"aws_api/rekognition","title":"start_text_detection","content":"pub fn start_text_detection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.start_text_detection\naws_api/rekognition start_text_detection","url":"aws_api/rekognition.html#start_text_detection"},{"doc":"aws_api/rekognition","title":"stop_project_version","content":"pub fn stop_project_version(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.stop_project_version\naws_api/rekognition stop_project_version","url":"aws_api/rekognition.html#stop_project_version"},{"doc":"aws_api/rekognition","title":"stop_stream_processor","content":"pub fn stop_stream_processor(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.stop_stream_processor\naws_api/rekognition stop_stream_processor","url":"aws_api/rekognition.html#stop_stream_processor"},{"doc":"aws_api/rekognition","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.tag_resource\naws_api/rekognition tag_resource","url":"aws_api/rekognition.html#tag_resource"},{"doc":"aws_api/rekognition","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.untag_resource\naws_api/rekognition untag_resource","url":"aws_api/rekognition.html#untag_resource"},{"doc":"aws_api/rekognition","title":"update_dataset_entries","content":"pub fn update_dataset_entries(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.update_dataset_entries\naws_api/rekognition update_dataset_entries","url":"aws_api/rekognition.html#update_dataset_entries"},{"doc":"aws_api/rekognition","title":"update_stream_processor","content":"pub fn update_stream_processor(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rekognition.update_stream_processor\naws_api/rekognition update_stream_processor","url":"aws_api/rekognition.html#update_stream_processor"},{"doc":"aws_api/rekognition","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/rekognition.with_custom_endpoint\naws_api/rekognition with_custom_endpoint","url":"aws_api/rekognition.html#with_custom_endpoint"},{"doc":"aws_api/rekognition","title":"aws_api/rekognition","content":"","url":"aws_api/rekognition.html"},{"doc":"aws_api/resiliencehub","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/resiliencehub.Client\naws_api/resiliencehub Client","url":"aws_api/resiliencehub.html#Client"},{"doc":"aws_api/resiliencehub","title":"accept_resource_grouping_recommendations","content":"pub fn accept_resource_grouping_recommendations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.accept_resource_grouping_recommendations\naws_api/resiliencehub accept_resource_grouping_recommendations","url":"aws_api/resiliencehub.html#accept_resource_grouping_recommendations"},{"doc":"aws_api/resiliencehub","title":"add_draft_app_version_resource_mappings","content":"pub fn add_draft_app_version_resource_mappings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.add_draft_app_version_resource_mappings\naws_api/resiliencehub add_draft_app_version_resource_mappings","url":"aws_api/resiliencehub.html#add_draft_app_version_resource_mappings"},{"doc":"aws_api/resiliencehub","title":"batch_update_recommendation_status","content":"pub fn batch_update_recommendation_status(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.batch_update_recommendation_status\naws_api/resiliencehub batch_update_recommendation_status","url":"aws_api/resiliencehub.html#batch_update_recommendation_status"},{"doc":"aws_api/resiliencehub","title":"create_app","content":"pub fn create_app(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.create_app\naws_api/resiliencehub create_app","url":"aws_api/resiliencehub.html#create_app"},{"doc":"aws_api/resiliencehub","title":"create_app_version_app_component","content":"pub fn create_app_version_app_component(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.create_app_version_app_component\naws_api/resiliencehub create_app_version_app_component","url":"aws_api/resiliencehub.html#create_app_version_app_component"},{"doc":"aws_api/resiliencehub","title":"create_app_version_resource","content":"pub fn create_app_version_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.create_app_version_resource\naws_api/resiliencehub create_app_version_resource","url":"aws_api/resiliencehub.html#create_app_version_resource"},{"doc":"aws_api/resiliencehub","title":"create_recommendation_template","content":"pub fn create_recommendation_template(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.create_recommendation_template\naws_api/resiliencehub create_recommendation_template","url":"aws_api/resiliencehub.html#create_recommendation_template"},{"doc":"aws_api/resiliencehub","title":"create_resiliency_policy","content":"pub fn create_resiliency_policy(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.create_resiliency_policy\naws_api/resiliencehub create_resiliency_policy","url":"aws_api/resiliencehub.html#create_resiliency_policy"},{"doc":"aws_api/resiliencehub","title":"delete_app","content":"pub fn delete_app(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.delete_app\naws_api/resiliencehub delete_app","url":"aws_api/resiliencehub.html#delete_app"},{"doc":"aws_api/resiliencehub","title":"delete_app_assessment","content":"pub fn delete_app_assessment(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.delete_app_assessment\naws_api/resiliencehub delete_app_assessment","url":"aws_api/resiliencehub.html#delete_app_assessment"},{"doc":"aws_api/resiliencehub","title":"delete_app_input_source","content":"pub fn delete_app_input_source(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.delete_app_input_source\naws_api/resiliencehub delete_app_input_source","url":"aws_api/resiliencehub.html#delete_app_input_source"},{"doc":"aws_api/resiliencehub","title":"delete_app_version_app_component","content":"pub fn delete_app_version_app_component(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.delete_app_version_app_component\naws_api/resiliencehub delete_app_version_app_component","url":"aws_api/resiliencehub.html#delete_app_version_app_component"},{"doc":"aws_api/resiliencehub","title":"delete_app_version_resource","content":"pub fn delete_app_version_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.delete_app_version_resource\naws_api/resiliencehub delete_app_version_resource","url":"aws_api/resiliencehub.html#delete_app_version_resource"},{"doc":"aws_api/resiliencehub","title":"delete_recommendation_template","content":"pub fn delete_recommendation_template(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.delete_recommendation_template\naws_api/resiliencehub delete_recommendation_template","url":"aws_api/resiliencehub.html#delete_recommendation_template"},{"doc":"aws_api/resiliencehub","title":"delete_resiliency_policy","content":"pub fn delete_resiliency_policy(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.delete_resiliency_policy\naws_api/resiliencehub delete_resiliency_policy","url":"aws_api/resiliencehub.html#delete_resiliency_policy"},{"doc":"aws_api/resiliencehub","title":"describe_app","content":"pub fn describe_app(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.describe_app\naws_api/resiliencehub describe_app","url":"aws_api/resiliencehub.html#describe_app"},{"doc":"aws_api/resiliencehub","title":"describe_app_assessment","content":"pub fn describe_app_assessment(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.describe_app_assessment\naws_api/resiliencehub describe_app_assessment","url":"aws_api/resiliencehub.html#describe_app_assessment"},{"doc":"aws_api/resiliencehub","title":"describe_app_version","content":"pub fn describe_app_version(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.describe_app_version\naws_api/resiliencehub describe_app_version","url":"aws_api/resiliencehub.html#describe_app_version"},{"doc":"aws_api/resiliencehub","title":"describe_app_version_app_component","content":"pub fn describe_app_version_app_component(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.describe_app_version_app_component\naws_api/resiliencehub describe_app_version_app_component","url":"aws_api/resiliencehub.html#describe_app_version_app_component"},{"doc":"aws_api/resiliencehub","title":"describe_app_version_resource","content":"pub fn describe_app_version_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.describe_app_version_resource\naws_api/resiliencehub describe_app_version_resource","url":"aws_api/resiliencehub.html#describe_app_version_resource"},{"doc":"aws_api/resiliencehub","title":"describe_app_version_resources_resolution_status","content":"pub fn describe_app_version_resources_resolution_status(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.describe_app_version_resources_resolution_status\naws_api/resiliencehub describe_app_version_resources_resolution_status","url":"aws_api/resiliencehub.html#describe_app_version_resources_resolution_status"},{"doc":"aws_api/resiliencehub","title":"describe_app_version_template","content":"pub fn describe_app_version_template(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.describe_app_version_template\naws_api/resiliencehub describe_app_version_template","url":"aws_api/resiliencehub.html#describe_app_version_template"},{"doc":"aws_api/resiliencehub","title":"describe_draft_app_version_resources_import_status","content":"pub fn describe_draft_app_version_resources_import_status(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.describe_draft_app_version_resources_import_status\naws_api/resiliencehub describe_draft_app_version_resources_import_status","url":"aws_api/resiliencehub.html#describe_draft_app_version_resources_import_status"},{"doc":"aws_api/resiliencehub","title":"describe_resiliency_policy","content":"pub fn describe_resiliency_policy(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.describe_resiliency_policy\naws_api/resiliencehub describe_resiliency_policy","url":"aws_api/resiliencehub.html#describe_resiliency_policy"},{"doc":"aws_api/resiliencehub","title":"describe_resource_grouping_recommendation_task","content":"pub fn describe_resource_grouping_recommendation_task(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.describe_resource_grouping_recommendation_task\naws_api/resiliencehub describe_resource_grouping_recommendation_task","url":"aws_api/resiliencehub.html#describe_resource_grouping_recommendation_task"},{"doc":"aws_api/resiliencehub","title":"import_resources_to_draft_app_version","content":"pub fn import_resources_to_draft_app_version(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.import_resources_to_draft_app_version\naws_api/resiliencehub import_resources_to_draft_app_version","url":"aws_api/resiliencehub.html#import_resources_to_draft_app_version"},{"doc":"aws_api/resiliencehub","title":"list_alarm_recommendations","content":"pub fn list_alarm_recommendations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.list_alarm_recommendations\naws_api/resiliencehub list_alarm_recommendations","url":"aws_api/resiliencehub.html#list_alarm_recommendations"},{"doc":"aws_api/resiliencehub","title":"list_app_assessment_compliance_drifts","content":"pub fn list_app_assessment_compliance_drifts(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.list_app_assessment_compliance_drifts\naws_api/resiliencehub list_app_assessment_compliance_drifts","url":"aws_api/resiliencehub.html#list_app_assessment_compliance_drifts"},{"doc":"aws_api/resiliencehub","title":"list_app_assessment_resource_drifts","content":"pub fn list_app_assessment_resource_drifts(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.list_app_assessment_resource_drifts\naws_api/resiliencehub list_app_assessment_resource_drifts","url":"aws_api/resiliencehub.html#list_app_assessment_resource_drifts"},{"doc":"aws_api/resiliencehub","title":"list_app_assessments","content":"pub fn list_app_assessments(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.list_app_assessments\naws_api/resiliencehub list_app_assessments","url":"aws_api/resiliencehub.html#list_app_assessments"},{"doc":"aws_api/resiliencehub","title":"list_app_component_compliances","content":"pub fn list_app_component_compliances(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.list_app_component_compliances\naws_api/resiliencehub list_app_component_compliances","url":"aws_api/resiliencehub.html#list_app_component_compliances"},{"doc":"aws_api/resiliencehub","title":"list_app_component_recommendations","content":"pub fn list_app_component_recommendations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.list_app_component_recommendations\naws_api/resiliencehub list_app_component_recommendations","url":"aws_api/resiliencehub.html#list_app_component_recommendations"},{"doc":"aws_api/resiliencehub","title":"list_app_input_sources","content":"pub fn list_app_input_sources(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.list_app_input_sources\naws_api/resiliencehub list_app_input_sources","url":"aws_api/resiliencehub.html#list_app_input_sources"},{"doc":"aws_api/resiliencehub","title":"list_app_version_app_components","content":"pub fn list_app_version_app_components(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.list_app_version_app_components\naws_api/resiliencehub list_app_version_app_components","url":"aws_api/resiliencehub.html#list_app_version_app_components"},{"doc":"aws_api/resiliencehub","title":"list_app_version_resource_mappings","content":"pub fn list_app_version_resource_mappings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.list_app_version_resource_mappings\naws_api/resiliencehub list_app_version_resource_mappings","url":"aws_api/resiliencehub.html#list_app_version_resource_mappings"},{"doc":"aws_api/resiliencehub","title":"list_app_version_resources","content":"pub fn list_app_version_resources(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.list_app_version_resources\naws_api/resiliencehub list_app_version_resources","url":"aws_api/resiliencehub.html#list_app_version_resources"},{"doc":"aws_api/resiliencehub","title":"list_app_versions","content":"pub fn list_app_versions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.list_app_versions\naws_api/resiliencehub list_app_versions","url":"aws_api/resiliencehub.html#list_app_versions"},{"doc":"aws_api/resiliencehub","title":"list_apps","content":"pub fn list_apps(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.list_apps\naws_api/resiliencehub list_apps","url":"aws_api/resiliencehub.html#list_apps"},{"doc":"aws_api/resiliencehub","title":"list_recommendation_templates","content":"pub fn list_recommendation_templates(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.list_recommendation_templates\naws_api/resiliencehub list_recommendation_templates","url":"aws_api/resiliencehub.html#list_recommendation_templates"},{"doc":"aws_api/resiliencehub","title":"list_resiliency_policies","content":"pub fn list_resiliency_policies(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.list_resiliency_policies\naws_api/resiliencehub list_resiliency_policies","url":"aws_api/resiliencehub.html#list_resiliency_policies"},{"doc":"aws_api/resiliencehub","title":"list_resource_grouping_recommendations","content":"pub fn list_resource_grouping_recommendations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.list_resource_grouping_recommendations\naws_api/resiliencehub list_resource_grouping_recommendations","url":"aws_api/resiliencehub.html#list_resource_grouping_recommendations"},{"doc":"aws_api/resiliencehub","title":"list_sop_recommendations","content":"pub fn list_sop_recommendations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.list_sop_recommendations\naws_api/resiliencehub list_sop_recommendations","url":"aws_api/resiliencehub.html#list_sop_recommendations"},{"doc":"aws_api/resiliencehub","title":"list_suggested_resiliency_policies","content":"pub fn list_suggested_resiliency_policies(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.list_suggested_resiliency_policies\naws_api/resiliencehub list_suggested_resiliency_policies","url":"aws_api/resiliencehub.html#list_suggested_resiliency_policies"},{"doc":"aws_api/resiliencehub","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.list_tags_for_resource\naws_api/resiliencehub list_tags_for_resource","url":"aws_api/resiliencehub.html#list_tags_for_resource"},{"doc":"aws_api/resiliencehub","title":"list_test_recommendations","content":"pub fn list_test_recommendations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.list_test_recommendations\naws_api/resiliencehub list_test_recommendations","url":"aws_api/resiliencehub.html#list_test_recommendations"},{"doc":"aws_api/resiliencehub","title":"list_unsupported_app_version_resources","content":"pub fn list_unsupported_app_version_resources(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.list_unsupported_app_version_resources\naws_api/resiliencehub list_unsupported_app_version_resources","url":"aws_api/resiliencehub.html#list_unsupported_app_version_resources"},{"doc":"aws_api/resiliencehub","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/resiliencehub.new\naws_api/resiliencehub new","url":"aws_api/resiliencehub.html#new"},{"doc":"aws_api/resiliencehub","title":"publish_app_version","content":"pub fn publish_app_version(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.publish_app_version\naws_api/resiliencehub publish_app_version","url":"aws_api/resiliencehub.html#publish_app_version"},{"doc":"aws_api/resiliencehub","title":"put_draft_app_version_template","content":"pub fn put_draft_app_version_template(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.put_draft_app_version_template\naws_api/resiliencehub put_draft_app_version_template","url":"aws_api/resiliencehub.html#put_draft_app_version_template"},{"doc":"aws_api/resiliencehub","title":"reject_resource_grouping_recommendations","content":"pub fn reject_resource_grouping_recommendations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.reject_resource_grouping_recommendations\naws_api/resiliencehub reject_resource_grouping_recommendations","url":"aws_api/resiliencehub.html#reject_resource_grouping_recommendations"},{"doc":"aws_api/resiliencehub","title":"remove_draft_app_version_resource_mappings","content":"pub fn remove_draft_app_version_resource_mappings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.remove_draft_app_version_resource_mappings\naws_api/resiliencehub remove_draft_app_version_resource_mappings","url":"aws_api/resiliencehub.html#remove_draft_app_version_resource_mappings"},{"doc":"aws_api/resiliencehub","title":"resolve_app_version_resources","content":"pub fn resolve_app_version_resources(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.resolve_app_version_resources\naws_api/resiliencehub resolve_app_version_resources","url":"aws_api/resiliencehub.html#resolve_app_version_resources"},{"doc":"aws_api/resiliencehub","title":"start_app_assessment","content":"pub fn start_app_assessment(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.start_app_assessment\naws_api/resiliencehub start_app_assessment","url":"aws_api/resiliencehub.html#start_app_assessment"},{"doc":"aws_api/resiliencehub","title":"start_resource_grouping_recommendation_task","content":"pub fn start_resource_grouping_recommendation_task(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.start_resource_grouping_recommendation_task\naws_api/resiliencehub start_resource_grouping_recommendation_task","url":"aws_api/resiliencehub.html#start_resource_grouping_recommendation_task"},{"doc":"aws_api/resiliencehub","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.tag_resource\naws_api/resiliencehub tag_resource","url":"aws_api/resiliencehub.html#tag_resource"},{"doc":"aws_api/resiliencehub","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.untag_resource\naws_api/resiliencehub untag_resource","url":"aws_api/resiliencehub.html#untag_resource"},{"doc":"aws_api/resiliencehub","title":"update_app","content":"pub fn update_app(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.update_app\naws_api/resiliencehub update_app","url":"aws_api/resiliencehub.html#update_app"},{"doc":"aws_api/resiliencehub","title":"update_app_version","content":"pub fn update_app_version(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.update_app_version\naws_api/resiliencehub update_app_version","url":"aws_api/resiliencehub.html#update_app_version"},{"doc":"aws_api/resiliencehub","title":"update_app_version_app_component","content":"pub fn update_app_version_app_component(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.update_app_version_app_component\naws_api/resiliencehub update_app_version_app_component","url":"aws_api/resiliencehub.html#update_app_version_app_component"},{"doc":"aws_api/resiliencehub","title":"update_app_version_resource","content":"pub fn update_app_version_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.update_app_version_resource\naws_api/resiliencehub update_app_version_resource","url":"aws_api/resiliencehub.html#update_app_version_resource"},{"doc":"aws_api/resiliencehub","title":"update_resiliency_policy","content":"pub fn update_resiliency_policy(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resiliencehub.update_resiliency_policy\naws_api/resiliencehub update_resiliency_policy","url":"aws_api/resiliencehub.html#update_resiliency_policy"},{"doc":"aws_api/resiliencehub","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/resiliencehub.with_custom_endpoint\naws_api/resiliencehub with_custom_endpoint","url":"aws_api/resiliencehub.html#with_custom_endpoint"},{"doc":"aws_api/resiliencehub","title":"aws_api/resiliencehub","content":"","url":"aws_api/resiliencehub.html"},{"doc":"aws_api/resource_explorer_2","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/resource_explorer_2.Client\naws_api/resource_explorer_2 Client","url":"aws_api/resource_explorer_2.html#Client"},{"doc":"aws_api/resource_explorer_2","title":"batch_get_view","content":"pub fn batch_get_view(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resource_explorer_2.batch_get_view\naws_api/resource_explorer_2 batch_get_view","url":"aws_api/resource_explorer_2.html#batch_get_view"},{"doc":"aws_api/resource_explorer_2","title":"disassociate_default_view","content":"pub fn disassociate_default_view(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resource_explorer_2.disassociate_default_view\naws_api/resource_explorer_2 disassociate_default_view","url":"aws_api/resource_explorer_2.html#disassociate_default_view"},{"doc":"aws_api/resource_explorer_2","title":"get_account_level_service_configuration","content":"pub fn get_account_level_service_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resource_explorer_2.get_account_level_service_configuration\naws_api/resource_explorer_2 get_account_level_service_configuration","url":"aws_api/resource_explorer_2.html#get_account_level_service_configuration"},{"doc":"aws_api/resource_explorer_2","title":"get_default_view","content":"pub fn get_default_view(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resource_explorer_2.get_default_view\naws_api/resource_explorer_2 get_default_view","url":"aws_api/resource_explorer_2.html#get_default_view"},{"doc":"aws_api/resource_explorer_2","title":"get_index","content":"pub fn get_index(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resource_explorer_2.get_index\naws_api/resource_explorer_2 get_index","url":"aws_api/resource_explorer_2.html#get_index"},{"doc":"aws_api/resource_explorer_2","title":"list_indexes_for_members","content":"pub fn list_indexes_for_members(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resource_explorer_2.list_indexes_for_members\naws_api/resource_explorer_2 list_indexes_for_members","url":"aws_api/resource_explorer_2.html#list_indexes_for_members"},{"doc":"aws_api/resource_explorer_2","title":"list_supported_resource_types","content":"pub fn list_supported_resource_types(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resource_explorer_2.list_supported_resource_types\naws_api/resource_explorer_2 list_supported_resource_types","url":"aws_api/resource_explorer_2.html#list_supported_resource_types"},{"doc":"aws_api/resource_explorer_2","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resource_explorer_2.list_tags_for_resource\naws_api/resource_explorer_2 list_tags_for_resource","url":"aws_api/resource_explorer_2.html#list_tags_for_resource"},{"doc":"aws_api/resource_explorer_2","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/resource_explorer_2.new\naws_api/resource_explorer_2 new","url":"aws_api/resource_explorer_2.html#new"},{"doc":"aws_api/resource_explorer_2","title":"search","content":"pub fn search(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resource_explorer_2.search\naws_api/resource_explorer_2 search","url":"aws_api/resource_explorer_2.html#search"},{"doc":"aws_api/resource_explorer_2","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resource_explorer_2.tag_resource\naws_api/resource_explorer_2 tag_resource","url":"aws_api/resource_explorer_2.html#tag_resource"},{"doc":"aws_api/resource_explorer_2","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resource_explorer_2.untag_resource\naws_api/resource_explorer_2 untag_resource","url":"aws_api/resource_explorer_2.html#untag_resource"},{"doc":"aws_api/resource_explorer_2","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/resource_explorer_2.with_custom_endpoint\naws_api/resource_explorer_2 with_custom_endpoint","url":"aws_api/resource_explorer_2.html#with_custom_endpoint"},{"doc":"aws_api/resource_explorer_2","title":"aws_api/resource_explorer_2","content":"","url":"aws_api/resource_explorer_2.html"},{"doc":"aws_api/resource_groups","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/resource_groups.Client\naws_api/resource_groups Client","url":"aws_api/resource_groups.html#Client"},{"doc":"aws_api/resource_groups","title":"create_group","content":"pub fn create_group(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resource_groups.create_group\naws_api/resource_groups create_group","url":"aws_api/resource_groups.html#create_group"},{"doc":"aws_api/resource_groups","title":"delete_group","content":"pub fn delete_group(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resource_groups.delete_group\naws_api/resource_groups delete_group","url":"aws_api/resource_groups.html#delete_group"},{"doc":"aws_api/resource_groups","title":"get_account_settings","content":"pub fn get_account_settings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resource_groups.get_account_settings\naws_api/resource_groups get_account_settings","url":"aws_api/resource_groups.html#get_account_settings"},{"doc":"aws_api/resource_groups","title":"get_group","content":"pub fn get_group(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resource_groups.get_group\naws_api/resource_groups get_group","url":"aws_api/resource_groups.html#get_group"},{"doc":"aws_api/resource_groups","title":"get_group_configuration","content":"pub fn get_group_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resource_groups.get_group_configuration\naws_api/resource_groups get_group_configuration","url":"aws_api/resource_groups.html#get_group_configuration"},{"doc":"aws_api/resource_groups","title":"get_group_query","content":"pub fn get_group_query(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resource_groups.get_group_query\naws_api/resource_groups get_group_query","url":"aws_api/resource_groups.html#get_group_query"},{"doc":"aws_api/resource_groups","title":"get_tags","content":"pub fn get_tags(\n  client: Client,\n  arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resource_groups.get_tags\naws_api/resource_groups get_tags","url":"aws_api/resource_groups.html#get_tags"},{"doc":"aws_api/resource_groups","title":"group_resources","content":"pub fn group_resources(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resource_groups.group_resources\naws_api/resource_groups group_resources","url":"aws_api/resource_groups.html#group_resources"},{"doc":"aws_api/resource_groups","title":"list_group_resources","content":"pub fn list_group_resources(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resource_groups.list_group_resources\naws_api/resource_groups list_group_resources","url":"aws_api/resource_groups.html#list_group_resources"},{"doc":"aws_api/resource_groups","title":"list_groups","content":"pub fn list_groups(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resource_groups.list_groups\naws_api/resource_groups list_groups","url":"aws_api/resource_groups.html#list_groups"},{"doc":"aws_api/resource_groups","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/resource_groups.new\naws_api/resource_groups new","url":"aws_api/resource_groups.html#new"},{"doc":"aws_api/resource_groups","title":"put_group_configuration","content":"pub fn put_group_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resource_groups.put_group_configuration\naws_api/resource_groups put_group_configuration","url":"aws_api/resource_groups.html#put_group_configuration"},{"doc":"aws_api/resource_groups","title":"search_resources","content":"pub fn search_resources(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resource_groups.search_resources\naws_api/resource_groups search_resources","url":"aws_api/resource_groups.html#search_resources"},{"doc":"aws_api/resource_groups","title":"tag","content":"pub fn tag(\n  client: Client,\n  arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resource_groups.tag\naws_api/resource_groups tag","url":"aws_api/resource_groups.html#tag"},{"doc":"aws_api/resource_groups","title":"ungroup_resources","content":"pub fn ungroup_resources(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resource_groups.ungroup_resources\naws_api/resource_groups ungroup_resources","url":"aws_api/resource_groups.html#ungroup_resources"},{"doc":"aws_api/resource_groups","title":"untag","content":"pub fn untag(\n  client: Client,\n  arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resource_groups.untag\naws_api/resource_groups untag","url":"aws_api/resource_groups.html#untag"},{"doc":"aws_api/resource_groups","title":"update_account_settings","content":"pub fn update_account_settings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resource_groups.update_account_settings\naws_api/resource_groups update_account_settings","url":"aws_api/resource_groups.html#update_account_settings"},{"doc":"aws_api/resource_groups","title":"update_group","content":"pub fn update_group(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resource_groups.update_group\naws_api/resource_groups update_group","url":"aws_api/resource_groups.html#update_group"},{"doc":"aws_api/resource_groups","title":"update_group_query","content":"pub fn update_group_query(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resource_groups.update_group_query\naws_api/resource_groups update_group_query","url":"aws_api/resource_groups.html#update_group_query"},{"doc":"aws_api/resource_groups","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/resource_groups.with_custom_endpoint\naws_api/resource_groups with_custom_endpoint","url":"aws_api/resource_groups.html#with_custom_endpoint"},{"doc":"aws_api/resource_groups","title":"aws_api/resource_groups","content":"","url":"aws_api/resource_groups.html"},{"doc":"aws_api/resource_groups_tagging_api","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/resource_groups_tagging_api.Client\naws_api/resource_groups_tagging_api Client","url":"aws_api/resource_groups_tagging_api.html#Client"},{"doc":"aws_api/resource_groups_tagging_api","title":"describe_report_creation","content":"pub fn describe_report_creation(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resource_groups_tagging_api.describe_report_creation\naws_api/resource_groups_tagging_api describe_report_creation","url":"aws_api/resource_groups_tagging_api.html#describe_report_creation"},{"doc":"aws_api/resource_groups_tagging_api","title":"get_compliance_summary","content":"pub fn get_compliance_summary(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resource_groups_tagging_api.get_compliance_summary\naws_api/resource_groups_tagging_api get_compliance_summary","url":"aws_api/resource_groups_tagging_api.html#get_compliance_summary"},{"doc":"aws_api/resource_groups_tagging_api","title":"get_resources","content":"pub fn get_resources(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resource_groups_tagging_api.get_resources\naws_api/resource_groups_tagging_api get_resources","url":"aws_api/resource_groups_tagging_api.html#get_resources"},{"doc":"aws_api/resource_groups_tagging_api","title":"get_tag_keys","content":"pub fn get_tag_keys(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resource_groups_tagging_api.get_tag_keys\naws_api/resource_groups_tagging_api get_tag_keys","url":"aws_api/resource_groups_tagging_api.html#get_tag_keys"},{"doc":"aws_api/resource_groups_tagging_api","title":"get_tag_values","content":"pub fn get_tag_values(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resource_groups_tagging_api.get_tag_values\naws_api/resource_groups_tagging_api get_tag_values","url":"aws_api/resource_groups_tagging_api.html#get_tag_values"},{"doc":"aws_api/resource_groups_tagging_api","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/resource_groups_tagging_api.new\naws_api/resource_groups_tagging_api new","url":"aws_api/resource_groups_tagging_api.html#new"},{"doc":"aws_api/resource_groups_tagging_api","title":"start_report_creation","content":"pub fn start_report_creation(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resource_groups_tagging_api.start_report_creation\naws_api/resource_groups_tagging_api start_report_creation","url":"aws_api/resource_groups_tagging_api.html#start_report_creation"},{"doc":"aws_api/resource_groups_tagging_api","title":"tag_resources","content":"pub fn tag_resources(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resource_groups_tagging_api.tag_resources\naws_api/resource_groups_tagging_api tag_resources","url":"aws_api/resource_groups_tagging_api.html#tag_resources"},{"doc":"aws_api/resource_groups_tagging_api","title":"untag_resources","content":"pub fn untag_resources(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/resource_groups_tagging_api.untag_resources\naws_api/resource_groups_tagging_api untag_resources","url":"aws_api/resource_groups_tagging_api.html#untag_resources"},{"doc":"aws_api/resource_groups_tagging_api","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/resource_groups_tagging_api.with_custom_endpoint\naws_api/resource_groups_tagging_api with_custom_endpoint","url":"aws_api/resource_groups_tagging_api.html#with_custom_endpoint"},{"doc":"aws_api/resource_groups_tagging_api","title":"aws_api/resource_groups_tagging_api","content":"","url":"aws_api/resource_groups_tagging_api.html"},{"doc":"aws_api/robomaker","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/robomaker.Client\naws_api/robomaker Client","url":"aws_api/robomaker.html#Client"},{"doc":"aws_api/robomaker","title":"batch_delete_worlds","content":"pub fn batch_delete_worlds(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.batch_delete_worlds\naws_api/robomaker batch_delete_worlds","url":"aws_api/robomaker.html#batch_delete_worlds"},{"doc":"aws_api/robomaker","title":"batch_describe_simulation_job","content":"pub fn batch_describe_simulation_job(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.batch_describe_simulation_job\naws_api/robomaker batch_describe_simulation_job","url":"aws_api/robomaker.html#batch_describe_simulation_job"},{"doc":"aws_api/robomaker","title":"cancel_deployment_job","content":"pub fn cancel_deployment_job(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.cancel_deployment_job\naws_api/robomaker cancel_deployment_job","url":"aws_api/robomaker.html#cancel_deployment_job"},{"doc":"aws_api/robomaker","title":"cancel_simulation_job","content":"pub fn cancel_simulation_job(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.cancel_simulation_job\naws_api/robomaker cancel_simulation_job","url":"aws_api/robomaker.html#cancel_simulation_job"},{"doc":"aws_api/robomaker","title":"cancel_simulation_job_batch","content":"pub fn cancel_simulation_job_batch(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.cancel_simulation_job_batch\naws_api/robomaker cancel_simulation_job_batch","url":"aws_api/robomaker.html#cancel_simulation_job_batch"},{"doc":"aws_api/robomaker","title":"cancel_world_export_job","content":"pub fn cancel_world_export_job(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.cancel_world_export_job\naws_api/robomaker cancel_world_export_job","url":"aws_api/robomaker.html#cancel_world_export_job"},{"doc":"aws_api/robomaker","title":"cancel_world_generation_job","content":"pub fn cancel_world_generation_job(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.cancel_world_generation_job\naws_api/robomaker cancel_world_generation_job","url":"aws_api/robomaker.html#cancel_world_generation_job"},{"doc":"aws_api/robomaker","title":"create_deployment_job","content":"pub fn create_deployment_job(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.create_deployment_job\naws_api/robomaker create_deployment_job","url":"aws_api/robomaker.html#create_deployment_job"},{"doc":"aws_api/robomaker","title":"create_fleet","content":"pub fn create_fleet(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.create_fleet\naws_api/robomaker create_fleet","url":"aws_api/robomaker.html#create_fleet"},{"doc":"aws_api/robomaker","title":"create_robot","content":"pub fn create_robot(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.create_robot\naws_api/robomaker create_robot","url":"aws_api/robomaker.html#create_robot"},{"doc":"aws_api/robomaker","title":"create_robot_application","content":"pub fn create_robot_application(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.create_robot_application\naws_api/robomaker create_robot_application","url":"aws_api/robomaker.html#create_robot_application"},{"doc":"aws_api/robomaker","title":"create_robot_application_version","content":"pub fn create_robot_application_version(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.create_robot_application_version\naws_api/robomaker create_robot_application_version","url":"aws_api/robomaker.html#create_robot_application_version"},{"doc":"aws_api/robomaker","title":"create_simulation_application","content":"pub fn create_simulation_application(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.create_simulation_application\naws_api/robomaker create_simulation_application","url":"aws_api/robomaker.html#create_simulation_application"},{"doc":"aws_api/robomaker","title":"create_simulation_application_version","content":"pub fn create_simulation_application_version(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.create_simulation_application_version\naws_api/robomaker create_simulation_application_version","url":"aws_api/robomaker.html#create_simulation_application_version"},{"doc":"aws_api/robomaker","title":"create_simulation_job","content":"pub fn create_simulation_job(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.create_simulation_job\naws_api/robomaker create_simulation_job","url":"aws_api/robomaker.html#create_simulation_job"},{"doc":"aws_api/robomaker","title":"create_world_export_job","content":"pub fn create_world_export_job(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.create_world_export_job\naws_api/robomaker create_world_export_job","url":"aws_api/robomaker.html#create_world_export_job"},{"doc":"aws_api/robomaker","title":"create_world_generation_job","content":"pub fn create_world_generation_job(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.create_world_generation_job\naws_api/robomaker create_world_generation_job","url":"aws_api/robomaker.html#create_world_generation_job"},{"doc":"aws_api/robomaker","title":"create_world_template","content":"pub fn create_world_template(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.create_world_template\naws_api/robomaker create_world_template","url":"aws_api/robomaker.html#create_world_template"},{"doc":"aws_api/robomaker","title":"delete_fleet","content":"pub fn delete_fleet(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.delete_fleet\naws_api/robomaker delete_fleet","url":"aws_api/robomaker.html#delete_fleet"},{"doc":"aws_api/robomaker","title":"delete_robot","content":"pub fn delete_robot(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.delete_robot\naws_api/robomaker delete_robot","url":"aws_api/robomaker.html#delete_robot"},{"doc":"aws_api/robomaker","title":"delete_robot_application","content":"pub fn delete_robot_application(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.delete_robot_application\naws_api/robomaker delete_robot_application","url":"aws_api/robomaker.html#delete_robot_application"},{"doc":"aws_api/robomaker","title":"delete_simulation_application","content":"pub fn delete_simulation_application(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.delete_simulation_application\naws_api/robomaker delete_simulation_application","url":"aws_api/robomaker.html#delete_simulation_application"},{"doc":"aws_api/robomaker","title":"delete_world_template","content":"pub fn delete_world_template(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.delete_world_template\naws_api/robomaker delete_world_template","url":"aws_api/robomaker.html#delete_world_template"},{"doc":"aws_api/robomaker","title":"deregister_robot","content":"pub fn deregister_robot(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.deregister_robot\naws_api/robomaker deregister_robot","url":"aws_api/robomaker.html#deregister_robot"},{"doc":"aws_api/robomaker","title":"describe_deployment_job","content":"pub fn describe_deployment_job(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.describe_deployment_job\naws_api/robomaker describe_deployment_job","url":"aws_api/robomaker.html#describe_deployment_job"},{"doc":"aws_api/robomaker","title":"describe_fleet","content":"pub fn describe_fleet(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.describe_fleet\naws_api/robomaker describe_fleet","url":"aws_api/robomaker.html#describe_fleet"},{"doc":"aws_api/robomaker","title":"describe_robot","content":"pub fn describe_robot(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.describe_robot\naws_api/robomaker describe_robot","url":"aws_api/robomaker.html#describe_robot"},{"doc":"aws_api/robomaker","title":"describe_robot_application","content":"pub fn describe_robot_application(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.describe_robot_application\naws_api/robomaker describe_robot_application","url":"aws_api/robomaker.html#describe_robot_application"},{"doc":"aws_api/robomaker","title":"describe_simulation_application","content":"pub fn describe_simulation_application(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.describe_simulation_application\naws_api/robomaker describe_simulation_application","url":"aws_api/robomaker.html#describe_simulation_application"},{"doc":"aws_api/robomaker","title":"describe_simulation_job","content":"pub fn describe_simulation_job(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.describe_simulation_job\naws_api/robomaker describe_simulation_job","url":"aws_api/robomaker.html#describe_simulation_job"},{"doc":"aws_api/robomaker","title":"describe_simulation_job_batch","content":"pub fn describe_simulation_job_batch(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.describe_simulation_job_batch\naws_api/robomaker describe_simulation_job_batch","url":"aws_api/robomaker.html#describe_simulation_job_batch"},{"doc":"aws_api/robomaker","title":"describe_world","content":"pub fn describe_world(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.describe_world\naws_api/robomaker describe_world","url":"aws_api/robomaker.html#describe_world"},{"doc":"aws_api/robomaker","title":"describe_world_export_job","content":"pub fn describe_world_export_job(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.describe_world_export_job\naws_api/robomaker describe_world_export_job","url":"aws_api/robomaker.html#describe_world_export_job"},{"doc":"aws_api/robomaker","title":"describe_world_generation_job","content":"pub fn describe_world_generation_job(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.describe_world_generation_job\naws_api/robomaker describe_world_generation_job","url":"aws_api/robomaker.html#describe_world_generation_job"},{"doc":"aws_api/robomaker","title":"describe_world_template","content":"pub fn describe_world_template(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.describe_world_template\naws_api/robomaker describe_world_template","url":"aws_api/robomaker.html#describe_world_template"},{"doc":"aws_api/robomaker","title":"get_world_template_body","content":"pub fn get_world_template_body(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.get_world_template_body\naws_api/robomaker get_world_template_body","url":"aws_api/robomaker.html#get_world_template_body"},{"doc":"aws_api/robomaker","title":"list_deployment_jobs","content":"pub fn list_deployment_jobs(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.list_deployment_jobs\naws_api/robomaker list_deployment_jobs","url":"aws_api/robomaker.html#list_deployment_jobs"},{"doc":"aws_api/robomaker","title":"list_fleets","content":"pub fn list_fleets(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.list_fleets\naws_api/robomaker list_fleets","url":"aws_api/robomaker.html#list_fleets"},{"doc":"aws_api/robomaker","title":"list_robot_applications","content":"pub fn list_robot_applications(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.list_robot_applications\naws_api/robomaker list_robot_applications","url":"aws_api/robomaker.html#list_robot_applications"},{"doc":"aws_api/robomaker","title":"list_robots","content":"pub fn list_robots(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.list_robots\naws_api/robomaker list_robots","url":"aws_api/robomaker.html#list_robots"},{"doc":"aws_api/robomaker","title":"list_simulation_applications","content":"pub fn list_simulation_applications(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.list_simulation_applications\naws_api/robomaker list_simulation_applications","url":"aws_api/robomaker.html#list_simulation_applications"},{"doc":"aws_api/robomaker","title":"list_simulation_job_batches","content":"pub fn list_simulation_job_batches(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.list_simulation_job_batches\naws_api/robomaker list_simulation_job_batches","url":"aws_api/robomaker.html#list_simulation_job_batches"},{"doc":"aws_api/robomaker","title":"list_simulation_jobs","content":"pub fn list_simulation_jobs(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.list_simulation_jobs\naws_api/robomaker list_simulation_jobs","url":"aws_api/robomaker.html#list_simulation_jobs"},{"doc":"aws_api/robomaker","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.list_tags_for_resource\naws_api/robomaker list_tags_for_resource","url":"aws_api/robomaker.html#list_tags_for_resource"},{"doc":"aws_api/robomaker","title":"list_world_export_jobs","content":"pub fn list_world_export_jobs(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.list_world_export_jobs\naws_api/robomaker list_world_export_jobs","url":"aws_api/robomaker.html#list_world_export_jobs"},{"doc":"aws_api/robomaker","title":"list_world_generation_jobs","content":"pub fn list_world_generation_jobs(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.list_world_generation_jobs\naws_api/robomaker list_world_generation_jobs","url":"aws_api/robomaker.html#list_world_generation_jobs"},{"doc":"aws_api/robomaker","title":"list_world_templates","content":"pub fn list_world_templates(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.list_world_templates\naws_api/robomaker list_world_templates","url":"aws_api/robomaker.html#list_world_templates"},{"doc":"aws_api/robomaker","title":"list_worlds","content":"pub fn list_worlds(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.list_worlds\naws_api/robomaker list_worlds","url":"aws_api/robomaker.html#list_worlds"},{"doc":"aws_api/robomaker","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/robomaker.new\naws_api/robomaker new","url":"aws_api/robomaker.html#new"},{"doc":"aws_api/robomaker","title":"register_robot","content":"pub fn register_robot(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.register_robot\naws_api/robomaker register_robot","url":"aws_api/robomaker.html#register_robot"},{"doc":"aws_api/robomaker","title":"restart_simulation_job","content":"pub fn restart_simulation_job(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.restart_simulation_job\naws_api/robomaker restart_simulation_job","url":"aws_api/robomaker.html#restart_simulation_job"},{"doc":"aws_api/robomaker","title":"start_simulation_job_batch","content":"pub fn start_simulation_job_batch(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.start_simulation_job_batch\naws_api/robomaker start_simulation_job_batch","url":"aws_api/robomaker.html#start_simulation_job_batch"},{"doc":"aws_api/robomaker","title":"sync_deployment_job","content":"pub fn sync_deployment_job(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.sync_deployment_job\naws_api/robomaker sync_deployment_job","url":"aws_api/robomaker.html#sync_deployment_job"},{"doc":"aws_api/robomaker","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.tag_resource\naws_api/robomaker tag_resource","url":"aws_api/robomaker.html#tag_resource"},{"doc":"aws_api/robomaker","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.untag_resource\naws_api/robomaker untag_resource","url":"aws_api/robomaker.html#untag_resource"},{"doc":"aws_api/robomaker","title":"update_robot_application","content":"pub fn update_robot_application(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.update_robot_application\naws_api/robomaker update_robot_application","url":"aws_api/robomaker.html#update_robot_application"},{"doc":"aws_api/robomaker","title":"update_simulation_application","content":"pub fn update_simulation_application(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.update_simulation_application\naws_api/robomaker update_simulation_application","url":"aws_api/robomaker.html#update_simulation_application"},{"doc":"aws_api/robomaker","title":"update_world_template","content":"pub fn update_world_template(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/robomaker.update_world_template\naws_api/robomaker update_world_template","url":"aws_api/robomaker.html#update_world_template"},{"doc":"aws_api/robomaker","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/robomaker.with_custom_endpoint\naws_api/robomaker with_custom_endpoint","url":"aws_api/robomaker.html#with_custom_endpoint"},{"doc":"aws_api/robomaker","title":"aws_api/robomaker","content":"","url":"aws_api/robomaker.html"},{"doc":"aws_api/rolesanywhere","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/rolesanywhere.Client\naws_api/rolesanywhere Client","url":"aws_api/rolesanywhere.html#Client"},{"doc":"aws_api/rolesanywhere","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rolesanywhere.list_tags_for_resource\naws_api/rolesanywhere list_tags_for_resource","url":"aws_api/rolesanywhere.html#list_tags_for_resource"},{"doc":"aws_api/rolesanywhere","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/rolesanywhere.new\naws_api/rolesanywhere new","url":"aws_api/rolesanywhere.html#new"},{"doc":"aws_api/rolesanywhere","title":"put_notification_settings","content":"pub fn put_notification_settings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rolesanywhere.put_notification_settings\naws_api/rolesanywhere put_notification_settings","url":"aws_api/rolesanywhere.html#put_notification_settings"},{"doc":"aws_api/rolesanywhere","title":"reset_notification_settings","content":"pub fn reset_notification_settings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rolesanywhere.reset_notification_settings\naws_api/rolesanywhere reset_notification_settings","url":"aws_api/rolesanywhere.html#reset_notification_settings"},{"doc":"aws_api/rolesanywhere","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rolesanywhere.tag_resource\naws_api/rolesanywhere tag_resource","url":"aws_api/rolesanywhere.html#tag_resource"},{"doc":"aws_api/rolesanywhere","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rolesanywhere.untag_resource\naws_api/rolesanywhere untag_resource","url":"aws_api/rolesanywhere.html#untag_resource"},{"doc":"aws_api/rolesanywhere","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/rolesanywhere.with_custom_endpoint\naws_api/rolesanywhere with_custom_endpoint","url":"aws_api/rolesanywhere.html#with_custom_endpoint"},{"doc":"aws_api/rolesanywhere","title":"aws_api/rolesanywhere","content":"","url":"aws_api/rolesanywhere.html"},{"doc":"aws_api/route53_recovery_control_config","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/route53_recovery_control_config.Client\naws_api/route53_recovery_control_config Client","url":"aws_api/route53_recovery_control_config.html#Client"},{"doc":"aws_api/route53_recovery_control_config","title":"create_cluster","content":"pub fn create_cluster(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53_recovery_control_config.create_cluster\naws_api/route53_recovery_control_config create_cluster","url":"aws_api/route53_recovery_control_config.html#create_cluster"},{"doc":"aws_api/route53_recovery_control_config","title":"create_control_panel","content":"pub fn create_control_panel(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53_recovery_control_config.create_control_panel\naws_api/route53_recovery_control_config create_control_panel","url":"aws_api/route53_recovery_control_config.html#create_control_panel"},{"doc":"aws_api/route53_recovery_control_config","title":"create_routing_control","content":"pub fn create_routing_control(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53_recovery_control_config.create_routing_control\naws_api/route53_recovery_control_config create_routing_control","url":"aws_api/route53_recovery_control_config.html#create_routing_control"},{"doc":"aws_api/route53_recovery_control_config","title":"create_safety_rule","content":"pub fn create_safety_rule(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53_recovery_control_config.create_safety_rule\naws_api/route53_recovery_control_config create_safety_rule","url":"aws_api/route53_recovery_control_config.html#create_safety_rule"},{"doc":"aws_api/route53_recovery_control_config","title":"delete_cluster","content":"pub fn delete_cluster(\n  client: Client,\n  cluster_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53_recovery_control_config.delete_cluster\naws_api/route53_recovery_control_config delete_cluster","url":"aws_api/route53_recovery_control_config.html#delete_cluster"},{"doc":"aws_api/route53_recovery_control_config","title":"delete_control_panel","content":"pub fn delete_control_panel(\n  client: Client,\n  control_panel_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53_recovery_control_config.delete_control_panel\naws_api/route53_recovery_control_config delete_control_panel","url":"aws_api/route53_recovery_control_config.html#delete_control_panel"},{"doc":"aws_api/route53_recovery_control_config","title":"delete_routing_control","content":"pub fn delete_routing_control(\n  client: Client,\n  routing_control_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53_recovery_control_config.delete_routing_control\naws_api/route53_recovery_control_config delete_routing_control","url":"aws_api/route53_recovery_control_config.html#delete_routing_control"},{"doc":"aws_api/route53_recovery_control_config","title":"delete_safety_rule","content":"pub fn delete_safety_rule(\n  client: Client,\n  safety_rule_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53_recovery_control_config.delete_safety_rule\naws_api/route53_recovery_control_config delete_safety_rule","url":"aws_api/route53_recovery_control_config.html#delete_safety_rule"},{"doc":"aws_api/route53_recovery_control_config","title":"describe_cluster","content":"pub fn describe_cluster(\n  client: Client,\n  cluster_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53_recovery_control_config.describe_cluster\naws_api/route53_recovery_control_config describe_cluster","url":"aws_api/route53_recovery_control_config.html#describe_cluster"},{"doc":"aws_api/route53_recovery_control_config","title":"describe_control_panel","content":"pub fn describe_control_panel(\n  client: Client,\n  control_panel_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53_recovery_control_config.describe_control_panel\naws_api/route53_recovery_control_config describe_control_panel","url":"aws_api/route53_recovery_control_config.html#describe_control_panel"},{"doc":"aws_api/route53_recovery_control_config","title":"describe_routing_control","content":"pub fn describe_routing_control(\n  client: Client,\n  routing_control_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53_recovery_control_config.describe_routing_control\naws_api/route53_recovery_control_config describe_routing_control","url":"aws_api/route53_recovery_control_config.html#describe_routing_control"},{"doc":"aws_api/route53_recovery_control_config","title":"describe_safety_rule","content":"pub fn describe_safety_rule(\n  client: Client,\n  safety_rule_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53_recovery_control_config.describe_safety_rule\naws_api/route53_recovery_control_config describe_safety_rule","url":"aws_api/route53_recovery_control_config.html#describe_safety_rule"},{"doc":"aws_api/route53_recovery_control_config","title":"get_resource_policy","content":"pub fn get_resource_policy(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53_recovery_control_config.get_resource_policy\naws_api/route53_recovery_control_config get_resource_policy","url":"aws_api/route53_recovery_control_config.html#get_resource_policy"},{"doc":"aws_api/route53_recovery_control_config","title":"list_associated_route53_health_checks","content":"pub fn list_associated_route53_health_checks(\n  client: Client,\n  routing_control_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53_recovery_control_config.list_associated_route53_health_checks\naws_api/route53_recovery_control_config list_associated_route53_health_checks","url":"aws_api/route53_recovery_control_config.html#list_associated_route53_health_checks"},{"doc":"aws_api/route53_recovery_control_config","title":"list_clusters","content":"pub fn list_clusters(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53_recovery_control_config.list_clusters\naws_api/route53_recovery_control_config list_clusters","url":"aws_api/route53_recovery_control_config.html#list_clusters"},{"doc":"aws_api/route53_recovery_control_config","title":"list_control_panels","content":"pub fn list_control_panels(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53_recovery_control_config.list_control_panels\naws_api/route53_recovery_control_config list_control_panels","url":"aws_api/route53_recovery_control_config.html#list_control_panels"},{"doc":"aws_api/route53_recovery_control_config","title":"list_routing_controls","content":"pub fn list_routing_controls(\n  client: Client,\n  control_panel_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53_recovery_control_config.list_routing_controls\naws_api/route53_recovery_control_config list_routing_controls","url":"aws_api/route53_recovery_control_config.html#list_routing_controls"},{"doc":"aws_api/route53_recovery_control_config","title":"list_safety_rules","content":"pub fn list_safety_rules(\n  client: Client,\n  control_panel_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53_recovery_control_config.list_safety_rules\naws_api/route53_recovery_control_config list_safety_rules","url":"aws_api/route53_recovery_control_config.html#list_safety_rules"},{"doc":"aws_api/route53_recovery_control_config","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53_recovery_control_config.list_tags_for_resource\naws_api/route53_recovery_control_config list_tags_for_resource","url":"aws_api/route53_recovery_control_config.html#list_tags_for_resource"},{"doc":"aws_api/route53_recovery_control_config","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/route53_recovery_control_config.new\naws_api/route53_recovery_control_config new","url":"aws_api/route53_recovery_control_config.html#new"},{"doc":"aws_api/route53_recovery_control_config","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53_recovery_control_config.tag_resource\naws_api/route53_recovery_control_config tag_resource","url":"aws_api/route53_recovery_control_config.html#tag_resource"},{"doc":"aws_api/route53_recovery_control_config","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53_recovery_control_config.untag_resource\naws_api/route53_recovery_control_config untag_resource","url":"aws_api/route53_recovery_control_config.html#untag_resource"},{"doc":"aws_api/route53_recovery_control_config","title":"update_control_panel","content":"pub fn update_control_panel(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53_recovery_control_config.update_control_panel\naws_api/route53_recovery_control_config update_control_panel","url":"aws_api/route53_recovery_control_config.html#update_control_panel"},{"doc":"aws_api/route53_recovery_control_config","title":"update_routing_control","content":"pub fn update_routing_control(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53_recovery_control_config.update_routing_control\naws_api/route53_recovery_control_config update_routing_control","url":"aws_api/route53_recovery_control_config.html#update_routing_control"},{"doc":"aws_api/route53_recovery_control_config","title":"update_safety_rule","content":"pub fn update_safety_rule(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53_recovery_control_config.update_safety_rule\naws_api/route53_recovery_control_config update_safety_rule","url":"aws_api/route53_recovery_control_config.html#update_safety_rule"},{"doc":"aws_api/route53_recovery_control_config","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/route53_recovery_control_config.with_custom_endpoint\naws_api/route53_recovery_control_config with_custom_endpoint","url":"aws_api/route53_recovery_control_config.html#with_custom_endpoint"},{"doc":"aws_api/route53_recovery_control_config","title":"aws_api/route53_recovery_control_config","content":"","url":"aws_api/route53_recovery_control_config.html"},{"doc":"aws_api/route53resolver","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/route53resolver.Client\naws_api/route53resolver Client","url":"aws_api/route53resolver.html#Client"},{"doc":"aws_api/route53resolver","title":"associate_firewall_rule_group","content":"pub fn associate_firewall_rule_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.associate_firewall_rule_group\naws_api/route53resolver associate_firewall_rule_group","url":"aws_api/route53resolver.html#associate_firewall_rule_group"},{"doc":"aws_api/route53resolver","title":"associate_resolver_endpoint_ip_address","content":"pub fn associate_resolver_endpoint_ip_address(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.associate_resolver_endpoint_ip_address\naws_api/route53resolver associate_resolver_endpoint_ip_address","url":"aws_api/route53resolver.html#associate_resolver_endpoint_ip_address"},{"doc":"aws_api/route53resolver","title":"associate_resolver_query_log_config","content":"pub fn associate_resolver_query_log_config(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.associate_resolver_query_log_config\naws_api/route53resolver associate_resolver_query_log_config","url":"aws_api/route53resolver.html#associate_resolver_query_log_config"},{"doc":"aws_api/route53resolver","title":"associate_resolver_rule","content":"pub fn associate_resolver_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.associate_resolver_rule\naws_api/route53resolver associate_resolver_rule","url":"aws_api/route53resolver.html#associate_resolver_rule"},{"doc":"aws_api/route53resolver","title":"create_firewall_domain_list","content":"pub fn create_firewall_domain_list(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.create_firewall_domain_list\naws_api/route53resolver create_firewall_domain_list","url":"aws_api/route53resolver.html#create_firewall_domain_list"},{"doc":"aws_api/route53resolver","title":"create_firewall_rule","content":"pub fn create_firewall_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.create_firewall_rule\naws_api/route53resolver create_firewall_rule","url":"aws_api/route53resolver.html#create_firewall_rule"},{"doc":"aws_api/route53resolver","title":"create_firewall_rule_group","content":"pub fn create_firewall_rule_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.create_firewall_rule_group\naws_api/route53resolver create_firewall_rule_group","url":"aws_api/route53resolver.html#create_firewall_rule_group"},{"doc":"aws_api/route53resolver","title":"create_outpost_resolver","content":"pub fn create_outpost_resolver(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.create_outpost_resolver\naws_api/route53resolver create_outpost_resolver","url":"aws_api/route53resolver.html#create_outpost_resolver"},{"doc":"aws_api/route53resolver","title":"create_resolver_endpoint","content":"pub fn create_resolver_endpoint(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.create_resolver_endpoint\naws_api/route53resolver create_resolver_endpoint","url":"aws_api/route53resolver.html#create_resolver_endpoint"},{"doc":"aws_api/route53resolver","title":"create_resolver_query_log_config","content":"pub fn create_resolver_query_log_config(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.create_resolver_query_log_config\naws_api/route53resolver create_resolver_query_log_config","url":"aws_api/route53resolver.html#create_resolver_query_log_config"},{"doc":"aws_api/route53resolver","title":"create_resolver_rule","content":"pub fn create_resolver_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.create_resolver_rule\naws_api/route53resolver create_resolver_rule","url":"aws_api/route53resolver.html#create_resolver_rule"},{"doc":"aws_api/route53resolver","title":"delete_firewall_domain_list","content":"pub fn delete_firewall_domain_list(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.delete_firewall_domain_list\naws_api/route53resolver delete_firewall_domain_list","url":"aws_api/route53resolver.html#delete_firewall_domain_list"},{"doc":"aws_api/route53resolver","title":"delete_firewall_rule","content":"pub fn delete_firewall_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.delete_firewall_rule\naws_api/route53resolver delete_firewall_rule","url":"aws_api/route53resolver.html#delete_firewall_rule"},{"doc":"aws_api/route53resolver","title":"delete_firewall_rule_group","content":"pub fn delete_firewall_rule_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.delete_firewall_rule_group\naws_api/route53resolver delete_firewall_rule_group","url":"aws_api/route53resolver.html#delete_firewall_rule_group"},{"doc":"aws_api/route53resolver","title":"delete_outpost_resolver","content":"pub fn delete_outpost_resolver(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.delete_outpost_resolver\naws_api/route53resolver delete_outpost_resolver","url":"aws_api/route53resolver.html#delete_outpost_resolver"},{"doc":"aws_api/route53resolver","title":"delete_resolver_endpoint","content":"pub fn delete_resolver_endpoint(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.delete_resolver_endpoint\naws_api/route53resolver delete_resolver_endpoint","url":"aws_api/route53resolver.html#delete_resolver_endpoint"},{"doc":"aws_api/route53resolver","title":"delete_resolver_query_log_config","content":"pub fn delete_resolver_query_log_config(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.delete_resolver_query_log_config\naws_api/route53resolver delete_resolver_query_log_config","url":"aws_api/route53resolver.html#delete_resolver_query_log_config"},{"doc":"aws_api/route53resolver","title":"delete_resolver_rule","content":"pub fn delete_resolver_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.delete_resolver_rule\naws_api/route53resolver delete_resolver_rule","url":"aws_api/route53resolver.html#delete_resolver_rule"},{"doc":"aws_api/route53resolver","title":"disassociate_firewall_rule_group","content":"pub fn disassociate_firewall_rule_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.disassociate_firewall_rule_group\naws_api/route53resolver disassociate_firewall_rule_group","url":"aws_api/route53resolver.html#disassociate_firewall_rule_group"},{"doc":"aws_api/route53resolver","title":"disassociate_resolver_endpoint_ip_address","content":"pub fn disassociate_resolver_endpoint_ip_address(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.disassociate_resolver_endpoint_ip_address\naws_api/route53resolver disassociate_resolver_endpoint_ip_address","url":"aws_api/route53resolver.html#disassociate_resolver_endpoint_ip_address"},{"doc":"aws_api/route53resolver","title":"disassociate_resolver_query_log_config","content":"pub fn disassociate_resolver_query_log_config(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.disassociate_resolver_query_log_config\naws_api/route53resolver disassociate_resolver_query_log_config","url":"aws_api/route53resolver.html#disassociate_resolver_query_log_config"},{"doc":"aws_api/route53resolver","title":"disassociate_resolver_rule","content":"pub fn disassociate_resolver_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.disassociate_resolver_rule\naws_api/route53resolver disassociate_resolver_rule","url":"aws_api/route53resolver.html#disassociate_resolver_rule"},{"doc":"aws_api/route53resolver","title":"get_firewall_config","content":"pub fn get_firewall_config(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.get_firewall_config\naws_api/route53resolver get_firewall_config","url":"aws_api/route53resolver.html#get_firewall_config"},{"doc":"aws_api/route53resolver","title":"get_firewall_domain_list","content":"pub fn get_firewall_domain_list(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.get_firewall_domain_list\naws_api/route53resolver get_firewall_domain_list","url":"aws_api/route53resolver.html#get_firewall_domain_list"},{"doc":"aws_api/route53resolver","title":"get_firewall_rule_group","content":"pub fn get_firewall_rule_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.get_firewall_rule_group\naws_api/route53resolver get_firewall_rule_group","url":"aws_api/route53resolver.html#get_firewall_rule_group"},{"doc":"aws_api/route53resolver","title":"get_firewall_rule_group_association","content":"pub fn get_firewall_rule_group_association(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.get_firewall_rule_group_association\naws_api/route53resolver get_firewall_rule_group_association","url":"aws_api/route53resolver.html#get_firewall_rule_group_association"},{"doc":"aws_api/route53resolver","title":"get_firewall_rule_group_policy","content":"pub fn get_firewall_rule_group_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.get_firewall_rule_group_policy\naws_api/route53resolver get_firewall_rule_group_policy","url":"aws_api/route53resolver.html#get_firewall_rule_group_policy"},{"doc":"aws_api/route53resolver","title":"get_outpost_resolver","content":"pub fn get_outpost_resolver(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.get_outpost_resolver\naws_api/route53resolver get_outpost_resolver","url":"aws_api/route53resolver.html#get_outpost_resolver"},{"doc":"aws_api/route53resolver","title":"get_resolver_config","content":"pub fn get_resolver_config(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.get_resolver_config\naws_api/route53resolver get_resolver_config","url":"aws_api/route53resolver.html#get_resolver_config"},{"doc":"aws_api/route53resolver","title":"get_resolver_dnssec_config","content":"pub fn get_resolver_dnssec_config(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.get_resolver_dnssec_config\naws_api/route53resolver get_resolver_dnssec_config","url":"aws_api/route53resolver.html#get_resolver_dnssec_config"},{"doc":"aws_api/route53resolver","title":"get_resolver_endpoint","content":"pub fn get_resolver_endpoint(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.get_resolver_endpoint\naws_api/route53resolver get_resolver_endpoint","url":"aws_api/route53resolver.html#get_resolver_endpoint"},{"doc":"aws_api/route53resolver","title":"get_resolver_query_log_config","content":"pub fn get_resolver_query_log_config(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.get_resolver_query_log_config\naws_api/route53resolver get_resolver_query_log_config","url":"aws_api/route53resolver.html#get_resolver_query_log_config"},{"doc":"aws_api/route53resolver","title":"get_resolver_query_log_config_association","content":"pub fn get_resolver_query_log_config_association(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.get_resolver_query_log_config_association\naws_api/route53resolver get_resolver_query_log_config_association","url":"aws_api/route53resolver.html#get_resolver_query_log_config_association"},{"doc":"aws_api/route53resolver","title":"get_resolver_query_log_config_policy","content":"pub fn get_resolver_query_log_config_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.get_resolver_query_log_config_policy\naws_api/route53resolver get_resolver_query_log_config_policy","url":"aws_api/route53resolver.html#get_resolver_query_log_config_policy"},{"doc":"aws_api/route53resolver","title":"get_resolver_rule","content":"pub fn get_resolver_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.get_resolver_rule\naws_api/route53resolver get_resolver_rule","url":"aws_api/route53resolver.html#get_resolver_rule"},{"doc":"aws_api/route53resolver","title":"get_resolver_rule_association","content":"pub fn get_resolver_rule_association(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.get_resolver_rule_association\naws_api/route53resolver get_resolver_rule_association","url":"aws_api/route53resolver.html#get_resolver_rule_association"},{"doc":"aws_api/route53resolver","title":"get_resolver_rule_policy","content":"pub fn get_resolver_rule_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.get_resolver_rule_policy\naws_api/route53resolver get_resolver_rule_policy","url":"aws_api/route53resolver.html#get_resolver_rule_policy"},{"doc":"aws_api/route53resolver","title":"import_firewall_domains","content":"pub fn import_firewall_domains(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.import_firewall_domains\naws_api/route53resolver import_firewall_domains","url":"aws_api/route53resolver.html#import_firewall_domains"},{"doc":"aws_api/route53resolver","title":"list_firewall_configs","content":"pub fn list_firewall_configs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.list_firewall_configs\naws_api/route53resolver list_firewall_configs","url":"aws_api/route53resolver.html#list_firewall_configs"},{"doc":"aws_api/route53resolver","title":"list_firewall_domain_lists","content":"pub fn list_firewall_domain_lists(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.list_firewall_domain_lists\naws_api/route53resolver list_firewall_domain_lists","url":"aws_api/route53resolver.html#list_firewall_domain_lists"},{"doc":"aws_api/route53resolver","title":"list_firewall_domains","content":"pub fn list_firewall_domains(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.list_firewall_domains\naws_api/route53resolver list_firewall_domains","url":"aws_api/route53resolver.html#list_firewall_domains"},{"doc":"aws_api/route53resolver","title":"list_firewall_rule_group_associations","content":"pub fn list_firewall_rule_group_associations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.list_firewall_rule_group_associations\naws_api/route53resolver list_firewall_rule_group_associations","url":"aws_api/route53resolver.html#list_firewall_rule_group_associations"},{"doc":"aws_api/route53resolver","title":"list_firewall_rule_groups","content":"pub fn list_firewall_rule_groups(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.list_firewall_rule_groups\naws_api/route53resolver list_firewall_rule_groups","url":"aws_api/route53resolver.html#list_firewall_rule_groups"},{"doc":"aws_api/route53resolver","title":"list_firewall_rules","content":"pub fn list_firewall_rules(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.list_firewall_rules\naws_api/route53resolver list_firewall_rules","url":"aws_api/route53resolver.html#list_firewall_rules"},{"doc":"aws_api/route53resolver","title":"list_outpost_resolvers","content":"pub fn list_outpost_resolvers(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.list_outpost_resolvers\naws_api/route53resolver list_outpost_resolvers","url":"aws_api/route53resolver.html#list_outpost_resolvers"},{"doc":"aws_api/route53resolver","title":"list_resolver_configs","content":"pub fn list_resolver_configs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.list_resolver_configs\naws_api/route53resolver list_resolver_configs","url":"aws_api/route53resolver.html#list_resolver_configs"},{"doc":"aws_api/route53resolver","title":"list_resolver_dnssec_configs","content":"pub fn list_resolver_dnssec_configs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.list_resolver_dnssec_configs\naws_api/route53resolver list_resolver_dnssec_configs","url":"aws_api/route53resolver.html#list_resolver_dnssec_configs"},{"doc":"aws_api/route53resolver","title":"list_resolver_endpoint_ip_addresses","content":"pub fn list_resolver_endpoint_ip_addresses(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.list_resolver_endpoint_ip_addresses\naws_api/route53resolver list_resolver_endpoint_ip_addresses","url":"aws_api/route53resolver.html#list_resolver_endpoint_ip_addresses"},{"doc":"aws_api/route53resolver","title":"list_resolver_endpoints","content":"pub fn list_resolver_endpoints(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.list_resolver_endpoints\naws_api/route53resolver list_resolver_endpoints","url":"aws_api/route53resolver.html#list_resolver_endpoints"},{"doc":"aws_api/route53resolver","title":"list_resolver_query_log_config_associations","content":"pub fn list_resolver_query_log_config_associations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.list_resolver_query_log_config_associations\naws_api/route53resolver list_resolver_query_log_config_associations","url":"aws_api/route53resolver.html#list_resolver_query_log_config_associations"},{"doc":"aws_api/route53resolver","title":"list_resolver_query_log_configs","content":"pub fn list_resolver_query_log_configs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.list_resolver_query_log_configs\naws_api/route53resolver list_resolver_query_log_configs","url":"aws_api/route53resolver.html#list_resolver_query_log_configs"},{"doc":"aws_api/route53resolver","title":"list_resolver_rule_associations","content":"pub fn list_resolver_rule_associations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.list_resolver_rule_associations\naws_api/route53resolver list_resolver_rule_associations","url":"aws_api/route53resolver.html#list_resolver_rule_associations"},{"doc":"aws_api/route53resolver","title":"list_resolver_rules","content":"pub fn list_resolver_rules(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.list_resolver_rules\naws_api/route53resolver list_resolver_rules","url":"aws_api/route53resolver.html#list_resolver_rules"},{"doc":"aws_api/route53resolver","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.list_tags_for_resource\naws_api/route53resolver list_tags_for_resource","url":"aws_api/route53resolver.html#list_tags_for_resource"},{"doc":"aws_api/route53resolver","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/route53resolver.new\naws_api/route53resolver new","url":"aws_api/route53resolver.html#new"},{"doc":"aws_api/route53resolver","title":"put_firewall_rule_group_policy","content":"pub fn put_firewall_rule_group_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.put_firewall_rule_group_policy\naws_api/route53resolver put_firewall_rule_group_policy","url":"aws_api/route53resolver.html#put_firewall_rule_group_policy"},{"doc":"aws_api/route53resolver","title":"put_resolver_query_log_config_policy","content":"pub fn put_resolver_query_log_config_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.put_resolver_query_log_config_policy\naws_api/route53resolver put_resolver_query_log_config_policy","url":"aws_api/route53resolver.html#put_resolver_query_log_config_policy"},{"doc":"aws_api/route53resolver","title":"put_resolver_rule_policy","content":"pub fn put_resolver_rule_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.put_resolver_rule_policy\naws_api/route53resolver put_resolver_rule_policy","url":"aws_api/route53resolver.html#put_resolver_rule_policy"},{"doc":"aws_api/route53resolver","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.tag_resource\naws_api/route53resolver tag_resource","url":"aws_api/route53resolver.html#tag_resource"},{"doc":"aws_api/route53resolver","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.untag_resource\naws_api/route53resolver untag_resource","url":"aws_api/route53resolver.html#untag_resource"},{"doc":"aws_api/route53resolver","title":"update_firewall_config","content":"pub fn update_firewall_config(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.update_firewall_config\naws_api/route53resolver update_firewall_config","url":"aws_api/route53resolver.html#update_firewall_config"},{"doc":"aws_api/route53resolver","title":"update_firewall_domains","content":"pub fn update_firewall_domains(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.update_firewall_domains\naws_api/route53resolver update_firewall_domains","url":"aws_api/route53resolver.html#update_firewall_domains"},{"doc":"aws_api/route53resolver","title":"update_firewall_rule","content":"pub fn update_firewall_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.update_firewall_rule\naws_api/route53resolver update_firewall_rule","url":"aws_api/route53resolver.html#update_firewall_rule"},{"doc":"aws_api/route53resolver","title":"update_firewall_rule_group_association","content":"pub fn update_firewall_rule_group_association(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.update_firewall_rule_group_association\naws_api/route53resolver update_firewall_rule_group_association","url":"aws_api/route53resolver.html#update_firewall_rule_group_association"},{"doc":"aws_api/route53resolver","title":"update_outpost_resolver","content":"pub fn update_outpost_resolver(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.update_outpost_resolver\naws_api/route53resolver update_outpost_resolver","url":"aws_api/route53resolver.html#update_outpost_resolver"},{"doc":"aws_api/route53resolver","title":"update_resolver_config","content":"pub fn update_resolver_config(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.update_resolver_config\naws_api/route53resolver update_resolver_config","url":"aws_api/route53resolver.html#update_resolver_config"},{"doc":"aws_api/route53resolver","title":"update_resolver_dnssec_config","content":"pub fn update_resolver_dnssec_config(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.update_resolver_dnssec_config\naws_api/route53resolver update_resolver_dnssec_config","url":"aws_api/route53resolver.html#update_resolver_dnssec_config"},{"doc":"aws_api/route53resolver","title":"update_resolver_endpoint","content":"pub fn update_resolver_endpoint(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.update_resolver_endpoint\naws_api/route53resolver update_resolver_endpoint","url":"aws_api/route53resolver.html#update_resolver_endpoint"},{"doc":"aws_api/route53resolver","title":"update_resolver_rule","content":"pub fn update_resolver_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route53resolver.update_resolver_rule\naws_api/route53resolver update_resolver_rule","url":"aws_api/route53resolver.html#update_resolver_rule"},{"doc":"aws_api/route53resolver","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/route53resolver.with_custom_endpoint\naws_api/route53resolver with_custom_endpoint","url":"aws_api/route53resolver.html#with_custom_endpoint"},{"doc":"aws_api/route53resolver","title":"aws_api/route53resolver","content":"","url":"aws_api/route53resolver.html"},{"doc":"aws_api/route_53","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/route_53.Client\naws_api/route_53 Client","url":"aws_api/route_53.html#Client"},{"doc":"aws_api/route_53","title":"activate_key_signing_key","content":"pub fn activate_key_signing_key(\n  client: Client,\n  hosted_zone_id: String,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.activate_key_signing_key\naws_api/route_53 activate_key_signing_key","url":"aws_api/route_53.html#activate_key_signing_key"},{"doc":"aws_api/route_53","title":"associate_vpc_with_hosted_zone","content":"pub fn associate_vpc_with_hosted_zone(\n  client: Client,\n  hosted_zone_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.associate_vpc_with_hosted_zone\naws_api/route_53 associate_vpc_with_hosted_zone","url":"aws_api/route_53.html#associate_vpc_with_hosted_zone"},{"doc":"aws_api/route_53","title":"change_cidr_collection","content":"pub fn change_cidr_collection(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.change_cidr_collection\naws_api/route_53 change_cidr_collection","url":"aws_api/route_53.html#change_cidr_collection"},{"doc":"aws_api/route_53","title":"change_resource_record_sets","content":"pub fn change_resource_record_sets(\n  client: Client,\n  hosted_zone_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.change_resource_record_sets\naws_api/route_53 change_resource_record_sets","url":"aws_api/route_53.html#change_resource_record_sets"},{"doc":"aws_api/route_53","title":"change_tags_for_resource","content":"pub fn change_tags_for_resource(\n  client: Client,\n  resource_type: String,\n  resource_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.change_tags_for_resource\naws_api/route_53 change_tags_for_resource","url":"aws_api/route_53.html#change_tags_for_resource"},{"doc":"aws_api/route_53","title":"create_cidr_collection","content":"pub fn create_cidr_collection(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.create_cidr_collection\naws_api/route_53 create_cidr_collection","url":"aws_api/route_53.html#create_cidr_collection"},{"doc":"aws_api/route_53","title":"create_health_check","content":"pub fn create_health_check(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.create_health_check\naws_api/route_53 create_health_check","url":"aws_api/route_53.html#create_health_check"},{"doc":"aws_api/route_53","title":"create_hosted_zone","content":"pub fn create_hosted_zone(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.create_hosted_zone\naws_api/route_53 create_hosted_zone","url":"aws_api/route_53.html#create_hosted_zone"},{"doc":"aws_api/route_53","title":"create_key_signing_key","content":"pub fn create_key_signing_key(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.create_key_signing_key\naws_api/route_53 create_key_signing_key","url":"aws_api/route_53.html#create_key_signing_key"},{"doc":"aws_api/route_53","title":"create_query_logging_config","content":"pub fn create_query_logging_config(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.create_query_logging_config\naws_api/route_53 create_query_logging_config","url":"aws_api/route_53.html#create_query_logging_config"},{"doc":"aws_api/route_53","title":"create_reusable_delegation_set","content":"pub fn create_reusable_delegation_set(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.create_reusable_delegation_set\naws_api/route_53 create_reusable_delegation_set","url":"aws_api/route_53.html#create_reusable_delegation_set"},{"doc":"aws_api/route_53","title":"create_traffic_policy","content":"pub fn create_traffic_policy(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.create_traffic_policy\naws_api/route_53 create_traffic_policy","url":"aws_api/route_53.html#create_traffic_policy"},{"doc":"aws_api/route_53","title":"create_traffic_policy_instance","content":"pub fn create_traffic_policy_instance(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.create_traffic_policy_instance\naws_api/route_53 create_traffic_policy_instance","url":"aws_api/route_53.html#create_traffic_policy_instance"},{"doc":"aws_api/route_53","title":"create_traffic_policy_version","content":"pub fn create_traffic_policy_version(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.create_traffic_policy_version\naws_api/route_53 create_traffic_policy_version","url":"aws_api/route_53.html#create_traffic_policy_version"},{"doc":"aws_api/route_53","title":"create_vpc_association_authorization","content":"pub fn create_vpc_association_authorization(\n  client: Client,\n  hosted_zone_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.create_vpc_association_authorization\naws_api/route_53 create_vpc_association_authorization","url":"aws_api/route_53.html#create_vpc_association_authorization"},{"doc":"aws_api/route_53","title":"deactivate_key_signing_key","content":"pub fn deactivate_key_signing_key(\n  client: Client,\n  hosted_zone_id: String,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.deactivate_key_signing_key\naws_api/route_53 deactivate_key_signing_key","url":"aws_api/route_53.html#deactivate_key_signing_key"},{"doc":"aws_api/route_53","title":"delete_cidr_collection","content":"pub fn delete_cidr_collection(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.delete_cidr_collection\naws_api/route_53 delete_cidr_collection","url":"aws_api/route_53.html#delete_cidr_collection"},{"doc":"aws_api/route_53","title":"delete_health_check","content":"pub fn delete_health_check(\n  client: Client,\n  health_check_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.delete_health_check\naws_api/route_53 delete_health_check","url":"aws_api/route_53.html#delete_health_check"},{"doc":"aws_api/route_53","title":"delete_hosted_zone","content":"pub fn delete_hosted_zone(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.delete_hosted_zone\naws_api/route_53 delete_hosted_zone","url":"aws_api/route_53.html#delete_hosted_zone"},{"doc":"aws_api/route_53","title":"delete_key_signing_key","content":"pub fn delete_key_signing_key(\n  client: Client,\n  hosted_zone_id: String,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.delete_key_signing_key\naws_api/route_53 delete_key_signing_key","url":"aws_api/route_53.html#delete_key_signing_key"},{"doc":"aws_api/route_53","title":"delete_query_logging_config","content":"pub fn delete_query_logging_config(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.delete_query_logging_config\naws_api/route_53 delete_query_logging_config","url":"aws_api/route_53.html#delete_query_logging_config"},{"doc":"aws_api/route_53","title":"delete_reusable_delegation_set","content":"pub fn delete_reusable_delegation_set(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.delete_reusable_delegation_set\naws_api/route_53 delete_reusable_delegation_set","url":"aws_api/route_53.html#delete_reusable_delegation_set"},{"doc":"aws_api/route_53","title":"delete_traffic_policy","content":"pub fn delete_traffic_policy(\n  client: Client,\n  id: String,\n  version: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.delete_traffic_policy\naws_api/route_53 delete_traffic_policy","url":"aws_api/route_53.html#delete_traffic_policy"},{"doc":"aws_api/route_53","title":"delete_traffic_policy_instance","content":"pub fn delete_traffic_policy_instance(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.delete_traffic_policy_instance\naws_api/route_53 delete_traffic_policy_instance","url":"aws_api/route_53.html#delete_traffic_policy_instance"},{"doc":"aws_api/route_53","title":"delete_vpc_association_authorization","content":"pub fn delete_vpc_association_authorization(\n  client: Client,\n  hosted_zone_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.delete_vpc_association_authorization\naws_api/route_53 delete_vpc_association_authorization","url":"aws_api/route_53.html#delete_vpc_association_authorization"},{"doc":"aws_api/route_53","title":"disable_hosted_zone_dnssec","content":"pub fn disable_hosted_zone_dnssec(\n  client: Client,\n  hosted_zone_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.disable_hosted_zone_dnssec\naws_api/route_53 disable_hosted_zone_dnssec","url":"aws_api/route_53.html#disable_hosted_zone_dnssec"},{"doc":"aws_api/route_53","title":"disassociate_vpc_from_hosted_zone","content":"pub fn disassociate_vpc_from_hosted_zone(\n  client: Client,\n  hosted_zone_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.disassociate_vpc_from_hosted_zone\naws_api/route_53 disassociate_vpc_from_hosted_zone","url":"aws_api/route_53.html#disassociate_vpc_from_hosted_zone"},{"doc":"aws_api/route_53","title":"enable_hosted_zone_dnssec","content":"pub fn enable_hosted_zone_dnssec(\n  client: Client,\n  hosted_zone_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.enable_hosted_zone_dnssec\naws_api/route_53 enable_hosted_zone_dnssec","url":"aws_api/route_53.html#enable_hosted_zone_dnssec"},{"doc":"aws_api/route_53","title":"get_account_limit","content":"pub fn get_account_limit(\n  client: Client,\n  type_: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.get_account_limit\naws_api/route_53 get_account_limit","url":"aws_api/route_53.html#get_account_limit"},{"doc":"aws_api/route_53","title":"get_change","content":"pub fn get_change(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.get_change\naws_api/route_53 get_change","url":"aws_api/route_53.html#get_change"},{"doc":"aws_api/route_53","title":"get_checker_ip_ranges","content":"pub fn get_checker_ip_ranges(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.get_checker_ip_ranges\naws_api/route_53 get_checker_ip_ranges","url":"aws_api/route_53.html#get_checker_ip_ranges"},{"doc":"aws_api/route_53","title":"get_dnssec","content":"pub fn get_dnssec(\n  client: Client,\n  hosted_zone_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.get_dnssec\naws_api/route_53 get_dnssec","url":"aws_api/route_53.html#get_dnssec"},{"doc":"aws_api/route_53","title":"get_geo_location","content":"pub fn get_geo_location(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.get_geo_location\naws_api/route_53 get_geo_location","url":"aws_api/route_53.html#get_geo_location"},{"doc":"aws_api/route_53","title":"get_health_check","content":"pub fn get_health_check(\n  client: Client,\n  health_check_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.get_health_check\naws_api/route_53 get_health_check","url":"aws_api/route_53.html#get_health_check"},{"doc":"aws_api/route_53","title":"get_health_check_count","content":"pub fn get_health_check_count(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.get_health_check_count\naws_api/route_53 get_health_check_count","url":"aws_api/route_53.html#get_health_check_count"},{"doc":"aws_api/route_53","title":"get_health_check_last_failure_reason","content":"pub fn get_health_check_last_failure_reason(\n  client: Client,\n  health_check_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.get_health_check_last_failure_reason\naws_api/route_53 get_health_check_last_failure_reason","url":"aws_api/route_53.html#get_health_check_last_failure_reason"},{"doc":"aws_api/route_53","title":"get_health_check_status","content":"pub fn get_health_check_status(\n  client: Client,\n  health_check_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.get_health_check_status\naws_api/route_53 get_health_check_status","url":"aws_api/route_53.html#get_health_check_status"},{"doc":"aws_api/route_53","title":"get_hosted_zone","content":"pub fn get_hosted_zone(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.get_hosted_zone\naws_api/route_53 get_hosted_zone","url":"aws_api/route_53.html#get_hosted_zone"},{"doc":"aws_api/route_53","title":"get_hosted_zone_count","content":"pub fn get_hosted_zone_count(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.get_hosted_zone_count\naws_api/route_53 get_hosted_zone_count","url":"aws_api/route_53.html#get_hosted_zone_count"},{"doc":"aws_api/route_53","title":"get_hosted_zone_limit","content":"pub fn get_hosted_zone_limit(\n  client: Client,\n  hosted_zone_id: String,\n  type_: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.get_hosted_zone_limit\naws_api/route_53 get_hosted_zone_limit","url":"aws_api/route_53.html#get_hosted_zone_limit"},{"doc":"aws_api/route_53","title":"get_query_logging_config","content":"pub fn get_query_logging_config(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.get_query_logging_config\naws_api/route_53 get_query_logging_config","url":"aws_api/route_53.html#get_query_logging_config"},{"doc":"aws_api/route_53","title":"get_reusable_delegation_set","content":"pub fn get_reusable_delegation_set(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.get_reusable_delegation_set\naws_api/route_53 get_reusable_delegation_set","url":"aws_api/route_53.html#get_reusable_delegation_set"},{"doc":"aws_api/route_53","title":"get_reusable_delegation_set_limit","content":"pub fn get_reusable_delegation_set_limit(\n  client: Client,\n  delegation_set_id: String,\n  type_: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.get_reusable_delegation_set_limit\naws_api/route_53 get_reusable_delegation_set_limit","url":"aws_api/route_53.html#get_reusable_delegation_set_limit"},{"doc":"aws_api/route_53","title":"get_traffic_policy","content":"pub fn get_traffic_policy(\n  client: Client,\n  id: String,\n  version: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.get_traffic_policy\naws_api/route_53 get_traffic_policy","url":"aws_api/route_53.html#get_traffic_policy"},{"doc":"aws_api/route_53","title":"get_traffic_policy_instance","content":"pub fn get_traffic_policy_instance(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.get_traffic_policy_instance\naws_api/route_53 get_traffic_policy_instance","url":"aws_api/route_53.html#get_traffic_policy_instance"},{"doc":"aws_api/route_53","title":"get_traffic_policy_instance_count","content":"pub fn get_traffic_policy_instance_count(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.get_traffic_policy_instance_count\naws_api/route_53 get_traffic_policy_instance_count","url":"aws_api/route_53.html#get_traffic_policy_instance_count"},{"doc":"aws_api/route_53","title":"list_cidr_blocks","content":"pub fn list_cidr_blocks(\n  client: Client,\n  collection_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.list_cidr_blocks\naws_api/route_53 list_cidr_blocks","url":"aws_api/route_53.html#list_cidr_blocks"},{"doc":"aws_api/route_53","title":"list_cidr_collections","content":"pub fn list_cidr_collections(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.list_cidr_collections\naws_api/route_53 list_cidr_collections","url":"aws_api/route_53.html#list_cidr_collections"},{"doc":"aws_api/route_53","title":"list_cidr_locations","content":"pub fn list_cidr_locations(\n  client: Client,\n  collection_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.list_cidr_locations\naws_api/route_53 list_cidr_locations","url":"aws_api/route_53.html#list_cidr_locations"},{"doc":"aws_api/route_53","title":"list_geo_locations","content":"pub fn list_geo_locations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.list_geo_locations\naws_api/route_53 list_geo_locations","url":"aws_api/route_53.html#list_geo_locations"},{"doc":"aws_api/route_53","title":"list_health_checks","content":"pub fn list_health_checks(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.list_health_checks\naws_api/route_53 list_health_checks","url":"aws_api/route_53.html#list_health_checks"},{"doc":"aws_api/route_53","title":"list_hosted_zones","content":"pub fn list_hosted_zones(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.list_hosted_zones\naws_api/route_53 list_hosted_zones","url":"aws_api/route_53.html#list_hosted_zones"},{"doc":"aws_api/route_53","title":"list_hosted_zones_by_name","content":"pub fn list_hosted_zones_by_name(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.list_hosted_zones_by_name\naws_api/route_53 list_hosted_zones_by_name","url":"aws_api/route_53.html#list_hosted_zones_by_name"},{"doc":"aws_api/route_53","title":"list_hosted_zones_by_vpc","content":"pub fn list_hosted_zones_by_vpc(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.list_hosted_zones_by_vpc\naws_api/route_53 list_hosted_zones_by_vpc","url":"aws_api/route_53.html#list_hosted_zones_by_vpc"},{"doc":"aws_api/route_53","title":"list_query_logging_configs","content":"pub fn list_query_logging_configs(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.list_query_logging_configs\naws_api/route_53 list_query_logging_configs","url":"aws_api/route_53.html#list_query_logging_configs"},{"doc":"aws_api/route_53","title":"list_resource_record_sets","content":"pub fn list_resource_record_sets(\n  client: Client,\n  hosted_zone_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.list_resource_record_sets\naws_api/route_53 list_resource_record_sets","url":"aws_api/route_53.html#list_resource_record_sets"},{"doc":"aws_api/route_53","title":"list_reusable_delegation_sets","content":"pub fn list_reusable_delegation_sets(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.list_reusable_delegation_sets\naws_api/route_53 list_reusable_delegation_sets","url":"aws_api/route_53.html#list_reusable_delegation_sets"},{"doc":"aws_api/route_53","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_type: String,\n  resource_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.list_tags_for_resource\naws_api/route_53 list_tags_for_resource","url":"aws_api/route_53.html#list_tags_for_resource"},{"doc":"aws_api/route_53","title":"list_tags_for_resources","content":"pub fn list_tags_for_resources(\n  client: Client,\n  resource_type: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.list_tags_for_resources\naws_api/route_53 list_tags_for_resources","url":"aws_api/route_53.html#list_tags_for_resources"},{"doc":"aws_api/route_53","title":"list_traffic_policies","content":"pub fn list_traffic_policies(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.list_traffic_policies\naws_api/route_53 list_traffic_policies","url":"aws_api/route_53.html#list_traffic_policies"},{"doc":"aws_api/route_53","title":"list_traffic_policy_instances","content":"pub fn list_traffic_policy_instances(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.list_traffic_policy_instances\naws_api/route_53 list_traffic_policy_instances","url":"aws_api/route_53.html#list_traffic_policy_instances"},{"doc":"aws_api/route_53","title":"list_traffic_policy_instances_by_hosted_zone","content":"pub fn list_traffic_policy_instances_by_hosted_zone(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.list_traffic_policy_instances_by_hosted_zone\naws_api/route_53 list_traffic_policy_instances_by_hosted_zone","url":"aws_api/route_53.html#list_traffic_policy_instances_by_hosted_zone"},{"doc":"aws_api/route_53","title":"list_traffic_policy_instances_by_policy","content":"pub fn list_traffic_policy_instances_by_policy(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.list_traffic_policy_instances_by_policy\naws_api/route_53 list_traffic_policy_instances_by_policy","url":"aws_api/route_53.html#list_traffic_policy_instances_by_policy"},{"doc":"aws_api/route_53","title":"list_traffic_policy_versions","content":"pub fn list_traffic_policy_versions(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.list_traffic_policy_versions\naws_api/route_53 list_traffic_policy_versions","url":"aws_api/route_53.html#list_traffic_policy_versions"},{"doc":"aws_api/route_53","title":"list_vpc_association_authorizations","content":"pub fn list_vpc_association_authorizations(\n  client: Client,\n  hosted_zone_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.list_vpc_association_authorizations\naws_api/route_53 list_vpc_association_authorizations","url":"aws_api/route_53.html#list_vpc_association_authorizations"},{"doc":"aws_api/route_53","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/route_53.new\naws_api/route_53 new","url":"aws_api/route_53.html#new"},{"doc":"aws_api/route_53","title":"test_dns_answer","content":"pub fn test_dns_answer(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.test_dns_answer\naws_api/route_53 test_dns_answer","url":"aws_api/route_53.html#test_dns_answer"},{"doc":"aws_api/route_53","title":"update_health_check","content":"pub fn update_health_check(\n  client: Client,\n  health_check_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.update_health_check\naws_api/route_53 update_health_check","url":"aws_api/route_53.html#update_health_check"},{"doc":"aws_api/route_53","title":"update_hosted_zone_comment","content":"pub fn update_hosted_zone_comment(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.update_hosted_zone_comment\naws_api/route_53 update_hosted_zone_comment","url":"aws_api/route_53.html#update_hosted_zone_comment"},{"doc":"aws_api/route_53","title":"update_traffic_policy_comment","content":"pub fn update_traffic_policy_comment(\n  client: Client,\n  id: String,\n  version: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.update_traffic_policy_comment\naws_api/route_53 update_traffic_policy_comment","url":"aws_api/route_53.html#update_traffic_policy_comment"},{"doc":"aws_api/route_53","title":"update_traffic_policy_instance","content":"pub fn update_traffic_policy_instance(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53.update_traffic_policy_instance\naws_api/route_53 update_traffic_policy_instance","url":"aws_api/route_53.html#update_traffic_policy_instance"},{"doc":"aws_api/route_53","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/route_53.with_custom_endpoint\naws_api/route_53 with_custom_endpoint","url":"aws_api/route_53.html#with_custom_endpoint"},{"doc":"aws_api/route_53","title":"aws_api/route_53","content":"","url":"aws_api/route_53.html"},{"doc":"aws_api/route_53_domains","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/route_53_domains.Client\naws_api/route_53_domains Client","url":"aws_api/route_53_domains.html#Client"},{"doc":"aws_api/route_53_domains","title":"accept_domain_transfer_from_another_aws_account","content":"pub fn accept_domain_transfer_from_another_aws_account(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53_domains.accept_domain_transfer_from_another_aws_account\naws_api/route_53_domains accept_domain_transfer_from_another_aws_account","url":"aws_api/route_53_domains.html#accept_domain_transfer_from_another_aws_account"},{"doc":"aws_api/route_53_domains","title":"associate_delegation_signer_to_domain","content":"pub fn associate_delegation_signer_to_domain(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53_domains.associate_delegation_signer_to_domain\naws_api/route_53_domains associate_delegation_signer_to_domain","url":"aws_api/route_53_domains.html#associate_delegation_signer_to_domain"},{"doc":"aws_api/route_53_domains","title":"cancel_domain_transfer_to_another_aws_account","content":"pub fn cancel_domain_transfer_to_another_aws_account(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53_domains.cancel_domain_transfer_to_another_aws_account\naws_api/route_53_domains cancel_domain_transfer_to_another_aws_account","url":"aws_api/route_53_domains.html#cancel_domain_transfer_to_another_aws_account"},{"doc":"aws_api/route_53_domains","title":"check_domain_availability","content":"pub fn check_domain_availability(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53_domains.check_domain_availability\naws_api/route_53_domains check_domain_availability","url":"aws_api/route_53_domains.html#check_domain_availability"},{"doc":"aws_api/route_53_domains","title":"check_domain_transferability","content":"pub fn check_domain_transferability(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53_domains.check_domain_transferability\naws_api/route_53_domains check_domain_transferability","url":"aws_api/route_53_domains.html#check_domain_transferability"},{"doc":"aws_api/route_53_domains","title":"delete_domain","content":"pub fn delete_domain(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53_domains.delete_domain\naws_api/route_53_domains delete_domain","url":"aws_api/route_53_domains.html#delete_domain"},{"doc":"aws_api/route_53_domains","title":"delete_tags_for_domain","content":"pub fn delete_tags_for_domain(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53_domains.delete_tags_for_domain\naws_api/route_53_domains delete_tags_for_domain","url":"aws_api/route_53_domains.html#delete_tags_for_domain"},{"doc":"aws_api/route_53_domains","title":"disable_domain_auto_renew","content":"pub fn disable_domain_auto_renew(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53_domains.disable_domain_auto_renew\naws_api/route_53_domains disable_domain_auto_renew","url":"aws_api/route_53_domains.html#disable_domain_auto_renew"},{"doc":"aws_api/route_53_domains","title":"disable_domain_transfer_lock","content":"pub fn disable_domain_transfer_lock(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53_domains.disable_domain_transfer_lock\naws_api/route_53_domains disable_domain_transfer_lock","url":"aws_api/route_53_domains.html#disable_domain_transfer_lock"},{"doc":"aws_api/route_53_domains","title":"disassociate_delegation_signer_from_domain","content":"pub fn disassociate_delegation_signer_from_domain(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53_domains.disassociate_delegation_signer_from_domain\naws_api/route_53_domains disassociate_delegation_signer_from_domain","url":"aws_api/route_53_domains.html#disassociate_delegation_signer_from_domain"},{"doc":"aws_api/route_53_domains","title":"enable_domain_auto_renew","content":"pub fn enable_domain_auto_renew(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53_domains.enable_domain_auto_renew\naws_api/route_53_domains enable_domain_auto_renew","url":"aws_api/route_53_domains.html#enable_domain_auto_renew"},{"doc":"aws_api/route_53_domains","title":"enable_domain_transfer_lock","content":"pub fn enable_domain_transfer_lock(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53_domains.enable_domain_transfer_lock\naws_api/route_53_domains enable_domain_transfer_lock","url":"aws_api/route_53_domains.html#enable_domain_transfer_lock"},{"doc":"aws_api/route_53_domains","title":"get_contact_reachability_status","content":"pub fn get_contact_reachability_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53_domains.get_contact_reachability_status\naws_api/route_53_domains get_contact_reachability_status","url":"aws_api/route_53_domains.html#get_contact_reachability_status"},{"doc":"aws_api/route_53_domains","title":"get_domain_detail","content":"pub fn get_domain_detail(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53_domains.get_domain_detail\naws_api/route_53_domains get_domain_detail","url":"aws_api/route_53_domains.html#get_domain_detail"},{"doc":"aws_api/route_53_domains","title":"get_domain_suggestions","content":"pub fn get_domain_suggestions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53_domains.get_domain_suggestions\naws_api/route_53_domains get_domain_suggestions","url":"aws_api/route_53_domains.html#get_domain_suggestions"},{"doc":"aws_api/route_53_domains","title":"get_operation_detail","content":"pub fn get_operation_detail(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53_domains.get_operation_detail\naws_api/route_53_domains get_operation_detail","url":"aws_api/route_53_domains.html#get_operation_detail"},{"doc":"aws_api/route_53_domains","title":"list_domains","content":"pub fn list_domains(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53_domains.list_domains\naws_api/route_53_domains list_domains","url":"aws_api/route_53_domains.html#list_domains"},{"doc":"aws_api/route_53_domains","title":"list_operations","content":"pub fn list_operations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53_domains.list_operations\naws_api/route_53_domains list_operations","url":"aws_api/route_53_domains.html#list_operations"},{"doc":"aws_api/route_53_domains","title":"list_prices","content":"pub fn list_prices(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53_domains.list_prices\naws_api/route_53_domains list_prices","url":"aws_api/route_53_domains.html#list_prices"},{"doc":"aws_api/route_53_domains","title":"list_tags_for_domain","content":"pub fn list_tags_for_domain(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53_domains.list_tags_for_domain\naws_api/route_53_domains list_tags_for_domain","url":"aws_api/route_53_domains.html#list_tags_for_domain"},{"doc":"aws_api/route_53_domains","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/route_53_domains.new\naws_api/route_53_domains new","url":"aws_api/route_53_domains.html#new"},{"doc":"aws_api/route_53_domains","title":"push_domain","content":"pub fn push_domain(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53_domains.push_domain\naws_api/route_53_domains push_domain","url":"aws_api/route_53_domains.html#push_domain"},{"doc":"aws_api/route_53_domains","title":"register_domain","content":"pub fn register_domain(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53_domains.register_domain\naws_api/route_53_domains register_domain","url":"aws_api/route_53_domains.html#register_domain"},{"doc":"aws_api/route_53_domains","title":"reject_domain_transfer_from_another_aws_account","content":"pub fn reject_domain_transfer_from_another_aws_account(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53_domains.reject_domain_transfer_from_another_aws_account\naws_api/route_53_domains reject_domain_transfer_from_another_aws_account","url":"aws_api/route_53_domains.html#reject_domain_transfer_from_another_aws_account"},{"doc":"aws_api/route_53_domains","title":"renew_domain","content":"pub fn renew_domain(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53_domains.renew_domain\naws_api/route_53_domains renew_domain","url":"aws_api/route_53_domains.html#renew_domain"},{"doc":"aws_api/route_53_domains","title":"resend_contact_reachability_email","content":"pub fn resend_contact_reachability_email(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53_domains.resend_contact_reachability_email\naws_api/route_53_domains resend_contact_reachability_email","url":"aws_api/route_53_domains.html#resend_contact_reachability_email"},{"doc":"aws_api/route_53_domains","title":"resend_operation_authorization","content":"pub fn resend_operation_authorization(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53_domains.resend_operation_authorization\naws_api/route_53_domains resend_operation_authorization","url":"aws_api/route_53_domains.html#resend_operation_authorization"},{"doc":"aws_api/route_53_domains","title":"retrieve_domain_auth_code","content":"pub fn retrieve_domain_auth_code(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53_domains.retrieve_domain_auth_code\naws_api/route_53_domains retrieve_domain_auth_code","url":"aws_api/route_53_domains.html#retrieve_domain_auth_code"},{"doc":"aws_api/route_53_domains","title":"transfer_domain","content":"pub fn transfer_domain(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53_domains.transfer_domain\naws_api/route_53_domains transfer_domain","url":"aws_api/route_53_domains.html#transfer_domain"},{"doc":"aws_api/route_53_domains","title":"transfer_domain_to_another_aws_account","content":"pub fn transfer_domain_to_another_aws_account(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53_domains.transfer_domain_to_another_aws_account\naws_api/route_53_domains transfer_domain_to_another_aws_account","url":"aws_api/route_53_domains.html#transfer_domain_to_another_aws_account"},{"doc":"aws_api/route_53_domains","title":"update_domain_contact","content":"pub fn update_domain_contact(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53_domains.update_domain_contact\naws_api/route_53_domains update_domain_contact","url":"aws_api/route_53_domains.html#update_domain_contact"},{"doc":"aws_api/route_53_domains","title":"update_domain_contact_privacy","content":"pub fn update_domain_contact_privacy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53_domains.update_domain_contact_privacy\naws_api/route_53_domains update_domain_contact_privacy","url":"aws_api/route_53_domains.html#update_domain_contact_privacy"},{"doc":"aws_api/route_53_domains","title":"update_domain_nameservers","content":"pub fn update_domain_nameservers(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53_domains.update_domain_nameservers\naws_api/route_53_domains update_domain_nameservers","url":"aws_api/route_53_domains.html#update_domain_nameservers"},{"doc":"aws_api/route_53_domains","title":"update_tags_for_domain","content":"pub fn update_tags_for_domain(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53_domains.update_tags_for_domain\naws_api/route_53_domains update_tags_for_domain","url":"aws_api/route_53_domains.html#update_tags_for_domain"},{"doc":"aws_api/route_53_domains","title":"view_billing","content":"pub fn view_billing(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/route_53_domains.view_billing\naws_api/route_53_domains view_billing","url":"aws_api/route_53_domains.html#view_billing"},{"doc":"aws_api/route_53_domains","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/route_53_domains.with_custom_endpoint\naws_api/route_53_domains with_custom_endpoint","url":"aws_api/route_53_domains.html#with_custom_endpoint"},{"doc":"aws_api/route_53_domains","title":"aws_api/route_53_domains","content":"","url":"aws_api/route_53_domains.html"},{"doc":"aws_api/rum","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/rum.Client\naws_api/rum Client","url":"aws_api/rum.html#Client"},{"doc":"aws_api/rum","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rum.list_tags_for_resource\naws_api/rum list_tags_for_resource","url":"aws_api/rum.html#list_tags_for_resource"},{"doc":"aws_api/rum","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/rum.new\naws_api/rum new","url":"aws_api/rum.html#new"},{"doc":"aws_api/rum","title":"put_rum_events","content":"pub fn put_rum_events(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rum.put_rum_events\naws_api/rum put_rum_events","url":"aws_api/rum.html#put_rum_events"},{"doc":"aws_api/rum","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rum.tag_resource\naws_api/rum tag_resource","url":"aws_api/rum.html#tag_resource"},{"doc":"aws_api/rum","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/rum.untag_resource\naws_api/rum untag_resource","url":"aws_api/rum.html#untag_resource"},{"doc":"aws_api/rum","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/rum.with_custom_endpoint\naws_api/rum with_custom_endpoint","url":"aws_api/rum.html#with_custom_endpoint"},{"doc":"aws_api/rum","title":"aws_api/rum","content":"","url":"aws_api/rum.html"},{"doc":"aws_api/s3","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/s3.Client\naws_api/s3 Client","url":"aws_api/s3.html#Client"},{"doc":"aws_api/s3","title":"abort_multipart_upload","content":"pub fn abort_multipart_upload(\n  client: Client,\n  bucket: String,\n  key: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.abort_multipart_upload\naws_api/s3 abort_multipart_upload","url":"aws_api/s3.html#abort_multipart_upload"},{"doc":"aws_api/s3","title":"complete_multipart_upload","content":"pub fn complete_multipart_upload(\n  client: Client,\n  bucket: String,\n  key: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.complete_multipart_upload\naws_api/s3 complete_multipart_upload","url":"aws_api/s3.html#complete_multipart_upload"},{"doc":"aws_api/s3","title":"copy_object","content":"pub fn copy_object(\n  client: Client,\n  bucket: String,\n  key: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.copy_object\naws_api/s3 copy_object","url":"aws_api/s3.html#copy_object"},{"doc":"aws_api/s3","title":"create_bucket","content":"pub fn create_bucket(\n  client: Client,\n  bucket: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.create_bucket\naws_api/s3 create_bucket","url":"aws_api/s3.html#create_bucket"},{"doc":"aws_api/s3","title":"create_multipart_upload","content":"pub fn create_multipart_upload(\n  client: Client,\n  bucket: String,\n  key: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.create_multipart_upload\naws_api/s3 create_multipart_upload","url":"aws_api/s3.html#create_multipart_upload"},{"doc":"aws_api/s3","title":"create_session","content":"pub fn create_session(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.create_session\naws_api/s3 create_session","url":"aws_api/s3.html#create_session"},{"doc":"aws_api/s3","title":"delete_bucket","content":"pub fn delete_bucket(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.delete_bucket\naws_api/s3 delete_bucket","url":"aws_api/s3.html#delete_bucket"},{"doc":"aws_api/s3","title":"delete_bucket_analytics_configuration","content":"pub fn delete_bucket_analytics_configuration(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.delete_bucket_analytics_configuration\naws_api/s3 delete_bucket_analytics_configuration","url":"aws_api/s3.html#delete_bucket_analytics_configuration"},{"doc":"aws_api/s3","title":"delete_bucket_cors","content":"pub fn delete_bucket_cors(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.delete_bucket_cors\naws_api/s3 delete_bucket_cors","url":"aws_api/s3.html#delete_bucket_cors"},{"doc":"aws_api/s3","title":"delete_bucket_encryption","content":"pub fn delete_bucket_encryption(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.delete_bucket_encryption\naws_api/s3 delete_bucket_encryption","url":"aws_api/s3.html#delete_bucket_encryption"},{"doc":"aws_api/s3","title":"delete_bucket_intelligent_tiering_configuration","content":"pub fn delete_bucket_intelligent_tiering_configuration(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.delete_bucket_intelligent_tiering_configuration\naws_api/s3 delete_bucket_intelligent_tiering_configuration","url":"aws_api/s3.html#delete_bucket_intelligent_tiering_configuration"},{"doc":"aws_api/s3","title":"delete_bucket_inventory_configuration","content":"pub fn delete_bucket_inventory_configuration(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.delete_bucket_inventory_configuration\naws_api/s3 delete_bucket_inventory_configuration","url":"aws_api/s3.html#delete_bucket_inventory_configuration"},{"doc":"aws_api/s3","title":"delete_bucket_lifecycle","content":"pub fn delete_bucket_lifecycle(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.delete_bucket_lifecycle\naws_api/s3 delete_bucket_lifecycle","url":"aws_api/s3.html#delete_bucket_lifecycle"},{"doc":"aws_api/s3","title":"delete_bucket_metrics_configuration","content":"pub fn delete_bucket_metrics_configuration(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.delete_bucket_metrics_configuration\naws_api/s3 delete_bucket_metrics_configuration","url":"aws_api/s3.html#delete_bucket_metrics_configuration"},{"doc":"aws_api/s3","title":"delete_bucket_ownership_controls","content":"pub fn delete_bucket_ownership_controls(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.delete_bucket_ownership_controls\naws_api/s3 delete_bucket_ownership_controls","url":"aws_api/s3.html#delete_bucket_ownership_controls"},{"doc":"aws_api/s3","title":"delete_bucket_policy","content":"pub fn delete_bucket_policy(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.delete_bucket_policy\naws_api/s3 delete_bucket_policy","url":"aws_api/s3.html#delete_bucket_policy"},{"doc":"aws_api/s3","title":"delete_bucket_replication","content":"pub fn delete_bucket_replication(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.delete_bucket_replication\naws_api/s3 delete_bucket_replication","url":"aws_api/s3.html#delete_bucket_replication"},{"doc":"aws_api/s3","title":"delete_bucket_tagging","content":"pub fn delete_bucket_tagging(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.delete_bucket_tagging\naws_api/s3 delete_bucket_tagging","url":"aws_api/s3.html#delete_bucket_tagging"},{"doc":"aws_api/s3","title":"delete_bucket_website","content":"pub fn delete_bucket_website(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.delete_bucket_website\naws_api/s3 delete_bucket_website","url":"aws_api/s3.html#delete_bucket_website"},{"doc":"aws_api/s3","title":"delete_object","content":"pub fn delete_object(\n  client: Client,\n  bucket: String,\n  key: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.delete_object\naws_api/s3 delete_object","url":"aws_api/s3.html#delete_object"},{"doc":"aws_api/s3","title":"delete_object_tagging","content":"pub fn delete_object_tagging(\n  client: Client,\n  bucket: String,\n  key: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.delete_object_tagging\naws_api/s3 delete_object_tagging","url":"aws_api/s3.html#delete_object_tagging"},{"doc":"aws_api/s3","title":"delete_objects","content":"pub fn delete_objects(\n  client: Client,\n  bucket: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.delete_objects\naws_api/s3 delete_objects","url":"aws_api/s3.html#delete_objects"},{"doc":"aws_api/s3","title":"delete_public_access_block","content":"pub fn delete_public_access_block(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.delete_public_access_block\naws_api/s3 delete_public_access_block","url":"aws_api/s3.html#delete_public_access_block"},{"doc":"aws_api/s3","title":"get_bucket_accelerate_configuration","content":"pub fn get_bucket_accelerate_configuration(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.get_bucket_accelerate_configuration\naws_api/s3 get_bucket_accelerate_configuration","url":"aws_api/s3.html#get_bucket_accelerate_configuration"},{"doc":"aws_api/s3","title":"get_bucket_acl","content":"pub fn get_bucket_acl(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.get_bucket_acl\naws_api/s3 get_bucket_acl","url":"aws_api/s3.html#get_bucket_acl"},{"doc":"aws_api/s3","title":"get_bucket_analytics_configuration","content":"pub fn get_bucket_analytics_configuration(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.get_bucket_analytics_configuration\naws_api/s3 get_bucket_analytics_configuration","url":"aws_api/s3.html#get_bucket_analytics_configuration"},{"doc":"aws_api/s3","title":"get_bucket_cors","content":"pub fn get_bucket_cors(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.get_bucket_cors\naws_api/s3 get_bucket_cors","url":"aws_api/s3.html#get_bucket_cors"},{"doc":"aws_api/s3","title":"get_bucket_encryption","content":"pub fn get_bucket_encryption(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.get_bucket_encryption\naws_api/s3 get_bucket_encryption","url":"aws_api/s3.html#get_bucket_encryption"},{"doc":"aws_api/s3","title":"get_bucket_intelligent_tiering_configuration","content":"pub fn get_bucket_intelligent_tiering_configuration(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.get_bucket_intelligent_tiering_configuration\naws_api/s3 get_bucket_intelligent_tiering_configuration","url":"aws_api/s3.html#get_bucket_intelligent_tiering_configuration"},{"doc":"aws_api/s3","title":"get_bucket_inventory_configuration","content":"pub fn get_bucket_inventory_configuration(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.get_bucket_inventory_configuration\naws_api/s3 get_bucket_inventory_configuration","url":"aws_api/s3.html#get_bucket_inventory_configuration"},{"doc":"aws_api/s3","title":"get_bucket_lifecycle_configuration","content":"pub fn get_bucket_lifecycle_configuration(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.get_bucket_lifecycle_configuration\naws_api/s3 get_bucket_lifecycle_configuration","url":"aws_api/s3.html#get_bucket_lifecycle_configuration"},{"doc":"aws_api/s3","title":"get_bucket_location","content":"pub fn get_bucket_location(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.get_bucket_location\naws_api/s3 get_bucket_location","url":"aws_api/s3.html#get_bucket_location"},{"doc":"aws_api/s3","title":"get_bucket_logging","content":"pub fn get_bucket_logging(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.get_bucket_logging\naws_api/s3 get_bucket_logging","url":"aws_api/s3.html#get_bucket_logging"},{"doc":"aws_api/s3","title":"get_bucket_metrics_configuration","content":"pub fn get_bucket_metrics_configuration(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.get_bucket_metrics_configuration\naws_api/s3 get_bucket_metrics_configuration","url":"aws_api/s3.html#get_bucket_metrics_configuration"},{"doc":"aws_api/s3","title":"get_bucket_notification_configuration","content":"pub fn get_bucket_notification_configuration(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.get_bucket_notification_configuration\naws_api/s3 get_bucket_notification_configuration","url":"aws_api/s3.html#get_bucket_notification_configuration"},{"doc":"aws_api/s3","title":"get_bucket_ownership_controls","content":"pub fn get_bucket_ownership_controls(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.get_bucket_ownership_controls\naws_api/s3 get_bucket_ownership_controls","url":"aws_api/s3.html#get_bucket_ownership_controls"},{"doc":"aws_api/s3","title":"get_bucket_policy","content":"pub fn get_bucket_policy(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.get_bucket_policy\naws_api/s3 get_bucket_policy","url":"aws_api/s3.html#get_bucket_policy"},{"doc":"aws_api/s3","title":"get_bucket_policy_status","content":"pub fn get_bucket_policy_status(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.get_bucket_policy_status\naws_api/s3 get_bucket_policy_status","url":"aws_api/s3.html#get_bucket_policy_status"},{"doc":"aws_api/s3","title":"get_bucket_replication","content":"pub fn get_bucket_replication(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.get_bucket_replication\naws_api/s3 get_bucket_replication","url":"aws_api/s3.html#get_bucket_replication"},{"doc":"aws_api/s3","title":"get_bucket_request_payment","content":"pub fn get_bucket_request_payment(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.get_bucket_request_payment\naws_api/s3 get_bucket_request_payment","url":"aws_api/s3.html#get_bucket_request_payment"},{"doc":"aws_api/s3","title":"get_bucket_tagging","content":"pub fn get_bucket_tagging(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.get_bucket_tagging\naws_api/s3 get_bucket_tagging","url":"aws_api/s3.html#get_bucket_tagging"},{"doc":"aws_api/s3","title":"get_bucket_versioning","content":"pub fn get_bucket_versioning(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.get_bucket_versioning\naws_api/s3 get_bucket_versioning","url":"aws_api/s3.html#get_bucket_versioning"},{"doc":"aws_api/s3","title":"get_bucket_website","content":"pub fn get_bucket_website(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.get_bucket_website\naws_api/s3 get_bucket_website","url":"aws_api/s3.html#get_bucket_website"},{"doc":"aws_api/s3","title":"get_object","content":"pub fn get_object(\n  client: Client,\n  bucket: String,\n  key: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.get_object\naws_api/s3 get_object","url":"aws_api/s3.html#get_object"},{"doc":"aws_api/s3","title":"get_object_acl","content":"pub fn get_object_acl(\n  client: Client,\n  bucket: String,\n  key: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.get_object_acl\naws_api/s3 get_object_acl","url":"aws_api/s3.html#get_object_acl"},{"doc":"aws_api/s3","title":"get_object_attributes","content":"pub fn get_object_attributes(\n  client: Client,\n  bucket: String,\n  key: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.get_object_attributes\naws_api/s3 get_object_attributes","url":"aws_api/s3.html#get_object_attributes"},{"doc":"aws_api/s3","title":"get_object_legal_hold","content":"pub fn get_object_legal_hold(\n  client: Client,\n  bucket: String,\n  key: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.get_object_legal_hold\naws_api/s3 get_object_legal_hold","url":"aws_api/s3.html#get_object_legal_hold"},{"doc":"aws_api/s3","title":"get_object_lock_configuration","content":"pub fn get_object_lock_configuration(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.get_object_lock_configuration\naws_api/s3 get_object_lock_configuration","url":"aws_api/s3.html#get_object_lock_configuration"},{"doc":"aws_api/s3","title":"get_object_retention","content":"pub fn get_object_retention(\n  client: Client,\n  bucket: String,\n  key: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.get_object_retention\naws_api/s3 get_object_retention","url":"aws_api/s3.html#get_object_retention"},{"doc":"aws_api/s3","title":"get_object_tagging","content":"pub fn get_object_tagging(\n  client: Client,\n  bucket: String,\n  key: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.get_object_tagging\naws_api/s3 get_object_tagging","url":"aws_api/s3.html#get_object_tagging"},{"doc":"aws_api/s3","title":"get_object_torrent","content":"pub fn get_object_torrent(\n  client: Client,\n  bucket: String,\n  key: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.get_object_torrent\naws_api/s3 get_object_torrent","url":"aws_api/s3.html#get_object_torrent"},{"doc":"aws_api/s3","title":"get_public_access_block","content":"pub fn get_public_access_block(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.get_public_access_block\naws_api/s3 get_public_access_block","url":"aws_api/s3.html#get_public_access_block"},{"doc":"aws_api/s3","title":"head_bucket","content":"pub fn head_bucket(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.head_bucket\naws_api/s3 head_bucket","url":"aws_api/s3.html#head_bucket"},{"doc":"aws_api/s3","title":"head_object","content":"pub fn head_object(\n  client: Client,\n  bucket: String,\n  key: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.head_object\naws_api/s3 head_object","url":"aws_api/s3.html#head_object"},{"doc":"aws_api/s3","title":"list_bucket_analytics_configurations","content":"pub fn list_bucket_analytics_configurations(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.list_bucket_analytics_configurations\naws_api/s3 list_bucket_analytics_configurations","url":"aws_api/s3.html#list_bucket_analytics_configurations"},{"doc":"aws_api/s3","title":"list_bucket_intelligent_tiering_configurations","content":"pub fn list_bucket_intelligent_tiering_configurations(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.list_bucket_intelligent_tiering_configurations\naws_api/s3 list_bucket_intelligent_tiering_configurations","url":"aws_api/s3.html#list_bucket_intelligent_tiering_configurations"},{"doc":"aws_api/s3","title":"list_bucket_inventory_configurations","content":"pub fn list_bucket_inventory_configurations(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.list_bucket_inventory_configurations\naws_api/s3 list_bucket_inventory_configurations","url":"aws_api/s3.html#list_bucket_inventory_configurations"},{"doc":"aws_api/s3","title":"list_bucket_metrics_configurations","content":"pub fn list_bucket_metrics_configurations(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.list_bucket_metrics_configurations\naws_api/s3 list_bucket_metrics_configurations","url":"aws_api/s3.html#list_bucket_metrics_configurations"},{"doc":"aws_api/s3","title":"list_buckets","content":"pub fn list_buckets(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.list_buckets\naws_api/s3 list_buckets","url":"aws_api/s3.html#list_buckets"},{"doc":"aws_api/s3","title":"list_directory_buckets","content":"pub fn list_directory_buckets(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.list_directory_buckets\naws_api/s3 list_directory_buckets","url":"aws_api/s3.html#list_directory_buckets"},{"doc":"aws_api/s3","title":"list_multipart_uploads","content":"pub fn list_multipart_uploads(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.list_multipart_uploads\naws_api/s3 list_multipart_uploads","url":"aws_api/s3.html#list_multipart_uploads"},{"doc":"aws_api/s3","title":"list_object_versions","content":"pub fn list_object_versions(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.list_object_versions\naws_api/s3 list_object_versions","url":"aws_api/s3.html#list_object_versions"},{"doc":"aws_api/s3","title":"list_objects","content":"pub fn list_objects(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.list_objects\naws_api/s3 list_objects","url":"aws_api/s3.html#list_objects"},{"doc":"aws_api/s3","title":"list_objects_v2","content":"pub fn list_objects_v2(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.list_objects_v2\naws_api/s3 list_objects_v2","url":"aws_api/s3.html#list_objects_v2"},{"doc":"aws_api/s3","title":"list_parts","content":"pub fn list_parts(\n  client: Client,\n  bucket: String,\n  key: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.list_parts\naws_api/s3 list_parts","url":"aws_api/s3.html#list_parts"},{"doc":"aws_api/s3","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/s3.new\naws_api/s3 new","url":"aws_api/s3.html#new"},{"doc":"aws_api/s3","title":"put_bucket_accelerate_configuration","content":"pub fn put_bucket_accelerate_configuration(\n  client: Client,\n  bucket: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.put_bucket_accelerate_configuration\naws_api/s3 put_bucket_accelerate_configuration","url":"aws_api/s3.html#put_bucket_accelerate_configuration"},{"doc":"aws_api/s3","title":"put_bucket_acl","content":"pub fn put_bucket_acl(\n  client: Client,\n  bucket: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.put_bucket_acl\naws_api/s3 put_bucket_acl","url":"aws_api/s3.html#put_bucket_acl"},{"doc":"aws_api/s3","title":"put_bucket_analytics_configuration","content":"pub fn put_bucket_analytics_configuration(\n  client: Client,\n  bucket: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.put_bucket_analytics_configuration\naws_api/s3 put_bucket_analytics_configuration","url":"aws_api/s3.html#put_bucket_analytics_configuration"},{"doc":"aws_api/s3","title":"put_bucket_cors","content":"pub fn put_bucket_cors(\n  client: Client,\n  bucket: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.put_bucket_cors\naws_api/s3 put_bucket_cors","url":"aws_api/s3.html#put_bucket_cors"},{"doc":"aws_api/s3","title":"put_bucket_encryption","content":"pub fn put_bucket_encryption(\n  client: Client,\n  bucket: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.put_bucket_encryption\naws_api/s3 put_bucket_encryption","url":"aws_api/s3.html#put_bucket_encryption"},{"doc":"aws_api/s3","title":"put_bucket_intelligent_tiering_configuration","content":"pub fn put_bucket_intelligent_tiering_configuration(\n  client: Client,\n  bucket: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.put_bucket_intelligent_tiering_configuration\naws_api/s3 put_bucket_intelligent_tiering_configuration","url":"aws_api/s3.html#put_bucket_intelligent_tiering_configuration"},{"doc":"aws_api/s3","title":"put_bucket_inventory_configuration","content":"pub fn put_bucket_inventory_configuration(\n  client: Client,\n  bucket: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.put_bucket_inventory_configuration\naws_api/s3 put_bucket_inventory_configuration","url":"aws_api/s3.html#put_bucket_inventory_configuration"},{"doc":"aws_api/s3","title":"put_bucket_lifecycle_configuration","content":"pub fn put_bucket_lifecycle_configuration(\n  client: Client,\n  bucket: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.put_bucket_lifecycle_configuration\naws_api/s3 put_bucket_lifecycle_configuration","url":"aws_api/s3.html#put_bucket_lifecycle_configuration"},{"doc":"aws_api/s3","title":"put_bucket_logging","content":"pub fn put_bucket_logging(\n  client: Client,\n  bucket: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.put_bucket_logging\naws_api/s3 put_bucket_logging","url":"aws_api/s3.html#put_bucket_logging"},{"doc":"aws_api/s3","title":"put_bucket_metrics_configuration","content":"pub fn put_bucket_metrics_configuration(\n  client: Client,\n  bucket: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.put_bucket_metrics_configuration\naws_api/s3 put_bucket_metrics_configuration","url":"aws_api/s3.html#put_bucket_metrics_configuration"},{"doc":"aws_api/s3","title":"put_bucket_notification_configuration","content":"pub fn put_bucket_notification_configuration(\n  client: Client,\n  bucket: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.put_bucket_notification_configuration\naws_api/s3 put_bucket_notification_configuration","url":"aws_api/s3.html#put_bucket_notification_configuration"},{"doc":"aws_api/s3","title":"put_bucket_ownership_controls","content":"pub fn put_bucket_ownership_controls(\n  client: Client,\n  bucket: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.put_bucket_ownership_controls\naws_api/s3 put_bucket_ownership_controls","url":"aws_api/s3.html#put_bucket_ownership_controls"},{"doc":"aws_api/s3","title":"put_bucket_policy","content":"pub fn put_bucket_policy(\n  client: Client,\n  bucket: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.put_bucket_policy\naws_api/s3 put_bucket_policy","url":"aws_api/s3.html#put_bucket_policy"},{"doc":"aws_api/s3","title":"put_bucket_replication","content":"pub fn put_bucket_replication(\n  client: Client,\n  bucket: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.put_bucket_replication\naws_api/s3 put_bucket_replication","url":"aws_api/s3.html#put_bucket_replication"},{"doc":"aws_api/s3","title":"put_bucket_request_payment","content":"pub fn put_bucket_request_payment(\n  client: Client,\n  bucket: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.put_bucket_request_payment\naws_api/s3 put_bucket_request_payment","url":"aws_api/s3.html#put_bucket_request_payment"},{"doc":"aws_api/s3","title":"put_bucket_tagging","content":"pub fn put_bucket_tagging(\n  client: Client,\n  bucket: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.put_bucket_tagging\naws_api/s3 put_bucket_tagging","url":"aws_api/s3.html#put_bucket_tagging"},{"doc":"aws_api/s3","title":"put_bucket_versioning","content":"pub fn put_bucket_versioning(\n  client: Client,\n  bucket: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.put_bucket_versioning\naws_api/s3 put_bucket_versioning","url":"aws_api/s3.html#put_bucket_versioning"},{"doc":"aws_api/s3","title":"put_bucket_website","content":"pub fn put_bucket_website(\n  client: Client,\n  bucket: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.put_bucket_website\naws_api/s3 put_bucket_website","url":"aws_api/s3.html#put_bucket_website"},{"doc":"aws_api/s3","title":"put_object","content":"pub fn put_object(\n  client: Client,\n  bucket: String,\n  key: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.put_object\naws_api/s3 put_object","url":"aws_api/s3.html#put_object"},{"doc":"aws_api/s3","title":"put_object_acl","content":"pub fn put_object_acl(\n  client: Client,\n  bucket: String,\n  key: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.put_object_acl\naws_api/s3 put_object_acl","url":"aws_api/s3.html#put_object_acl"},{"doc":"aws_api/s3","title":"put_object_legal_hold","content":"pub fn put_object_legal_hold(\n  client: Client,\n  bucket: String,\n  key: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.put_object_legal_hold\naws_api/s3 put_object_legal_hold","url":"aws_api/s3.html#put_object_legal_hold"},{"doc":"aws_api/s3","title":"put_object_lock_configuration","content":"pub fn put_object_lock_configuration(\n  client: Client,\n  bucket: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.put_object_lock_configuration\naws_api/s3 put_object_lock_configuration","url":"aws_api/s3.html#put_object_lock_configuration"},{"doc":"aws_api/s3","title":"put_object_retention","content":"pub fn put_object_retention(\n  client: Client,\n  bucket: String,\n  key: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.put_object_retention\naws_api/s3 put_object_retention","url":"aws_api/s3.html#put_object_retention"},{"doc":"aws_api/s3","title":"put_object_tagging","content":"pub fn put_object_tagging(\n  client: Client,\n  bucket: String,\n  key: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.put_object_tagging\naws_api/s3 put_object_tagging","url":"aws_api/s3.html#put_object_tagging"},{"doc":"aws_api/s3","title":"put_public_access_block","content":"pub fn put_public_access_block(\n  client: Client,\n  bucket: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.put_public_access_block\naws_api/s3 put_public_access_block","url":"aws_api/s3.html#put_public_access_block"},{"doc":"aws_api/s3","title":"restore_object","content":"pub fn restore_object(\n  client: Client,\n  bucket: String,\n  key: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.restore_object\naws_api/s3 restore_object","url":"aws_api/s3.html#restore_object"},{"doc":"aws_api/s3","title":"select_object_content","content":"pub fn select_object_content(\n  client: Client,\n  bucket: String,\n  key: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.select_object_content\naws_api/s3 select_object_content","url":"aws_api/s3.html#select_object_content"},{"doc":"aws_api/s3","title":"upload_part","content":"pub fn upload_part(\n  client: Client,\n  bucket: String,\n  key: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.upload_part\naws_api/s3 upload_part","url":"aws_api/s3.html#upload_part"},{"doc":"aws_api/s3","title":"upload_part_copy","content":"pub fn upload_part_copy(\n  client: Client,\n  bucket: String,\n  key: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.upload_part_copy\naws_api/s3 upload_part_copy","url":"aws_api/s3.html#upload_part_copy"},{"doc":"aws_api/s3","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/s3.with_custom_endpoint\naws_api/s3 with_custom_endpoint","url":"aws_api/s3.html#with_custom_endpoint"},{"doc":"aws_api/s3","title":"write_get_object_response","content":"pub fn write_get_object_response(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3.write_get_object_response\naws_api/s3 write_get_object_response","url":"aws_api/s3.html#write_get_object_response"},{"doc":"aws_api/s3","title":"aws_api/s3","content":"","url":"aws_api/s3.html"},{"doc":"aws_api/s3_control","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/s3_control.Client\naws_api/s3_control Client","url":"aws_api/s3_control.html#Client"},{"doc":"aws_api/s3_control","title":"associate_access_grants_identity_center","content":"pub fn associate_access_grants_identity_center(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.associate_access_grants_identity_center\naws_api/s3_control associate_access_grants_identity_center","url":"aws_api/s3_control.html#associate_access_grants_identity_center"},{"doc":"aws_api/s3_control","title":"create_access_grant","content":"pub fn create_access_grant(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.create_access_grant\naws_api/s3_control create_access_grant","url":"aws_api/s3_control.html#create_access_grant"},{"doc":"aws_api/s3_control","title":"create_access_grants_instance","content":"pub fn create_access_grants_instance(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.create_access_grants_instance\naws_api/s3_control create_access_grants_instance","url":"aws_api/s3_control.html#create_access_grants_instance"},{"doc":"aws_api/s3_control","title":"create_access_grants_location","content":"pub fn create_access_grants_location(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.create_access_grants_location\naws_api/s3_control create_access_grants_location","url":"aws_api/s3_control.html#create_access_grants_location"},{"doc":"aws_api/s3_control","title":"create_access_point","content":"pub fn create_access_point(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.create_access_point\naws_api/s3_control create_access_point","url":"aws_api/s3_control.html#create_access_point"},{"doc":"aws_api/s3_control","title":"create_access_point_for_object_lambda","content":"pub fn create_access_point_for_object_lambda(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.create_access_point_for_object_lambda\naws_api/s3_control create_access_point_for_object_lambda","url":"aws_api/s3_control.html#create_access_point_for_object_lambda"},{"doc":"aws_api/s3_control","title":"create_bucket","content":"pub fn create_bucket(\n  client: Client,\n  bucket: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.create_bucket\naws_api/s3_control create_bucket","url":"aws_api/s3_control.html#create_bucket"},{"doc":"aws_api/s3_control","title":"create_job","content":"pub fn create_job(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.create_job\naws_api/s3_control create_job","url":"aws_api/s3_control.html#create_job"},{"doc":"aws_api/s3_control","title":"create_multi_region_access_point","content":"pub fn create_multi_region_access_point(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.create_multi_region_access_point\naws_api/s3_control create_multi_region_access_point","url":"aws_api/s3_control.html#create_multi_region_access_point"},{"doc":"aws_api/s3_control","title":"create_storage_lens_group","content":"pub fn create_storage_lens_group(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.create_storage_lens_group\naws_api/s3_control create_storage_lens_group","url":"aws_api/s3_control.html#create_storage_lens_group"},{"doc":"aws_api/s3_control","title":"delete_access_grant","content":"pub fn delete_access_grant(\n  client: Client,\n  access_grant_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.delete_access_grant\naws_api/s3_control delete_access_grant","url":"aws_api/s3_control.html#delete_access_grant"},{"doc":"aws_api/s3_control","title":"delete_access_grants_instance","content":"pub fn delete_access_grants_instance(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.delete_access_grants_instance\naws_api/s3_control delete_access_grants_instance","url":"aws_api/s3_control.html#delete_access_grants_instance"},{"doc":"aws_api/s3_control","title":"delete_access_grants_instance_resource_policy","content":"pub fn delete_access_grants_instance_resource_policy(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.delete_access_grants_instance_resource_policy\naws_api/s3_control delete_access_grants_instance_resource_policy","url":"aws_api/s3_control.html#delete_access_grants_instance_resource_policy"},{"doc":"aws_api/s3_control","title":"delete_access_grants_location","content":"pub fn delete_access_grants_location(\n  client: Client,\n  access_grants_location_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.delete_access_grants_location\naws_api/s3_control delete_access_grants_location","url":"aws_api/s3_control.html#delete_access_grants_location"},{"doc":"aws_api/s3_control","title":"delete_access_point","content":"pub fn delete_access_point(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.delete_access_point\naws_api/s3_control delete_access_point","url":"aws_api/s3_control.html#delete_access_point"},{"doc":"aws_api/s3_control","title":"delete_access_point_for_object_lambda","content":"pub fn delete_access_point_for_object_lambda(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.delete_access_point_for_object_lambda\naws_api/s3_control delete_access_point_for_object_lambda","url":"aws_api/s3_control.html#delete_access_point_for_object_lambda"},{"doc":"aws_api/s3_control","title":"delete_access_point_policy","content":"pub fn delete_access_point_policy(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.delete_access_point_policy\naws_api/s3_control delete_access_point_policy","url":"aws_api/s3_control.html#delete_access_point_policy"},{"doc":"aws_api/s3_control","title":"delete_access_point_policy_for_object_lambda","content":"pub fn delete_access_point_policy_for_object_lambda(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.delete_access_point_policy_for_object_lambda\naws_api/s3_control delete_access_point_policy_for_object_lambda","url":"aws_api/s3_control.html#delete_access_point_policy_for_object_lambda"},{"doc":"aws_api/s3_control","title":"delete_bucket","content":"pub fn delete_bucket(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.delete_bucket\naws_api/s3_control delete_bucket","url":"aws_api/s3_control.html#delete_bucket"},{"doc":"aws_api/s3_control","title":"delete_bucket_lifecycle_configuration","content":"pub fn delete_bucket_lifecycle_configuration(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.delete_bucket_lifecycle_configuration\naws_api/s3_control delete_bucket_lifecycle_configuration","url":"aws_api/s3_control.html#delete_bucket_lifecycle_configuration"},{"doc":"aws_api/s3_control","title":"delete_bucket_policy","content":"pub fn delete_bucket_policy(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.delete_bucket_policy\naws_api/s3_control delete_bucket_policy","url":"aws_api/s3_control.html#delete_bucket_policy"},{"doc":"aws_api/s3_control","title":"delete_bucket_replication","content":"pub fn delete_bucket_replication(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.delete_bucket_replication\naws_api/s3_control delete_bucket_replication","url":"aws_api/s3_control.html#delete_bucket_replication"},{"doc":"aws_api/s3_control","title":"delete_bucket_tagging","content":"pub fn delete_bucket_tagging(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.delete_bucket_tagging\naws_api/s3_control delete_bucket_tagging","url":"aws_api/s3_control.html#delete_bucket_tagging"},{"doc":"aws_api/s3_control","title":"delete_job_tagging","content":"pub fn delete_job_tagging(\n  client: Client,\n  job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.delete_job_tagging\naws_api/s3_control delete_job_tagging","url":"aws_api/s3_control.html#delete_job_tagging"},{"doc":"aws_api/s3_control","title":"delete_multi_region_access_point","content":"pub fn delete_multi_region_access_point(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.delete_multi_region_access_point\naws_api/s3_control delete_multi_region_access_point","url":"aws_api/s3_control.html#delete_multi_region_access_point"},{"doc":"aws_api/s3_control","title":"delete_public_access_block","content":"pub fn delete_public_access_block(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.delete_public_access_block\naws_api/s3_control delete_public_access_block","url":"aws_api/s3_control.html#delete_public_access_block"},{"doc":"aws_api/s3_control","title":"delete_storage_lens_configuration","content":"pub fn delete_storage_lens_configuration(\n  client: Client,\n  config_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.delete_storage_lens_configuration\naws_api/s3_control delete_storage_lens_configuration","url":"aws_api/s3_control.html#delete_storage_lens_configuration"},{"doc":"aws_api/s3_control","title":"delete_storage_lens_configuration_tagging","content":"pub fn delete_storage_lens_configuration_tagging(\n  client: Client,\n  config_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.delete_storage_lens_configuration_tagging\naws_api/s3_control delete_storage_lens_configuration_tagging","url":"aws_api/s3_control.html#delete_storage_lens_configuration_tagging"},{"doc":"aws_api/s3_control","title":"delete_storage_lens_group","content":"pub fn delete_storage_lens_group(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.delete_storage_lens_group\naws_api/s3_control delete_storage_lens_group","url":"aws_api/s3_control.html#delete_storage_lens_group"},{"doc":"aws_api/s3_control","title":"describe_job","content":"pub fn describe_job(\n  client: Client,\n  job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.describe_job\naws_api/s3_control describe_job","url":"aws_api/s3_control.html#describe_job"},{"doc":"aws_api/s3_control","title":"describe_multi_region_access_point_operation","content":"pub fn describe_multi_region_access_point_operation(\n  client: Client,\n  request_token_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.describe_multi_region_access_point_operation\naws_api/s3_control describe_multi_region_access_point_operation","url":"aws_api/s3_control.html#describe_multi_region_access_point_operation"},{"doc":"aws_api/s3_control","title":"dissociate_access_grants_identity_center","content":"pub fn dissociate_access_grants_identity_center(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.dissociate_access_grants_identity_center\naws_api/s3_control dissociate_access_grants_identity_center","url":"aws_api/s3_control.html#dissociate_access_grants_identity_center"},{"doc":"aws_api/s3_control","title":"get_access_grant","content":"pub fn get_access_grant(\n  client: Client,\n  access_grant_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.get_access_grant\naws_api/s3_control get_access_grant","url":"aws_api/s3_control.html#get_access_grant"},{"doc":"aws_api/s3_control","title":"get_access_grants_instance","content":"pub fn get_access_grants_instance(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.get_access_grants_instance\naws_api/s3_control get_access_grants_instance","url":"aws_api/s3_control.html#get_access_grants_instance"},{"doc":"aws_api/s3_control","title":"get_access_grants_instance_for_prefix","content":"pub fn get_access_grants_instance_for_prefix(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.get_access_grants_instance_for_prefix\naws_api/s3_control get_access_grants_instance_for_prefix","url":"aws_api/s3_control.html#get_access_grants_instance_for_prefix"},{"doc":"aws_api/s3_control","title":"get_access_grants_instance_resource_policy","content":"pub fn get_access_grants_instance_resource_policy(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.get_access_grants_instance_resource_policy\naws_api/s3_control get_access_grants_instance_resource_policy","url":"aws_api/s3_control.html#get_access_grants_instance_resource_policy"},{"doc":"aws_api/s3_control","title":"get_access_grants_location","content":"pub fn get_access_grants_location(\n  client: Client,\n  access_grants_location_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.get_access_grants_location\naws_api/s3_control get_access_grants_location","url":"aws_api/s3_control.html#get_access_grants_location"},{"doc":"aws_api/s3_control","title":"get_access_point","content":"pub fn get_access_point(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.get_access_point\naws_api/s3_control get_access_point","url":"aws_api/s3_control.html#get_access_point"},{"doc":"aws_api/s3_control","title":"get_access_point_configuration_for_object_lambda","content":"pub fn get_access_point_configuration_for_object_lambda(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.get_access_point_configuration_for_object_lambda\naws_api/s3_control get_access_point_configuration_for_object_lambda","url":"aws_api/s3_control.html#get_access_point_configuration_for_object_lambda"},{"doc":"aws_api/s3_control","title":"get_access_point_for_object_lambda","content":"pub fn get_access_point_for_object_lambda(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.get_access_point_for_object_lambda\naws_api/s3_control get_access_point_for_object_lambda","url":"aws_api/s3_control.html#get_access_point_for_object_lambda"},{"doc":"aws_api/s3_control","title":"get_access_point_policy","content":"pub fn get_access_point_policy(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.get_access_point_policy\naws_api/s3_control get_access_point_policy","url":"aws_api/s3_control.html#get_access_point_policy"},{"doc":"aws_api/s3_control","title":"get_access_point_policy_for_object_lambda","content":"pub fn get_access_point_policy_for_object_lambda(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.get_access_point_policy_for_object_lambda\naws_api/s3_control get_access_point_policy_for_object_lambda","url":"aws_api/s3_control.html#get_access_point_policy_for_object_lambda"},{"doc":"aws_api/s3_control","title":"get_access_point_policy_status","content":"pub fn get_access_point_policy_status(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.get_access_point_policy_status\naws_api/s3_control get_access_point_policy_status","url":"aws_api/s3_control.html#get_access_point_policy_status"},{"doc":"aws_api/s3_control","title":"get_access_point_policy_status_for_object_lambda","content":"pub fn get_access_point_policy_status_for_object_lambda(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.get_access_point_policy_status_for_object_lambda\naws_api/s3_control get_access_point_policy_status_for_object_lambda","url":"aws_api/s3_control.html#get_access_point_policy_status_for_object_lambda"},{"doc":"aws_api/s3_control","title":"get_bucket","content":"pub fn get_bucket(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.get_bucket\naws_api/s3_control get_bucket","url":"aws_api/s3_control.html#get_bucket"},{"doc":"aws_api/s3_control","title":"get_bucket_lifecycle_configuration","content":"pub fn get_bucket_lifecycle_configuration(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.get_bucket_lifecycle_configuration\naws_api/s3_control get_bucket_lifecycle_configuration","url":"aws_api/s3_control.html#get_bucket_lifecycle_configuration"},{"doc":"aws_api/s3_control","title":"get_bucket_policy","content":"pub fn get_bucket_policy(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.get_bucket_policy\naws_api/s3_control get_bucket_policy","url":"aws_api/s3_control.html#get_bucket_policy"},{"doc":"aws_api/s3_control","title":"get_bucket_replication","content":"pub fn get_bucket_replication(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.get_bucket_replication\naws_api/s3_control get_bucket_replication","url":"aws_api/s3_control.html#get_bucket_replication"},{"doc":"aws_api/s3_control","title":"get_bucket_tagging","content":"pub fn get_bucket_tagging(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.get_bucket_tagging\naws_api/s3_control get_bucket_tagging","url":"aws_api/s3_control.html#get_bucket_tagging"},{"doc":"aws_api/s3_control","title":"get_bucket_versioning","content":"pub fn get_bucket_versioning(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.get_bucket_versioning\naws_api/s3_control get_bucket_versioning","url":"aws_api/s3_control.html#get_bucket_versioning"},{"doc":"aws_api/s3_control","title":"get_data_access","content":"pub fn get_data_access(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.get_data_access\naws_api/s3_control get_data_access","url":"aws_api/s3_control.html#get_data_access"},{"doc":"aws_api/s3_control","title":"get_job_tagging","content":"pub fn get_job_tagging(\n  client: Client,\n  job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.get_job_tagging\naws_api/s3_control get_job_tagging","url":"aws_api/s3_control.html#get_job_tagging"},{"doc":"aws_api/s3_control","title":"get_multi_region_access_point","content":"pub fn get_multi_region_access_point(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.get_multi_region_access_point\naws_api/s3_control get_multi_region_access_point","url":"aws_api/s3_control.html#get_multi_region_access_point"},{"doc":"aws_api/s3_control","title":"get_multi_region_access_point_policy","content":"pub fn get_multi_region_access_point_policy(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.get_multi_region_access_point_policy\naws_api/s3_control get_multi_region_access_point_policy","url":"aws_api/s3_control.html#get_multi_region_access_point_policy"},{"doc":"aws_api/s3_control","title":"get_multi_region_access_point_policy_status","content":"pub fn get_multi_region_access_point_policy_status(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.get_multi_region_access_point_policy_status\naws_api/s3_control get_multi_region_access_point_policy_status","url":"aws_api/s3_control.html#get_multi_region_access_point_policy_status"},{"doc":"aws_api/s3_control","title":"get_multi_region_access_point_routes","content":"pub fn get_multi_region_access_point_routes(\n  client: Client,\n  mrap: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.get_multi_region_access_point_routes\naws_api/s3_control get_multi_region_access_point_routes","url":"aws_api/s3_control.html#get_multi_region_access_point_routes"},{"doc":"aws_api/s3_control","title":"get_public_access_block","content":"pub fn get_public_access_block(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.get_public_access_block\naws_api/s3_control get_public_access_block","url":"aws_api/s3_control.html#get_public_access_block"},{"doc":"aws_api/s3_control","title":"get_storage_lens_configuration","content":"pub fn get_storage_lens_configuration(\n  client: Client,\n  config_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.get_storage_lens_configuration\naws_api/s3_control get_storage_lens_configuration","url":"aws_api/s3_control.html#get_storage_lens_configuration"},{"doc":"aws_api/s3_control","title":"get_storage_lens_configuration_tagging","content":"pub fn get_storage_lens_configuration_tagging(\n  client: Client,\n  config_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.get_storage_lens_configuration_tagging\naws_api/s3_control get_storage_lens_configuration_tagging","url":"aws_api/s3_control.html#get_storage_lens_configuration_tagging"},{"doc":"aws_api/s3_control","title":"get_storage_lens_group","content":"pub fn get_storage_lens_group(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.get_storage_lens_group\naws_api/s3_control get_storage_lens_group","url":"aws_api/s3_control.html#get_storage_lens_group"},{"doc":"aws_api/s3_control","title":"list_access_grants","content":"pub fn list_access_grants(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.list_access_grants\naws_api/s3_control list_access_grants","url":"aws_api/s3_control.html#list_access_grants"},{"doc":"aws_api/s3_control","title":"list_access_grants_instances","content":"pub fn list_access_grants_instances(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.list_access_grants_instances\naws_api/s3_control list_access_grants_instances","url":"aws_api/s3_control.html#list_access_grants_instances"},{"doc":"aws_api/s3_control","title":"list_access_grants_locations","content":"pub fn list_access_grants_locations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.list_access_grants_locations\naws_api/s3_control list_access_grants_locations","url":"aws_api/s3_control.html#list_access_grants_locations"},{"doc":"aws_api/s3_control","title":"list_access_points","content":"pub fn list_access_points(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.list_access_points\naws_api/s3_control list_access_points","url":"aws_api/s3_control.html#list_access_points"},{"doc":"aws_api/s3_control","title":"list_access_points_for_object_lambda","content":"pub fn list_access_points_for_object_lambda(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.list_access_points_for_object_lambda\naws_api/s3_control list_access_points_for_object_lambda","url":"aws_api/s3_control.html#list_access_points_for_object_lambda"},{"doc":"aws_api/s3_control","title":"list_jobs","content":"pub fn list_jobs(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.list_jobs\naws_api/s3_control list_jobs","url":"aws_api/s3_control.html#list_jobs"},{"doc":"aws_api/s3_control","title":"list_multi_region_access_points","content":"pub fn list_multi_region_access_points(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.list_multi_region_access_points\naws_api/s3_control list_multi_region_access_points","url":"aws_api/s3_control.html#list_multi_region_access_points"},{"doc":"aws_api/s3_control","title":"list_regional_buckets","content":"pub fn list_regional_buckets(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.list_regional_buckets\naws_api/s3_control list_regional_buckets","url":"aws_api/s3_control.html#list_regional_buckets"},{"doc":"aws_api/s3_control","title":"list_storage_lens_configurations","content":"pub fn list_storage_lens_configurations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.list_storage_lens_configurations\naws_api/s3_control list_storage_lens_configurations","url":"aws_api/s3_control.html#list_storage_lens_configurations"},{"doc":"aws_api/s3_control","title":"list_storage_lens_groups","content":"pub fn list_storage_lens_groups(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.list_storage_lens_groups\naws_api/s3_control list_storage_lens_groups","url":"aws_api/s3_control.html#list_storage_lens_groups"},{"doc":"aws_api/s3_control","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.list_tags_for_resource\naws_api/s3_control list_tags_for_resource","url":"aws_api/s3_control.html#list_tags_for_resource"},{"doc":"aws_api/s3_control","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/s3_control.new\naws_api/s3_control new","url":"aws_api/s3_control.html#new"},{"doc":"aws_api/s3_control","title":"put_access_grants_instance_resource_policy","content":"pub fn put_access_grants_instance_resource_policy(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.put_access_grants_instance_resource_policy\naws_api/s3_control put_access_grants_instance_resource_policy","url":"aws_api/s3_control.html#put_access_grants_instance_resource_policy"},{"doc":"aws_api/s3_control","title":"put_access_point_configuration_for_object_lambda","content":"pub fn put_access_point_configuration_for_object_lambda(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.put_access_point_configuration_for_object_lambda\naws_api/s3_control put_access_point_configuration_for_object_lambda","url":"aws_api/s3_control.html#put_access_point_configuration_for_object_lambda"},{"doc":"aws_api/s3_control","title":"put_access_point_policy","content":"pub fn put_access_point_policy(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.put_access_point_policy\naws_api/s3_control put_access_point_policy","url":"aws_api/s3_control.html#put_access_point_policy"},{"doc":"aws_api/s3_control","title":"put_access_point_policy_for_object_lambda","content":"pub fn put_access_point_policy_for_object_lambda(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.put_access_point_policy_for_object_lambda\naws_api/s3_control put_access_point_policy_for_object_lambda","url":"aws_api/s3_control.html#put_access_point_policy_for_object_lambda"},{"doc":"aws_api/s3_control","title":"put_bucket_lifecycle_configuration","content":"pub fn put_bucket_lifecycle_configuration(\n  client: Client,\n  bucket: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.put_bucket_lifecycle_configuration\naws_api/s3_control put_bucket_lifecycle_configuration","url":"aws_api/s3_control.html#put_bucket_lifecycle_configuration"},{"doc":"aws_api/s3_control","title":"put_bucket_policy","content":"pub fn put_bucket_policy(\n  client: Client,\n  bucket: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.put_bucket_policy\naws_api/s3_control put_bucket_policy","url":"aws_api/s3_control.html#put_bucket_policy"},{"doc":"aws_api/s3_control","title":"put_bucket_replication","content":"pub fn put_bucket_replication(\n  client: Client,\n  bucket: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.put_bucket_replication\naws_api/s3_control put_bucket_replication","url":"aws_api/s3_control.html#put_bucket_replication"},{"doc":"aws_api/s3_control","title":"put_bucket_tagging","content":"pub fn put_bucket_tagging(\n  client: Client,\n  bucket: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.put_bucket_tagging\naws_api/s3_control put_bucket_tagging","url":"aws_api/s3_control.html#put_bucket_tagging"},{"doc":"aws_api/s3_control","title":"put_bucket_versioning","content":"pub fn put_bucket_versioning(\n  client: Client,\n  bucket: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.put_bucket_versioning\naws_api/s3_control put_bucket_versioning","url":"aws_api/s3_control.html#put_bucket_versioning"},{"doc":"aws_api/s3_control","title":"put_job_tagging","content":"pub fn put_job_tagging(\n  client: Client,\n  job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.put_job_tagging\naws_api/s3_control put_job_tagging","url":"aws_api/s3_control.html#put_job_tagging"},{"doc":"aws_api/s3_control","title":"put_multi_region_access_point_policy","content":"pub fn put_multi_region_access_point_policy(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.put_multi_region_access_point_policy\naws_api/s3_control put_multi_region_access_point_policy","url":"aws_api/s3_control.html#put_multi_region_access_point_policy"},{"doc":"aws_api/s3_control","title":"put_public_access_block","content":"pub fn put_public_access_block(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.put_public_access_block\naws_api/s3_control put_public_access_block","url":"aws_api/s3_control.html#put_public_access_block"},{"doc":"aws_api/s3_control","title":"put_storage_lens_configuration","content":"pub fn put_storage_lens_configuration(\n  client: Client,\n  config_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.put_storage_lens_configuration\naws_api/s3_control put_storage_lens_configuration","url":"aws_api/s3_control.html#put_storage_lens_configuration"},{"doc":"aws_api/s3_control","title":"put_storage_lens_configuration_tagging","content":"pub fn put_storage_lens_configuration_tagging(\n  client: Client,\n  config_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.put_storage_lens_configuration_tagging\naws_api/s3_control put_storage_lens_configuration_tagging","url":"aws_api/s3_control.html#put_storage_lens_configuration_tagging"},{"doc":"aws_api/s3_control","title":"submit_multi_region_access_point_routes","content":"pub fn submit_multi_region_access_point_routes(\n  client: Client,\n  mrap: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.submit_multi_region_access_point_routes\naws_api/s3_control submit_multi_region_access_point_routes","url":"aws_api/s3_control.html#submit_multi_region_access_point_routes"},{"doc":"aws_api/s3_control","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.tag_resource\naws_api/s3_control tag_resource","url":"aws_api/s3_control.html#tag_resource"},{"doc":"aws_api/s3_control","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.untag_resource\naws_api/s3_control untag_resource","url":"aws_api/s3_control.html#untag_resource"},{"doc":"aws_api/s3_control","title":"update_access_grants_location","content":"pub fn update_access_grants_location(\n  client: Client,\n  access_grants_location_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.update_access_grants_location\naws_api/s3_control update_access_grants_location","url":"aws_api/s3_control.html#update_access_grants_location"},{"doc":"aws_api/s3_control","title":"update_job_priority","content":"pub fn update_job_priority(\n  client: Client,\n  job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.update_job_priority\naws_api/s3_control update_job_priority","url":"aws_api/s3_control.html#update_job_priority"},{"doc":"aws_api/s3_control","title":"update_job_status","content":"pub fn update_job_status(\n  client: Client,\n  job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.update_job_status\naws_api/s3_control update_job_status","url":"aws_api/s3_control.html#update_job_status"},{"doc":"aws_api/s3_control","title":"update_storage_lens_group","content":"pub fn update_storage_lens_group(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3_control.update_storage_lens_group\naws_api/s3_control update_storage_lens_group","url":"aws_api/s3_control.html#update_storage_lens_group"},{"doc":"aws_api/s3_control","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/s3_control.with_custom_endpoint\naws_api/s3_control with_custom_endpoint","url":"aws_api/s3_control.html#with_custom_endpoint"},{"doc":"aws_api/s3_control","title":"aws_api/s3_control","content":"","url":"aws_api/s3_control.html"},{"doc":"aws_api/s3outposts","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/s3outposts.Client\naws_api/s3outposts Client","url":"aws_api/s3outposts.html#Client"},{"doc":"aws_api/s3outposts","title":"create_endpoint","content":"pub fn create_endpoint(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3outposts.create_endpoint\naws_api/s3outposts create_endpoint","url":"aws_api/s3outposts.html#create_endpoint"},{"doc":"aws_api/s3outposts","title":"delete_endpoint","content":"pub fn delete_endpoint(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3outposts.delete_endpoint\naws_api/s3outposts delete_endpoint","url":"aws_api/s3outposts.html#delete_endpoint"},{"doc":"aws_api/s3outposts","title":"list_endpoints","content":"pub fn list_endpoints(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3outposts.list_endpoints\naws_api/s3outposts list_endpoints","url":"aws_api/s3outposts.html#list_endpoints"},{"doc":"aws_api/s3outposts","title":"list_outposts_with_s3","content":"pub fn list_outposts_with_s3(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3outposts.list_outposts_with_s3\naws_api/s3outposts list_outposts_with_s3","url":"aws_api/s3outposts.html#list_outposts_with_s3"},{"doc":"aws_api/s3outposts","title":"list_shared_endpoints","content":"pub fn list_shared_endpoints(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/s3outposts.list_shared_endpoints\naws_api/s3outposts list_shared_endpoints","url":"aws_api/s3outposts.html#list_shared_endpoints"},{"doc":"aws_api/s3outposts","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/s3outposts.new\naws_api/s3outposts new","url":"aws_api/s3outposts.html#new"},{"doc":"aws_api/s3outposts","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/s3outposts.with_custom_endpoint\naws_api/s3outposts with_custom_endpoint","url":"aws_api/s3outposts.html#with_custom_endpoint"},{"doc":"aws_api/s3outposts","title":"aws_api/s3outposts","content":"","url":"aws_api/s3outposts.html"},{"doc":"aws_api/sagemaker","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/sagemaker.Client\naws_api/sagemaker Client","url":"aws_api/sagemaker.html#Client"},{"doc":"aws_api/sagemaker","title":"add_association","content":"pub fn add_association(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.add_association\naws_api/sagemaker add_association","url":"aws_api/sagemaker.html#add_association"},{"doc":"aws_api/sagemaker","title":"add_tags","content":"pub fn add_tags(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.add_tags\naws_api/sagemaker add_tags","url":"aws_api/sagemaker.html#add_tags"},{"doc":"aws_api/sagemaker","title":"associate_trial_component","content":"pub fn associate_trial_component(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.associate_trial_component\naws_api/sagemaker associate_trial_component","url":"aws_api/sagemaker.html#associate_trial_component"},{"doc":"aws_api/sagemaker","title":"batch_describe_model_package","content":"pub fn batch_describe_model_package(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.batch_describe_model_package\naws_api/sagemaker batch_describe_model_package","url":"aws_api/sagemaker.html#batch_describe_model_package"},{"doc":"aws_api/sagemaker","title":"create_action","content":"pub fn create_action(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_action\naws_api/sagemaker create_action","url":"aws_api/sagemaker.html#create_action"},{"doc":"aws_api/sagemaker","title":"create_algorithm","content":"pub fn create_algorithm(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_algorithm\naws_api/sagemaker create_algorithm","url":"aws_api/sagemaker.html#create_algorithm"},{"doc":"aws_api/sagemaker","title":"create_app","content":"pub fn create_app(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_app\naws_api/sagemaker create_app","url":"aws_api/sagemaker.html#create_app"},{"doc":"aws_api/sagemaker","title":"create_app_image_config","content":"pub fn create_app_image_config(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_app_image_config\naws_api/sagemaker create_app_image_config","url":"aws_api/sagemaker.html#create_app_image_config"},{"doc":"aws_api/sagemaker","title":"create_artifact","content":"pub fn create_artifact(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_artifact\naws_api/sagemaker create_artifact","url":"aws_api/sagemaker.html#create_artifact"},{"doc":"aws_api/sagemaker","title":"create_auto_ml_job","content":"pub fn create_auto_ml_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_auto_ml_job\naws_api/sagemaker create_auto_ml_job","url":"aws_api/sagemaker.html#create_auto_ml_job"},{"doc":"aws_api/sagemaker","title":"create_auto_ml_job_v2","content":"pub fn create_auto_ml_job_v2(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_auto_ml_job_v2\naws_api/sagemaker create_auto_ml_job_v2","url":"aws_api/sagemaker.html#create_auto_ml_job_v2"},{"doc":"aws_api/sagemaker","title":"create_cluster","content":"pub fn create_cluster(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_cluster\naws_api/sagemaker create_cluster","url":"aws_api/sagemaker.html#create_cluster"},{"doc":"aws_api/sagemaker","title":"create_code_repository","content":"pub fn create_code_repository(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_code_repository\naws_api/sagemaker create_code_repository","url":"aws_api/sagemaker.html#create_code_repository"},{"doc":"aws_api/sagemaker","title":"create_compilation_job","content":"pub fn create_compilation_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_compilation_job\naws_api/sagemaker create_compilation_job","url":"aws_api/sagemaker.html#create_compilation_job"},{"doc":"aws_api/sagemaker","title":"create_context","content":"pub fn create_context(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_context\naws_api/sagemaker create_context","url":"aws_api/sagemaker.html#create_context"},{"doc":"aws_api/sagemaker","title":"create_data_quality_job_definition","content":"pub fn create_data_quality_job_definition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_data_quality_job_definition\naws_api/sagemaker create_data_quality_job_definition","url":"aws_api/sagemaker.html#create_data_quality_job_definition"},{"doc":"aws_api/sagemaker","title":"create_device_fleet","content":"pub fn create_device_fleet(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_device_fleet\naws_api/sagemaker create_device_fleet","url":"aws_api/sagemaker.html#create_device_fleet"},{"doc":"aws_api/sagemaker","title":"create_domain","content":"pub fn create_domain(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_domain\naws_api/sagemaker create_domain","url":"aws_api/sagemaker.html#create_domain"},{"doc":"aws_api/sagemaker","title":"create_edge_deployment_plan","content":"pub fn create_edge_deployment_plan(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_edge_deployment_plan\naws_api/sagemaker create_edge_deployment_plan","url":"aws_api/sagemaker.html#create_edge_deployment_plan"},{"doc":"aws_api/sagemaker","title":"create_edge_deployment_stage","content":"pub fn create_edge_deployment_stage(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_edge_deployment_stage\naws_api/sagemaker create_edge_deployment_stage","url":"aws_api/sagemaker.html#create_edge_deployment_stage"},{"doc":"aws_api/sagemaker","title":"create_edge_packaging_job","content":"pub fn create_edge_packaging_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_edge_packaging_job\naws_api/sagemaker create_edge_packaging_job","url":"aws_api/sagemaker.html#create_edge_packaging_job"},{"doc":"aws_api/sagemaker","title":"create_endpoint","content":"pub fn create_endpoint(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_endpoint\naws_api/sagemaker create_endpoint","url":"aws_api/sagemaker.html#create_endpoint"},{"doc":"aws_api/sagemaker","title":"create_endpoint_config","content":"pub fn create_endpoint_config(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_endpoint_config\naws_api/sagemaker create_endpoint_config","url":"aws_api/sagemaker.html#create_endpoint_config"},{"doc":"aws_api/sagemaker","title":"create_experiment","content":"pub fn create_experiment(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_experiment\naws_api/sagemaker create_experiment","url":"aws_api/sagemaker.html#create_experiment"},{"doc":"aws_api/sagemaker","title":"create_feature_group","content":"pub fn create_feature_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_feature_group\naws_api/sagemaker create_feature_group","url":"aws_api/sagemaker.html#create_feature_group"},{"doc":"aws_api/sagemaker","title":"create_flow_definition","content":"pub fn create_flow_definition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_flow_definition\naws_api/sagemaker create_flow_definition","url":"aws_api/sagemaker.html#create_flow_definition"},{"doc":"aws_api/sagemaker","title":"create_hub","content":"pub fn create_hub(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_hub\naws_api/sagemaker create_hub","url":"aws_api/sagemaker.html#create_hub"},{"doc":"aws_api/sagemaker","title":"create_hub_content_reference","content":"pub fn create_hub_content_reference(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_hub_content_reference\naws_api/sagemaker create_hub_content_reference","url":"aws_api/sagemaker.html#create_hub_content_reference"},{"doc":"aws_api/sagemaker","title":"create_human_task_ui","content":"pub fn create_human_task_ui(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_human_task_ui\naws_api/sagemaker create_human_task_ui","url":"aws_api/sagemaker.html#create_human_task_ui"},{"doc":"aws_api/sagemaker","title":"create_hyper_parameter_tuning_job","content":"pub fn create_hyper_parameter_tuning_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_hyper_parameter_tuning_job\naws_api/sagemaker create_hyper_parameter_tuning_job","url":"aws_api/sagemaker.html#create_hyper_parameter_tuning_job"},{"doc":"aws_api/sagemaker","title":"create_image","content":"pub fn create_image(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_image\naws_api/sagemaker create_image","url":"aws_api/sagemaker.html#create_image"},{"doc":"aws_api/sagemaker","title":"create_image_version","content":"pub fn create_image_version(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_image_version\naws_api/sagemaker create_image_version","url":"aws_api/sagemaker.html#create_image_version"},{"doc":"aws_api/sagemaker","title":"create_inference_component","content":"pub fn create_inference_component(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_inference_component\naws_api/sagemaker create_inference_component","url":"aws_api/sagemaker.html#create_inference_component"},{"doc":"aws_api/sagemaker","title":"create_inference_experiment","content":"pub fn create_inference_experiment(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_inference_experiment\naws_api/sagemaker create_inference_experiment","url":"aws_api/sagemaker.html#create_inference_experiment"},{"doc":"aws_api/sagemaker","title":"create_inference_recommendations_job","content":"pub fn create_inference_recommendations_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_inference_recommendations_job\naws_api/sagemaker create_inference_recommendations_job","url":"aws_api/sagemaker.html#create_inference_recommendations_job"},{"doc":"aws_api/sagemaker","title":"create_labeling_job","content":"pub fn create_labeling_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_labeling_job\naws_api/sagemaker create_labeling_job","url":"aws_api/sagemaker.html#create_labeling_job"},{"doc":"aws_api/sagemaker","title":"create_mlflow_tracking_server","content":"pub fn create_mlflow_tracking_server(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_mlflow_tracking_server\naws_api/sagemaker create_mlflow_tracking_server","url":"aws_api/sagemaker.html#create_mlflow_tracking_server"},{"doc":"aws_api/sagemaker","title":"create_model","content":"pub fn create_model(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_model\naws_api/sagemaker create_model","url":"aws_api/sagemaker.html#create_model"},{"doc":"aws_api/sagemaker","title":"create_model_bias_job_definition","content":"pub fn create_model_bias_job_definition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_model_bias_job_definition\naws_api/sagemaker create_model_bias_job_definition","url":"aws_api/sagemaker.html#create_model_bias_job_definition"},{"doc":"aws_api/sagemaker","title":"create_model_card","content":"pub fn create_model_card(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_model_card\naws_api/sagemaker create_model_card","url":"aws_api/sagemaker.html#create_model_card"},{"doc":"aws_api/sagemaker","title":"create_model_card_export_job","content":"pub fn create_model_card_export_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_model_card_export_job\naws_api/sagemaker create_model_card_export_job","url":"aws_api/sagemaker.html#create_model_card_export_job"},{"doc":"aws_api/sagemaker","title":"create_model_explainability_job_definition","content":"pub fn create_model_explainability_job_definition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_model_explainability_job_definition\naws_api/sagemaker create_model_explainability_job_definition","url":"aws_api/sagemaker.html#create_model_explainability_job_definition"},{"doc":"aws_api/sagemaker","title":"create_model_package","content":"pub fn create_model_package(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_model_package\naws_api/sagemaker create_model_package","url":"aws_api/sagemaker.html#create_model_package"},{"doc":"aws_api/sagemaker","title":"create_model_package_group","content":"pub fn create_model_package_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_model_package_group\naws_api/sagemaker create_model_package_group","url":"aws_api/sagemaker.html#create_model_package_group"},{"doc":"aws_api/sagemaker","title":"create_model_quality_job_definition","content":"pub fn create_model_quality_job_definition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_model_quality_job_definition\naws_api/sagemaker create_model_quality_job_definition","url":"aws_api/sagemaker.html#create_model_quality_job_definition"},{"doc":"aws_api/sagemaker","title":"create_monitoring_schedule","content":"pub fn create_monitoring_schedule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_monitoring_schedule\naws_api/sagemaker create_monitoring_schedule","url":"aws_api/sagemaker.html#create_monitoring_schedule"},{"doc":"aws_api/sagemaker","title":"create_notebook_instance","content":"pub fn create_notebook_instance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_notebook_instance\naws_api/sagemaker create_notebook_instance","url":"aws_api/sagemaker.html#create_notebook_instance"},{"doc":"aws_api/sagemaker","title":"create_notebook_instance_lifecycle_config","content":"pub fn create_notebook_instance_lifecycle_config(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_notebook_instance_lifecycle_config\naws_api/sagemaker create_notebook_instance_lifecycle_config","url":"aws_api/sagemaker.html#create_notebook_instance_lifecycle_config"},{"doc":"aws_api/sagemaker","title":"create_optimization_job","content":"pub fn create_optimization_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_optimization_job\naws_api/sagemaker create_optimization_job","url":"aws_api/sagemaker.html#create_optimization_job"},{"doc":"aws_api/sagemaker","title":"create_pipeline","content":"pub fn create_pipeline(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_pipeline\naws_api/sagemaker create_pipeline","url":"aws_api/sagemaker.html#create_pipeline"},{"doc":"aws_api/sagemaker","title":"create_presigned_domain_url","content":"pub fn create_presigned_domain_url(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_presigned_domain_url\naws_api/sagemaker create_presigned_domain_url","url":"aws_api/sagemaker.html#create_presigned_domain_url"},{"doc":"aws_api/sagemaker","title":"create_presigned_mlflow_tracking_server_url","content":"pub fn create_presigned_mlflow_tracking_server_url(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_presigned_mlflow_tracking_server_url\naws_api/sagemaker create_presigned_mlflow_tracking_server_url","url":"aws_api/sagemaker.html#create_presigned_mlflow_tracking_server_url"},{"doc":"aws_api/sagemaker","title":"create_presigned_notebook_instance_url","content":"pub fn create_presigned_notebook_instance_url(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_presigned_notebook_instance_url\naws_api/sagemaker create_presigned_notebook_instance_url","url":"aws_api/sagemaker.html#create_presigned_notebook_instance_url"},{"doc":"aws_api/sagemaker","title":"create_processing_job","content":"pub fn create_processing_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_processing_job\naws_api/sagemaker create_processing_job","url":"aws_api/sagemaker.html#create_processing_job"},{"doc":"aws_api/sagemaker","title":"create_project","content":"pub fn create_project(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_project\naws_api/sagemaker create_project","url":"aws_api/sagemaker.html#create_project"},{"doc":"aws_api/sagemaker","title":"create_space","content":"pub fn create_space(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_space\naws_api/sagemaker create_space","url":"aws_api/sagemaker.html#create_space"},{"doc":"aws_api/sagemaker","title":"create_studio_lifecycle_config","content":"pub fn create_studio_lifecycle_config(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_studio_lifecycle_config\naws_api/sagemaker create_studio_lifecycle_config","url":"aws_api/sagemaker.html#create_studio_lifecycle_config"},{"doc":"aws_api/sagemaker","title":"create_training_job","content":"pub fn create_training_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_training_job\naws_api/sagemaker create_training_job","url":"aws_api/sagemaker.html#create_training_job"},{"doc":"aws_api/sagemaker","title":"create_transform_job","content":"pub fn create_transform_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_transform_job\naws_api/sagemaker create_transform_job","url":"aws_api/sagemaker.html#create_transform_job"},{"doc":"aws_api/sagemaker","title":"create_trial","content":"pub fn create_trial(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_trial\naws_api/sagemaker create_trial","url":"aws_api/sagemaker.html#create_trial"},{"doc":"aws_api/sagemaker","title":"create_trial_component","content":"pub fn create_trial_component(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_trial_component\naws_api/sagemaker create_trial_component","url":"aws_api/sagemaker.html#create_trial_component"},{"doc":"aws_api/sagemaker","title":"create_user_profile","content":"pub fn create_user_profile(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_user_profile\naws_api/sagemaker create_user_profile","url":"aws_api/sagemaker.html#create_user_profile"},{"doc":"aws_api/sagemaker","title":"create_workforce","content":"pub fn create_workforce(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_workforce\naws_api/sagemaker create_workforce","url":"aws_api/sagemaker.html#create_workforce"},{"doc":"aws_api/sagemaker","title":"create_workteam","content":"pub fn create_workteam(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.create_workteam\naws_api/sagemaker create_workteam","url":"aws_api/sagemaker.html#create_workteam"},{"doc":"aws_api/sagemaker","title":"delete_action","content":"pub fn delete_action(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_action\naws_api/sagemaker delete_action","url":"aws_api/sagemaker.html#delete_action"},{"doc":"aws_api/sagemaker","title":"delete_algorithm","content":"pub fn delete_algorithm(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_algorithm\naws_api/sagemaker delete_algorithm","url":"aws_api/sagemaker.html#delete_algorithm"},{"doc":"aws_api/sagemaker","title":"delete_app","content":"pub fn delete_app(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_app\naws_api/sagemaker delete_app","url":"aws_api/sagemaker.html#delete_app"},{"doc":"aws_api/sagemaker","title":"delete_app_image_config","content":"pub fn delete_app_image_config(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_app_image_config\naws_api/sagemaker delete_app_image_config","url":"aws_api/sagemaker.html#delete_app_image_config"},{"doc":"aws_api/sagemaker","title":"delete_artifact","content":"pub fn delete_artifact(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_artifact\naws_api/sagemaker delete_artifact","url":"aws_api/sagemaker.html#delete_artifact"},{"doc":"aws_api/sagemaker","title":"delete_association","content":"pub fn delete_association(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_association\naws_api/sagemaker delete_association","url":"aws_api/sagemaker.html#delete_association"},{"doc":"aws_api/sagemaker","title":"delete_cluster","content":"pub fn delete_cluster(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_cluster\naws_api/sagemaker delete_cluster","url":"aws_api/sagemaker.html#delete_cluster"},{"doc":"aws_api/sagemaker","title":"delete_code_repository","content":"pub fn delete_code_repository(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_code_repository\naws_api/sagemaker delete_code_repository","url":"aws_api/sagemaker.html#delete_code_repository"},{"doc":"aws_api/sagemaker","title":"delete_compilation_job","content":"pub fn delete_compilation_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_compilation_job\naws_api/sagemaker delete_compilation_job","url":"aws_api/sagemaker.html#delete_compilation_job"},{"doc":"aws_api/sagemaker","title":"delete_context","content":"pub fn delete_context(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_context\naws_api/sagemaker delete_context","url":"aws_api/sagemaker.html#delete_context"},{"doc":"aws_api/sagemaker","title":"delete_data_quality_job_definition","content":"pub fn delete_data_quality_job_definition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_data_quality_job_definition\naws_api/sagemaker delete_data_quality_job_definition","url":"aws_api/sagemaker.html#delete_data_quality_job_definition"},{"doc":"aws_api/sagemaker","title":"delete_device_fleet","content":"pub fn delete_device_fleet(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_device_fleet\naws_api/sagemaker delete_device_fleet","url":"aws_api/sagemaker.html#delete_device_fleet"},{"doc":"aws_api/sagemaker","title":"delete_domain","content":"pub fn delete_domain(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_domain\naws_api/sagemaker delete_domain","url":"aws_api/sagemaker.html#delete_domain"},{"doc":"aws_api/sagemaker","title":"delete_edge_deployment_plan","content":"pub fn delete_edge_deployment_plan(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_edge_deployment_plan\naws_api/sagemaker delete_edge_deployment_plan","url":"aws_api/sagemaker.html#delete_edge_deployment_plan"},{"doc":"aws_api/sagemaker","title":"delete_edge_deployment_stage","content":"pub fn delete_edge_deployment_stage(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_edge_deployment_stage\naws_api/sagemaker delete_edge_deployment_stage","url":"aws_api/sagemaker.html#delete_edge_deployment_stage"},{"doc":"aws_api/sagemaker","title":"delete_endpoint","content":"pub fn delete_endpoint(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_endpoint\naws_api/sagemaker delete_endpoint","url":"aws_api/sagemaker.html#delete_endpoint"},{"doc":"aws_api/sagemaker","title":"delete_endpoint_config","content":"pub fn delete_endpoint_config(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_endpoint_config\naws_api/sagemaker delete_endpoint_config","url":"aws_api/sagemaker.html#delete_endpoint_config"},{"doc":"aws_api/sagemaker","title":"delete_experiment","content":"pub fn delete_experiment(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_experiment\naws_api/sagemaker delete_experiment","url":"aws_api/sagemaker.html#delete_experiment"},{"doc":"aws_api/sagemaker","title":"delete_feature_group","content":"pub fn delete_feature_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_feature_group\naws_api/sagemaker delete_feature_group","url":"aws_api/sagemaker.html#delete_feature_group"},{"doc":"aws_api/sagemaker","title":"delete_flow_definition","content":"pub fn delete_flow_definition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_flow_definition\naws_api/sagemaker delete_flow_definition","url":"aws_api/sagemaker.html#delete_flow_definition"},{"doc":"aws_api/sagemaker","title":"delete_hub","content":"pub fn delete_hub(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_hub\naws_api/sagemaker delete_hub","url":"aws_api/sagemaker.html#delete_hub"},{"doc":"aws_api/sagemaker","title":"delete_hub_content","content":"pub fn delete_hub_content(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_hub_content\naws_api/sagemaker delete_hub_content","url":"aws_api/sagemaker.html#delete_hub_content"},{"doc":"aws_api/sagemaker","title":"delete_hub_content_reference","content":"pub fn delete_hub_content_reference(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_hub_content_reference\naws_api/sagemaker delete_hub_content_reference","url":"aws_api/sagemaker.html#delete_hub_content_reference"},{"doc":"aws_api/sagemaker","title":"delete_human_task_ui","content":"pub fn delete_human_task_ui(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_human_task_ui\naws_api/sagemaker delete_human_task_ui","url":"aws_api/sagemaker.html#delete_human_task_ui"},{"doc":"aws_api/sagemaker","title":"delete_hyper_parameter_tuning_job","content":"pub fn delete_hyper_parameter_tuning_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_hyper_parameter_tuning_job\naws_api/sagemaker delete_hyper_parameter_tuning_job","url":"aws_api/sagemaker.html#delete_hyper_parameter_tuning_job"},{"doc":"aws_api/sagemaker","title":"delete_image","content":"pub fn delete_image(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_image\naws_api/sagemaker delete_image","url":"aws_api/sagemaker.html#delete_image"},{"doc":"aws_api/sagemaker","title":"delete_image_version","content":"pub fn delete_image_version(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_image_version\naws_api/sagemaker delete_image_version","url":"aws_api/sagemaker.html#delete_image_version"},{"doc":"aws_api/sagemaker","title":"delete_inference_component","content":"pub fn delete_inference_component(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_inference_component\naws_api/sagemaker delete_inference_component","url":"aws_api/sagemaker.html#delete_inference_component"},{"doc":"aws_api/sagemaker","title":"delete_inference_experiment","content":"pub fn delete_inference_experiment(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_inference_experiment\naws_api/sagemaker delete_inference_experiment","url":"aws_api/sagemaker.html#delete_inference_experiment"},{"doc":"aws_api/sagemaker","title":"delete_mlflow_tracking_server","content":"pub fn delete_mlflow_tracking_server(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_mlflow_tracking_server\naws_api/sagemaker delete_mlflow_tracking_server","url":"aws_api/sagemaker.html#delete_mlflow_tracking_server"},{"doc":"aws_api/sagemaker","title":"delete_model","content":"pub fn delete_model(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_model\naws_api/sagemaker delete_model","url":"aws_api/sagemaker.html#delete_model"},{"doc":"aws_api/sagemaker","title":"delete_model_bias_job_definition","content":"pub fn delete_model_bias_job_definition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_model_bias_job_definition\naws_api/sagemaker delete_model_bias_job_definition","url":"aws_api/sagemaker.html#delete_model_bias_job_definition"},{"doc":"aws_api/sagemaker","title":"delete_model_card","content":"pub fn delete_model_card(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_model_card\naws_api/sagemaker delete_model_card","url":"aws_api/sagemaker.html#delete_model_card"},{"doc":"aws_api/sagemaker","title":"delete_model_explainability_job_definition","content":"pub fn delete_model_explainability_job_definition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_model_explainability_job_definition\naws_api/sagemaker delete_model_explainability_job_definition","url":"aws_api/sagemaker.html#delete_model_explainability_job_definition"},{"doc":"aws_api/sagemaker","title":"delete_model_package","content":"pub fn delete_model_package(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_model_package\naws_api/sagemaker delete_model_package","url":"aws_api/sagemaker.html#delete_model_package"},{"doc":"aws_api/sagemaker","title":"delete_model_package_group","content":"pub fn delete_model_package_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_model_package_group\naws_api/sagemaker delete_model_package_group","url":"aws_api/sagemaker.html#delete_model_package_group"},{"doc":"aws_api/sagemaker","title":"delete_model_package_group_policy","content":"pub fn delete_model_package_group_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_model_package_group_policy\naws_api/sagemaker delete_model_package_group_policy","url":"aws_api/sagemaker.html#delete_model_package_group_policy"},{"doc":"aws_api/sagemaker","title":"delete_model_quality_job_definition","content":"pub fn delete_model_quality_job_definition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_model_quality_job_definition\naws_api/sagemaker delete_model_quality_job_definition","url":"aws_api/sagemaker.html#delete_model_quality_job_definition"},{"doc":"aws_api/sagemaker","title":"delete_monitoring_schedule","content":"pub fn delete_monitoring_schedule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_monitoring_schedule\naws_api/sagemaker delete_monitoring_schedule","url":"aws_api/sagemaker.html#delete_monitoring_schedule"},{"doc":"aws_api/sagemaker","title":"delete_notebook_instance","content":"pub fn delete_notebook_instance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_notebook_instance\naws_api/sagemaker delete_notebook_instance","url":"aws_api/sagemaker.html#delete_notebook_instance"},{"doc":"aws_api/sagemaker","title":"delete_notebook_instance_lifecycle_config","content":"pub fn delete_notebook_instance_lifecycle_config(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_notebook_instance_lifecycle_config\naws_api/sagemaker delete_notebook_instance_lifecycle_config","url":"aws_api/sagemaker.html#delete_notebook_instance_lifecycle_config"},{"doc":"aws_api/sagemaker","title":"delete_optimization_job","content":"pub fn delete_optimization_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_optimization_job\naws_api/sagemaker delete_optimization_job","url":"aws_api/sagemaker.html#delete_optimization_job"},{"doc":"aws_api/sagemaker","title":"delete_pipeline","content":"pub fn delete_pipeline(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_pipeline\naws_api/sagemaker delete_pipeline","url":"aws_api/sagemaker.html#delete_pipeline"},{"doc":"aws_api/sagemaker","title":"delete_project","content":"pub fn delete_project(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_project\naws_api/sagemaker delete_project","url":"aws_api/sagemaker.html#delete_project"},{"doc":"aws_api/sagemaker","title":"delete_space","content":"pub fn delete_space(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_space\naws_api/sagemaker delete_space","url":"aws_api/sagemaker.html#delete_space"},{"doc":"aws_api/sagemaker","title":"delete_studio_lifecycle_config","content":"pub fn delete_studio_lifecycle_config(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_studio_lifecycle_config\naws_api/sagemaker delete_studio_lifecycle_config","url":"aws_api/sagemaker.html#delete_studio_lifecycle_config"},{"doc":"aws_api/sagemaker","title":"delete_tags","content":"pub fn delete_tags(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_tags\naws_api/sagemaker delete_tags","url":"aws_api/sagemaker.html#delete_tags"},{"doc":"aws_api/sagemaker","title":"delete_trial","content":"pub fn delete_trial(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_trial\naws_api/sagemaker delete_trial","url":"aws_api/sagemaker.html#delete_trial"},{"doc":"aws_api/sagemaker","title":"delete_trial_component","content":"pub fn delete_trial_component(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_trial_component\naws_api/sagemaker delete_trial_component","url":"aws_api/sagemaker.html#delete_trial_component"},{"doc":"aws_api/sagemaker","title":"delete_user_profile","content":"pub fn delete_user_profile(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_user_profile\naws_api/sagemaker delete_user_profile","url":"aws_api/sagemaker.html#delete_user_profile"},{"doc":"aws_api/sagemaker","title":"delete_workforce","content":"pub fn delete_workforce(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_workforce\naws_api/sagemaker delete_workforce","url":"aws_api/sagemaker.html#delete_workforce"},{"doc":"aws_api/sagemaker","title":"delete_workteam","content":"pub fn delete_workteam(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.delete_workteam\naws_api/sagemaker delete_workteam","url":"aws_api/sagemaker.html#delete_workteam"},{"doc":"aws_api/sagemaker","title":"deregister_devices","content":"pub fn deregister_devices(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.deregister_devices\naws_api/sagemaker deregister_devices","url":"aws_api/sagemaker.html#deregister_devices"},{"doc":"aws_api/sagemaker","title":"describe_action","content":"pub fn describe_action(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_action\naws_api/sagemaker describe_action","url":"aws_api/sagemaker.html#describe_action"},{"doc":"aws_api/sagemaker","title":"describe_algorithm","content":"pub fn describe_algorithm(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_algorithm\naws_api/sagemaker describe_algorithm","url":"aws_api/sagemaker.html#describe_algorithm"},{"doc":"aws_api/sagemaker","title":"describe_app","content":"pub fn describe_app(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_app\naws_api/sagemaker describe_app","url":"aws_api/sagemaker.html#describe_app"},{"doc":"aws_api/sagemaker","title":"describe_app_image_config","content":"pub fn describe_app_image_config(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_app_image_config\naws_api/sagemaker describe_app_image_config","url":"aws_api/sagemaker.html#describe_app_image_config"},{"doc":"aws_api/sagemaker","title":"describe_artifact","content":"pub fn describe_artifact(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_artifact\naws_api/sagemaker describe_artifact","url":"aws_api/sagemaker.html#describe_artifact"},{"doc":"aws_api/sagemaker","title":"describe_auto_ml_job","content":"pub fn describe_auto_ml_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_auto_ml_job\naws_api/sagemaker describe_auto_ml_job","url":"aws_api/sagemaker.html#describe_auto_ml_job"},{"doc":"aws_api/sagemaker","title":"describe_auto_ml_job_v2","content":"pub fn describe_auto_ml_job_v2(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_auto_ml_job_v2\naws_api/sagemaker describe_auto_ml_job_v2","url":"aws_api/sagemaker.html#describe_auto_ml_job_v2"},{"doc":"aws_api/sagemaker","title":"describe_cluster","content":"pub fn describe_cluster(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_cluster\naws_api/sagemaker describe_cluster","url":"aws_api/sagemaker.html#describe_cluster"},{"doc":"aws_api/sagemaker","title":"describe_cluster_node","content":"pub fn describe_cluster_node(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_cluster_node\naws_api/sagemaker describe_cluster_node","url":"aws_api/sagemaker.html#describe_cluster_node"},{"doc":"aws_api/sagemaker","title":"describe_code_repository","content":"pub fn describe_code_repository(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_code_repository\naws_api/sagemaker describe_code_repository","url":"aws_api/sagemaker.html#describe_code_repository"},{"doc":"aws_api/sagemaker","title":"describe_compilation_job","content":"pub fn describe_compilation_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_compilation_job\naws_api/sagemaker describe_compilation_job","url":"aws_api/sagemaker.html#describe_compilation_job"},{"doc":"aws_api/sagemaker","title":"describe_context","content":"pub fn describe_context(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_context\naws_api/sagemaker describe_context","url":"aws_api/sagemaker.html#describe_context"},{"doc":"aws_api/sagemaker","title":"describe_data_quality_job_definition","content":"pub fn describe_data_quality_job_definition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_data_quality_job_definition\naws_api/sagemaker describe_data_quality_job_definition","url":"aws_api/sagemaker.html#describe_data_quality_job_definition"},{"doc":"aws_api/sagemaker","title":"describe_device","content":"pub fn describe_device(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_device\naws_api/sagemaker describe_device","url":"aws_api/sagemaker.html#describe_device"},{"doc":"aws_api/sagemaker","title":"describe_device_fleet","content":"pub fn describe_device_fleet(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_device_fleet\naws_api/sagemaker describe_device_fleet","url":"aws_api/sagemaker.html#describe_device_fleet"},{"doc":"aws_api/sagemaker","title":"describe_domain","content":"pub fn describe_domain(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_domain\naws_api/sagemaker describe_domain","url":"aws_api/sagemaker.html#describe_domain"},{"doc":"aws_api/sagemaker","title":"describe_edge_deployment_plan","content":"pub fn describe_edge_deployment_plan(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_edge_deployment_plan\naws_api/sagemaker describe_edge_deployment_plan","url":"aws_api/sagemaker.html#describe_edge_deployment_plan"},{"doc":"aws_api/sagemaker","title":"describe_edge_packaging_job","content":"pub fn describe_edge_packaging_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_edge_packaging_job\naws_api/sagemaker describe_edge_packaging_job","url":"aws_api/sagemaker.html#describe_edge_packaging_job"},{"doc":"aws_api/sagemaker","title":"describe_endpoint","content":"pub fn describe_endpoint(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_endpoint\naws_api/sagemaker describe_endpoint","url":"aws_api/sagemaker.html#describe_endpoint"},{"doc":"aws_api/sagemaker","title":"describe_endpoint_config","content":"pub fn describe_endpoint_config(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_endpoint_config\naws_api/sagemaker describe_endpoint_config","url":"aws_api/sagemaker.html#describe_endpoint_config"},{"doc":"aws_api/sagemaker","title":"describe_experiment","content":"pub fn describe_experiment(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_experiment\naws_api/sagemaker describe_experiment","url":"aws_api/sagemaker.html#describe_experiment"},{"doc":"aws_api/sagemaker","title":"describe_feature_group","content":"pub fn describe_feature_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_feature_group\naws_api/sagemaker describe_feature_group","url":"aws_api/sagemaker.html#describe_feature_group"},{"doc":"aws_api/sagemaker","title":"describe_feature_metadata","content":"pub fn describe_feature_metadata(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_feature_metadata\naws_api/sagemaker describe_feature_metadata","url":"aws_api/sagemaker.html#describe_feature_metadata"},{"doc":"aws_api/sagemaker","title":"describe_flow_definition","content":"pub fn describe_flow_definition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_flow_definition\naws_api/sagemaker describe_flow_definition","url":"aws_api/sagemaker.html#describe_flow_definition"},{"doc":"aws_api/sagemaker","title":"describe_hub","content":"pub fn describe_hub(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_hub\naws_api/sagemaker describe_hub","url":"aws_api/sagemaker.html#describe_hub"},{"doc":"aws_api/sagemaker","title":"describe_hub_content","content":"pub fn describe_hub_content(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_hub_content\naws_api/sagemaker describe_hub_content","url":"aws_api/sagemaker.html#describe_hub_content"},{"doc":"aws_api/sagemaker","title":"describe_human_task_ui","content":"pub fn describe_human_task_ui(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_human_task_ui\naws_api/sagemaker describe_human_task_ui","url":"aws_api/sagemaker.html#describe_human_task_ui"},{"doc":"aws_api/sagemaker","title":"describe_hyper_parameter_tuning_job","content":"pub fn describe_hyper_parameter_tuning_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_hyper_parameter_tuning_job\naws_api/sagemaker describe_hyper_parameter_tuning_job","url":"aws_api/sagemaker.html#describe_hyper_parameter_tuning_job"},{"doc":"aws_api/sagemaker","title":"describe_image","content":"pub fn describe_image(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_image\naws_api/sagemaker describe_image","url":"aws_api/sagemaker.html#describe_image"},{"doc":"aws_api/sagemaker","title":"describe_image_version","content":"pub fn describe_image_version(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_image_version\naws_api/sagemaker describe_image_version","url":"aws_api/sagemaker.html#describe_image_version"},{"doc":"aws_api/sagemaker","title":"describe_inference_component","content":"pub fn describe_inference_component(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_inference_component\naws_api/sagemaker describe_inference_component","url":"aws_api/sagemaker.html#describe_inference_component"},{"doc":"aws_api/sagemaker","title":"describe_inference_experiment","content":"pub fn describe_inference_experiment(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_inference_experiment\naws_api/sagemaker describe_inference_experiment","url":"aws_api/sagemaker.html#describe_inference_experiment"},{"doc":"aws_api/sagemaker","title":"describe_inference_recommendations_job","content":"pub fn describe_inference_recommendations_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_inference_recommendations_job\naws_api/sagemaker describe_inference_recommendations_job","url":"aws_api/sagemaker.html#describe_inference_recommendations_job"},{"doc":"aws_api/sagemaker","title":"describe_labeling_job","content":"pub fn describe_labeling_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_labeling_job\naws_api/sagemaker describe_labeling_job","url":"aws_api/sagemaker.html#describe_labeling_job"},{"doc":"aws_api/sagemaker","title":"describe_lineage_group","content":"pub fn describe_lineage_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_lineage_group\naws_api/sagemaker describe_lineage_group","url":"aws_api/sagemaker.html#describe_lineage_group"},{"doc":"aws_api/sagemaker","title":"describe_mlflow_tracking_server","content":"pub fn describe_mlflow_tracking_server(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_mlflow_tracking_server\naws_api/sagemaker describe_mlflow_tracking_server","url":"aws_api/sagemaker.html#describe_mlflow_tracking_server"},{"doc":"aws_api/sagemaker","title":"describe_model","content":"pub fn describe_model(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_model\naws_api/sagemaker describe_model","url":"aws_api/sagemaker.html#describe_model"},{"doc":"aws_api/sagemaker","title":"describe_model_bias_job_definition","content":"pub fn describe_model_bias_job_definition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_model_bias_job_definition\naws_api/sagemaker describe_model_bias_job_definition","url":"aws_api/sagemaker.html#describe_model_bias_job_definition"},{"doc":"aws_api/sagemaker","title":"describe_model_card","content":"pub fn describe_model_card(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_model_card\naws_api/sagemaker describe_model_card","url":"aws_api/sagemaker.html#describe_model_card"},{"doc":"aws_api/sagemaker","title":"describe_model_card_export_job","content":"pub fn describe_model_card_export_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_model_card_export_job\naws_api/sagemaker describe_model_card_export_job","url":"aws_api/sagemaker.html#describe_model_card_export_job"},{"doc":"aws_api/sagemaker","title":"describe_model_explainability_job_definition","content":"pub fn describe_model_explainability_job_definition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_model_explainability_job_definition\naws_api/sagemaker describe_model_explainability_job_definition","url":"aws_api/sagemaker.html#describe_model_explainability_job_definition"},{"doc":"aws_api/sagemaker","title":"describe_model_package","content":"pub fn describe_model_package(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_model_package\naws_api/sagemaker describe_model_package","url":"aws_api/sagemaker.html#describe_model_package"},{"doc":"aws_api/sagemaker","title":"describe_model_package_group","content":"pub fn describe_model_package_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_model_package_group\naws_api/sagemaker describe_model_package_group","url":"aws_api/sagemaker.html#describe_model_package_group"},{"doc":"aws_api/sagemaker","title":"describe_model_quality_job_definition","content":"pub fn describe_model_quality_job_definition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_model_quality_job_definition\naws_api/sagemaker describe_model_quality_job_definition","url":"aws_api/sagemaker.html#describe_model_quality_job_definition"},{"doc":"aws_api/sagemaker","title":"describe_monitoring_schedule","content":"pub fn describe_monitoring_schedule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_monitoring_schedule\naws_api/sagemaker describe_monitoring_schedule","url":"aws_api/sagemaker.html#describe_monitoring_schedule"},{"doc":"aws_api/sagemaker","title":"describe_notebook_instance","content":"pub fn describe_notebook_instance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_notebook_instance\naws_api/sagemaker describe_notebook_instance","url":"aws_api/sagemaker.html#describe_notebook_instance"},{"doc":"aws_api/sagemaker","title":"describe_notebook_instance_lifecycle_config","content":"pub fn describe_notebook_instance_lifecycle_config(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_notebook_instance_lifecycle_config\naws_api/sagemaker describe_notebook_instance_lifecycle_config","url":"aws_api/sagemaker.html#describe_notebook_instance_lifecycle_config"},{"doc":"aws_api/sagemaker","title":"describe_optimization_job","content":"pub fn describe_optimization_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_optimization_job\naws_api/sagemaker describe_optimization_job","url":"aws_api/sagemaker.html#describe_optimization_job"},{"doc":"aws_api/sagemaker","title":"describe_pipeline","content":"pub fn describe_pipeline(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_pipeline\naws_api/sagemaker describe_pipeline","url":"aws_api/sagemaker.html#describe_pipeline"},{"doc":"aws_api/sagemaker","title":"describe_pipeline_definition_for_execution","content":"pub fn describe_pipeline_definition_for_execution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_pipeline_definition_for_execution\naws_api/sagemaker describe_pipeline_definition_for_execution","url":"aws_api/sagemaker.html#describe_pipeline_definition_for_execution"},{"doc":"aws_api/sagemaker","title":"describe_pipeline_execution","content":"pub fn describe_pipeline_execution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_pipeline_execution\naws_api/sagemaker describe_pipeline_execution","url":"aws_api/sagemaker.html#describe_pipeline_execution"},{"doc":"aws_api/sagemaker","title":"describe_processing_job","content":"pub fn describe_processing_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_processing_job\naws_api/sagemaker describe_processing_job","url":"aws_api/sagemaker.html#describe_processing_job"},{"doc":"aws_api/sagemaker","title":"describe_project","content":"pub fn describe_project(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_project\naws_api/sagemaker describe_project","url":"aws_api/sagemaker.html#describe_project"},{"doc":"aws_api/sagemaker","title":"describe_space","content":"pub fn describe_space(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_space\naws_api/sagemaker describe_space","url":"aws_api/sagemaker.html#describe_space"},{"doc":"aws_api/sagemaker","title":"describe_studio_lifecycle_config","content":"pub fn describe_studio_lifecycle_config(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_studio_lifecycle_config\naws_api/sagemaker describe_studio_lifecycle_config","url":"aws_api/sagemaker.html#describe_studio_lifecycle_config"},{"doc":"aws_api/sagemaker","title":"describe_subscribed_workteam","content":"pub fn describe_subscribed_workteam(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_subscribed_workteam\naws_api/sagemaker describe_subscribed_workteam","url":"aws_api/sagemaker.html#describe_subscribed_workteam"},{"doc":"aws_api/sagemaker","title":"describe_training_job","content":"pub fn describe_training_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_training_job\naws_api/sagemaker describe_training_job","url":"aws_api/sagemaker.html#describe_training_job"},{"doc":"aws_api/sagemaker","title":"describe_transform_job","content":"pub fn describe_transform_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_transform_job\naws_api/sagemaker describe_transform_job","url":"aws_api/sagemaker.html#describe_transform_job"},{"doc":"aws_api/sagemaker","title":"describe_trial","content":"pub fn describe_trial(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_trial\naws_api/sagemaker describe_trial","url":"aws_api/sagemaker.html#describe_trial"},{"doc":"aws_api/sagemaker","title":"describe_trial_component","content":"pub fn describe_trial_component(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_trial_component\naws_api/sagemaker describe_trial_component","url":"aws_api/sagemaker.html#describe_trial_component"},{"doc":"aws_api/sagemaker","title":"describe_user_profile","content":"pub fn describe_user_profile(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_user_profile\naws_api/sagemaker describe_user_profile","url":"aws_api/sagemaker.html#describe_user_profile"},{"doc":"aws_api/sagemaker","title":"describe_workforce","content":"pub fn describe_workforce(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_workforce\naws_api/sagemaker describe_workforce","url":"aws_api/sagemaker.html#describe_workforce"},{"doc":"aws_api/sagemaker","title":"describe_workteam","content":"pub fn describe_workteam(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.describe_workteam\naws_api/sagemaker describe_workteam","url":"aws_api/sagemaker.html#describe_workteam"},{"doc":"aws_api/sagemaker","title":"disable_sagemaker_servicecatalog_portfolio","content":"pub fn disable_sagemaker_servicecatalog_portfolio(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.disable_sagemaker_servicecatalog_portfolio\naws_api/sagemaker disable_sagemaker_servicecatalog_portfolio","url":"aws_api/sagemaker.html#disable_sagemaker_servicecatalog_portfolio"},{"doc":"aws_api/sagemaker","title":"disassociate_trial_component","content":"pub fn disassociate_trial_component(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.disassociate_trial_component\naws_api/sagemaker disassociate_trial_component","url":"aws_api/sagemaker.html#disassociate_trial_component"},{"doc":"aws_api/sagemaker","title":"enable_sagemaker_servicecatalog_portfolio","content":"pub fn enable_sagemaker_servicecatalog_portfolio(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.enable_sagemaker_servicecatalog_portfolio\naws_api/sagemaker enable_sagemaker_servicecatalog_portfolio","url":"aws_api/sagemaker.html#enable_sagemaker_servicecatalog_portfolio"},{"doc":"aws_api/sagemaker","title":"get_device_fleet_report","content":"pub fn get_device_fleet_report(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.get_device_fleet_report\naws_api/sagemaker get_device_fleet_report","url":"aws_api/sagemaker.html#get_device_fleet_report"},{"doc":"aws_api/sagemaker","title":"get_lineage_group_policy","content":"pub fn get_lineage_group_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.get_lineage_group_policy\naws_api/sagemaker get_lineage_group_policy","url":"aws_api/sagemaker.html#get_lineage_group_policy"},{"doc":"aws_api/sagemaker","title":"get_model_package_group_policy","content":"pub fn get_model_package_group_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.get_model_package_group_policy\naws_api/sagemaker get_model_package_group_policy","url":"aws_api/sagemaker.html#get_model_package_group_policy"},{"doc":"aws_api/sagemaker","title":"get_sagemaker_servicecatalog_portfolio_status","content":"pub fn get_sagemaker_servicecatalog_portfolio_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.get_sagemaker_servicecatalog_portfolio_status\naws_api/sagemaker get_sagemaker_servicecatalog_portfolio_status","url":"aws_api/sagemaker.html#get_sagemaker_servicecatalog_portfolio_status"},{"doc":"aws_api/sagemaker","title":"get_scaling_configuration_recommendation","content":"pub fn get_scaling_configuration_recommendation(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.get_scaling_configuration_recommendation\naws_api/sagemaker get_scaling_configuration_recommendation","url":"aws_api/sagemaker.html#get_scaling_configuration_recommendation"},{"doc":"aws_api/sagemaker","title":"get_search_suggestions","content":"pub fn get_search_suggestions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.get_search_suggestions\naws_api/sagemaker get_search_suggestions","url":"aws_api/sagemaker.html#get_search_suggestions"},{"doc":"aws_api/sagemaker","title":"import_hub_content","content":"pub fn import_hub_content(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.import_hub_content\naws_api/sagemaker import_hub_content","url":"aws_api/sagemaker.html#import_hub_content"},{"doc":"aws_api/sagemaker","title":"list_actions","content":"pub fn list_actions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_actions\naws_api/sagemaker list_actions","url":"aws_api/sagemaker.html#list_actions"},{"doc":"aws_api/sagemaker","title":"list_algorithms","content":"pub fn list_algorithms(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_algorithms\naws_api/sagemaker list_algorithms","url":"aws_api/sagemaker.html#list_algorithms"},{"doc":"aws_api/sagemaker","title":"list_aliases","content":"pub fn list_aliases(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_aliases\naws_api/sagemaker list_aliases","url":"aws_api/sagemaker.html#list_aliases"},{"doc":"aws_api/sagemaker","title":"list_app_image_configs","content":"pub fn list_app_image_configs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_app_image_configs\naws_api/sagemaker list_app_image_configs","url":"aws_api/sagemaker.html#list_app_image_configs"},{"doc":"aws_api/sagemaker","title":"list_apps","content":"pub fn list_apps(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_apps\naws_api/sagemaker list_apps","url":"aws_api/sagemaker.html#list_apps"},{"doc":"aws_api/sagemaker","title":"list_artifacts","content":"pub fn list_artifacts(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_artifacts\naws_api/sagemaker list_artifacts","url":"aws_api/sagemaker.html#list_artifacts"},{"doc":"aws_api/sagemaker","title":"list_associations","content":"pub fn list_associations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_associations\naws_api/sagemaker list_associations","url":"aws_api/sagemaker.html#list_associations"},{"doc":"aws_api/sagemaker","title":"list_auto_ml_jobs","content":"pub fn list_auto_ml_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_auto_ml_jobs\naws_api/sagemaker list_auto_ml_jobs","url":"aws_api/sagemaker.html#list_auto_ml_jobs"},{"doc":"aws_api/sagemaker","title":"list_candidates_for_auto_ml_job","content":"pub fn list_candidates_for_auto_ml_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_candidates_for_auto_ml_job\naws_api/sagemaker list_candidates_for_auto_ml_job","url":"aws_api/sagemaker.html#list_candidates_for_auto_ml_job"},{"doc":"aws_api/sagemaker","title":"list_cluster_nodes","content":"pub fn list_cluster_nodes(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_cluster_nodes\naws_api/sagemaker list_cluster_nodes","url":"aws_api/sagemaker.html#list_cluster_nodes"},{"doc":"aws_api/sagemaker","title":"list_clusters","content":"pub fn list_clusters(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_clusters\naws_api/sagemaker list_clusters","url":"aws_api/sagemaker.html#list_clusters"},{"doc":"aws_api/sagemaker","title":"list_code_repositories","content":"pub fn list_code_repositories(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_code_repositories\naws_api/sagemaker list_code_repositories","url":"aws_api/sagemaker.html#list_code_repositories"},{"doc":"aws_api/sagemaker","title":"list_compilation_jobs","content":"pub fn list_compilation_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_compilation_jobs\naws_api/sagemaker list_compilation_jobs","url":"aws_api/sagemaker.html#list_compilation_jobs"},{"doc":"aws_api/sagemaker","title":"list_contexts","content":"pub fn list_contexts(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_contexts\naws_api/sagemaker list_contexts","url":"aws_api/sagemaker.html#list_contexts"},{"doc":"aws_api/sagemaker","title":"list_data_quality_job_definitions","content":"pub fn list_data_quality_job_definitions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_data_quality_job_definitions\naws_api/sagemaker list_data_quality_job_definitions","url":"aws_api/sagemaker.html#list_data_quality_job_definitions"},{"doc":"aws_api/sagemaker","title":"list_device_fleets","content":"pub fn list_device_fleets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_device_fleets\naws_api/sagemaker list_device_fleets","url":"aws_api/sagemaker.html#list_device_fleets"},{"doc":"aws_api/sagemaker","title":"list_devices","content":"pub fn list_devices(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_devices\naws_api/sagemaker list_devices","url":"aws_api/sagemaker.html#list_devices"},{"doc":"aws_api/sagemaker","title":"list_domains","content":"pub fn list_domains(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_domains\naws_api/sagemaker list_domains","url":"aws_api/sagemaker.html#list_domains"},{"doc":"aws_api/sagemaker","title":"list_edge_deployment_plans","content":"pub fn list_edge_deployment_plans(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_edge_deployment_plans\naws_api/sagemaker list_edge_deployment_plans","url":"aws_api/sagemaker.html#list_edge_deployment_plans"},{"doc":"aws_api/sagemaker","title":"list_edge_packaging_jobs","content":"pub fn list_edge_packaging_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_edge_packaging_jobs\naws_api/sagemaker list_edge_packaging_jobs","url":"aws_api/sagemaker.html#list_edge_packaging_jobs"},{"doc":"aws_api/sagemaker","title":"list_endpoint_configs","content":"pub fn list_endpoint_configs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_endpoint_configs\naws_api/sagemaker list_endpoint_configs","url":"aws_api/sagemaker.html#list_endpoint_configs"},{"doc":"aws_api/sagemaker","title":"list_endpoints","content":"pub fn list_endpoints(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_endpoints\naws_api/sagemaker list_endpoints","url":"aws_api/sagemaker.html#list_endpoints"},{"doc":"aws_api/sagemaker","title":"list_experiments","content":"pub fn list_experiments(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_experiments\naws_api/sagemaker list_experiments","url":"aws_api/sagemaker.html#list_experiments"},{"doc":"aws_api/sagemaker","title":"list_feature_groups","content":"pub fn list_feature_groups(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_feature_groups\naws_api/sagemaker list_feature_groups","url":"aws_api/sagemaker.html#list_feature_groups"},{"doc":"aws_api/sagemaker","title":"list_flow_definitions","content":"pub fn list_flow_definitions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_flow_definitions\naws_api/sagemaker list_flow_definitions","url":"aws_api/sagemaker.html#list_flow_definitions"},{"doc":"aws_api/sagemaker","title":"list_hub_content_versions","content":"pub fn list_hub_content_versions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_hub_content_versions\naws_api/sagemaker list_hub_content_versions","url":"aws_api/sagemaker.html#list_hub_content_versions"},{"doc":"aws_api/sagemaker","title":"list_hub_contents","content":"pub fn list_hub_contents(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_hub_contents\naws_api/sagemaker list_hub_contents","url":"aws_api/sagemaker.html#list_hub_contents"},{"doc":"aws_api/sagemaker","title":"list_hubs","content":"pub fn list_hubs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_hubs\naws_api/sagemaker list_hubs","url":"aws_api/sagemaker.html#list_hubs"},{"doc":"aws_api/sagemaker","title":"list_human_task_uis","content":"pub fn list_human_task_uis(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_human_task_uis\naws_api/sagemaker list_human_task_uis","url":"aws_api/sagemaker.html#list_human_task_uis"},{"doc":"aws_api/sagemaker","title":"list_hyper_parameter_tuning_jobs","content":"pub fn list_hyper_parameter_tuning_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_hyper_parameter_tuning_jobs\naws_api/sagemaker list_hyper_parameter_tuning_jobs","url":"aws_api/sagemaker.html#list_hyper_parameter_tuning_jobs"},{"doc":"aws_api/sagemaker","title":"list_image_versions","content":"pub fn list_image_versions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_image_versions\naws_api/sagemaker list_image_versions","url":"aws_api/sagemaker.html#list_image_versions"},{"doc":"aws_api/sagemaker","title":"list_images","content":"pub fn list_images(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_images\naws_api/sagemaker list_images","url":"aws_api/sagemaker.html#list_images"},{"doc":"aws_api/sagemaker","title":"list_inference_components","content":"pub fn list_inference_components(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_inference_components\naws_api/sagemaker list_inference_components","url":"aws_api/sagemaker.html#list_inference_components"},{"doc":"aws_api/sagemaker","title":"list_inference_experiments","content":"pub fn list_inference_experiments(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_inference_experiments\naws_api/sagemaker list_inference_experiments","url":"aws_api/sagemaker.html#list_inference_experiments"},{"doc":"aws_api/sagemaker","title":"list_inference_recommendations_job_steps","content":"pub fn list_inference_recommendations_job_steps(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_inference_recommendations_job_steps\naws_api/sagemaker list_inference_recommendations_job_steps","url":"aws_api/sagemaker.html#list_inference_recommendations_job_steps"},{"doc":"aws_api/sagemaker","title":"list_inference_recommendations_jobs","content":"pub fn list_inference_recommendations_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_inference_recommendations_jobs\naws_api/sagemaker list_inference_recommendations_jobs","url":"aws_api/sagemaker.html#list_inference_recommendations_jobs"},{"doc":"aws_api/sagemaker","title":"list_labeling_jobs","content":"pub fn list_labeling_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_labeling_jobs\naws_api/sagemaker list_labeling_jobs","url":"aws_api/sagemaker.html#list_labeling_jobs"},{"doc":"aws_api/sagemaker","title":"list_labeling_jobs_for_workteam","content":"pub fn list_labeling_jobs_for_workteam(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_labeling_jobs_for_workteam\naws_api/sagemaker list_labeling_jobs_for_workteam","url":"aws_api/sagemaker.html#list_labeling_jobs_for_workteam"},{"doc":"aws_api/sagemaker","title":"list_lineage_groups","content":"pub fn list_lineage_groups(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_lineage_groups\naws_api/sagemaker list_lineage_groups","url":"aws_api/sagemaker.html#list_lineage_groups"},{"doc":"aws_api/sagemaker","title":"list_mlflow_tracking_servers","content":"pub fn list_mlflow_tracking_servers(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_mlflow_tracking_servers\naws_api/sagemaker list_mlflow_tracking_servers","url":"aws_api/sagemaker.html#list_mlflow_tracking_servers"},{"doc":"aws_api/sagemaker","title":"list_model_bias_job_definitions","content":"pub fn list_model_bias_job_definitions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_model_bias_job_definitions\naws_api/sagemaker list_model_bias_job_definitions","url":"aws_api/sagemaker.html#list_model_bias_job_definitions"},{"doc":"aws_api/sagemaker","title":"list_model_card_export_jobs","content":"pub fn list_model_card_export_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_model_card_export_jobs\naws_api/sagemaker list_model_card_export_jobs","url":"aws_api/sagemaker.html#list_model_card_export_jobs"},{"doc":"aws_api/sagemaker","title":"list_model_card_versions","content":"pub fn list_model_card_versions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_model_card_versions\naws_api/sagemaker list_model_card_versions","url":"aws_api/sagemaker.html#list_model_card_versions"},{"doc":"aws_api/sagemaker","title":"list_model_cards","content":"pub fn list_model_cards(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_model_cards\naws_api/sagemaker list_model_cards","url":"aws_api/sagemaker.html#list_model_cards"},{"doc":"aws_api/sagemaker","title":"list_model_explainability_job_definitions","content":"pub fn list_model_explainability_job_definitions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_model_explainability_job_definitions\naws_api/sagemaker list_model_explainability_job_definitions","url":"aws_api/sagemaker.html#list_model_explainability_job_definitions"},{"doc":"aws_api/sagemaker","title":"list_model_metadata","content":"pub fn list_model_metadata(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_model_metadata\naws_api/sagemaker list_model_metadata","url":"aws_api/sagemaker.html#list_model_metadata"},{"doc":"aws_api/sagemaker","title":"list_model_package_groups","content":"pub fn list_model_package_groups(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_model_package_groups\naws_api/sagemaker list_model_package_groups","url":"aws_api/sagemaker.html#list_model_package_groups"},{"doc":"aws_api/sagemaker","title":"list_model_packages","content":"pub fn list_model_packages(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_model_packages\naws_api/sagemaker list_model_packages","url":"aws_api/sagemaker.html#list_model_packages"},{"doc":"aws_api/sagemaker","title":"list_model_quality_job_definitions","content":"pub fn list_model_quality_job_definitions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_model_quality_job_definitions\naws_api/sagemaker list_model_quality_job_definitions","url":"aws_api/sagemaker.html#list_model_quality_job_definitions"},{"doc":"aws_api/sagemaker","title":"list_models","content":"pub fn list_models(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_models\naws_api/sagemaker list_models","url":"aws_api/sagemaker.html#list_models"},{"doc":"aws_api/sagemaker","title":"list_monitoring_alert_history","content":"pub fn list_monitoring_alert_history(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_monitoring_alert_history\naws_api/sagemaker list_monitoring_alert_history","url":"aws_api/sagemaker.html#list_monitoring_alert_history"},{"doc":"aws_api/sagemaker","title":"list_monitoring_alerts","content":"pub fn list_monitoring_alerts(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_monitoring_alerts\naws_api/sagemaker list_monitoring_alerts","url":"aws_api/sagemaker.html#list_monitoring_alerts"},{"doc":"aws_api/sagemaker","title":"list_monitoring_executions","content":"pub fn list_monitoring_executions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_monitoring_executions\naws_api/sagemaker list_monitoring_executions","url":"aws_api/sagemaker.html#list_monitoring_executions"},{"doc":"aws_api/sagemaker","title":"list_monitoring_schedules","content":"pub fn list_monitoring_schedules(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_monitoring_schedules\naws_api/sagemaker list_monitoring_schedules","url":"aws_api/sagemaker.html#list_monitoring_schedules"},{"doc":"aws_api/sagemaker","title":"list_notebook_instance_lifecycle_configs","content":"pub fn list_notebook_instance_lifecycle_configs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_notebook_instance_lifecycle_configs\naws_api/sagemaker list_notebook_instance_lifecycle_configs","url":"aws_api/sagemaker.html#list_notebook_instance_lifecycle_configs"},{"doc":"aws_api/sagemaker","title":"list_notebook_instances","content":"pub fn list_notebook_instances(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_notebook_instances\naws_api/sagemaker list_notebook_instances","url":"aws_api/sagemaker.html#list_notebook_instances"},{"doc":"aws_api/sagemaker","title":"list_optimization_jobs","content":"pub fn list_optimization_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_optimization_jobs\naws_api/sagemaker list_optimization_jobs","url":"aws_api/sagemaker.html#list_optimization_jobs"},{"doc":"aws_api/sagemaker","title":"list_pipeline_execution_steps","content":"pub fn list_pipeline_execution_steps(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_pipeline_execution_steps\naws_api/sagemaker list_pipeline_execution_steps","url":"aws_api/sagemaker.html#list_pipeline_execution_steps"},{"doc":"aws_api/sagemaker","title":"list_pipeline_executions","content":"pub fn list_pipeline_executions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_pipeline_executions\naws_api/sagemaker list_pipeline_executions","url":"aws_api/sagemaker.html#list_pipeline_executions"},{"doc":"aws_api/sagemaker","title":"list_pipeline_parameters_for_execution","content":"pub fn list_pipeline_parameters_for_execution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_pipeline_parameters_for_execution\naws_api/sagemaker list_pipeline_parameters_for_execution","url":"aws_api/sagemaker.html#list_pipeline_parameters_for_execution"},{"doc":"aws_api/sagemaker","title":"list_pipelines","content":"pub fn list_pipelines(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_pipelines\naws_api/sagemaker list_pipelines","url":"aws_api/sagemaker.html#list_pipelines"},{"doc":"aws_api/sagemaker","title":"list_processing_jobs","content":"pub fn list_processing_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_processing_jobs\naws_api/sagemaker list_processing_jobs","url":"aws_api/sagemaker.html#list_processing_jobs"},{"doc":"aws_api/sagemaker","title":"list_projects","content":"pub fn list_projects(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_projects\naws_api/sagemaker list_projects","url":"aws_api/sagemaker.html#list_projects"},{"doc":"aws_api/sagemaker","title":"list_resource_catalogs","content":"pub fn list_resource_catalogs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_resource_catalogs\naws_api/sagemaker list_resource_catalogs","url":"aws_api/sagemaker.html#list_resource_catalogs"},{"doc":"aws_api/sagemaker","title":"list_spaces","content":"pub fn list_spaces(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_spaces\naws_api/sagemaker list_spaces","url":"aws_api/sagemaker.html#list_spaces"},{"doc":"aws_api/sagemaker","title":"list_stage_devices","content":"pub fn list_stage_devices(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_stage_devices\naws_api/sagemaker list_stage_devices","url":"aws_api/sagemaker.html#list_stage_devices"},{"doc":"aws_api/sagemaker","title":"list_studio_lifecycle_configs","content":"pub fn list_studio_lifecycle_configs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_studio_lifecycle_configs\naws_api/sagemaker list_studio_lifecycle_configs","url":"aws_api/sagemaker.html#list_studio_lifecycle_configs"},{"doc":"aws_api/sagemaker","title":"list_subscribed_workteams","content":"pub fn list_subscribed_workteams(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_subscribed_workteams\naws_api/sagemaker list_subscribed_workteams","url":"aws_api/sagemaker.html#list_subscribed_workteams"},{"doc":"aws_api/sagemaker","title":"list_tags","content":"pub fn list_tags(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_tags\naws_api/sagemaker list_tags","url":"aws_api/sagemaker.html#list_tags"},{"doc":"aws_api/sagemaker","title":"list_training_jobs","content":"pub fn list_training_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_training_jobs\naws_api/sagemaker list_training_jobs","url":"aws_api/sagemaker.html#list_training_jobs"},{"doc":"aws_api/sagemaker","title":"list_training_jobs_for_hyper_parameter_tuning_job","content":"pub fn list_training_jobs_for_hyper_parameter_tuning_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_training_jobs_for_hyper_parameter_tuning_job\naws_api/sagemaker list_training_jobs_for_hyper_parameter_tuning_job","url":"aws_api/sagemaker.html#list_training_jobs_for_hyper_parameter_tuning_job"},{"doc":"aws_api/sagemaker","title":"list_transform_jobs","content":"pub fn list_transform_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_transform_jobs\naws_api/sagemaker list_transform_jobs","url":"aws_api/sagemaker.html#list_transform_jobs"},{"doc":"aws_api/sagemaker","title":"list_trial_components","content":"pub fn list_trial_components(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_trial_components\naws_api/sagemaker list_trial_components","url":"aws_api/sagemaker.html#list_trial_components"},{"doc":"aws_api/sagemaker","title":"list_trials","content":"pub fn list_trials(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_trials\naws_api/sagemaker list_trials","url":"aws_api/sagemaker.html#list_trials"},{"doc":"aws_api/sagemaker","title":"list_user_profiles","content":"pub fn list_user_profiles(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_user_profiles\naws_api/sagemaker list_user_profiles","url":"aws_api/sagemaker.html#list_user_profiles"},{"doc":"aws_api/sagemaker","title":"list_workforces","content":"pub fn list_workforces(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_workforces\naws_api/sagemaker list_workforces","url":"aws_api/sagemaker.html#list_workforces"},{"doc":"aws_api/sagemaker","title":"list_workteams","content":"pub fn list_workteams(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.list_workteams\naws_api/sagemaker list_workteams","url":"aws_api/sagemaker.html#list_workteams"},{"doc":"aws_api/sagemaker","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/sagemaker.new\naws_api/sagemaker new","url":"aws_api/sagemaker.html#new"},{"doc":"aws_api/sagemaker","title":"put_model_package_group_policy","content":"pub fn put_model_package_group_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.put_model_package_group_policy\naws_api/sagemaker put_model_package_group_policy","url":"aws_api/sagemaker.html#put_model_package_group_policy"},{"doc":"aws_api/sagemaker","title":"query_lineage","content":"pub fn query_lineage(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.query_lineage\naws_api/sagemaker query_lineage","url":"aws_api/sagemaker.html#query_lineage"},{"doc":"aws_api/sagemaker","title":"register_devices","content":"pub fn register_devices(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.register_devices\naws_api/sagemaker register_devices","url":"aws_api/sagemaker.html#register_devices"},{"doc":"aws_api/sagemaker","title":"render_ui_template","content":"pub fn render_ui_template(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.render_ui_template\naws_api/sagemaker render_ui_template","url":"aws_api/sagemaker.html#render_ui_template"},{"doc":"aws_api/sagemaker","title":"retry_pipeline_execution","content":"pub fn retry_pipeline_execution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.retry_pipeline_execution\naws_api/sagemaker retry_pipeline_execution","url":"aws_api/sagemaker.html#retry_pipeline_execution"},{"doc":"aws_api/sagemaker","title":"search","content":"pub fn search(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.search\naws_api/sagemaker search","url":"aws_api/sagemaker.html#search"},{"doc":"aws_api/sagemaker","title":"send_pipeline_execution_step_failure","content":"pub fn send_pipeline_execution_step_failure(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.send_pipeline_execution_step_failure\naws_api/sagemaker send_pipeline_execution_step_failure","url":"aws_api/sagemaker.html#send_pipeline_execution_step_failure"},{"doc":"aws_api/sagemaker","title":"send_pipeline_execution_step_success","content":"pub fn send_pipeline_execution_step_success(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.send_pipeline_execution_step_success\naws_api/sagemaker send_pipeline_execution_step_success","url":"aws_api/sagemaker.html#send_pipeline_execution_step_success"},{"doc":"aws_api/sagemaker","title":"start_edge_deployment_stage","content":"pub fn start_edge_deployment_stage(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.start_edge_deployment_stage\naws_api/sagemaker start_edge_deployment_stage","url":"aws_api/sagemaker.html#start_edge_deployment_stage"},{"doc":"aws_api/sagemaker","title":"start_inference_experiment","content":"pub fn start_inference_experiment(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.start_inference_experiment\naws_api/sagemaker start_inference_experiment","url":"aws_api/sagemaker.html#start_inference_experiment"},{"doc":"aws_api/sagemaker","title":"start_mlflow_tracking_server","content":"pub fn start_mlflow_tracking_server(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.start_mlflow_tracking_server\naws_api/sagemaker start_mlflow_tracking_server","url":"aws_api/sagemaker.html#start_mlflow_tracking_server"},{"doc":"aws_api/sagemaker","title":"start_monitoring_schedule","content":"pub fn start_monitoring_schedule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.start_monitoring_schedule\naws_api/sagemaker start_monitoring_schedule","url":"aws_api/sagemaker.html#start_monitoring_schedule"},{"doc":"aws_api/sagemaker","title":"start_notebook_instance","content":"pub fn start_notebook_instance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.start_notebook_instance\naws_api/sagemaker start_notebook_instance","url":"aws_api/sagemaker.html#start_notebook_instance"},{"doc":"aws_api/sagemaker","title":"start_pipeline_execution","content":"pub fn start_pipeline_execution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.start_pipeline_execution\naws_api/sagemaker start_pipeline_execution","url":"aws_api/sagemaker.html#start_pipeline_execution"},{"doc":"aws_api/sagemaker","title":"stop_auto_ml_job","content":"pub fn stop_auto_ml_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.stop_auto_ml_job\naws_api/sagemaker stop_auto_ml_job","url":"aws_api/sagemaker.html#stop_auto_ml_job"},{"doc":"aws_api/sagemaker","title":"stop_compilation_job","content":"pub fn stop_compilation_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.stop_compilation_job\naws_api/sagemaker stop_compilation_job","url":"aws_api/sagemaker.html#stop_compilation_job"},{"doc":"aws_api/sagemaker","title":"stop_edge_deployment_stage","content":"pub fn stop_edge_deployment_stage(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.stop_edge_deployment_stage\naws_api/sagemaker stop_edge_deployment_stage","url":"aws_api/sagemaker.html#stop_edge_deployment_stage"},{"doc":"aws_api/sagemaker","title":"stop_edge_packaging_job","content":"pub fn stop_edge_packaging_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.stop_edge_packaging_job\naws_api/sagemaker stop_edge_packaging_job","url":"aws_api/sagemaker.html#stop_edge_packaging_job"},{"doc":"aws_api/sagemaker","title":"stop_hyper_parameter_tuning_job","content":"pub fn stop_hyper_parameter_tuning_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.stop_hyper_parameter_tuning_job\naws_api/sagemaker stop_hyper_parameter_tuning_job","url":"aws_api/sagemaker.html#stop_hyper_parameter_tuning_job"},{"doc":"aws_api/sagemaker","title":"stop_inference_experiment","content":"pub fn stop_inference_experiment(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.stop_inference_experiment\naws_api/sagemaker stop_inference_experiment","url":"aws_api/sagemaker.html#stop_inference_experiment"},{"doc":"aws_api/sagemaker","title":"stop_inference_recommendations_job","content":"pub fn stop_inference_recommendations_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.stop_inference_recommendations_job\naws_api/sagemaker stop_inference_recommendations_job","url":"aws_api/sagemaker.html#stop_inference_recommendations_job"},{"doc":"aws_api/sagemaker","title":"stop_labeling_job","content":"pub fn stop_labeling_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.stop_labeling_job\naws_api/sagemaker stop_labeling_job","url":"aws_api/sagemaker.html#stop_labeling_job"},{"doc":"aws_api/sagemaker","title":"stop_mlflow_tracking_server","content":"pub fn stop_mlflow_tracking_server(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.stop_mlflow_tracking_server\naws_api/sagemaker stop_mlflow_tracking_server","url":"aws_api/sagemaker.html#stop_mlflow_tracking_server"},{"doc":"aws_api/sagemaker","title":"stop_monitoring_schedule","content":"pub fn stop_monitoring_schedule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.stop_monitoring_schedule\naws_api/sagemaker stop_monitoring_schedule","url":"aws_api/sagemaker.html#stop_monitoring_schedule"},{"doc":"aws_api/sagemaker","title":"stop_notebook_instance","content":"pub fn stop_notebook_instance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.stop_notebook_instance\naws_api/sagemaker stop_notebook_instance","url":"aws_api/sagemaker.html#stop_notebook_instance"},{"doc":"aws_api/sagemaker","title":"stop_optimization_job","content":"pub fn stop_optimization_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.stop_optimization_job\naws_api/sagemaker stop_optimization_job","url":"aws_api/sagemaker.html#stop_optimization_job"},{"doc":"aws_api/sagemaker","title":"stop_pipeline_execution","content":"pub fn stop_pipeline_execution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.stop_pipeline_execution\naws_api/sagemaker stop_pipeline_execution","url":"aws_api/sagemaker.html#stop_pipeline_execution"},{"doc":"aws_api/sagemaker","title":"stop_processing_job","content":"pub fn stop_processing_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.stop_processing_job\naws_api/sagemaker stop_processing_job","url":"aws_api/sagemaker.html#stop_processing_job"},{"doc":"aws_api/sagemaker","title":"stop_training_job","content":"pub fn stop_training_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.stop_training_job\naws_api/sagemaker stop_training_job","url":"aws_api/sagemaker.html#stop_training_job"},{"doc":"aws_api/sagemaker","title":"stop_transform_job","content":"pub fn stop_transform_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.stop_transform_job\naws_api/sagemaker stop_transform_job","url":"aws_api/sagemaker.html#stop_transform_job"},{"doc":"aws_api/sagemaker","title":"update_action","content":"pub fn update_action(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.update_action\naws_api/sagemaker update_action","url":"aws_api/sagemaker.html#update_action"},{"doc":"aws_api/sagemaker","title":"update_app_image_config","content":"pub fn update_app_image_config(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.update_app_image_config\naws_api/sagemaker update_app_image_config","url":"aws_api/sagemaker.html#update_app_image_config"},{"doc":"aws_api/sagemaker","title":"update_artifact","content":"pub fn update_artifact(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.update_artifact\naws_api/sagemaker update_artifact","url":"aws_api/sagemaker.html#update_artifact"},{"doc":"aws_api/sagemaker","title":"update_cluster","content":"pub fn update_cluster(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.update_cluster\naws_api/sagemaker update_cluster","url":"aws_api/sagemaker.html#update_cluster"},{"doc":"aws_api/sagemaker","title":"update_cluster_software","content":"pub fn update_cluster_software(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.update_cluster_software\naws_api/sagemaker update_cluster_software","url":"aws_api/sagemaker.html#update_cluster_software"},{"doc":"aws_api/sagemaker","title":"update_code_repository","content":"pub fn update_code_repository(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.update_code_repository\naws_api/sagemaker update_code_repository","url":"aws_api/sagemaker.html#update_code_repository"},{"doc":"aws_api/sagemaker","title":"update_context","content":"pub fn update_context(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.update_context\naws_api/sagemaker update_context","url":"aws_api/sagemaker.html#update_context"},{"doc":"aws_api/sagemaker","title":"update_device_fleet","content":"pub fn update_device_fleet(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.update_device_fleet\naws_api/sagemaker update_device_fleet","url":"aws_api/sagemaker.html#update_device_fleet"},{"doc":"aws_api/sagemaker","title":"update_devices","content":"pub fn update_devices(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.update_devices\naws_api/sagemaker update_devices","url":"aws_api/sagemaker.html#update_devices"},{"doc":"aws_api/sagemaker","title":"update_domain","content":"pub fn update_domain(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.update_domain\naws_api/sagemaker update_domain","url":"aws_api/sagemaker.html#update_domain"},{"doc":"aws_api/sagemaker","title":"update_endpoint","content":"pub fn update_endpoint(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.update_endpoint\naws_api/sagemaker update_endpoint","url":"aws_api/sagemaker.html#update_endpoint"},{"doc":"aws_api/sagemaker","title":"update_endpoint_weights_and_capacities","content":"pub fn update_endpoint_weights_and_capacities(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.update_endpoint_weights_and_capacities\naws_api/sagemaker update_endpoint_weights_and_capacities","url":"aws_api/sagemaker.html#update_endpoint_weights_and_capacities"},{"doc":"aws_api/sagemaker","title":"update_experiment","content":"pub fn update_experiment(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.update_experiment\naws_api/sagemaker update_experiment","url":"aws_api/sagemaker.html#update_experiment"},{"doc":"aws_api/sagemaker","title":"update_feature_group","content":"pub fn update_feature_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.update_feature_group\naws_api/sagemaker update_feature_group","url":"aws_api/sagemaker.html#update_feature_group"},{"doc":"aws_api/sagemaker","title":"update_feature_metadata","content":"pub fn update_feature_metadata(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.update_feature_metadata\naws_api/sagemaker update_feature_metadata","url":"aws_api/sagemaker.html#update_feature_metadata"},{"doc":"aws_api/sagemaker","title":"update_hub","content":"pub fn update_hub(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.update_hub\naws_api/sagemaker update_hub","url":"aws_api/sagemaker.html#update_hub"},{"doc":"aws_api/sagemaker","title":"update_image","content":"pub fn update_image(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.update_image\naws_api/sagemaker update_image","url":"aws_api/sagemaker.html#update_image"},{"doc":"aws_api/sagemaker","title":"update_image_version","content":"pub fn update_image_version(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.update_image_version\naws_api/sagemaker update_image_version","url":"aws_api/sagemaker.html#update_image_version"},{"doc":"aws_api/sagemaker","title":"update_inference_component","content":"pub fn update_inference_component(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.update_inference_component\naws_api/sagemaker update_inference_component","url":"aws_api/sagemaker.html#update_inference_component"},{"doc":"aws_api/sagemaker","title":"update_inference_component_runtime_config","content":"pub fn update_inference_component_runtime_config(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.update_inference_component_runtime_config\naws_api/sagemaker update_inference_component_runtime_config","url":"aws_api/sagemaker.html#update_inference_component_runtime_config"},{"doc":"aws_api/sagemaker","title":"update_inference_experiment","content":"pub fn update_inference_experiment(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.update_inference_experiment\naws_api/sagemaker update_inference_experiment","url":"aws_api/sagemaker.html#update_inference_experiment"},{"doc":"aws_api/sagemaker","title":"update_mlflow_tracking_server","content":"pub fn update_mlflow_tracking_server(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.update_mlflow_tracking_server\naws_api/sagemaker update_mlflow_tracking_server","url":"aws_api/sagemaker.html#update_mlflow_tracking_server"},{"doc":"aws_api/sagemaker","title":"update_model_card","content":"pub fn update_model_card(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.update_model_card\naws_api/sagemaker update_model_card","url":"aws_api/sagemaker.html#update_model_card"},{"doc":"aws_api/sagemaker","title":"update_model_package","content":"pub fn update_model_package(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.update_model_package\naws_api/sagemaker update_model_package","url":"aws_api/sagemaker.html#update_model_package"},{"doc":"aws_api/sagemaker","title":"update_monitoring_alert","content":"pub fn update_monitoring_alert(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.update_monitoring_alert\naws_api/sagemaker update_monitoring_alert","url":"aws_api/sagemaker.html#update_monitoring_alert"},{"doc":"aws_api/sagemaker","title":"update_monitoring_schedule","content":"pub fn update_monitoring_schedule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.update_monitoring_schedule\naws_api/sagemaker update_monitoring_schedule","url":"aws_api/sagemaker.html#update_monitoring_schedule"},{"doc":"aws_api/sagemaker","title":"update_notebook_instance","content":"pub fn update_notebook_instance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.update_notebook_instance\naws_api/sagemaker update_notebook_instance","url":"aws_api/sagemaker.html#update_notebook_instance"},{"doc":"aws_api/sagemaker","title":"update_notebook_instance_lifecycle_config","content":"pub fn update_notebook_instance_lifecycle_config(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.update_notebook_instance_lifecycle_config\naws_api/sagemaker update_notebook_instance_lifecycle_config","url":"aws_api/sagemaker.html#update_notebook_instance_lifecycle_config"},{"doc":"aws_api/sagemaker","title":"update_pipeline","content":"pub fn update_pipeline(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.update_pipeline\naws_api/sagemaker update_pipeline","url":"aws_api/sagemaker.html#update_pipeline"},{"doc":"aws_api/sagemaker","title":"update_pipeline_execution","content":"pub fn update_pipeline_execution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.update_pipeline_execution\naws_api/sagemaker update_pipeline_execution","url":"aws_api/sagemaker.html#update_pipeline_execution"},{"doc":"aws_api/sagemaker","title":"update_project","content":"pub fn update_project(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.update_project\naws_api/sagemaker update_project","url":"aws_api/sagemaker.html#update_project"},{"doc":"aws_api/sagemaker","title":"update_space","content":"pub fn update_space(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.update_space\naws_api/sagemaker update_space","url":"aws_api/sagemaker.html#update_space"},{"doc":"aws_api/sagemaker","title":"update_training_job","content":"pub fn update_training_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.update_training_job\naws_api/sagemaker update_training_job","url":"aws_api/sagemaker.html#update_training_job"},{"doc":"aws_api/sagemaker","title":"update_trial","content":"pub fn update_trial(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.update_trial\naws_api/sagemaker update_trial","url":"aws_api/sagemaker.html#update_trial"},{"doc":"aws_api/sagemaker","title":"update_trial_component","content":"pub fn update_trial_component(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.update_trial_component\naws_api/sagemaker update_trial_component","url":"aws_api/sagemaker.html#update_trial_component"},{"doc":"aws_api/sagemaker","title":"update_user_profile","content":"pub fn update_user_profile(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.update_user_profile\naws_api/sagemaker update_user_profile","url":"aws_api/sagemaker.html#update_user_profile"},{"doc":"aws_api/sagemaker","title":"update_workforce","content":"pub fn update_workforce(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.update_workforce\naws_api/sagemaker update_workforce","url":"aws_api/sagemaker.html#update_workforce"},{"doc":"aws_api/sagemaker","title":"update_workteam","content":"pub fn update_workteam(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker.update_workteam\naws_api/sagemaker update_workteam","url":"aws_api/sagemaker.html#update_workteam"},{"doc":"aws_api/sagemaker","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/sagemaker.with_custom_endpoint\naws_api/sagemaker with_custom_endpoint","url":"aws_api/sagemaker.html#with_custom_endpoint"},{"doc":"aws_api/sagemaker","title":"aws_api/sagemaker","content":"","url":"aws_api/sagemaker.html"},{"doc":"aws_api/sagemaker_edge","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/sagemaker_edge.Client\naws_api/sagemaker_edge Client","url":"aws_api/sagemaker_edge.html#Client"},{"doc":"aws_api/sagemaker_edge","title":"get_deployments","content":"pub fn get_deployments(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker_edge.get_deployments\naws_api/sagemaker_edge get_deployments","url":"aws_api/sagemaker_edge.html#get_deployments"},{"doc":"aws_api/sagemaker_edge","title":"get_device_registration","content":"pub fn get_device_registration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker_edge.get_device_registration\naws_api/sagemaker_edge get_device_registration","url":"aws_api/sagemaker_edge.html#get_device_registration"},{"doc":"aws_api/sagemaker_edge","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/sagemaker_edge.new\naws_api/sagemaker_edge new","url":"aws_api/sagemaker_edge.html#new"},{"doc":"aws_api/sagemaker_edge","title":"send_heartbeat","content":"pub fn send_heartbeat(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker_edge.send_heartbeat\naws_api/sagemaker_edge send_heartbeat","url":"aws_api/sagemaker_edge.html#send_heartbeat"},{"doc":"aws_api/sagemaker_edge","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/sagemaker_edge.with_custom_endpoint\naws_api/sagemaker_edge with_custom_endpoint","url":"aws_api/sagemaker_edge.html#with_custom_endpoint"},{"doc":"aws_api/sagemaker_edge","title":"aws_api/sagemaker_edge","content":"","url":"aws_api/sagemaker_edge.html"},{"doc":"aws_api/sagemaker_geospatial","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/sagemaker_geospatial.Client\naws_api/sagemaker_geospatial Client","url":"aws_api/sagemaker_geospatial.html#Client"},{"doc":"aws_api/sagemaker_geospatial","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker_geospatial.list_tags_for_resource\naws_api/sagemaker_geospatial list_tags_for_resource","url":"aws_api/sagemaker_geospatial.html#list_tags_for_resource"},{"doc":"aws_api/sagemaker_geospatial","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/sagemaker_geospatial.new\naws_api/sagemaker_geospatial new","url":"aws_api/sagemaker_geospatial.html#new"},{"doc":"aws_api/sagemaker_geospatial","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker_geospatial.tag_resource\naws_api/sagemaker_geospatial tag_resource","url":"aws_api/sagemaker_geospatial.html#tag_resource"},{"doc":"aws_api/sagemaker_geospatial","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker_geospatial.untag_resource\naws_api/sagemaker_geospatial untag_resource","url":"aws_api/sagemaker_geospatial.html#untag_resource"},{"doc":"aws_api/sagemaker_geospatial","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/sagemaker_geospatial.with_custom_endpoint\naws_api/sagemaker_geospatial with_custom_endpoint","url":"aws_api/sagemaker_geospatial.html#with_custom_endpoint"},{"doc":"aws_api/sagemaker_geospatial","title":"aws_api/sagemaker_geospatial","content":"","url":"aws_api/sagemaker_geospatial.html"},{"doc":"aws_api/sagemaker_metrics","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/sagemaker_metrics.Client\naws_api/sagemaker_metrics Client","url":"aws_api/sagemaker_metrics.html#Client"},{"doc":"aws_api/sagemaker_metrics","title":"batch_put_metrics","content":"pub fn batch_put_metrics(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker_metrics.batch_put_metrics\naws_api/sagemaker_metrics batch_put_metrics","url":"aws_api/sagemaker_metrics.html#batch_put_metrics"},{"doc":"aws_api/sagemaker_metrics","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/sagemaker_metrics.new\naws_api/sagemaker_metrics new","url":"aws_api/sagemaker_metrics.html#new"},{"doc":"aws_api/sagemaker_metrics","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/sagemaker_metrics.with_custom_endpoint\naws_api/sagemaker_metrics with_custom_endpoint","url":"aws_api/sagemaker_metrics.html#with_custom_endpoint"},{"doc":"aws_api/sagemaker_metrics","title":"aws_api/sagemaker_metrics","content":"","url":"aws_api/sagemaker_metrics.html"},{"doc":"aws_api/sagemaker_runtime","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/sagemaker_runtime.Client\naws_api/sagemaker_runtime Client","url":"aws_api/sagemaker_runtime.html#Client"},{"doc":"aws_api/sagemaker_runtime","title":"invoke_endpoint","content":"pub fn invoke_endpoint(\n  client: Client,\n  endpoint_name: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker_runtime.invoke_endpoint\naws_api/sagemaker_runtime invoke_endpoint","url":"aws_api/sagemaker_runtime.html#invoke_endpoint"},{"doc":"aws_api/sagemaker_runtime","title":"invoke_endpoint_async","content":"pub fn invoke_endpoint_async(\n  client: Client,\n  endpoint_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker_runtime.invoke_endpoint_async\naws_api/sagemaker_runtime invoke_endpoint_async","url":"aws_api/sagemaker_runtime.html#invoke_endpoint_async"},{"doc":"aws_api/sagemaker_runtime","title":"invoke_endpoint_with_response_stream","content":"pub fn invoke_endpoint_with_response_stream(\n  client: Client,\n  endpoint_name: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sagemaker_runtime.invoke_endpoint_with_response_stream\naws_api/sagemaker_runtime invoke_endpoint_with_response_stream","url":"aws_api/sagemaker_runtime.html#invoke_endpoint_with_response_stream"},{"doc":"aws_api/sagemaker_runtime","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/sagemaker_runtime.new\naws_api/sagemaker_runtime new","url":"aws_api/sagemaker_runtime.html#new"},{"doc":"aws_api/sagemaker_runtime","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/sagemaker_runtime.with_custom_endpoint\naws_api/sagemaker_runtime with_custom_endpoint","url":"aws_api/sagemaker_runtime.html#with_custom_endpoint"},{"doc":"aws_api/sagemaker_runtime","title":"aws_api/sagemaker_runtime","content":"","url":"aws_api/sagemaker_runtime.html"},{"doc":"aws_api/savingsplans","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/savingsplans.Client\naws_api/savingsplans Client","url":"aws_api/savingsplans.html#Client"},{"doc":"aws_api/savingsplans","title":"create_savings_plan","content":"pub fn create_savings_plan(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/savingsplans.create_savings_plan\naws_api/savingsplans create_savings_plan","url":"aws_api/savingsplans.html#create_savings_plan"},{"doc":"aws_api/savingsplans","title":"delete_queued_savings_plan","content":"pub fn delete_queued_savings_plan(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/savingsplans.delete_queued_savings_plan\naws_api/savingsplans delete_queued_savings_plan","url":"aws_api/savingsplans.html#delete_queued_savings_plan"},{"doc":"aws_api/savingsplans","title":"describe_savings_plan_rates","content":"pub fn describe_savings_plan_rates(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/savingsplans.describe_savings_plan_rates\naws_api/savingsplans describe_savings_plan_rates","url":"aws_api/savingsplans.html#describe_savings_plan_rates"},{"doc":"aws_api/savingsplans","title":"describe_savings_plans","content":"pub fn describe_savings_plans(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/savingsplans.describe_savings_plans\naws_api/savingsplans describe_savings_plans","url":"aws_api/savingsplans.html#describe_savings_plans"},{"doc":"aws_api/savingsplans","title":"describe_savings_plans_offering_rates","content":"pub fn describe_savings_plans_offering_rates(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/savingsplans.describe_savings_plans_offering_rates\naws_api/savingsplans describe_savings_plans_offering_rates","url":"aws_api/savingsplans.html#describe_savings_plans_offering_rates"},{"doc":"aws_api/savingsplans","title":"describe_savings_plans_offerings","content":"pub fn describe_savings_plans_offerings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/savingsplans.describe_savings_plans_offerings\naws_api/savingsplans describe_savings_plans_offerings","url":"aws_api/savingsplans.html#describe_savings_plans_offerings"},{"doc":"aws_api/savingsplans","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/savingsplans.list_tags_for_resource\naws_api/savingsplans list_tags_for_resource","url":"aws_api/savingsplans.html#list_tags_for_resource"},{"doc":"aws_api/savingsplans","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/savingsplans.new\naws_api/savingsplans new","url":"aws_api/savingsplans.html#new"},{"doc":"aws_api/savingsplans","title":"return_savings_plan","content":"pub fn return_savings_plan(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/savingsplans.return_savings_plan\naws_api/savingsplans return_savings_plan","url":"aws_api/savingsplans.html#return_savings_plan"},{"doc":"aws_api/savingsplans","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/savingsplans.tag_resource\naws_api/savingsplans tag_resource","url":"aws_api/savingsplans.html#tag_resource"},{"doc":"aws_api/savingsplans","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/savingsplans.untag_resource\naws_api/savingsplans untag_resource","url":"aws_api/savingsplans.html#untag_resource"},{"doc":"aws_api/savingsplans","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/savingsplans.with_custom_endpoint\naws_api/savingsplans with_custom_endpoint","url":"aws_api/savingsplans.html#with_custom_endpoint"},{"doc":"aws_api/savingsplans","title":"aws_api/savingsplans","content":"","url":"aws_api/savingsplans.html"},{"doc":"aws_api/scheduler","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/scheduler.Client\naws_api/scheduler Client","url":"aws_api/scheduler.html#Client"},{"doc":"aws_api/scheduler","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/scheduler.list_tags_for_resource\naws_api/scheduler list_tags_for_resource","url":"aws_api/scheduler.html#list_tags_for_resource"},{"doc":"aws_api/scheduler","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/scheduler.new\naws_api/scheduler new","url":"aws_api/scheduler.html#new"},{"doc":"aws_api/scheduler","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/scheduler.tag_resource\naws_api/scheduler tag_resource","url":"aws_api/scheduler.html#tag_resource"},{"doc":"aws_api/scheduler","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/scheduler.untag_resource\naws_api/scheduler untag_resource","url":"aws_api/scheduler.html#untag_resource"},{"doc":"aws_api/scheduler","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/scheduler.with_custom_endpoint\naws_api/scheduler with_custom_endpoint","url":"aws_api/scheduler.html#with_custom_endpoint"},{"doc":"aws_api/scheduler","title":"aws_api/scheduler","content":"","url":"aws_api/scheduler.html"},{"doc":"aws_api/schemas","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/schemas.Client\naws_api/schemas Client","url":"aws_api/schemas.html#Client"},{"doc":"aws_api/schemas","title":"create_discoverer","content":"pub fn create_discoverer(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/schemas.create_discoverer\naws_api/schemas create_discoverer","url":"aws_api/schemas.html#create_discoverer"},{"doc":"aws_api/schemas","title":"create_registry","content":"pub fn create_registry(\n  client: Client,\n  registry_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/schemas.create_registry\naws_api/schemas create_registry","url":"aws_api/schemas.html#create_registry"},{"doc":"aws_api/schemas","title":"create_schema","content":"pub fn create_schema(\n  client: Client,\n  registry_name: String,\n  schema_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/schemas.create_schema\naws_api/schemas create_schema","url":"aws_api/schemas.html#create_schema"},{"doc":"aws_api/schemas","title":"delete_discoverer","content":"pub fn delete_discoverer(\n  client: Client,\n  discoverer_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/schemas.delete_discoverer\naws_api/schemas delete_discoverer","url":"aws_api/schemas.html#delete_discoverer"},{"doc":"aws_api/schemas","title":"delete_registry","content":"pub fn delete_registry(\n  client: Client,\n  registry_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/schemas.delete_registry\naws_api/schemas delete_registry","url":"aws_api/schemas.html#delete_registry"},{"doc":"aws_api/schemas","title":"delete_resource_policy","content":"pub fn delete_resource_policy(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/schemas.delete_resource_policy\naws_api/schemas delete_resource_policy","url":"aws_api/schemas.html#delete_resource_policy"},{"doc":"aws_api/schemas","title":"delete_schema","content":"pub fn delete_schema(\n  client: Client,\n  registry_name: String,\n  schema_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/schemas.delete_schema\naws_api/schemas delete_schema","url":"aws_api/schemas.html#delete_schema"},{"doc":"aws_api/schemas","title":"delete_schema_version","content":"pub fn delete_schema_version(\n  client: Client,\n  registry_name: String,\n  schema_name: String,\n  schema_version: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/schemas.delete_schema_version\naws_api/schemas delete_schema_version","url":"aws_api/schemas.html#delete_schema_version"},{"doc":"aws_api/schemas","title":"describe_code_binding","content":"pub fn describe_code_binding(\n  client: Client,\n  registry_name: String,\n  schema_name: String,\n  language: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/schemas.describe_code_binding\naws_api/schemas describe_code_binding","url":"aws_api/schemas.html#describe_code_binding"},{"doc":"aws_api/schemas","title":"describe_discoverer","content":"pub fn describe_discoverer(\n  client: Client,\n  discoverer_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/schemas.describe_discoverer\naws_api/schemas describe_discoverer","url":"aws_api/schemas.html#describe_discoverer"},{"doc":"aws_api/schemas","title":"describe_registry","content":"pub fn describe_registry(\n  client: Client,\n  registry_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/schemas.describe_registry\naws_api/schemas describe_registry","url":"aws_api/schemas.html#describe_registry"},{"doc":"aws_api/schemas","title":"describe_schema","content":"pub fn describe_schema(\n  client: Client,\n  registry_name: String,\n  schema_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/schemas.describe_schema\naws_api/schemas describe_schema","url":"aws_api/schemas.html#describe_schema"},{"doc":"aws_api/schemas","title":"export_schema","content":"pub fn export_schema(\n  client: Client,\n  registry_name: String,\n  schema_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/schemas.export_schema\naws_api/schemas export_schema","url":"aws_api/schemas.html#export_schema"},{"doc":"aws_api/schemas","title":"get_code_binding_source","content":"pub fn get_code_binding_source(\n  client: Client,\n  registry_name: String,\n  schema_name: String,\n  language: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/schemas.get_code_binding_source\naws_api/schemas get_code_binding_source","url":"aws_api/schemas.html#get_code_binding_source"},{"doc":"aws_api/schemas","title":"get_discovered_schema","content":"pub fn get_discovered_schema(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/schemas.get_discovered_schema\naws_api/schemas get_discovered_schema","url":"aws_api/schemas.html#get_discovered_schema"},{"doc":"aws_api/schemas","title":"get_resource_policy","content":"pub fn get_resource_policy(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/schemas.get_resource_policy\naws_api/schemas get_resource_policy","url":"aws_api/schemas.html#get_resource_policy"},{"doc":"aws_api/schemas","title":"list_discoverers","content":"pub fn list_discoverers(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/schemas.list_discoverers\naws_api/schemas list_discoverers","url":"aws_api/schemas.html#list_discoverers"},{"doc":"aws_api/schemas","title":"list_registries","content":"pub fn list_registries(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/schemas.list_registries\naws_api/schemas list_registries","url":"aws_api/schemas.html#list_registries"},{"doc":"aws_api/schemas","title":"list_schema_versions","content":"pub fn list_schema_versions(\n  client: Client,\n  registry_name: String,\n  schema_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/schemas.list_schema_versions\naws_api/schemas list_schema_versions","url":"aws_api/schemas.html#list_schema_versions"},{"doc":"aws_api/schemas","title":"list_schemas","content":"pub fn list_schemas(\n  client: Client,\n  registry_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/schemas.list_schemas\naws_api/schemas list_schemas","url":"aws_api/schemas.html#list_schemas"},{"doc":"aws_api/schemas","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/schemas.list_tags_for_resource\naws_api/schemas list_tags_for_resource","url":"aws_api/schemas.html#list_tags_for_resource"},{"doc":"aws_api/schemas","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/schemas.new\naws_api/schemas new","url":"aws_api/schemas.html#new"},{"doc":"aws_api/schemas","title":"put_code_binding","content":"pub fn put_code_binding(\n  client: Client,\n  registry_name: String,\n  schema_name: String,\n  language: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/schemas.put_code_binding\naws_api/schemas put_code_binding","url":"aws_api/schemas.html#put_code_binding"},{"doc":"aws_api/schemas","title":"put_resource_policy","content":"pub fn put_resource_policy(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/schemas.put_resource_policy\naws_api/schemas put_resource_policy","url":"aws_api/schemas.html#put_resource_policy"},{"doc":"aws_api/schemas","title":"search_schemas","content":"pub fn search_schemas(\n  client: Client,\n  registry_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/schemas.search_schemas\naws_api/schemas search_schemas","url":"aws_api/schemas.html#search_schemas"},{"doc":"aws_api/schemas","title":"start_discoverer","content":"pub fn start_discoverer(\n  client: Client,\n  discoverer_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/schemas.start_discoverer\naws_api/schemas start_discoverer","url":"aws_api/schemas.html#start_discoverer"},{"doc":"aws_api/schemas","title":"stop_discoverer","content":"pub fn stop_discoverer(\n  client: Client,\n  discoverer_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/schemas.stop_discoverer\naws_api/schemas stop_discoverer","url":"aws_api/schemas.html#stop_discoverer"},{"doc":"aws_api/schemas","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/schemas.tag_resource\naws_api/schemas tag_resource","url":"aws_api/schemas.html#tag_resource"},{"doc":"aws_api/schemas","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/schemas.untag_resource\naws_api/schemas untag_resource","url":"aws_api/schemas.html#untag_resource"},{"doc":"aws_api/schemas","title":"update_discoverer","content":"pub fn update_discoverer(\n  client: Client,\n  discoverer_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/schemas.update_discoverer\naws_api/schemas update_discoverer","url":"aws_api/schemas.html#update_discoverer"},{"doc":"aws_api/schemas","title":"update_registry","content":"pub fn update_registry(\n  client: Client,\n  registry_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/schemas.update_registry\naws_api/schemas update_registry","url":"aws_api/schemas.html#update_registry"},{"doc":"aws_api/schemas","title":"update_schema","content":"pub fn update_schema(\n  client: Client,\n  registry_name: String,\n  schema_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/schemas.update_schema\naws_api/schemas update_schema","url":"aws_api/schemas.html#update_schema"},{"doc":"aws_api/schemas","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/schemas.with_custom_endpoint\naws_api/schemas with_custom_endpoint","url":"aws_api/schemas.html#with_custom_endpoint"},{"doc":"aws_api/schemas","title":"aws_api/schemas","content":"","url":"aws_api/schemas.html"},{"doc":"aws_api/secrets_manager","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/secrets_manager.Client\naws_api/secrets_manager Client","url":"aws_api/secrets_manager.html#Client"},{"doc":"aws_api/secrets_manager","title":"batch_get_secret_value","content":"pub fn batch_get_secret_value(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/secrets_manager.batch_get_secret_value\naws_api/secrets_manager batch_get_secret_value","url":"aws_api/secrets_manager.html#batch_get_secret_value"},{"doc":"aws_api/secrets_manager","title":"cancel_rotate_secret","content":"pub fn cancel_rotate_secret(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/secrets_manager.cancel_rotate_secret\naws_api/secrets_manager cancel_rotate_secret","url":"aws_api/secrets_manager.html#cancel_rotate_secret"},{"doc":"aws_api/secrets_manager","title":"create_secret","content":"pub fn create_secret(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/secrets_manager.create_secret\naws_api/secrets_manager create_secret","url":"aws_api/secrets_manager.html#create_secret"},{"doc":"aws_api/secrets_manager","title":"delete_resource_policy","content":"pub fn delete_resource_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/secrets_manager.delete_resource_policy\naws_api/secrets_manager delete_resource_policy","url":"aws_api/secrets_manager.html#delete_resource_policy"},{"doc":"aws_api/secrets_manager","title":"delete_secret","content":"pub fn delete_secret(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/secrets_manager.delete_secret\naws_api/secrets_manager delete_secret","url":"aws_api/secrets_manager.html#delete_secret"},{"doc":"aws_api/secrets_manager","title":"describe_secret","content":"pub fn describe_secret(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/secrets_manager.describe_secret\naws_api/secrets_manager describe_secret","url":"aws_api/secrets_manager.html#describe_secret"},{"doc":"aws_api/secrets_manager","title":"get_random_password","content":"pub fn get_random_password(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/secrets_manager.get_random_password\naws_api/secrets_manager get_random_password","url":"aws_api/secrets_manager.html#get_random_password"},{"doc":"aws_api/secrets_manager","title":"get_resource_policy","content":"pub fn get_resource_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/secrets_manager.get_resource_policy\naws_api/secrets_manager get_resource_policy","url":"aws_api/secrets_manager.html#get_resource_policy"},{"doc":"aws_api/secrets_manager","title":"get_secret_value","content":"pub fn get_secret_value(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/secrets_manager.get_secret_value\naws_api/secrets_manager get_secret_value","url":"aws_api/secrets_manager.html#get_secret_value"},{"doc":"aws_api/secrets_manager","title":"list_secret_version_ids","content":"pub fn list_secret_version_ids(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/secrets_manager.list_secret_version_ids\naws_api/secrets_manager list_secret_version_ids","url":"aws_api/secrets_manager.html#list_secret_version_ids"},{"doc":"aws_api/secrets_manager","title":"list_secrets","content":"pub fn list_secrets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/secrets_manager.list_secrets\naws_api/secrets_manager list_secrets","url":"aws_api/secrets_manager.html#list_secrets"},{"doc":"aws_api/secrets_manager","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/secrets_manager.new\naws_api/secrets_manager new","url":"aws_api/secrets_manager.html#new"},{"doc":"aws_api/secrets_manager","title":"put_resource_policy","content":"pub fn put_resource_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/secrets_manager.put_resource_policy\naws_api/secrets_manager put_resource_policy","url":"aws_api/secrets_manager.html#put_resource_policy"},{"doc":"aws_api/secrets_manager","title":"put_secret_value","content":"pub fn put_secret_value(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/secrets_manager.put_secret_value\naws_api/secrets_manager put_secret_value","url":"aws_api/secrets_manager.html#put_secret_value"},{"doc":"aws_api/secrets_manager","title":"remove_regions_from_replication","content":"pub fn remove_regions_from_replication(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/secrets_manager.remove_regions_from_replication\naws_api/secrets_manager remove_regions_from_replication","url":"aws_api/secrets_manager.html#remove_regions_from_replication"},{"doc":"aws_api/secrets_manager","title":"replicate_secret_to_regions","content":"pub fn replicate_secret_to_regions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/secrets_manager.replicate_secret_to_regions\naws_api/secrets_manager replicate_secret_to_regions","url":"aws_api/secrets_manager.html#replicate_secret_to_regions"},{"doc":"aws_api/secrets_manager","title":"restore_secret","content":"pub fn restore_secret(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/secrets_manager.restore_secret\naws_api/secrets_manager restore_secret","url":"aws_api/secrets_manager.html#restore_secret"},{"doc":"aws_api/secrets_manager","title":"rotate_secret","content":"pub fn rotate_secret(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/secrets_manager.rotate_secret\naws_api/secrets_manager rotate_secret","url":"aws_api/secrets_manager.html#rotate_secret"},{"doc":"aws_api/secrets_manager","title":"stop_replication_to_replica","content":"pub fn stop_replication_to_replica(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/secrets_manager.stop_replication_to_replica\naws_api/secrets_manager stop_replication_to_replica","url":"aws_api/secrets_manager.html#stop_replication_to_replica"},{"doc":"aws_api/secrets_manager","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/secrets_manager.tag_resource\naws_api/secrets_manager tag_resource","url":"aws_api/secrets_manager.html#tag_resource"},{"doc":"aws_api/secrets_manager","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/secrets_manager.untag_resource\naws_api/secrets_manager untag_resource","url":"aws_api/secrets_manager.html#untag_resource"},{"doc":"aws_api/secrets_manager","title":"update_secret","content":"pub fn update_secret(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/secrets_manager.update_secret\naws_api/secrets_manager update_secret","url":"aws_api/secrets_manager.html#update_secret"},{"doc":"aws_api/secrets_manager","title":"update_secret_version_stage","content":"pub fn update_secret_version_stage(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/secrets_manager.update_secret_version_stage\naws_api/secrets_manager update_secret_version_stage","url":"aws_api/secrets_manager.html#update_secret_version_stage"},{"doc":"aws_api/secrets_manager","title":"validate_resource_policy","content":"pub fn validate_resource_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/secrets_manager.validate_resource_policy\naws_api/secrets_manager validate_resource_policy","url":"aws_api/secrets_manager.html#validate_resource_policy"},{"doc":"aws_api/secrets_manager","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/secrets_manager.with_custom_endpoint\naws_api/secrets_manager with_custom_endpoint","url":"aws_api/secrets_manager.html#with_custom_endpoint"},{"doc":"aws_api/secrets_manager","title":"aws_api/secrets_manager","content":"","url":"aws_api/secrets_manager.html"},{"doc":"aws_api/securityhub","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/securityhub.Client\naws_api/securityhub Client","url":"aws_api/securityhub.html#Client"},{"doc":"aws_api/securityhub","title":"accept_administrator_invitation","content":"pub fn accept_administrator_invitation(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.accept_administrator_invitation\naws_api/securityhub accept_administrator_invitation","url":"aws_api/securityhub.html#accept_administrator_invitation"},{"doc":"aws_api/securityhub","title":"accept_invitation","content":"pub fn accept_invitation(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.accept_invitation\naws_api/securityhub accept_invitation","url":"aws_api/securityhub.html#accept_invitation"},{"doc":"aws_api/securityhub","title":"batch_delete_automation_rules","content":"pub fn batch_delete_automation_rules(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.batch_delete_automation_rules\naws_api/securityhub batch_delete_automation_rules","url":"aws_api/securityhub.html#batch_delete_automation_rules"},{"doc":"aws_api/securityhub","title":"batch_disable_standards","content":"pub fn batch_disable_standards(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.batch_disable_standards\naws_api/securityhub batch_disable_standards","url":"aws_api/securityhub.html#batch_disable_standards"},{"doc":"aws_api/securityhub","title":"batch_enable_standards","content":"pub fn batch_enable_standards(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.batch_enable_standards\naws_api/securityhub batch_enable_standards","url":"aws_api/securityhub.html#batch_enable_standards"},{"doc":"aws_api/securityhub","title":"batch_get_automation_rules","content":"pub fn batch_get_automation_rules(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.batch_get_automation_rules\naws_api/securityhub batch_get_automation_rules","url":"aws_api/securityhub.html#batch_get_automation_rules"},{"doc":"aws_api/securityhub","title":"batch_get_configuration_policy_associations","content":"pub fn batch_get_configuration_policy_associations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.batch_get_configuration_policy_associations\naws_api/securityhub batch_get_configuration_policy_associations","url":"aws_api/securityhub.html#batch_get_configuration_policy_associations"},{"doc":"aws_api/securityhub","title":"batch_get_security_controls","content":"pub fn batch_get_security_controls(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.batch_get_security_controls\naws_api/securityhub batch_get_security_controls","url":"aws_api/securityhub.html#batch_get_security_controls"},{"doc":"aws_api/securityhub","title":"batch_get_standards_control_associations","content":"pub fn batch_get_standards_control_associations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.batch_get_standards_control_associations\naws_api/securityhub batch_get_standards_control_associations","url":"aws_api/securityhub.html#batch_get_standards_control_associations"},{"doc":"aws_api/securityhub","title":"batch_import_findings","content":"pub fn batch_import_findings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.batch_import_findings\naws_api/securityhub batch_import_findings","url":"aws_api/securityhub.html#batch_import_findings"},{"doc":"aws_api/securityhub","title":"batch_update_automation_rules","content":"pub fn batch_update_automation_rules(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.batch_update_automation_rules\naws_api/securityhub batch_update_automation_rules","url":"aws_api/securityhub.html#batch_update_automation_rules"},{"doc":"aws_api/securityhub","title":"batch_update_findings","content":"pub fn batch_update_findings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.batch_update_findings\naws_api/securityhub batch_update_findings","url":"aws_api/securityhub.html#batch_update_findings"},{"doc":"aws_api/securityhub","title":"batch_update_standards_control_associations","content":"pub fn batch_update_standards_control_associations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.batch_update_standards_control_associations\naws_api/securityhub batch_update_standards_control_associations","url":"aws_api/securityhub.html#batch_update_standards_control_associations"},{"doc":"aws_api/securityhub","title":"create_action_target","content":"pub fn create_action_target(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.create_action_target\naws_api/securityhub create_action_target","url":"aws_api/securityhub.html#create_action_target"},{"doc":"aws_api/securityhub","title":"create_automation_rule","content":"pub fn create_automation_rule(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.create_automation_rule\naws_api/securityhub create_automation_rule","url":"aws_api/securityhub.html#create_automation_rule"},{"doc":"aws_api/securityhub","title":"create_configuration_policy","content":"pub fn create_configuration_policy(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.create_configuration_policy\naws_api/securityhub create_configuration_policy","url":"aws_api/securityhub.html#create_configuration_policy"},{"doc":"aws_api/securityhub","title":"create_finding_aggregator","content":"pub fn create_finding_aggregator(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.create_finding_aggregator\naws_api/securityhub create_finding_aggregator","url":"aws_api/securityhub.html#create_finding_aggregator"},{"doc":"aws_api/securityhub","title":"create_insight","content":"pub fn create_insight(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.create_insight\naws_api/securityhub create_insight","url":"aws_api/securityhub.html#create_insight"},{"doc":"aws_api/securityhub","title":"create_members","content":"pub fn create_members(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.create_members\naws_api/securityhub create_members","url":"aws_api/securityhub.html#create_members"},{"doc":"aws_api/securityhub","title":"decline_invitations","content":"pub fn decline_invitations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.decline_invitations\naws_api/securityhub decline_invitations","url":"aws_api/securityhub.html#decline_invitations"},{"doc":"aws_api/securityhub","title":"delete_action_target","content":"pub fn delete_action_target(\n  client: Client,\n  action_target_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.delete_action_target\naws_api/securityhub delete_action_target","url":"aws_api/securityhub.html#delete_action_target"},{"doc":"aws_api/securityhub","title":"delete_configuration_policy","content":"pub fn delete_configuration_policy(\n  client: Client,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.delete_configuration_policy\naws_api/securityhub delete_configuration_policy","url":"aws_api/securityhub.html#delete_configuration_policy"},{"doc":"aws_api/securityhub","title":"delete_finding_aggregator","content":"pub fn delete_finding_aggregator(\n  client: Client,\n  finding_aggregator_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.delete_finding_aggregator\naws_api/securityhub delete_finding_aggregator","url":"aws_api/securityhub.html#delete_finding_aggregator"},{"doc":"aws_api/securityhub","title":"delete_insight","content":"pub fn delete_insight(\n  client: Client,\n  insight_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.delete_insight\naws_api/securityhub delete_insight","url":"aws_api/securityhub.html#delete_insight"},{"doc":"aws_api/securityhub","title":"delete_invitations","content":"pub fn delete_invitations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.delete_invitations\naws_api/securityhub delete_invitations","url":"aws_api/securityhub.html#delete_invitations"},{"doc":"aws_api/securityhub","title":"delete_members","content":"pub fn delete_members(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.delete_members\naws_api/securityhub delete_members","url":"aws_api/securityhub.html#delete_members"},{"doc":"aws_api/securityhub","title":"describe_action_targets","content":"pub fn describe_action_targets(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.describe_action_targets\naws_api/securityhub describe_action_targets","url":"aws_api/securityhub.html#describe_action_targets"},{"doc":"aws_api/securityhub","title":"describe_hub","content":"pub fn describe_hub(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.describe_hub\naws_api/securityhub describe_hub","url":"aws_api/securityhub.html#describe_hub"},{"doc":"aws_api/securityhub","title":"describe_organization_configuration","content":"pub fn describe_organization_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.describe_organization_configuration\naws_api/securityhub describe_organization_configuration","url":"aws_api/securityhub.html#describe_organization_configuration"},{"doc":"aws_api/securityhub","title":"describe_products","content":"pub fn describe_products(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.describe_products\naws_api/securityhub describe_products","url":"aws_api/securityhub.html#describe_products"},{"doc":"aws_api/securityhub","title":"describe_standards","content":"pub fn describe_standards(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.describe_standards\naws_api/securityhub describe_standards","url":"aws_api/securityhub.html#describe_standards"},{"doc":"aws_api/securityhub","title":"describe_standards_controls","content":"pub fn describe_standards_controls(\n  client: Client,\n  standards_subscription_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.describe_standards_controls\naws_api/securityhub describe_standards_controls","url":"aws_api/securityhub.html#describe_standards_controls"},{"doc":"aws_api/securityhub","title":"disable_import_findings_for_product","content":"pub fn disable_import_findings_for_product(\n  client: Client,\n  product_subscription_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.disable_import_findings_for_product\naws_api/securityhub disable_import_findings_for_product","url":"aws_api/securityhub.html#disable_import_findings_for_product"},{"doc":"aws_api/securityhub","title":"disable_organization_admin_account","content":"pub fn disable_organization_admin_account(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.disable_organization_admin_account\naws_api/securityhub disable_organization_admin_account","url":"aws_api/securityhub.html#disable_organization_admin_account"},{"doc":"aws_api/securityhub","title":"disable_security_hub","content":"pub fn disable_security_hub(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.disable_security_hub\naws_api/securityhub disable_security_hub","url":"aws_api/securityhub.html#disable_security_hub"},{"doc":"aws_api/securityhub","title":"disassociate_from_administrator_account","content":"pub fn disassociate_from_administrator_account(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.disassociate_from_administrator_account\naws_api/securityhub disassociate_from_administrator_account","url":"aws_api/securityhub.html#disassociate_from_administrator_account"},{"doc":"aws_api/securityhub","title":"disassociate_from_master_account","content":"pub fn disassociate_from_master_account(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.disassociate_from_master_account\naws_api/securityhub disassociate_from_master_account","url":"aws_api/securityhub.html#disassociate_from_master_account"},{"doc":"aws_api/securityhub","title":"disassociate_members","content":"pub fn disassociate_members(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.disassociate_members\naws_api/securityhub disassociate_members","url":"aws_api/securityhub.html#disassociate_members"},{"doc":"aws_api/securityhub","title":"enable_import_findings_for_product","content":"pub fn enable_import_findings_for_product(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.enable_import_findings_for_product\naws_api/securityhub enable_import_findings_for_product","url":"aws_api/securityhub.html#enable_import_findings_for_product"},{"doc":"aws_api/securityhub","title":"enable_organization_admin_account","content":"pub fn enable_organization_admin_account(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.enable_organization_admin_account\naws_api/securityhub enable_organization_admin_account","url":"aws_api/securityhub.html#enable_organization_admin_account"},{"doc":"aws_api/securityhub","title":"enable_security_hub","content":"pub fn enable_security_hub(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.enable_security_hub\naws_api/securityhub enable_security_hub","url":"aws_api/securityhub.html#enable_security_hub"},{"doc":"aws_api/securityhub","title":"get_administrator_account","content":"pub fn get_administrator_account(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.get_administrator_account\naws_api/securityhub get_administrator_account","url":"aws_api/securityhub.html#get_administrator_account"},{"doc":"aws_api/securityhub","title":"get_configuration_policy","content":"pub fn get_configuration_policy(\n  client: Client,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.get_configuration_policy\naws_api/securityhub get_configuration_policy","url":"aws_api/securityhub.html#get_configuration_policy"},{"doc":"aws_api/securityhub","title":"get_configuration_policy_association","content":"pub fn get_configuration_policy_association(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.get_configuration_policy_association\naws_api/securityhub get_configuration_policy_association","url":"aws_api/securityhub.html#get_configuration_policy_association"},{"doc":"aws_api/securityhub","title":"get_enabled_standards","content":"pub fn get_enabled_standards(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.get_enabled_standards\naws_api/securityhub get_enabled_standards","url":"aws_api/securityhub.html#get_enabled_standards"},{"doc":"aws_api/securityhub","title":"get_finding_aggregator","content":"pub fn get_finding_aggregator(\n  client: Client,\n  finding_aggregator_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.get_finding_aggregator\naws_api/securityhub get_finding_aggregator","url":"aws_api/securityhub.html#get_finding_aggregator"},{"doc":"aws_api/securityhub","title":"get_finding_history","content":"pub fn get_finding_history(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.get_finding_history\naws_api/securityhub get_finding_history","url":"aws_api/securityhub.html#get_finding_history"},{"doc":"aws_api/securityhub","title":"get_findings","content":"pub fn get_findings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.get_findings\naws_api/securityhub get_findings","url":"aws_api/securityhub.html#get_findings"},{"doc":"aws_api/securityhub","title":"get_insight_results","content":"pub fn get_insight_results(\n  client: Client,\n  insight_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.get_insight_results\naws_api/securityhub get_insight_results","url":"aws_api/securityhub.html#get_insight_results"},{"doc":"aws_api/securityhub","title":"get_insights","content":"pub fn get_insights(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.get_insights\naws_api/securityhub get_insights","url":"aws_api/securityhub.html#get_insights"},{"doc":"aws_api/securityhub","title":"get_invitations_count","content":"pub fn get_invitations_count(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.get_invitations_count\naws_api/securityhub get_invitations_count","url":"aws_api/securityhub.html#get_invitations_count"},{"doc":"aws_api/securityhub","title":"get_master_account","content":"pub fn get_master_account(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.get_master_account\naws_api/securityhub get_master_account","url":"aws_api/securityhub.html#get_master_account"},{"doc":"aws_api/securityhub","title":"get_members","content":"pub fn get_members(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.get_members\naws_api/securityhub get_members","url":"aws_api/securityhub.html#get_members"},{"doc":"aws_api/securityhub","title":"get_security_control_definition","content":"pub fn get_security_control_definition(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.get_security_control_definition\naws_api/securityhub get_security_control_definition","url":"aws_api/securityhub.html#get_security_control_definition"},{"doc":"aws_api/securityhub","title":"invite_members","content":"pub fn invite_members(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.invite_members\naws_api/securityhub invite_members","url":"aws_api/securityhub.html#invite_members"},{"doc":"aws_api/securityhub","title":"list_automation_rules","content":"pub fn list_automation_rules(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.list_automation_rules\naws_api/securityhub list_automation_rules","url":"aws_api/securityhub.html#list_automation_rules"},{"doc":"aws_api/securityhub","title":"list_configuration_policies","content":"pub fn list_configuration_policies(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.list_configuration_policies\naws_api/securityhub list_configuration_policies","url":"aws_api/securityhub.html#list_configuration_policies"},{"doc":"aws_api/securityhub","title":"list_configuration_policy_associations","content":"pub fn list_configuration_policy_associations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.list_configuration_policy_associations\naws_api/securityhub list_configuration_policy_associations","url":"aws_api/securityhub.html#list_configuration_policy_associations"},{"doc":"aws_api/securityhub","title":"list_enabled_products_for_import","content":"pub fn list_enabled_products_for_import(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.list_enabled_products_for_import\naws_api/securityhub list_enabled_products_for_import","url":"aws_api/securityhub.html#list_enabled_products_for_import"},{"doc":"aws_api/securityhub","title":"list_finding_aggregators","content":"pub fn list_finding_aggregators(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.list_finding_aggregators\naws_api/securityhub list_finding_aggregators","url":"aws_api/securityhub.html#list_finding_aggregators"},{"doc":"aws_api/securityhub","title":"list_invitations","content":"pub fn list_invitations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.list_invitations\naws_api/securityhub list_invitations","url":"aws_api/securityhub.html#list_invitations"},{"doc":"aws_api/securityhub","title":"list_members","content":"pub fn list_members(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.list_members\naws_api/securityhub list_members","url":"aws_api/securityhub.html#list_members"},{"doc":"aws_api/securityhub","title":"list_organization_admin_accounts","content":"pub fn list_organization_admin_accounts(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.list_organization_admin_accounts\naws_api/securityhub list_organization_admin_accounts","url":"aws_api/securityhub.html#list_organization_admin_accounts"},{"doc":"aws_api/securityhub","title":"list_security_control_definitions","content":"pub fn list_security_control_definitions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.list_security_control_definitions\naws_api/securityhub list_security_control_definitions","url":"aws_api/securityhub.html#list_security_control_definitions"},{"doc":"aws_api/securityhub","title":"list_standards_control_associations","content":"pub fn list_standards_control_associations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.list_standards_control_associations\naws_api/securityhub list_standards_control_associations","url":"aws_api/securityhub.html#list_standards_control_associations"},{"doc":"aws_api/securityhub","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.list_tags_for_resource\naws_api/securityhub list_tags_for_resource","url":"aws_api/securityhub.html#list_tags_for_resource"},{"doc":"aws_api/securityhub","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/securityhub.new\naws_api/securityhub new","url":"aws_api/securityhub.html#new"},{"doc":"aws_api/securityhub","title":"start_configuration_policy_association","content":"pub fn start_configuration_policy_association(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.start_configuration_policy_association\naws_api/securityhub start_configuration_policy_association","url":"aws_api/securityhub.html#start_configuration_policy_association"},{"doc":"aws_api/securityhub","title":"start_configuration_policy_disassociation","content":"pub fn start_configuration_policy_disassociation(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.start_configuration_policy_disassociation\naws_api/securityhub start_configuration_policy_disassociation","url":"aws_api/securityhub.html#start_configuration_policy_disassociation"},{"doc":"aws_api/securityhub","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.tag_resource\naws_api/securityhub tag_resource","url":"aws_api/securityhub.html#tag_resource"},{"doc":"aws_api/securityhub","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.untag_resource\naws_api/securityhub untag_resource","url":"aws_api/securityhub.html#untag_resource"},{"doc":"aws_api/securityhub","title":"update_action_target","content":"pub fn update_action_target(\n  client: Client,\n  action_target_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.update_action_target\naws_api/securityhub update_action_target","url":"aws_api/securityhub.html#update_action_target"},{"doc":"aws_api/securityhub","title":"update_configuration_policy","content":"pub fn update_configuration_policy(\n  client: Client,\n  identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.update_configuration_policy\naws_api/securityhub update_configuration_policy","url":"aws_api/securityhub.html#update_configuration_policy"},{"doc":"aws_api/securityhub","title":"update_finding_aggregator","content":"pub fn update_finding_aggregator(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.update_finding_aggregator\naws_api/securityhub update_finding_aggregator","url":"aws_api/securityhub.html#update_finding_aggregator"},{"doc":"aws_api/securityhub","title":"update_findings","content":"pub fn update_findings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.update_findings\naws_api/securityhub update_findings","url":"aws_api/securityhub.html#update_findings"},{"doc":"aws_api/securityhub","title":"update_insight","content":"pub fn update_insight(\n  client: Client,\n  insight_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.update_insight\naws_api/securityhub update_insight","url":"aws_api/securityhub.html#update_insight"},{"doc":"aws_api/securityhub","title":"update_organization_configuration","content":"pub fn update_organization_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.update_organization_configuration\naws_api/securityhub update_organization_configuration","url":"aws_api/securityhub.html#update_organization_configuration"},{"doc":"aws_api/securityhub","title":"update_security_control","content":"pub fn update_security_control(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.update_security_control\naws_api/securityhub update_security_control","url":"aws_api/securityhub.html#update_security_control"},{"doc":"aws_api/securityhub","title":"update_security_hub_configuration","content":"pub fn update_security_hub_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.update_security_hub_configuration\naws_api/securityhub update_security_hub_configuration","url":"aws_api/securityhub.html#update_security_hub_configuration"},{"doc":"aws_api/securityhub","title":"update_standards_control","content":"pub fn update_standards_control(\n  client: Client,\n  standards_control_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securityhub.update_standards_control\naws_api/securityhub update_standards_control","url":"aws_api/securityhub.html#update_standards_control"},{"doc":"aws_api/securityhub","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/securityhub.with_custom_endpoint\naws_api/securityhub with_custom_endpoint","url":"aws_api/securityhub.html#with_custom_endpoint"},{"doc":"aws_api/securityhub","title":"aws_api/securityhub","content":"","url":"aws_api/securityhub.html"},{"doc":"aws_api/securitylake","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/securitylake.Client\naws_api/securitylake Client","url":"aws_api/securitylake.html#Client"},{"doc":"aws_api/securitylake","title":"create_data_lake_exception_subscription","content":"pub fn create_data_lake_exception_subscription(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securitylake.create_data_lake_exception_subscription\naws_api/securitylake create_data_lake_exception_subscription","url":"aws_api/securitylake.html#create_data_lake_exception_subscription"},{"doc":"aws_api/securitylake","title":"delete_data_lake_exception_subscription","content":"pub fn delete_data_lake_exception_subscription(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securitylake.delete_data_lake_exception_subscription\naws_api/securitylake delete_data_lake_exception_subscription","url":"aws_api/securitylake.html#delete_data_lake_exception_subscription"},{"doc":"aws_api/securitylake","title":"deregister_data_lake_delegated_administrator","content":"pub fn deregister_data_lake_delegated_administrator(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securitylake.deregister_data_lake_delegated_administrator\naws_api/securitylake deregister_data_lake_delegated_administrator","url":"aws_api/securitylake.html#deregister_data_lake_delegated_administrator"},{"doc":"aws_api/securitylake","title":"get_data_lake_exception_subscription","content":"pub fn get_data_lake_exception_subscription(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securitylake.get_data_lake_exception_subscription\naws_api/securitylake get_data_lake_exception_subscription","url":"aws_api/securitylake.html#get_data_lake_exception_subscription"},{"doc":"aws_api/securitylake","title":"list_data_lake_exceptions","content":"pub fn list_data_lake_exceptions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securitylake.list_data_lake_exceptions\naws_api/securitylake list_data_lake_exceptions","url":"aws_api/securitylake.html#list_data_lake_exceptions"},{"doc":"aws_api/securitylake","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securitylake.list_tags_for_resource\naws_api/securitylake list_tags_for_resource","url":"aws_api/securitylake.html#list_tags_for_resource"},{"doc":"aws_api/securitylake","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/securitylake.new\naws_api/securitylake new","url":"aws_api/securitylake.html#new"},{"doc":"aws_api/securitylake","title":"register_data_lake_delegated_administrator","content":"pub fn register_data_lake_delegated_administrator(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securitylake.register_data_lake_delegated_administrator\naws_api/securitylake register_data_lake_delegated_administrator","url":"aws_api/securitylake.html#register_data_lake_delegated_administrator"},{"doc":"aws_api/securitylake","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securitylake.tag_resource\naws_api/securitylake tag_resource","url":"aws_api/securitylake.html#tag_resource"},{"doc":"aws_api/securitylake","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securitylake.untag_resource\naws_api/securitylake untag_resource","url":"aws_api/securitylake.html#untag_resource"},{"doc":"aws_api/securitylake","title":"update_data_lake_exception_subscription","content":"pub fn update_data_lake_exception_subscription(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/securitylake.update_data_lake_exception_subscription\naws_api/securitylake update_data_lake_exception_subscription","url":"aws_api/securitylake.html#update_data_lake_exception_subscription"},{"doc":"aws_api/securitylake","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/securitylake.with_custom_endpoint\naws_api/securitylake with_custom_endpoint","url":"aws_api/securitylake.html#with_custom_endpoint"},{"doc":"aws_api/securitylake","title":"aws_api/securitylake","content":"","url":"aws_api/securitylake.html"},{"doc":"aws_api/serverlessapplicationrepository","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/serverlessapplicationrepository.Client\naws_api/serverlessapplicationrepository Client","url":"aws_api/serverlessapplicationrepository.html#Client"},{"doc":"aws_api/serverlessapplicationrepository","title":"create_application","content":"pub fn create_application(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/serverlessapplicationrepository.create_application\naws_api/serverlessapplicationrepository create_application","url":"aws_api/serverlessapplicationrepository.html#create_application"},{"doc":"aws_api/serverlessapplicationrepository","title":"create_application_version","content":"pub fn create_application_version(\n  client: Client,\n  application_id: String,\n  semantic_version: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/serverlessapplicationrepository.create_application_version\naws_api/serverlessapplicationrepository create_application_version","url":"aws_api/serverlessapplicationrepository.html#create_application_version"},{"doc":"aws_api/serverlessapplicationrepository","title":"create_cloud_formation_change_set","content":"pub fn create_cloud_formation_change_set(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/serverlessapplicationrepository.create_cloud_formation_change_set\naws_api/serverlessapplicationrepository create_cloud_formation_change_set","url":"aws_api/serverlessapplicationrepository.html#create_cloud_formation_change_set"},{"doc":"aws_api/serverlessapplicationrepository","title":"create_cloud_formation_template","content":"pub fn create_cloud_formation_template(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/serverlessapplicationrepository.create_cloud_formation_template\naws_api/serverlessapplicationrepository create_cloud_formation_template","url":"aws_api/serverlessapplicationrepository.html#create_cloud_formation_template"},{"doc":"aws_api/serverlessapplicationrepository","title":"delete_application","content":"pub fn delete_application(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/serverlessapplicationrepository.delete_application\naws_api/serverlessapplicationrepository delete_application","url":"aws_api/serverlessapplicationrepository.html#delete_application"},{"doc":"aws_api/serverlessapplicationrepository","title":"get_application","content":"pub fn get_application(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/serverlessapplicationrepository.get_application\naws_api/serverlessapplicationrepository get_application","url":"aws_api/serverlessapplicationrepository.html#get_application"},{"doc":"aws_api/serverlessapplicationrepository","title":"get_application_policy","content":"pub fn get_application_policy(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/serverlessapplicationrepository.get_application_policy\naws_api/serverlessapplicationrepository get_application_policy","url":"aws_api/serverlessapplicationrepository.html#get_application_policy"},{"doc":"aws_api/serverlessapplicationrepository","title":"get_cloud_formation_template","content":"pub fn get_cloud_formation_template(\n  client: Client,\n  application_id: String,\n  template_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/serverlessapplicationrepository.get_cloud_formation_template\naws_api/serverlessapplicationrepository get_cloud_formation_template","url":"aws_api/serverlessapplicationrepository.html#get_cloud_formation_template"},{"doc":"aws_api/serverlessapplicationrepository","title":"list_application_dependencies","content":"pub fn list_application_dependencies(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/serverlessapplicationrepository.list_application_dependencies\naws_api/serverlessapplicationrepository list_application_dependencies","url":"aws_api/serverlessapplicationrepository.html#list_application_dependencies"},{"doc":"aws_api/serverlessapplicationrepository","title":"list_application_versions","content":"pub fn list_application_versions(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/serverlessapplicationrepository.list_application_versions\naws_api/serverlessapplicationrepository list_application_versions","url":"aws_api/serverlessapplicationrepository.html#list_application_versions"},{"doc":"aws_api/serverlessapplicationrepository","title":"list_applications","content":"pub fn list_applications(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/serverlessapplicationrepository.list_applications\naws_api/serverlessapplicationrepository list_applications","url":"aws_api/serverlessapplicationrepository.html#list_applications"},{"doc":"aws_api/serverlessapplicationrepository","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/serverlessapplicationrepository.new\naws_api/serverlessapplicationrepository new","url":"aws_api/serverlessapplicationrepository.html#new"},{"doc":"aws_api/serverlessapplicationrepository","title":"put_application_policy","content":"pub fn put_application_policy(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/serverlessapplicationrepository.put_application_policy\naws_api/serverlessapplicationrepository put_application_policy","url":"aws_api/serverlessapplicationrepository.html#put_application_policy"},{"doc":"aws_api/serverlessapplicationrepository","title":"unshare_application","content":"pub fn unshare_application(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/serverlessapplicationrepository.unshare_application\naws_api/serverlessapplicationrepository unshare_application","url":"aws_api/serverlessapplicationrepository.html#unshare_application"},{"doc":"aws_api/serverlessapplicationrepository","title":"update_application","content":"pub fn update_application(\n  client: Client,\n  application_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/serverlessapplicationrepository.update_application\naws_api/serverlessapplicationrepository update_application","url":"aws_api/serverlessapplicationrepository.html#update_application"},{"doc":"aws_api/serverlessapplicationrepository","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/serverlessapplicationrepository.with_custom_endpoint\naws_api/serverlessapplicationrepository with_custom_endpoint","url":"aws_api/serverlessapplicationrepository.html#with_custom_endpoint"},{"doc":"aws_api/serverlessapplicationrepository","title":"aws_api/serverlessapplicationrepository","content":"","url":"aws_api/serverlessapplicationrepository.html"},{"doc":"aws_api/service_catalog","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/service_catalog.Client\naws_api/service_catalog Client","url":"aws_api/service_catalog.html#Client"},{"doc":"aws_api/service_catalog","title":"accept_portfolio_share","content":"pub fn accept_portfolio_share(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.accept_portfolio_share\naws_api/service_catalog accept_portfolio_share","url":"aws_api/service_catalog.html#accept_portfolio_share"},{"doc":"aws_api/service_catalog","title":"associate_budget_with_resource","content":"pub fn associate_budget_with_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.associate_budget_with_resource\naws_api/service_catalog associate_budget_with_resource","url":"aws_api/service_catalog.html#associate_budget_with_resource"},{"doc":"aws_api/service_catalog","title":"associate_principal_with_portfolio","content":"pub fn associate_principal_with_portfolio(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.associate_principal_with_portfolio\naws_api/service_catalog associate_principal_with_portfolio","url":"aws_api/service_catalog.html#associate_principal_with_portfolio"},{"doc":"aws_api/service_catalog","title":"associate_product_with_portfolio","content":"pub fn associate_product_with_portfolio(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.associate_product_with_portfolio\naws_api/service_catalog associate_product_with_portfolio","url":"aws_api/service_catalog.html#associate_product_with_portfolio"},{"doc":"aws_api/service_catalog","title":"associate_service_action_with_provisioning_artifact","content":"pub fn associate_service_action_with_provisioning_artifact(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.associate_service_action_with_provisioning_artifact\naws_api/service_catalog associate_service_action_with_provisioning_artifact","url":"aws_api/service_catalog.html#associate_service_action_with_provisioning_artifact"},{"doc":"aws_api/service_catalog","title":"associate_tag_option_with_resource","content":"pub fn associate_tag_option_with_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.associate_tag_option_with_resource\naws_api/service_catalog associate_tag_option_with_resource","url":"aws_api/service_catalog.html#associate_tag_option_with_resource"},{"doc":"aws_api/service_catalog","title":"batch_associate_service_action_with_provisioning_artifact","content":"pub fn batch_associate_service_action_with_provisioning_artifact(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.batch_associate_service_action_with_provisioning_artifact\naws_api/service_catalog batch_associate_service_action_with_provisioning_artifact","url":"aws_api/service_catalog.html#batch_associate_service_action_with_provisioning_artifact"},{"doc":"aws_api/service_catalog","title":"batch_disassociate_service_action_from_provisioning_artifact","content":"pub fn batch_disassociate_service_action_from_provisioning_artifact(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.batch_disassociate_service_action_from_provisioning_artifact\naws_api/service_catalog batch_disassociate_service_action_from_provisioning_artifact","url":"aws_api/service_catalog.html#batch_disassociate_service_action_from_provisioning_artifact"},{"doc":"aws_api/service_catalog","title":"copy_product","content":"pub fn copy_product(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.copy_product\naws_api/service_catalog copy_product","url":"aws_api/service_catalog.html#copy_product"},{"doc":"aws_api/service_catalog","title":"create_constraint","content":"pub fn create_constraint(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.create_constraint\naws_api/service_catalog create_constraint","url":"aws_api/service_catalog.html#create_constraint"},{"doc":"aws_api/service_catalog","title":"create_portfolio","content":"pub fn create_portfolio(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.create_portfolio\naws_api/service_catalog create_portfolio","url":"aws_api/service_catalog.html#create_portfolio"},{"doc":"aws_api/service_catalog","title":"create_portfolio_share","content":"pub fn create_portfolio_share(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.create_portfolio_share\naws_api/service_catalog create_portfolio_share","url":"aws_api/service_catalog.html#create_portfolio_share"},{"doc":"aws_api/service_catalog","title":"create_product","content":"pub fn create_product(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.create_product\naws_api/service_catalog create_product","url":"aws_api/service_catalog.html#create_product"},{"doc":"aws_api/service_catalog","title":"create_provisioned_product_plan","content":"pub fn create_provisioned_product_plan(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.create_provisioned_product_plan\naws_api/service_catalog create_provisioned_product_plan","url":"aws_api/service_catalog.html#create_provisioned_product_plan"},{"doc":"aws_api/service_catalog","title":"create_provisioning_artifact","content":"pub fn create_provisioning_artifact(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.create_provisioning_artifact\naws_api/service_catalog create_provisioning_artifact","url":"aws_api/service_catalog.html#create_provisioning_artifact"},{"doc":"aws_api/service_catalog","title":"create_service_action","content":"pub fn create_service_action(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.create_service_action\naws_api/service_catalog create_service_action","url":"aws_api/service_catalog.html#create_service_action"},{"doc":"aws_api/service_catalog","title":"create_tag_option","content":"pub fn create_tag_option(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.create_tag_option\naws_api/service_catalog create_tag_option","url":"aws_api/service_catalog.html#create_tag_option"},{"doc":"aws_api/service_catalog","title":"delete_constraint","content":"pub fn delete_constraint(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.delete_constraint\naws_api/service_catalog delete_constraint","url":"aws_api/service_catalog.html#delete_constraint"},{"doc":"aws_api/service_catalog","title":"delete_portfolio","content":"pub fn delete_portfolio(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.delete_portfolio\naws_api/service_catalog delete_portfolio","url":"aws_api/service_catalog.html#delete_portfolio"},{"doc":"aws_api/service_catalog","title":"delete_portfolio_share","content":"pub fn delete_portfolio_share(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.delete_portfolio_share\naws_api/service_catalog delete_portfolio_share","url":"aws_api/service_catalog.html#delete_portfolio_share"},{"doc":"aws_api/service_catalog","title":"delete_product","content":"pub fn delete_product(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.delete_product\naws_api/service_catalog delete_product","url":"aws_api/service_catalog.html#delete_product"},{"doc":"aws_api/service_catalog","title":"delete_provisioned_product_plan","content":"pub fn delete_provisioned_product_plan(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.delete_provisioned_product_plan\naws_api/service_catalog delete_provisioned_product_plan","url":"aws_api/service_catalog.html#delete_provisioned_product_plan"},{"doc":"aws_api/service_catalog","title":"delete_provisioning_artifact","content":"pub fn delete_provisioning_artifact(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.delete_provisioning_artifact\naws_api/service_catalog delete_provisioning_artifact","url":"aws_api/service_catalog.html#delete_provisioning_artifact"},{"doc":"aws_api/service_catalog","title":"delete_service_action","content":"pub fn delete_service_action(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.delete_service_action\naws_api/service_catalog delete_service_action","url":"aws_api/service_catalog.html#delete_service_action"},{"doc":"aws_api/service_catalog","title":"delete_tag_option","content":"pub fn delete_tag_option(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.delete_tag_option\naws_api/service_catalog delete_tag_option","url":"aws_api/service_catalog.html#delete_tag_option"},{"doc":"aws_api/service_catalog","title":"describe_constraint","content":"pub fn describe_constraint(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.describe_constraint\naws_api/service_catalog describe_constraint","url":"aws_api/service_catalog.html#describe_constraint"},{"doc":"aws_api/service_catalog","title":"describe_copy_product_status","content":"pub fn describe_copy_product_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.describe_copy_product_status\naws_api/service_catalog describe_copy_product_status","url":"aws_api/service_catalog.html#describe_copy_product_status"},{"doc":"aws_api/service_catalog","title":"describe_portfolio","content":"pub fn describe_portfolio(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.describe_portfolio\naws_api/service_catalog describe_portfolio","url":"aws_api/service_catalog.html#describe_portfolio"},{"doc":"aws_api/service_catalog","title":"describe_portfolio_share_status","content":"pub fn describe_portfolio_share_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.describe_portfolio_share_status\naws_api/service_catalog describe_portfolio_share_status","url":"aws_api/service_catalog.html#describe_portfolio_share_status"},{"doc":"aws_api/service_catalog","title":"describe_portfolio_shares","content":"pub fn describe_portfolio_shares(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.describe_portfolio_shares\naws_api/service_catalog describe_portfolio_shares","url":"aws_api/service_catalog.html#describe_portfolio_shares"},{"doc":"aws_api/service_catalog","title":"describe_product","content":"pub fn describe_product(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.describe_product\naws_api/service_catalog describe_product","url":"aws_api/service_catalog.html#describe_product"},{"doc":"aws_api/service_catalog","title":"describe_product_as_admin","content":"pub fn describe_product_as_admin(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.describe_product_as_admin\naws_api/service_catalog describe_product_as_admin","url":"aws_api/service_catalog.html#describe_product_as_admin"},{"doc":"aws_api/service_catalog","title":"describe_product_view","content":"pub fn describe_product_view(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.describe_product_view\naws_api/service_catalog describe_product_view","url":"aws_api/service_catalog.html#describe_product_view"},{"doc":"aws_api/service_catalog","title":"describe_provisioned_product","content":"pub fn describe_provisioned_product(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.describe_provisioned_product\naws_api/service_catalog describe_provisioned_product","url":"aws_api/service_catalog.html#describe_provisioned_product"},{"doc":"aws_api/service_catalog","title":"describe_provisioned_product_plan","content":"pub fn describe_provisioned_product_plan(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.describe_provisioned_product_plan\naws_api/service_catalog describe_provisioned_product_plan","url":"aws_api/service_catalog.html#describe_provisioned_product_plan"},{"doc":"aws_api/service_catalog","title":"describe_provisioning_artifact","content":"pub fn describe_provisioning_artifact(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.describe_provisioning_artifact\naws_api/service_catalog describe_provisioning_artifact","url":"aws_api/service_catalog.html#describe_provisioning_artifact"},{"doc":"aws_api/service_catalog","title":"describe_provisioning_parameters","content":"pub fn describe_provisioning_parameters(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.describe_provisioning_parameters\naws_api/service_catalog describe_provisioning_parameters","url":"aws_api/service_catalog.html#describe_provisioning_parameters"},{"doc":"aws_api/service_catalog","title":"describe_record","content":"pub fn describe_record(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.describe_record\naws_api/service_catalog describe_record","url":"aws_api/service_catalog.html#describe_record"},{"doc":"aws_api/service_catalog","title":"describe_service_action","content":"pub fn describe_service_action(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.describe_service_action\naws_api/service_catalog describe_service_action","url":"aws_api/service_catalog.html#describe_service_action"},{"doc":"aws_api/service_catalog","title":"describe_service_action_execution_parameters","content":"pub fn describe_service_action_execution_parameters(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.describe_service_action_execution_parameters\naws_api/service_catalog describe_service_action_execution_parameters","url":"aws_api/service_catalog.html#describe_service_action_execution_parameters"},{"doc":"aws_api/service_catalog","title":"describe_tag_option","content":"pub fn describe_tag_option(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.describe_tag_option\naws_api/service_catalog describe_tag_option","url":"aws_api/service_catalog.html#describe_tag_option"},{"doc":"aws_api/service_catalog","title":"disable_aws_organizations_access","content":"pub fn disable_aws_organizations_access(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.disable_aws_organizations_access\naws_api/service_catalog disable_aws_organizations_access","url":"aws_api/service_catalog.html#disable_aws_organizations_access"},{"doc":"aws_api/service_catalog","title":"disassociate_budget_from_resource","content":"pub fn disassociate_budget_from_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.disassociate_budget_from_resource\naws_api/service_catalog disassociate_budget_from_resource","url":"aws_api/service_catalog.html#disassociate_budget_from_resource"},{"doc":"aws_api/service_catalog","title":"disassociate_principal_from_portfolio","content":"pub fn disassociate_principal_from_portfolio(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.disassociate_principal_from_portfolio\naws_api/service_catalog disassociate_principal_from_portfolio","url":"aws_api/service_catalog.html#disassociate_principal_from_portfolio"},{"doc":"aws_api/service_catalog","title":"disassociate_product_from_portfolio","content":"pub fn disassociate_product_from_portfolio(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.disassociate_product_from_portfolio\naws_api/service_catalog disassociate_product_from_portfolio","url":"aws_api/service_catalog.html#disassociate_product_from_portfolio"},{"doc":"aws_api/service_catalog","title":"disassociate_service_action_from_provisioning_artifact","content":"pub fn disassociate_service_action_from_provisioning_artifact(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.disassociate_service_action_from_provisioning_artifact\naws_api/service_catalog disassociate_service_action_from_provisioning_artifact","url":"aws_api/service_catalog.html#disassociate_service_action_from_provisioning_artifact"},{"doc":"aws_api/service_catalog","title":"disassociate_tag_option_from_resource","content":"pub fn disassociate_tag_option_from_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.disassociate_tag_option_from_resource\naws_api/service_catalog disassociate_tag_option_from_resource","url":"aws_api/service_catalog.html#disassociate_tag_option_from_resource"},{"doc":"aws_api/service_catalog","title":"enable_aws_organizations_access","content":"pub fn enable_aws_organizations_access(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.enable_aws_organizations_access\naws_api/service_catalog enable_aws_organizations_access","url":"aws_api/service_catalog.html#enable_aws_organizations_access"},{"doc":"aws_api/service_catalog","title":"execute_provisioned_product_plan","content":"pub fn execute_provisioned_product_plan(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.execute_provisioned_product_plan\naws_api/service_catalog execute_provisioned_product_plan","url":"aws_api/service_catalog.html#execute_provisioned_product_plan"},{"doc":"aws_api/service_catalog","title":"execute_provisioned_product_service_action","content":"pub fn execute_provisioned_product_service_action(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.execute_provisioned_product_service_action\naws_api/service_catalog execute_provisioned_product_service_action","url":"aws_api/service_catalog.html#execute_provisioned_product_service_action"},{"doc":"aws_api/service_catalog","title":"get_aws_organizations_access_status","content":"pub fn get_aws_organizations_access_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.get_aws_organizations_access_status\naws_api/service_catalog get_aws_organizations_access_status","url":"aws_api/service_catalog.html#get_aws_organizations_access_status"},{"doc":"aws_api/service_catalog","title":"get_provisioned_product_outputs","content":"pub fn get_provisioned_product_outputs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.get_provisioned_product_outputs\naws_api/service_catalog get_provisioned_product_outputs","url":"aws_api/service_catalog.html#get_provisioned_product_outputs"},{"doc":"aws_api/service_catalog","title":"import_as_provisioned_product","content":"pub fn import_as_provisioned_product(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.import_as_provisioned_product\naws_api/service_catalog import_as_provisioned_product","url":"aws_api/service_catalog.html#import_as_provisioned_product"},{"doc":"aws_api/service_catalog","title":"list_accepted_portfolio_shares","content":"pub fn list_accepted_portfolio_shares(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.list_accepted_portfolio_shares\naws_api/service_catalog list_accepted_portfolio_shares","url":"aws_api/service_catalog.html#list_accepted_portfolio_shares"},{"doc":"aws_api/service_catalog","title":"list_budgets_for_resource","content":"pub fn list_budgets_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.list_budgets_for_resource\naws_api/service_catalog list_budgets_for_resource","url":"aws_api/service_catalog.html#list_budgets_for_resource"},{"doc":"aws_api/service_catalog","title":"list_constraints_for_portfolio","content":"pub fn list_constraints_for_portfolio(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.list_constraints_for_portfolio\naws_api/service_catalog list_constraints_for_portfolio","url":"aws_api/service_catalog.html#list_constraints_for_portfolio"},{"doc":"aws_api/service_catalog","title":"list_launch_paths","content":"pub fn list_launch_paths(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.list_launch_paths\naws_api/service_catalog list_launch_paths","url":"aws_api/service_catalog.html#list_launch_paths"},{"doc":"aws_api/service_catalog","title":"list_organization_portfolio_access","content":"pub fn list_organization_portfolio_access(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.list_organization_portfolio_access\naws_api/service_catalog list_organization_portfolio_access","url":"aws_api/service_catalog.html#list_organization_portfolio_access"},{"doc":"aws_api/service_catalog","title":"list_portfolio_access","content":"pub fn list_portfolio_access(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.list_portfolio_access\naws_api/service_catalog list_portfolio_access","url":"aws_api/service_catalog.html#list_portfolio_access"},{"doc":"aws_api/service_catalog","title":"list_portfolios","content":"pub fn list_portfolios(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.list_portfolios\naws_api/service_catalog list_portfolios","url":"aws_api/service_catalog.html#list_portfolios"},{"doc":"aws_api/service_catalog","title":"list_portfolios_for_product","content":"pub fn list_portfolios_for_product(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.list_portfolios_for_product\naws_api/service_catalog list_portfolios_for_product","url":"aws_api/service_catalog.html#list_portfolios_for_product"},{"doc":"aws_api/service_catalog","title":"list_principals_for_portfolio","content":"pub fn list_principals_for_portfolio(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.list_principals_for_portfolio\naws_api/service_catalog list_principals_for_portfolio","url":"aws_api/service_catalog.html#list_principals_for_portfolio"},{"doc":"aws_api/service_catalog","title":"list_provisioned_product_plans","content":"pub fn list_provisioned_product_plans(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.list_provisioned_product_plans\naws_api/service_catalog list_provisioned_product_plans","url":"aws_api/service_catalog.html#list_provisioned_product_plans"},{"doc":"aws_api/service_catalog","title":"list_provisioning_artifacts","content":"pub fn list_provisioning_artifacts(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.list_provisioning_artifacts\naws_api/service_catalog list_provisioning_artifacts","url":"aws_api/service_catalog.html#list_provisioning_artifacts"},{"doc":"aws_api/service_catalog","title":"list_provisioning_artifacts_for_service_action","content":"pub fn list_provisioning_artifacts_for_service_action(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.list_provisioning_artifacts_for_service_action\naws_api/service_catalog list_provisioning_artifacts_for_service_action","url":"aws_api/service_catalog.html#list_provisioning_artifacts_for_service_action"},{"doc":"aws_api/service_catalog","title":"list_record_history","content":"pub fn list_record_history(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.list_record_history\naws_api/service_catalog list_record_history","url":"aws_api/service_catalog.html#list_record_history"},{"doc":"aws_api/service_catalog","title":"list_resources_for_tag_option","content":"pub fn list_resources_for_tag_option(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.list_resources_for_tag_option\naws_api/service_catalog list_resources_for_tag_option","url":"aws_api/service_catalog.html#list_resources_for_tag_option"},{"doc":"aws_api/service_catalog","title":"list_service_actions","content":"pub fn list_service_actions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.list_service_actions\naws_api/service_catalog list_service_actions","url":"aws_api/service_catalog.html#list_service_actions"},{"doc":"aws_api/service_catalog","title":"list_service_actions_for_provisioning_artifact","content":"pub fn list_service_actions_for_provisioning_artifact(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.list_service_actions_for_provisioning_artifact\naws_api/service_catalog list_service_actions_for_provisioning_artifact","url":"aws_api/service_catalog.html#list_service_actions_for_provisioning_artifact"},{"doc":"aws_api/service_catalog","title":"list_stack_instances_for_provisioned_product","content":"pub fn list_stack_instances_for_provisioned_product(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.list_stack_instances_for_provisioned_product\naws_api/service_catalog list_stack_instances_for_provisioned_product","url":"aws_api/service_catalog.html#list_stack_instances_for_provisioned_product"},{"doc":"aws_api/service_catalog","title":"list_tag_options","content":"pub fn list_tag_options(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.list_tag_options\naws_api/service_catalog list_tag_options","url":"aws_api/service_catalog.html#list_tag_options"},{"doc":"aws_api/service_catalog","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/service_catalog.new\naws_api/service_catalog new","url":"aws_api/service_catalog.html#new"},{"doc":"aws_api/service_catalog","title":"notify_provision_product_engine_workflow_result","content":"pub fn notify_provision_product_engine_workflow_result(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.notify_provision_product_engine_workflow_result\naws_api/service_catalog notify_provision_product_engine_workflow_result","url":"aws_api/service_catalog.html#notify_provision_product_engine_workflow_result"},{"doc":"aws_api/service_catalog","title":"notify_terminate_provisioned_product_engine_workflow_result","content":"pub fn notify_terminate_provisioned_product_engine_workflow_result(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.notify_terminate_provisioned_product_engine_workflow_result\naws_api/service_catalog notify_terminate_provisioned_product_engine_workflow_result","url":"aws_api/service_catalog.html#notify_terminate_provisioned_product_engine_workflow_result"},{"doc":"aws_api/service_catalog","title":"notify_update_provisioned_product_engine_workflow_result","content":"pub fn notify_update_provisioned_product_engine_workflow_result(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.notify_update_provisioned_product_engine_workflow_result\naws_api/service_catalog notify_update_provisioned_product_engine_workflow_result","url":"aws_api/service_catalog.html#notify_update_provisioned_product_engine_workflow_result"},{"doc":"aws_api/service_catalog","title":"provision_product","content":"pub fn provision_product(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.provision_product\naws_api/service_catalog provision_product","url":"aws_api/service_catalog.html#provision_product"},{"doc":"aws_api/service_catalog","title":"reject_portfolio_share","content":"pub fn reject_portfolio_share(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.reject_portfolio_share\naws_api/service_catalog reject_portfolio_share","url":"aws_api/service_catalog.html#reject_portfolio_share"},{"doc":"aws_api/service_catalog","title":"scan_provisioned_products","content":"pub fn scan_provisioned_products(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.scan_provisioned_products\naws_api/service_catalog scan_provisioned_products","url":"aws_api/service_catalog.html#scan_provisioned_products"},{"doc":"aws_api/service_catalog","title":"search_products","content":"pub fn search_products(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.search_products\naws_api/service_catalog search_products","url":"aws_api/service_catalog.html#search_products"},{"doc":"aws_api/service_catalog","title":"search_products_as_admin","content":"pub fn search_products_as_admin(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.search_products_as_admin\naws_api/service_catalog search_products_as_admin","url":"aws_api/service_catalog.html#search_products_as_admin"},{"doc":"aws_api/service_catalog","title":"search_provisioned_products","content":"pub fn search_provisioned_products(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.search_provisioned_products\naws_api/service_catalog search_provisioned_products","url":"aws_api/service_catalog.html#search_provisioned_products"},{"doc":"aws_api/service_catalog","title":"terminate_provisioned_product","content":"pub fn terminate_provisioned_product(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.terminate_provisioned_product\naws_api/service_catalog terminate_provisioned_product","url":"aws_api/service_catalog.html#terminate_provisioned_product"},{"doc":"aws_api/service_catalog","title":"update_constraint","content":"pub fn update_constraint(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.update_constraint\naws_api/service_catalog update_constraint","url":"aws_api/service_catalog.html#update_constraint"},{"doc":"aws_api/service_catalog","title":"update_portfolio","content":"pub fn update_portfolio(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.update_portfolio\naws_api/service_catalog update_portfolio","url":"aws_api/service_catalog.html#update_portfolio"},{"doc":"aws_api/service_catalog","title":"update_portfolio_share","content":"pub fn update_portfolio_share(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.update_portfolio_share\naws_api/service_catalog update_portfolio_share","url":"aws_api/service_catalog.html#update_portfolio_share"},{"doc":"aws_api/service_catalog","title":"update_product","content":"pub fn update_product(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.update_product\naws_api/service_catalog update_product","url":"aws_api/service_catalog.html#update_product"},{"doc":"aws_api/service_catalog","title":"update_provisioned_product","content":"pub fn update_provisioned_product(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.update_provisioned_product\naws_api/service_catalog update_provisioned_product","url":"aws_api/service_catalog.html#update_provisioned_product"},{"doc":"aws_api/service_catalog","title":"update_provisioned_product_properties","content":"pub fn update_provisioned_product_properties(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.update_provisioned_product_properties\naws_api/service_catalog update_provisioned_product_properties","url":"aws_api/service_catalog.html#update_provisioned_product_properties"},{"doc":"aws_api/service_catalog","title":"update_provisioning_artifact","content":"pub fn update_provisioning_artifact(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.update_provisioning_artifact\naws_api/service_catalog update_provisioning_artifact","url":"aws_api/service_catalog.html#update_provisioning_artifact"},{"doc":"aws_api/service_catalog","title":"update_service_action","content":"pub fn update_service_action(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.update_service_action\naws_api/service_catalog update_service_action","url":"aws_api/service_catalog.html#update_service_action"},{"doc":"aws_api/service_catalog","title":"update_tag_option","content":"pub fn update_tag_option(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog.update_tag_option\naws_api/service_catalog update_tag_option","url":"aws_api/service_catalog.html#update_tag_option"},{"doc":"aws_api/service_catalog","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/service_catalog.with_custom_endpoint\naws_api/service_catalog with_custom_endpoint","url":"aws_api/service_catalog.html#with_custom_endpoint"},{"doc":"aws_api/service_catalog","title":"aws_api/service_catalog","content":"","url":"aws_api/service_catalog.html"},{"doc":"aws_api/service_catalog_appregistry","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/service_catalog_appregistry.Client\naws_api/service_catalog_appregistry Client","url":"aws_api/service_catalog_appregistry.html#Client"},{"doc":"aws_api/service_catalog_appregistry","title":"associate_attribute_group","content":"pub fn associate_attribute_group(\n  client: Client,\n  application: String,\n  attribute_group: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog_appregistry.associate_attribute_group\naws_api/service_catalog_appregistry associate_attribute_group","url":"aws_api/service_catalog_appregistry.html#associate_attribute_group"},{"doc":"aws_api/service_catalog_appregistry","title":"associate_resource","content":"pub fn associate_resource(\n  client: Client,\n  application: String,\n  resource_type: String,\n  resource: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog_appregistry.associate_resource\naws_api/service_catalog_appregistry associate_resource","url":"aws_api/service_catalog_appregistry.html#associate_resource"},{"doc":"aws_api/service_catalog_appregistry","title":"create_application","content":"pub fn create_application(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog_appregistry.create_application\naws_api/service_catalog_appregistry create_application","url":"aws_api/service_catalog_appregistry.html#create_application"},{"doc":"aws_api/service_catalog_appregistry","title":"create_attribute_group","content":"pub fn create_attribute_group(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog_appregistry.create_attribute_group\naws_api/service_catalog_appregistry create_attribute_group","url":"aws_api/service_catalog_appregistry.html#create_attribute_group"},{"doc":"aws_api/service_catalog_appregistry","title":"delete_application","content":"pub fn delete_application(\n  client: Client,\n  application: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog_appregistry.delete_application\naws_api/service_catalog_appregistry delete_application","url":"aws_api/service_catalog_appregistry.html#delete_application"},{"doc":"aws_api/service_catalog_appregistry","title":"delete_attribute_group","content":"pub fn delete_attribute_group(\n  client: Client,\n  attribute_group: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog_appregistry.delete_attribute_group\naws_api/service_catalog_appregistry delete_attribute_group","url":"aws_api/service_catalog_appregistry.html#delete_attribute_group"},{"doc":"aws_api/service_catalog_appregistry","title":"disassociate_attribute_group","content":"pub fn disassociate_attribute_group(\n  client: Client,\n  application: String,\n  attribute_group: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog_appregistry.disassociate_attribute_group\naws_api/service_catalog_appregistry disassociate_attribute_group","url":"aws_api/service_catalog_appregistry.html#disassociate_attribute_group"},{"doc":"aws_api/service_catalog_appregistry","title":"disassociate_resource","content":"pub fn disassociate_resource(\n  client: Client,\n  application: String,\n  resource_type: String,\n  resource: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog_appregistry.disassociate_resource\naws_api/service_catalog_appregistry disassociate_resource","url":"aws_api/service_catalog_appregistry.html#disassociate_resource"},{"doc":"aws_api/service_catalog_appregistry","title":"get_application","content":"pub fn get_application(\n  client: Client,\n  application: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog_appregistry.get_application\naws_api/service_catalog_appregistry get_application","url":"aws_api/service_catalog_appregistry.html#get_application"},{"doc":"aws_api/service_catalog_appregistry","title":"get_associated_resource","content":"pub fn get_associated_resource(\n  client: Client,\n  application: String,\n  resource_type: String,\n  resource: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog_appregistry.get_associated_resource\naws_api/service_catalog_appregistry get_associated_resource","url":"aws_api/service_catalog_appregistry.html#get_associated_resource"},{"doc":"aws_api/service_catalog_appregistry","title":"get_attribute_group","content":"pub fn get_attribute_group(\n  client: Client,\n  attribute_group: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog_appregistry.get_attribute_group\naws_api/service_catalog_appregistry get_attribute_group","url":"aws_api/service_catalog_appregistry.html#get_attribute_group"},{"doc":"aws_api/service_catalog_appregistry","title":"get_configuration","content":"pub fn get_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog_appregistry.get_configuration\naws_api/service_catalog_appregistry get_configuration","url":"aws_api/service_catalog_appregistry.html#get_configuration"},{"doc":"aws_api/service_catalog_appregistry","title":"list_applications","content":"pub fn list_applications(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog_appregistry.list_applications\naws_api/service_catalog_appregistry list_applications","url":"aws_api/service_catalog_appregistry.html#list_applications"},{"doc":"aws_api/service_catalog_appregistry","title":"list_associated_attribute_groups","content":"pub fn list_associated_attribute_groups(\n  client: Client,\n  application: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog_appregistry.list_associated_attribute_groups\naws_api/service_catalog_appregistry list_associated_attribute_groups","url":"aws_api/service_catalog_appregistry.html#list_associated_attribute_groups"},{"doc":"aws_api/service_catalog_appregistry","title":"list_associated_resources","content":"pub fn list_associated_resources(\n  client: Client,\n  application: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog_appregistry.list_associated_resources\naws_api/service_catalog_appregistry list_associated_resources","url":"aws_api/service_catalog_appregistry.html#list_associated_resources"},{"doc":"aws_api/service_catalog_appregistry","title":"list_attribute_groups","content":"pub fn list_attribute_groups(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog_appregistry.list_attribute_groups\naws_api/service_catalog_appregistry list_attribute_groups","url":"aws_api/service_catalog_appregistry.html#list_attribute_groups"},{"doc":"aws_api/service_catalog_appregistry","title":"list_attribute_groups_for_application","content":"pub fn list_attribute_groups_for_application(\n  client: Client,\n  application: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog_appregistry.list_attribute_groups_for_application\naws_api/service_catalog_appregistry list_attribute_groups_for_application","url":"aws_api/service_catalog_appregistry.html#list_attribute_groups_for_application"},{"doc":"aws_api/service_catalog_appregistry","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog_appregistry.list_tags_for_resource\naws_api/service_catalog_appregistry list_tags_for_resource","url":"aws_api/service_catalog_appregistry.html#list_tags_for_resource"},{"doc":"aws_api/service_catalog_appregistry","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/service_catalog_appregistry.new\naws_api/service_catalog_appregistry new","url":"aws_api/service_catalog_appregistry.html#new"},{"doc":"aws_api/service_catalog_appregistry","title":"put_configuration","content":"pub fn put_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog_appregistry.put_configuration\naws_api/service_catalog_appregistry put_configuration","url":"aws_api/service_catalog_appregistry.html#put_configuration"},{"doc":"aws_api/service_catalog_appregistry","title":"sync_resource","content":"pub fn sync_resource(\n  client: Client,\n  resource_type: String,\n  resource: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog_appregistry.sync_resource\naws_api/service_catalog_appregistry sync_resource","url":"aws_api/service_catalog_appregistry.html#sync_resource"},{"doc":"aws_api/service_catalog_appregistry","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog_appregistry.tag_resource\naws_api/service_catalog_appregistry tag_resource","url":"aws_api/service_catalog_appregistry.html#tag_resource"},{"doc":"aws_api/service_catalog_appregistry","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog_appregistry.untag_resource\naws_api/service_catalog_appregistry untag_resource","url":"aws_api/service_catalog_appregistry.html#untag_resource"},{"doc":"aws_api/service_catalog_appregistry","title":"update_application","content":"pub fn update_application(\n  client: Client,\n  application: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog_appregistry.update_application\naws_api/service_catalog_appregistry update_application","url":"aws_api/service_catalog_appregistry.html#update_application"},{"doc":"aws_api/service_catalog_appregistry","title":"update_attribute_group","content":"pub fn update_attribute_group(\n  client: Client,\n  attribute_group: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_catalog_appregistry.update_attribute_group\naws_api/service_catalog_appregistry update_attribute_group","url":"aws_api/service_catalog_appregistry.html#update_attribute_group"},{"doc":"aws_api/service_catalog_appregistry","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/service_catalog_appregistry.with_custom_endpoint\naws_api/service_catalog_appregistry with_custom_endpoint","url":"aws_api/service_catalog_appregistry.html#with_custom_endpoint"},{"doc":"aws_api/service_catalog_appregistry","title":"aws_api/service_catalog_appregistry","content":"","url":"aws_api/service_catalog_appregistry.html"},{"doc":"aws_api/service_quotas","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/service_quotas.Client\naws_api/service_quotas Client","url":"aws_api/service_quotas.html#Client"},{"doc":"aws_api/service_quotas","title":"associate_service_quota_template","content":"pub fn associate_service_quota_template(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_quotas.associate_service_quota_template\naws_api/service_quotas associate_service_quota_template","url":"aws_api/service_quotas.html#associate_service_quota_template"},{"doc":"aws_api/service_quotas","title":"delete_service_quota_increase_request_from_template","content":"pub fn delete_service_quota_increase_request_from_template(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_quotas.delete_service_quota_increase_request_from_template\naws_api/service_quotas delete_service_quota_increase_request_from_template","url":"aws_api/service_quotas.html#delete_service_quota_increase_request_from_template"},{"doc":"aws_api/service_quotas","title":"disassociate_service_quota_template","content":"pub fn disassociate_service_quota_template(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_quotas.disassociate_service_quota_template\naws_api/service_quotas disassociate_service_quota_template","url":"aws_api/service_quotas.html#disassociate_service_quota_template"},{"doc":"aws_api/service_quotas","title":"get_association_for_service_quota_template","content":"pub fn get_association_for_service_quota_template(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_quotas.get_association_for_service_quota_template\naws_api/service_quotas get_association_for_service_quota_template","url":"aws_api/service_quotas.html#get_association_for_service_quota_template"},{"doc":"aws_api/service_quotas","title":"get_aws_default_service_quota","content":"pub fn get_aws_default_service_quota(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_quotas.get_aws_default_service_quota\naws_api/service_quotas get_aws_default_service_quota","url":"aws_api/service_quotas.html#get_aws_default_service_quota"},{"doc":"aws_api/service_quotas","title":"get_requested_service_quota_change","content":"pub fn get_requested_service_quota_change(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_quotas.get_requested_service_quota_change\naws_api/service_quotas get_requested_service_quota_change","url":"aws_api/service_quotas.html#get_requested_service_quota_change"},{"doc":"aws_api/service_quotas","title":"get_service_quota","content":"pub fn get_service_quota(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_quotas.get_service_quota\naws_api/service_quotas get_service_quota","url":"aws_api/service_quotas.html#get_service_quota"},{"doc":"aws_api/service_quotas","title":"get_service_quota_increase_request_from_template","content":"pub fn get_service_quota_increase_request_from_template(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_quotas.get_service_quota_increase_request_from_template\naws_api/service_quotas get_service_quota_increase_request_from_template","url":"aws_api/service_quotas.html#get_service_quota_increase_request_from_template"},{"doc":"aws_api/service_quotas","title":"list_aws_default_service_quotas","content":"pub fn list_aws_default_service_quotas(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_quotas.list_aws_default_service_quotas\naws_api/service_quotas list_aws_default_service_quotas","url":"aws_api/service_quotas.html#list_aws_default_service_quotas"},{"doc":"aws_api/service_quotas","title":"list_requested_service_quota_change_history","content":"pub fn list_requested_service_quota_change_history(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_quotas.list_requested_service_quota_change_history\naws_api/service_quotas list_requested_service_quota_change_history","url":"aws_api/service_quotas.html#list_requested_service_quota_change_history"},{"doc":"aws_api/service_quotas","title":"list_requested_service_quota_change_history_by_quota","content":"pub fn list_requested_service_quota_change_history_by_quota(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_quotas.list_requested_service_quota_change_history_by_quota\naws_api/service_quotas list_requested_service_quota_change_history_by_quota","url":"aws_api/service_quotas.html#list_requested_service_quota_change_history_by_quota"},{"doc":"aws_api/service_quotas","title":"list_service_quota_increase_requests_in_template","content":"pub fn list_service_quota_increase_requests_in_template(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_quotas.list_service_quota_increase_requests_in_template\naws_api/service_quotas list_service_quota_increase_requests_in_template","url":"aws_api/service_quotas.html#list_service_quota_increase_requests_in_template"},{"doc":"aws_api/service_quotas","title":"list_service_quotas","content":"pub fn list_service_quotas(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_quotas.list_service_quotas\naws_api/service_quotas list_service_quotas","url":"aws_api/service_quotas.html#list_service_quotas"},{"doc":"aws_api/service_quotas","title":"list_services","content":"pub fn list_services(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_quotas.list_services\naws_api/service_quotas list_services","url":"aws_api/service_quotas.html#list_services"},{"doc":"aws_api/service_quotas","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_quotas.list_tags_for_resource\naws_api/service_quotas list_tags_for_resource","url":"aws_api/service_quotas.html#list_tags_for_resource"},{"doc":"aws_api/service_quotas","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/service_quotas.new\naws_api/service_quotas new","url":"aws_api/service_quotas.html#new"},{"doc":"aws_api/service_quotas","title":"put_service_quota_increase_request_into_template","content":"pub fn put_service_quota_increase_request_into_template(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_quotas.put_service_quota_increase_request_into_template\naws_api/service_quotas put_service_quota_increase_request_into_template","url":"aws_api/service_quotas.html#put_service_quota_increase_request_into_template"},{"doc":"aws_api/service_quotas","title":"request_service_quota_increase","content":"pub fn request_service_quota_increase(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_quotas.request_service_quota_increase\naws_api/service_quotas request_service_quota_increase","url":"aws_api/service_quotas.html#request_service_quota_increase"},{"doc":"aws_api/service_quotas","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_quotas.tag_resource\naws_api/service_quotas tag_resource","url":"aws_api/service_quotas.html#tag_resource"},{"doc":"aws_api/service_quotas","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/service_quotas.untag_resource\naws_api/service_quotas untag_resource","url":"aws_api/service_quotas.html#untag_resource"},{"doc":"aws_api/service_quotas","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/service_quotas.with_custom_endpoint\naws_api/service_quotas with_custom_endpoint","url":"aws_api/service_quotas.html#with_custom_endpoint"},{"doc":"aws_api/service_quotas","title":"aws_api/service_quotas","content":"","url":"aws_api/service_quotas.html"},{"doc":"aws_api/servicediscovery","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/servicediscovery.Client\naws_api/servicediscovery Client","url":"aws_api/servicediscovery.html#Client"},{"doc":"aws_api/servicediscovery","title":"create_http_namespace","content":"pub fn create_http_namespace(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/servicediscovery.create_http_namespace\naws_api/servicediscovery create_http_namespace","url":"aws_api/servicediscovery.html#create_http_namespace"},{"doc":"aws_api/servicediscovery","title":"create_private_dns_namespace","content":"pub fn create_private_dns_namespace(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/servicediscovery.create_private_dns_namespace\naws_api/servicediscovery create_private_dns_namespace","url":"aws_api/servicediscovery.html#create_private_dns_namespace"},{"doc":"aws_api/servicediscovery","title":"create_public_dns_namespace","content":"pub fn create_public_dns_namespace(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/servicediscovery.create_public_dns_namespace\naws_api/servicediscovery create_public_dns_namespace","url":"aws_api/servicediscovery.html#create_public_dns_namespace"},{"doc":"aws_api/servicediscovery","title":"create_service","content":"pub fn create_service(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/servicediscovery.create_service\naws_api/servicediscovery create_service","url":"aws_api/servicediscovery.html#create_service"},{"doc":"aws_api/servicediscovery","title":"delete_namespace","content":"pub fn delete_namespace(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/servicediscovery.delete_namespace\naws_api/servicediscovery delete_namespace","url":"aws_api/servicediscovery.html#delete_namespace"},{"doc":"aws_api/servicediscovery","title":"delete_service","content":"pub fn delete_service(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/servicediscovery.delete_service\naws_api/servicediscovery delete_service","url":"aws_api/servicediscovery.html#delete_service"},{"doc":"aws_api/servicediscovery","title":"deregister_instance","content":"pub fn deregister_instance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/servicediscovery.deregister_instance\naws_api/servicediscovery deregister_instance","url":"aws_api/servicediscovery.html#deregister_instance"},{"doc":"aws_api/servicediscovery","title":"discover_instances","content":"pub fn discover_instances(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/servicediscovery.discover_instances\naws_api/servicediscovery discover_instances","url":"aws_api/servicediscovery.html#discover_instances"},{"doc":"aws_api/servicediscovery","title":"discover_instances_revision","content":"pub fn discover_instances_revision(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/servicediscovery.discover_instances_revision\naws_api/servicediscovery discover_instances_revision","url":"aws_api/servicediscovery.html#discover_instances_revision"},{"doc":"aws_api/servicediscovery","title":"get_instance","content":"pub fn get_instance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/servicediscovery.get_instance\naws_api/servicediscovery get_instance","url":"aws_api/servicediscovery.html#get_instance"},{"doc":"aws_api/servicediscovery","title":"get_instances_health_status","content":"pub fn get_instances_health_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/servicediscovery.get_instances_health_status\naws_api/servicediscovery get_instances_health_status","url":"aws_api/servicediscovery.html#get_instances_health_status"},{"doc":"aws_api/servicediscovery","title":"get_namespace","content":"pub fn get_namespace(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/servicediscovery.get_namespace\naws_api/servicediscovery get_namespace","url":"aws_api/servicediscovery.html#get_namespace"},{"doc":"aws_api/servicediscovery","title":"get_operation","content":"pub fn get_operation(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/servicediscovery.get_operation\naws_api/servicediscovery get_operation","url":"aws_api/servicediscovery.html#get_operation"},{"doc":"aws_api/servicediscovery","title":"get_service","content":"pub fn get_service(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/servicediscovery.get_service\naws_api/servicediscovery get_service","url":"aws_api/servicediscovery.html#get_service"},{"doc":"aws_api/servicediscovery","title":"list_instances","content":"pub fn list_instances(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/servicediscovery.list_instances\naws_api/servicediscovery list_instances","url":"aws_api/servicediscovery.html#list_instances"},{"doc":"aws_api/servicediscovery","title":"list_namespaces","content":"pub fn list_namespaces(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/servicediscovery.list_namespaces\naws_api/servicediscovery list_namespaces","url":"aws_api/servicediscovery.html#list_namespaces"},{"doc":"aws_api/servicediscovery","title":"list_operations","content":"pub fn list_operations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/servicediscovery.list_operations\naws_api/servicediscovery list_operations","url":"aws_api/servicediscovery.html#list_operations"},{"doc":"aws_api/servicediscovery","title":"list_services","content":"pub fn list_services(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/servicediscovery.list_services\naws_api/servicediscovery list_services","url":"aws_api/servicediscovery.html#list_services"},{"doc":"aws_api/servicediscovery","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/servicediscovery.list_tags_for_resource\naws_api/servicediscovery list_tags_for_resource","url":"aws_api/servicediscovery.html#list_tags_for_resource"},{"doc":"aws_api/servicediscovery","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/servicediscovery.new\naws_api/servicediscovery new","url":"aws_api/servicediscovery.html#new"},{"doc":"aws_api/servicediscovery","title":"register_instance","content":"pub fn register_instance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/servicediscovery.register_instance\naws_api/servicediscovery register_instance","url":"aws_api/servicediscovery.html#register_instance"},{"doc":"aws_api/servicediscovery","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/servicediscovery.tag_resource\naws_api/servicediscovery tag_resource","url":"aws_api/servicediscovery.html#tag_resource"},{"doc":"aws_api/servicediscovery","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/servicediscovery.untag_resource\naws_api/servicediscovery untag_resource","url":"aws_api/servicediscovery.html#untag_resource"},{"doc":"aws_api/servicediscovery","title":"update_http_namespace","content":"pub fn update_http_namespace(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/servicediscovery.update_http_namespace\naws_api/servicediscovery update_http_namespace","url":"aws_api/servicediscovery.html#update_http_namespace"},{"doc":"aws_api/servicediscovery","title":"update_instance_custom_health_status","content":"pub fn update_instance_custom_health_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/servicediscovery.update_instance_custom_health_status\naws_api/servicediscovery update_instance_custom_health_status","url":"aws_api/servicediscovery.html#update_instance_custom_health_status"},{"doc":"aws_api/servicediscovery","title":"update_private_dns_namespace","content":"pub fn update_private_dns_namespace(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/servicediscovery.update_private_dns_namespace\naws_api/servicediscovery update_private_dns_namespace","url":"aws_api/servicediscovery.html#update_private_dns_namespace"},{"doc":"aws_api/servicediscovery","title":"update_public_dns_namespace","content":"pub fn update_public_dns_namespace(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/servicediscovery.update_public_dns_namespace\naws_api/servicediscovery update_public_dns_namespace","url":"aws_api/servicediscovery.html#update_public_dns_namespace"},{"doc":"aws_api/servicediscovery","title":"update_service","content":"pub fn update_service(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/servicediscovery.update_service\naws_api/servicediscovery update_service","url":"aws_api/servicediscovery.html#update_service"},{"doc":"aws_api/servicediscovery","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/servicediscovery.with_custom_endpoint\naws_api/servicediscovery with_custom_endpoint","url":"aws_api/servicediscovery.html#with_custom_endpoint"},{"doc":"aws_api/servicediscovery","title":"aws_api/servicediscovery","content":"","url":"aws_api/servicediscovery.html"},{"doc":"aws_api/ses","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/ses.Client\naws_api/ses Client","url":"aws_api/ses.html#Client"},{"doc":"aws_api/ses","title":"clone_receipt_rule_set","content":"pub fn clone_receipt_rule_set(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.clone_receipt_rule_set\naws_api/ses clone_receipt_rule_set","url":"aws_api/ses.html#clone_receipt_rule_set"},{"doc":"aws_api/ses","title":"create_configuration_set","content":"pub fn create_configuration_set(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.create_configuration_set\naws_api/ses create_configuration_set","url":"aws_api/ses.html#create_configuration_set"},{"doc":"aws_api/ses","title":"create_configuration_set_event_destination","content":"pub fn create_configuration_set_event_destination(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.create_configuration_set_event_destination\naws_api/ses create_configuration_set_event_destination","url":"aws_api/ses.html#create_configuration_set_event_destination"},{"doc":"aws_api/ses","title":"create_configuration_set_tracking_options","content":"pub fn create_configuration_set_tracking_options(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.create_configuration_set_tracking_options\naws_api/ses create_configuration_set_tracking_options","url":"aws_api/ses.html#create_configuration_set_tracking_options"},{"doc":"aws_api/ses","title":"create_custom_verification_email_template","content":"pub fn create_custom_verification_email_template(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.create_custom_verification_email_template\naws_api/ses create_custom_verification_email_template","url":"aws_api/ses.html#create_custom_verification_email_template"},{"doc":"aws_api/ses","title":"create_receipt_filter","content":"pub fn create_receipt_filter(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.create_receipt_filter\naws_api/ses create_receipt_filter","url":"aws_api/ses.html#create_receipt_filter"},{"doc":"aws_api/ses","title":"create_receipt_rule","content":"pub fn create_receipt_rule(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.create_receipt_rule\naws_api/ses create_receipt_rule","url":"aws_api/ses.html#create_receipt_rule"},{"doc":"aws_api/ses","title":"create_receipt_rule_set","content":"pub fn create_receipt_rule_set(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.create_receipt_rule_set\naws_api/ses create_receipt_rule_set","url":"aws_api/ses.html#create_receipt_rule_set"},{"doc":"aws_api/ses","title":"create_template","content":"pub fn create_template(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.create_template\naws_api/ses create_template","url":"aws_api/ses.html#create_template"},{"doc":"aws_api/ses","title":"delete_configuration_set","content":"pub fn delete_configuration_set(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.delete_configuration_set\naws_api/ses delete_configuration_set","url":"aws_api/ses.html#delete_configuration_set"},{"doc":"aws_api/ses","title":"delete_configuration_set_event_destination","content":"pub fn delete_configuration_set_event_destination(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.delete_configuration_set_event_destination\naws_api/ses delete_configuration_set_event_destination","url":"aws_api/ses.html#delete_configuration_set_event_destination"},{"doc":"aws_api/ses","title":"delete_configuration_set_tracking_options","content":"pub fn delete_configuration_set_tracking_options(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.delete_configuration_set_tracking_options\naws_api/ses delete_configuration_set_tracking_options","url":"aws_api/ses.html#delete_configuration_set_tracking_options"},{"doc":"aws_api/ses","title":"delete_custom_verification_email_template","content":"pub fn delete_custom_verification_email_template(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.delete_custom_verification_email_template\naws_api/ses delete_custom_verification_email_template","url":"aws_api/ses.html#delete_custom_verification_email_template"},{"doc":"aws_api/ses","title":"delete_identity","content":"pub fn delete_identity(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.delete_identity\naws_api/ses delete_identity","url":"aws_api/ses.html#delete_identity"},{"doc":"aws_api/ses","title":"delete_identity_policy","content":"pub fn delete_identity_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.delete_identity_policy\naws_api/ses delete_identity_policy","url":"aws_api/ses.html#delete_identity_policy"},{"doc":"aws_api/ses","title":"delete_receipt_filter","content":"pub fn delete_receipt_filter(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.delete_receipt_filter\naws_api/ses delete_receipt_filter","url":"aws_api/ses.html#delete_receipt_filter"},{"doc":"aws_api/ses","title":"delete_receipt_rule","content":"pub fn delete_receipt_rule(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.delete_receipt_rule\naws_api/ses delete_receipt_rule","url":"aws_api/ses.html#delete_receipt_rule"},{"doc":"aws_api/ses","title":"delete_receipt_rule_set","content":"pub fn delete_receipt_rule_set(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.delete_receipt_rule_set\naws_api/ses delete_receipt_rule_set","url":"aws_api/ses.html#delete_receipt_rule_set"},{"doc":"aws_api/ses","title":"delete_template","content":"pub fn delete_template(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.delete_template\naws_api/ses delete_template","url":"aws_api/ses.html#delete_template"},{"doc":"aws_api/ses","title":"delete_verified_email_address","content":"pub fn delete_verified_email_address(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.delete_verified_email_address\naws_api/ses delete_verified_email_address","url":"aws_api/ses.html#delete_verified_email_address"},{"doc":"aws_api/ses","title":"describe_active_receipt_rule_set","content":"pub fn describe_active_receipt_rule_set(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.describe_active_receipt_rule_set\naws_api/ses describe_active_receipt_rule_set","url":"aws_api/ses.html#describe_active_receipt_rule_set"},{"doc":"aws_api/ses","title":"describe_configuration_set","content":"pub fn describe_configuration_set(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.describe_configuration_set\naws_api/ses describe_configuration_set","url":"aws_api/ses.html#describe_configuration_set"},{"doc":"aws_api/ses","title":"describe_receipt_rule","content":"pub fn describe_receipt_rule(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.describe_receipt_rule\naws_api/ses describe_receipt_rule","url":"aws_api/ses.html#describe_receipt_rule"},{"doc":"aws_api/ses","title":"describe_receipt_rule_set","content":"pub fn describe_receipt_rule_set(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.describe_receipt_rule_set\naws_api/ses describe_receipt_rule_set","url":"aws_api/ses.html#describe_receipt_rule_set"},{"doc":"aws_api/ses","title":"get_account_sending_enabled","content":"pub fn get_account_sending_enabled(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.get_account_sending_enabled\naws_api/ses get_account_sending_enabled","url":"aws_api/ses.html#get_account_sending_enabled"},{"doc":"aws_api/ses","title":"get_custom_verification_email_template","content":"pub fn get_custom_verification_email_template(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.get_custom_verification_email_template\naws_api/ses get_custom_verification_email_template","url":"aws_api/ses.html#get_custom_verification_email_template"},{"doc":"aws_api/ses","title":"get_identity_dkim_attributes","content":"pub fn get_identity_dkim_attributes(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.get_identity_dkim_attributes\naws_api/ses get_identity_dkim_attributes","url":"aws_api/ses.html#get_identity_dkim_attributes"},{"doc":"aws_api/ses","title":"get_identity_mail_from_domain_attributes","content":"pub fn get_identity_mail_from_domain_attributes(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.get_identity_mail_from_domain_attributes\naws_api/ses get_identity_mail_from_domain_attributes","url":"aws_api/ses.html#get_identity_mail_from_domain_attributes"},{"doc":"aws_api/ses","title":"get_identity_notification_attributes","content":"pub fn get_identity_notification_attributes(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.get_identity_notification_attributes\naws_api/ses get_identity_notification_attributes","url":"aws_api/ses.html#get_identity_notification_attributes"},{"doc":"aws_api/ses","title":"get_identity_policies","content":"pub fn get_identity_policies(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.get_identity_policies\naws_api/ses get_identity_policies","url":"aws_api/ses.html#get_identity_policies"},{"doc":"aws_api/ses","title":"get_identity_verification_attributes","content":"pub fn get_identity_verification_attributes(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.get_identity_verification_attributes\naws_api/ses get_identity_verification_attributes","url":"aws_api/ses.html#get_identity_verification_attributes"},{"doc":"aws_api/ses","title":"get_send_quota","content":"pub fn get_send_quota(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.get_send_quota\naws_api/ses get_send_quota","url":"aws_api/ses.html#get_send_quota"},{"doc":"aws_api/ses","title":"get_send_statistics","content":"pub fn get_send_statistics(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.get_send_statistics\naws_api/ses get_send_statistics","url":"aws_api/ses.html#get_send_statistics"},{"doc":"aws_api/ses","title":"get_template","content":"pub fn get_template(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.get_template\naws_api/ses get_template","url":"aws_api/ses.html#get_template"},{"doc":"aws_api/ses","title":"list_configuration_sets","content":"pub fn list_configuration_sets(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.list_configuration_sets\naws_api/ses list_configuration_sets","url":"aws_api/ses.html#list_configuration_sets"},{"doc":"aws_api/ses","title":"list_custom_verification_email_templates","content":"pub fn list_custom_verification_email_templates(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.list_custom_verification_email_templates\naws_api/ses list_custom_verification_email_templates","url":"aws_api/ses.html#list_custom_verification_email_templates"},{"doc":"aws_api/ses","title":"list_identities","content":"pub fn list_identities(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.list_identities\naws_api/ses list_identities","url":"aws_api/ses.html#list_identities"},{"doc":"aws_api/ses","title":"list_identity_policies","content":"pub fn list_identity_policies(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.list_identity_policies\naws_api/ses list_identity_policies","url":"aws_api/ses.html#list_identity_policies"},{"doc":"aws_api/ses","title":"list_receipt_filters","content":"pub fn list_receipt_filters(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.list_receipt_filters\naws_api/ses list_receipt_filters","url":"aws_api/ses.html#list_receipt_filters"},{"doc":"aws_api/ses","title":"list_receipt_rule_sets","content":"pub fn list_receipt_rule_sets(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.list_receipt_rule_sets\naws_api/ses list_receipt_rule_sets","url":"aws_api/ses.html#list_receipt_rule_sets"},{"doc":"aws_api/ses","title":"list_templates","content":"pub fn list_templates(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.list_templates\naws_api/ses list_templates","url":"aws_api/ses.html#list_templates"},{"doc":"aws_api/ses","title":"list_verified_email_addresses","content":"pub fn list_verified_email_addresses(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.list_verified_email_addresses\naws_api/ses list_verified_email_addresses","url":"aws_api/ses.html#list_verified_email_addresses"},{"doc":"aws_api/ses","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/ses.new\naws_api/ses new","url":"aws_api/ses.html#new"},{"doc":"aws_api/ses","title":"put_configuration_set_delivery_options","content":"pub fn put_configuration_set_delivery_options(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.put_configuration_set_delivery_options\naws_api/ses put_configuration_set_delivery_options","url":"aws_api/ses.html#put_configuration_set_delivery_options"},{"doc":"aws_api/ses","title":"put_identity_policy","content":"pub fn put_identity_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.put_identity_policy\naws_api/ses put_identity_policy","url":"aws_api/ses.html#put_identity_policy"},{"doc":"aws_api/ses","title":"reorder_receipt_rule_set","content":"pub fn reorder_receipt_rule_set(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.reorder_receipt_rule_set\naws_api/ses reorder_receipt_rule_set","url":"aws_api/ses.html#reorder_receipt_rule_set"},{"doc":"aws_api/ses","title":"send_bounce","content":"pub fn send_bounce(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.send_bounce\naws_api/ses send_bounce","url":"aws_api/ses.html#send_bounce"},{"doc":"aws_api/ses","title":"send_bulk_templated_email","content":"pub fn send_bulk_templated_email(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.send_bulk_templated_email\naws_api/ses send_bulk_templated_email","url":"aws_api/ses.html#send_bulk_templated_email"},{"doc":"aws_api/ses","title":"send_custom_verification_email","content":"pub fn send_custom_verification_email(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.send_custom_verification_email\naws_api/ses send_custom_verification_email","url":"aws_api/ses.html#send_custom_verification_email"},{"doc":"aws_api/ses","title":"send_email","content":"pub fn send_email(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.send_email\naws_api/ses send_email","url":"aws_api/ses.html#send_email"},{"doc":"aws_api/ses","title":"send_raw_email","content":"pub fn send_raw_email(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.send_raw_email\naws_api/ses send_raw_email","url":"aws_api/ses.html#send_raw_email"},{"doc":"aws_api/ses","title":"send_templated_email","content":"pub fn send_templated_email(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.send_templated_email\naws_api/ses send_templated_email","url":"aws_api/ses.html#send_templated_email"},{"doc":"aws_api/ses","title":"set_active_receipt_rule_set","content":"pub fn set_active_receipt_rule_set(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.set_active_receipt_rule_set\naws_api/ses set_active_receipt_rule_set","url":"aws_api/ses.html#set_active_receipt_rule_set"},{"doc":"aws_api/ses","title":"set_identity_dkim_enabled","content":"pub fn set_identity_dkim_enabled(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.set_identity_dkim_enabled\naws_api/ses set_identity_dkim_enabled","url":"aws_api/ses.html#set_identity_dkim_enabled"},{"doc":"aws_api/ses","title":"set_identity_feedback_forwarding_enabled","content":"pub fn set_identity_feedback_forwarding_enabled(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.set_identity_feedback_forwarding_enabled\naws_api/ses set_identity_feedback_forwarding_enabled","url":"aws_api/ses.html#set_identity_feedback_forwarding_enabled"},{"doc":"aws_api/ses","title":"set_identity_headers_in_notifications_enabled","content":"pub fn set_identity_headers_in_notifications_enabled(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.set_identity_headers_in_notifications_enabled\naws_api/ses set_identity_headers_in_notifications_enabled","url":"aws_api/ses.html#set_identity_headers_in_notifications_enabled"},{"doc":"aws_api/ses","title":"set_identity_mail_from_domain","content":"pub fn set_identity_mail_from_domain(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.set_identity_mail_from_domain\naws_api/ses set_identity_mail_from_domain","url":"aws_api/ses.html#set_identity_mail_from_domain"},{"doc":"aws_api/ses","title":"set_identity_notification_topic","content":"pub fn set_identity_notification_topic(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.set_identity_notification_topic\naws_api/ses set_identity_notification_topic","url":"aws_api/ses.html#set_identity_notification_topic"},{"doc":"aws_api/ses","title":"set_receipt_rule_position","content":"pub fn set_receipt_rule_position(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.set_receipt_rule_position\naws_api/ses set_receipt_rule_position","url":"aws_api/ses.html#set_receipt_rule_position"},{"doc":"aws_api/ses","title":"test_render_template","content":"pub fn test_render_template(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.test_render_template\naws_api/ses test_render_template","url":"aws_api/ses.html#test_render_template"},{"doc":"aws_api/ses","title":"update_account_sending_enabled","content":"pub fn update_account_sending_enabled(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.update_account_sending_enabled\naws_api/ses update_account_sending_enabled","url":"aws_api/ses.html#update_account_sending_enabled"},{"doc":"aws_api/ses","title":"update_configuration_set_event_destination","content":"pub fn update_configuration_set_event_destination(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.update_configuration_set_event_destination\naws_api/ses update_configuration_set_event_destination","url":"aws_api/ses.html#update_configuration_set_event_destination"},{"doc":"aws_api/ses","title":"update_configuration_set_reputation_metrics_enabled","content":"pub fn update_configuration_set_reputation_metrics_enabled(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.update_configuration_set_reputation_metrics_enabled\naws_api/ses update_configuration_set_reputation_metrics_enabled","url":"aws_api/ses.html#update_configuration_set_reputation_metrics_enabled"},{"doc":"aws_api/ses","title":"update_configuration_set_sending_enabled","content":"pub fn update_configuration_set_sending_enabled(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.update_configuration_set_sending_enabled\naws_api/ses update_configuration_set_sending_enabled","url":"aws_api/ses.html#update_configuration_set_sending_enabled"},{"doc":"aws_api/ses","title":"update_configuration_set_tracking_options","content":"pub fn update_configuration_set_tracking_options(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.update_configuration_set_tracking_options\naws_api/ses update_configuration_set_tracking_options","url":"aws_api/ses.html#update_configuration_set_tracking_options"},{"doc":"aws_api/ses","title":"update_custom_verification_email_template","content":"pub fn update_custom_verification_email_template(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.update_custom_verification_email_template\naws_api/ses update_custom_verification_email_template","url":"aws_api/ses.html#update_custom_verification_email_template"},{"doc":"aws_api/ses","title":"update_receipt_rule","content":"pub fn update_receipt_rule(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.update_receipt_rule\naws_api/ses update_receipt_rule","url":"aws_api/ses.html#update_receipt_rule"},{"doc":"aws_api/ses","title":"update_template","content":"pub fn update_template(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.update_template\naws_api/ses update_template","url":"aws_api/ses.html#update_template"},{"doc":"aws_api/ses","title":"verify_domain_dkim","content":"pub fn verify_domain_dkim(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.verify_domain_dkim\naws_api/ses verify_domain_dkim","url":"aws_api/ses.html#verify_domain_dkim"},{"doc":"aws_api/ses","title":"verify_domain_identity","content":"pub fn verify_domain_identity(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.verify_domain_identity\naws_api/ses verify_domain_identity","url":"aws_api/ses.html#verify_domain_identity"},{"doc":"aws_api/ses","title":"verify_email_address","content":"pub fn verify_email_address(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.verify_email_address\naws_api/ses verify_email_address","url":"aws_api/ses.html#verify_email_address"},{"doc":"aws_api/ses","title":"verify_email_identity","content":"pub fn verify_email_identity(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ses.verify_email_identity\naws_api/ses verify_email_identity","url":"aws_api/ses.html#verify_email_identity"},{"doc":"aws_api/ses","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/ses.with_custom_endpoint\naws_api/ses with_custom_endpoint","url":"aws_api/ses.html#with_custom_endpoint"},{"doc":"aws_api/ses","title":"aws_api/ses","content":"","url":"aws_api/ses.html"},{"doc":"aws_api/sesv2","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/sesv2.Client\naws_api/sesv2 Client","url":"aws_api/sesv2.html#Client"},{"doc":"aws_api/sesv2","title":"batch_get_metric_data","content":"pub fn batch_get_metric_data(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.batch_get_metric_data\naws_api/sesv2 batch_get_metric_data","url":"aws_api/sesv2.html#batch_get_metric_data"},{"doc":"aws_api/sesv2","title":"cancel_export_job","content":"pub fn cancel_export_job(\n  client: Client,\n  job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.cancel_export_job\naws_api/sesv2 cancel_export_job","url":"aws_api/sesv2.html#cancel_export_job"},{"doc":"aws_api/sesv2","title":"create_configuration_set","content":"pub fn create_configuration_set(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.create_configuration_set\naws_api/sesv2 create_configuration_set","url":"aws_api/sesv2.html#create_configuration_set"},{"doc":"aws_api/sesv2","title":"create_configuration_set_event_destination","content":"pub fn create_configuration_set_event_destination(\n  client: Client,\n  configuration_set_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.create_configuration_set_event_destination\naws_api/sesv2 create_configuration_set_event_destination","url":"aws_api/sesv2.html#create_configuration_set_event_destination"},{"doc":"aws_api/sesv2","title":"create_contact","content":"pub fn create_contact(\n  client: Client,\n  contact_list_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.create_contact\naws_api/sesv2 create_contact","url":"aws_api/sesv2.html#create_contact"},{"doc":"aws_api/sesv2","title":"create_contact_list","content":"pub fn create_contact_list(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.create_contact_list\naws_api/sesv2 create_contact_list","url":"aws_api/sesv2.html#create_contact_list"},{"doc":"aws_api/sesv2","title":"create_custom_verification_email_template","content":"pub fn create_custom_verification_email_template(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.create_custom_verification_email_template\naws_api/sesv2 create_custom_verification_email_template","url":"aws_api/sesv2.html#create_custom_verification_email_template"},{"doc":"aws_api/sesv2","title":"create_dedicated_ip_pool","content":"pub fn create_dedicated_ip_pool(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.create_dedicated_ip_pool\naws_api/sesv2 create_dedicated_ip_pool","url":"aws_api/sesv2.html#create_dedicated_ip_pool"},{"doc":"aws_api/sesv2","title":"create_deliverability_test_report","content":"pub fn create_deliverability_test_report(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.create_deliverability_test_report\naws_api/sesv2 create_deliverability_test_report","url":"aws_api/sesv2.html#create_deliverability_test_report"},{"doc":"aws_api/sesv2","title":"create_email_identity","content":"pub fn create_email_identity(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.create_email_identity\naws_api/sesv2 create_email_identity","url":"aws_api/sesv2.html#create_email_identity"},{"doc":"aws_api/sesv2","title":"create_email_identity_policy","content":"pub fn create_email_identity_policy(\n  client: Client,\n  email_identity: String,\n  policy_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.create_email_identity_policy\naws_api/sesv2 create_email_identity_policy","url":"aws_api/sesv2.html#create_email_identity_policy"},{"doc":"aws_api/sesv2","title":"create_email_template","content":"pub fn create_email_template(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.create_email_template\naws_api/sesv2 create_email_template","url":"aws_api/sesv2.html#create_email_template"},{"doc":"aws_api/sesv2","title":"create_export_job","content":"pub fn create_export_job(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.create_export_job\naws_api/sesv2 create_export_job","url":"aws_api/sesv2.html#create_export_job"},{"doc":"aws_api/sesv2","title":"create_import_job","content":"pub fn create_import_job(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.create_import_job\naws_api/sesv2 create_import_job","url":"aws_api/sesv2.html#create_import_job"},{"doc":"aws_api/sesv2","title":"delete_configuration_set","content":"pub fn delete_configuration_set(\n  client: Client,\n  configuration_set_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.delete_configuration_set\naws_api/sesv2 delete_configuration_set","url":"aws_api/sesv2.html#delete_configuration_set"},{"doc":"aws_api/sesv2","title":"delete_configuration_set_event_destination","content":"pub fn delete_configuration_set_event_destination(\n  client: Client,\n  configuration_set_name: String,\n  event_destination_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.delete_configuration_set_event_destination\naws_api/sesv2 delete_configuration_set_event_destination","url":"aws_api/sesv2.html#delete_configuration_set_event_destination"},{"doc":"aws_api/sesv2","title":"delete_contact","content":"pub fn delete_contact(\n  client: Client,\n  contact_list_name: String,\n  email_address: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.delete_contact\naws_api/sesv2 delete_contact","url":"aws_api/sesv2.html#delete_contact"},{"doc":"aws_api/sesv2","title":"delete_contact_list","content":"pub fn delete_contact_list(\n  client: Client,\n  contact_list_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.delete_contact_list\naws_api/sesv2 delete_contact_list","url":"aws_api/sesv2.html#delete_contact_list"},{"doc":"aws_api/sesv2","title":"delete_custom_verification_email_template","content":"pub fn delete_custom_verification_email_template(\n  client: Client,\n  template_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.delete_custom_verification_email_template\naws_api/sesv2 delete_custom_verification_email_template","url":"aws_api/sesv2.html#delete_custom_verification_email_template"},{"doc":"aws_api/sesv2","title":"delete_dedicated_ip_pool","content":"pub fn delete_dedicated_ip_pool(\n  client: Client,\n  pool_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.delete_dedicated_ip_pool\naws_api/sesv2 delete_dedicated_ip_pool","url":"aws_api/sesv2.html#delete_dedicated_ip_pool"},{"doc":"aws_api/sesv2","title":"delete_email_identity","content":"pub fn delete_email_identity(\n  client: Client,\n  email_identity: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.delete_email_identity\naws_api/sesv2 delete_email_identity","url":"aws_api/sesv2.html#delete_email_identity"},{"doc":"aws_api/sesv2","title":"delete_email_identity_policy","content":"pub fn delete_email_identity_policy(\n  client: Client,\n  email_identity: String,\n  policy_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.delete_email_identity_policy\naws_api/sesv2 delete_email_identity_policy","url":"aws_api/sesv2.html#delete_email_identity_policy"},{"doc":"aws_api/sesv2","title":"delete_email_template","content":"pub fn delete_email_template(\n  client: Client,\n  template_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.delete_email_template\naws_api/sesv2 delete_email_template","url":"aws_api/sesv2.html#delete_email_template"},{"doc":"aws_api/sesv2","title":"delete_suppressed_destination","content":"pub fn delete_suppressed_destination(\n  client: Client,\n  email_address: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.delete_suppressed_destination\naws_api/sesv2 delete_suppressed_destination","url":"aws_api/sesv2.html#delete_suppressed_destination"},{"doc":"aws_api/sesv2","title":"get_account","content":"pub fn get_account(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.get_account\naws_api/sesv2 get_account","url":"aws_api/sesv2.html#get_account"},{"doc":"aws_api/sesv2","title":"get_blacklist_reports","content":"pub fn get_blacklist_reports(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.get_blacklist_reports\naws_api/sesv2 get_blacklist_reports","url":"aws_api/sesv2.html#get_blacklist_reports"},{"doc":"aws_api/sesv2","title":"get_configuration_set","content":"pub fn get_configuration_set(\n  client: Client,\n  configuration_set_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.get_configuration_set\naws_api/sesv2 get_configuration_set","url":"aws_api/sesv2.html#get_configuration_set"},{"doc":"aws_api/sesv2","title":"get_configuration_set_event_destinations","content":"pub fn get_configuration_set_event_destinations(\n  client: Client,\n  configuration_set_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.get_configuration_set_event_destinations\naws_api/sesv2 get_configuration_set_event_destinations","url":"aws_api/sesv2.html#get_configuration_set_event_destinations"},{"doc":"aws_api/sesv2","title":"get_contact","content":"pub fn get_contact(\n  client: Client,\n  contact_list_name: String,\n  email_address: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.get_contact\naws_api/sesv2 get_contact","url":"aws_api/sesv2.html#get_contact"},{"doc":"aws_api/sesv2","title":"get_contact_list","content":"pub fn get_contact_list(\n  client: Client,\n  contact_list_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.get_contact_list\naws_api/sesv2 get_contact_list","url":"aws_api/sesv2.html#get_contact_list"},{"doc":"aws_api/sesv2","title":"get_custom_verification_email_template","content":"pub fn get_custom_verification_email_template(\n  client: Client,\n  template_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.get_custom_verification_email_template\naws_api/sesv2 get_custom_verification_email_template","url":"aws_api/sesv2.html#get_custom_verification_email_template"},{"doc":"aws_api/sesv2","title":"get_dedicated_ip","content":"pub fn get_dedicated_ip(\n  client: Client,\n  ip: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.get_dedicated_ip\naws_api/sesv2 get_dedicated_ip","url":"aws_api/sesv2.html#get_dedicated_ip"},{"doc":"aws_api/sesv2","title":"get_dedicated_ip_pool","content":"pub fn get_dedicated_ip_pool(\n  client: Client,\n  pool_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.get_dedicated_ip_pool\naws_api/sesv2 get_dedicated_ip_pool","url":"aws_api/sesv2.html#get_dedicated_ip_pool"},{"doc":"aws_api/sesv2","title":"get_dedicated_ips","content":"pub fn get_dedicated_ips(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.get_dedicated_ips\naws_api/sesv2 get_dedicated_ips","url":"aws_api/sesv2.html#get_dedicated_ips"},{"doc":"aws_api/sesv2","title":"get_deliverability_dashboard_options","content":"pub fn get_deliverability_dashboard_options(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.get_deliverability_dashboard_options\naws_api/sesv2 get_deliverability_dashboard_options","url":"aws_api/sesv2.html#get_deliverability_dashboard_options"},{"doc":"aws_api/sesv2","title":"get_deliverability_test_report","content":"pub fn get_deliverability_test_report(\n  client: Client,\n  report_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.get_deliverability_test_report\naws_api/sesv2 get_deliverability_test_report","url":"aws_api/sesv2.html#get_deliverability_test_report"},{"doc":"aws_api/sesv2","title":"get_domain_deliverability_campaign","content":"pub fn get_domain_deliverability_campaign(\n  client: Client,\n  campaign_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.get_domain_deliverability_campaign\naws_api/sesv2 get_domain_deliverability_campaign","url":"aws_api/sesv2.html#get_domain_deliverability_campaign"},{"doc":"aws_api/sesv2","title":"get_domain_statistics_report","content":"pub fn get_domain_statistics_report(\n  client: Client,\n  domain: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.get_domain_statistics_report\naws_api/sesv2 get_domain_statistics_report","url":"aws_api/sesv2.html#get_domain_statistics_report"},{"doc":"aws_api/sesv2","title":"get_email_identity","content":"pub fn get_email_identity(\n  client: Client,\n  email_identity: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.get_email_identity\naws_api/sesv2 get_email_identity","url":"aws_api/sesv2.html#get_email_identity"},{"doc":"aws_api/sesv2","title":"get_email_identity_policies","content":"pub fn get_email_identity_policies(\n  client: Client,\n  email_identity: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.get_email_identity_policies\naws_api/sesv2 get_email_identity_policies","url":"aws_api/sesv2.html#get_email_identity_policies"},{"doc":"aws_api/sesv2","title":"get_email_template","content":"pub fn get_email_template(\n  client: Client,\n  template_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.get_email_template\naws_api/sesv2 get_email_template","url":"aws_api/sesv2.html#get_email_template"},{"doc":"aws_api/sesv2","title":"get_export_job","content":"pub fn get_export_job(\n  client: Client,\n  job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.get_export_job\naws_api/sesv2 get_export_job","url":"aws_api/sesv2.html#get_export_job"},{"doc":"aws_api/sesv2","title":"get_import_job","content":"pub fn get_import_job(\n  client: Client,\n  job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.get_import_job\naws_api/sesv2 get_import_job","url":"aws_api/sesv2.html#get_import_job"},{"doc":"aws_api/sesv2","title":"get_message_insights","content":"pub fn get_message_insights(\n  client: Client,\n  message_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.get_message_insights\naws_api/sesv2 get_message_insights","url":"aws_api/sesv2.html#get_message_insights"},{"doc":"aws_api/sesv2","title":"get_suppressed_destination","content":"pub fn get_suppressed_destination(\n  client: Client,\n  email_address: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.get_suppressed_destination\naws_api/sesv2 get_suppressed_destination","url":"aws_api/sesv2.html#get_suppressed_destination"},{"doc":"aws_api/sesv2","title":"list_configuration_sets","content":"pub fn list_configuration_sets(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.list_configuration_sets\naws_api/sesv2 list_configuration_sets","url":"aws_api/sesv2.html#list_configuration_sets"},{"doc":"aws_api/sesv2","title":"list_contact_lists","content":"pub fn list_contact_lists(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.list_contact_lists\naws_api/sesv2 list_contact_lists","url":"aws_api/sesv2.html#list_contact_lists"},{"doc":"aws_api/sesv2","title":"list_contacts","content":"pub fn list_contacts(\n  client: Client,\n  contact_list_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.list_contacts\naws_api/sesv2 list_contacts","url":"aws_api/sesv2.html#list_contacts"},{"doc":"aws_api/sesv2","title":"list_custom_verification_email_templates","content":"pub fn list_custom_verification_email_templates(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.list_custom_verification_email_templates\naws_api/sesv2 list_custom_verification_email_templates","url":"aws_api/sesv2.html#list_custom_verification_email_templates"},{"doc":"aws_api/sesv2","title":"list_dedicated_ip_pools","content":"pub fn list_dedicated_ip_pools(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.list_dedicated_ip_pools\naws_api/sesv2 list_dedicated_ip_pools","url":"aws_api/sesv2.html#list_dedicated_ip_pools"},{"doc":"aws_api/sesv2","title":"list_deliverability_test_reports","content":"pub fn list_deliverability_test_reports(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.list_deliverability_test_reports\naws_api/sesv2 list_deliverability_test_reports","url":"aws_api/sesv2.html#list_deliverability_test_reports"},{"doc":"aws_api/sesv2","title":"list_domain_deliverability_campaigns","content":"pub fn list_domain_deliverability_campaigns(\n  client: Client,\n  subscribed_domain: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.list_domain_deliverability_campaigns\naws_api/sesv2 list_domain_deliverability_campaigns","url":"aws_api/sesv2.html#list_domain_deliverability_campaigns"},{"doc":"aws_api/sesv2","title":"list_email_identities","content":"pub fn list_email_identities(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.list_email_identities\naws_api/sesv2 list_email_identities","url":"aws_api/sesv2.html#list_email_identities"},{"doc":"aws_api/sesv2","title":"list_email_templates","content":"pub fn list_email_templates(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.list_email_templates\naws_api/sesv2 list_email_templates","url":"aws_api/sesv2.html#list_email_templates"},{"doc":"aws_api/sesv2","title":"list_export_jobs","content":"pub fn list_export_jobs(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.list_export_jobs\naws_api/sesv2 list_export_jobs","url":"aws_api/sesv2.html#list_export_jobs"},{"doc":"aws_api/sesv2","title":"list_import_jobs","content":"pub fn list_import_jobs(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.list_import_jobs\naws_api/sesv2 list_import_jobs","url":"aws_api/sesv2.html#list_import_jobs"},{"doc":"aws_api/sesv2","title":"list_recommendations","content":"pub fn list_recommendations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.list_recommendations\naws_api/sesv2 list_recommendations","url":"aws_api/sesv2.html#list_recommendations"},{"doc":"aws_api/sesv2","title":"list_suppressed_destinations","content":"pub fn list_suppressed_destinations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.list_suppressed_destinations\naws_api/sesv2 list_suppressed_destinations","url":"aws_api/sesv2.html#list_suppressed_destinations"},{"doc":"aws_api/sesv2","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.list_tags_for_resource\naws_api/sesv2 list_tags_for_resource","url":"aws_api/sesv2.html#list_tags_for_resource"},{"doc":"aws_api/sesv2","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/sesv2.new\naws_api/sesv2 new","url":"aws_api/sesv2.html#new"},{"doc":"aws_api/sesv2","title":"put_account_dedicated_ip_warmup_attributes","content":"pub fn put_account_dedicated_ip_warmup_attributes(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.put_account_dedicated_ip_warmup_attributes\naws_api/sesv2 put_account_dedicated_ip_warmup_attributes","url":"aws_api/sesv2.html#put_account_dedicated_ip_warmup_attributes"},{"doc":"aws_api/sesv2","title":"put_account_details","content":"pub fn put_account_details(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.put_account_details\naws_api/sesv2 put_account_details","url":"aws_api/sesv2.html#put_account_details"},{"doc":"aws_api/sesv2","title":"put_account_sending_attributes","content":"pub fn put_account_sending_attributes(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.put_account_sending_attributes\naws_api/sesv2 put_account_sending_attributes","url":"aws_api/sesv2.html#put_account_sending_attributes"},{"doc":"aws_api/sesv2","title":"put_account_suppression_attributes","content":"pub fn put_account_suppression_attributes(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.put_account_suppression_attributes\naws_api/sesv2 put_account_suppression_attributes","url":"aws_api/sesv2.html#put_account_suppression_attributes"},{"doc":"aws_api/sesv2","title":"put_account_vdm_attributes","content":"pub fn put_account_vdm_attributes(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.put_account_vdm_attributes\naws_api/sesv2 put_account_vdm_attributes","url":"aws_api/sesv2.html#put_account_vdm_attributes"},{"doc":"aws_api/sesv2","title":"put_configuration_set_delivery_options","content":"pub fn put_configuration_set_delivery_options(\n  client: Client,\n  configuration_set_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.put_configuration_set_delivery_options\naws_api/sesv2 put_configuration_set_delivery_options","url":"aws_api/sesv2.html#put_configuration_set_delivery_options"},{"doc":"aws_api/sesv2","title":"put_configuration_set_reputation_options","content":"pub fn put_configuration_set_reputation_options(\n  client: Client,\n  configuration_set_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.put_configuration_set_reputation_options\naws_api/sesv2 put_configuration_set_reputation_options","url":"aws_api/sesv2.html#put_configuration_set_reputation_options"},{"doc":"aws_api/sesv2","title":"put_configuration_set_sending_options","content":"pub fn put_configuration_set_sending_options(\n  client: Client,\n  configuration_set_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.put_configuration_set_sending_options\naws_api/sesv2 put_configuration_set_sending_options","url":"aws_api/sesv2.html#put_configuration_set_sending_options"},{"doc":"aws_api/sesv2","title":"put_configuration_set_suppression_options","content":"pub fn put_configuration_set_suppression_options(\n  client: Client,\n  configuration_set_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.put_configuration_set_suppression_options\naws_api/sesv2 put_configuration_set_suppression_options","url":"aws_api/sesv2.html#put_configuration_set_suppression_options"},{"doc":"aws_api/sesv2","title":"put_configuration_set_tracking_options","content":"pub fn put_configuration_set_tracking_options(\n  client: Client,\n  configuration_set_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.put_configuration_set_tracking_options\naws_api/sesv2 put_configuration_set_tracking_options","url":"aws_api/sesv2.html#put_configuration_set_tracking_options"},{"doc":"aws_api/sesv2","title":"put_configuration_set_vdm_options","content":"pub fn put_configuration_set_vdm_options(\n  client: Client,\n  configuration_set_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.put_configuration_set_vdm_options\naws_api/sesv2 put_configuration_set_vdm_options","url":"aws_api/sesv2.html#put_configuration_set_vdm_options"},{"doc":"aws_api/sesv2","title":"put_dedicated_ip_in_pool","content":"pub fn put_dedicated_ip_in_pool(\n  client: Client,\n  ip: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.put_dedicated_ip_in_pool\naws_api/sesv2 put_dedicated_ip_in_pool","url":"aws_api/sesv2.html#put_dedicated_ip_in_pool"},{"doc":"aws_api/sesv2","title":"put_dedicated_ip_pool_scaling_attributes","content":"pub fn put_dedicated_ip_pool_scaling_attributes(\n  client: Client,\n  pool_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.put_dedicated_ip_pool_scaling_attributes\naws_api/sesv2 put_dedicated_ip_pool_scaling_attributes","url":"aws_api/sesv2.html#put_dedicated_ip_pool_scaling_attributes"},{"doc":"aws_api/sesv2","title":"put_dedicated_ip_warmup_attributes","content":"pub fn put_dedicated_ip_warmup_attributes(\n  client: Client,\n  ip: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.put_dedicated_ip_warmup_attributes\naws_api/sesv2 put_dedicated_ip_warmup_attributes","url":"aws_api/sesv2.html#put_dedicated_ip_warmup_attributes"},{"doc":"aws_api/sesv2","title":"put_deliverability_dashboard_option","content":"pub fn put_deliverability_dashboard_option(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.put_deliverability_dashboard_option\naws_api/sesv2 put_deliverability_dashboard_option","url":"aws_api/sesv2.html#put_deliverability_dashboard_option"},{"doc":"aws_api/sesv2","title":"put_email_identity_configuration_set_attributes","content":"pub fn put_email_identity_configuration_set_attributes(\n  client: Client,\n  email_identity: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.put_email_identity_configuration_set_attributes\naws_api/sesv2 put_email_identity_configuration_set_attributes","url":"aws_api/sesv2.html#put_email_identity_configuration_set_attributes"},{"doc":"aws_api/sesv2","title":"put_email_identity_dkim_attributes","content":"pub fn put_email_identity_dkim_attributes(\n  client: Client,\n  email_identity: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.put_email_identity_dkim_attributes\naws_api/sesv2 put_email_identity_dkim_attributes","url":"aws_api/sesv2.html#put_email_identity_dkim_attributes"},{"doc":"aws_api/sesv2","title":"put_email_identity_dkim_signing_attributes","content":"pub fn put_email_identity_dkim_signing_attributes(\n  client: Client,\n  email_identity: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.put_email_identity_dkim_signing_attributes\naws_api/sesv2 put_email_identity_dkim_signing_attributes","url":"aws_api/sesv2.html#put_email_identity_dkim_signing_attributes"},{"doc":"aws_api/sesv2","title":"put_email_identity_feedback_attributes","content":"pub fn put_email_identity_feedback_attributes(\n  client: Client,\n  email_identity: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.put_email_identity_feedback_attributes\naws_api/sesv2 put_email_identity_feedback_attributes","url":"aws_api/sesv2.html#put_email_identity_feedback_attributes"},{"doc":"aws_api/sesv2","title":"put_email_identity_mail_from_attributes","content":"pub fn put_email_identity_mail_from_attributes(\n  client: Client,\n  email_identity: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.put_email_identity_mail_from_attributes\naws_api/sesv2 put_email_identity_mail_from_attributes","url":"aws_api/sesv2.html#put_email_identity_mail_from_attributes"},{"doc":"aws_api/sesv2","title":"put_suppressed_destination","content":"pub fn put_suppressed_destination(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.put_suppressed_destination\naws_api/sesv2 put_suppressed_destination","url":"aws_api/sesv2.html#put_suppressed_destination"},{"doc":"aws_api/sesv2","title":"send_bulk_email","content":"pub fn send_bulk_email(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.send_bulk_email\naws_api/sesv2 send_bulk_email","url":"aws_api/sesv2.html#send_bulk_email"},{"doc":"aws_api/sesv2","title":"send_custom_verification_email","content":"pub fn send_custom_verification_email(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.send_custom_verification_email\naws_api/sesv2 send_custom_verification_email","url":"aws_api/sesv2.html#send_custom_verification_email"},{"doc":"aws_api/sesv2","title":"send_email","content":"pub fn send_email(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.send_email\naws_api/sesv2 send_email","url":"aws_api/sesv2.html#send_email"},{"doc":"aws_api/sesv2","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.tag_resource\naws_api/sesv2 tag_resource","url":"aws_api/sesv2.html#tag_resource"},{"doc":"aws_api/sesv2","title":"test_render_email_template","content":"pub fn test_render_email_template(\n  client: Client,\n  template_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.test_render_email_template\naws_api/sesv2 test_render_email_template","url":"aws_api/sesv2.html#test_render_email_template"},{"doc":"aws_api/sesv2","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.untag_resource\naws_api/sesv2 untag_resource","url":"aws_api/sesv2.html#untag_resource"},{"doc":"aws_api/sesv2","title":"update_configuration_set_event_destination","content":"pub fn update_configuration_set_event_destination(\n  client: Client,\n  configuration_set_name: String,\n  event_destination_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.update_configuration_set_event_destination\naws_api/sesv2 update_configuration_set_event_destination","url":"aws_api/sesv2.html#update_configuration_set_event_destination"},{"doc":"aws_api/sesv2","title":"update_contact","content":"pub fn update_contact(\n  client: Client,\n  contact_list_name: String,\n  email_address: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.update_contact\naws_api/sesv2 update_contact","url":"aws_api/sesv2.html#update_contact"},{"doc":"aws_api/sesv2","title":"update_contact_list","content":"pub fn update_contact_list(\n  client: Client,\n  contact_list_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.update_contact_list\naws_api/sesv2 update_contact_list","url":"aws_api/sesv2.html#update_contact_list"},{"doc":"aws_api/sesv2","title":"update_custom_verification_email_template","content":"pub fn update_custom_verification_email_template(\n  client: Client,\n  template_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.update_custom_verification_email_template\naws_api/sesv2 update_custom_verification_email_template","url":"aws_api/sesv2.html#update_custom_verification_email_template"},{"doc":"aws_api/sesv2","title":"update_email_identity_policy","content":"pub fn update_email_identity_policy(\n  client: Client,\n  email_identity: String,\n  policy_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.update_email_identity_policy\naws_api/sesv2 update_email_identity_policy","url":"aws_api/sesv2.html#update_email_identity_policy"},{"doc":"aws_api/sesv2","title":"update_email_template","content":"pub fn update_email_template(\n  client: Client,\n  template_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sesv2.update_email_template\naws_api/sesv2 update_email_template","url":"aws_api/sesv2.html#update_email_template"},{"doc":"aws_api/sesv2","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/sesv2.with_custom_endpoint\naws_api/sesv2 with_custom_endpoint","url":"aws_api/sesv2.html#with_custom_endpoint"},{"doc":"aws_api/sesv2","title":"aws_api/sesv2","content":"","url":"aws_api/sesv2.html"},{"doc":"aws_api/sfn","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/sfn.Client\naws_api/sfn Client","url":"aws_api/sfn.html#Client"},{"doc":"aws_api/sfn","title":"create_activity","content":"pub fn create_activity(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sfn.create_activity\naws_api/sfn create_activity","url":"aws_api/sfn.html#create_activity"},{"doc":"aws_api/sfn","title":"create_state_machine","content":"pub fn create_state_machine(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sfn.create_state_machine\naws_api/sfn create_state_machine","url":"aws_api/sfn.html#create_state_machine"},{"doc":"aws_api/sfn","title":"create_state_machine_alias","content":"pub fn create_state_machine_alias(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sfn.create_state_machine_alias\naws_api/sfn create_state_machine_alias","url":"aws_api/sfn.html#create_state_machine_alias"},{"doc":"aws_api/sfn","title":"delete_activity","content":"pub fn delete_activity(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sfn.delete_activity\naws_api/sfn delete_activity","url":"aws_api/sfn.html#delete_activity"},{"doc":"aws_api/sfn","title":"delete_state_machine","content":"pub fn delete_state_machine(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sfn.delete_state_machine\naws_api/sfn delete_state_machine","url":"aws_api/sfn.html#delete_state_machine"},{"doc":"aws_api/sfn","title":"delete_state_machine_alias","content":"pub fn delete_state_machine_alias(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sfn.delete_state_machine_alias\naws_api/sfn delete_state_machine_alias","url":"aws_api/sfn.html#delete_state_machine_alias"},{"doc":"aws_api/sfn","title":"delete_state_machine_version","content":"pub fn delete_state_machine_version(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sfn.delete_state_machine_version\naws_api/sfn delete_state_machine_version","url":"aws_api/sfn.html#delete_state_machine_version"},{"doc":"aws_api/sfn","title":"describe_activity","content":"pub fn describe_activity(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sfn.describe_activity\naws_api/sfn describe_activity","url":"aws_api/sfn.html#describe_activity"},{"doc":"aws_api/sfn","title":"describe_execution","content":"pub fn describe_execution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sfn.describe_execution\naws_api/sfn describe_execution","url":"aws_api/sfn.html#describe_execution"},{"doc":"aws_api/sfn","title":"describe_map_run","content":"pub fn describe_map_run(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sfn.describe_map_run\naws_api/sfn describe_map_run","url":"aws_api/sfn.html#describe_map_run"},{"doc":"aws_api/sfn","title":"describe_state_machine","content":"pub fn describe_state_machine(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sfn.describe_state_machine\naws_api/sfn describe_state_machine","url":"aws_api/sfn.html#describe_state_machine"},{"doc":"aws_api/sfn","title":"describe_state_machine_alias","content":"pub fn describe_state_machine_alias(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sfn.describe_state_machine_alias\naws_api/sfn describe_state_machine_alias","url":"aws_api/sfn.html#describe_state_machine_alias"},{"doc":"aws_api/sfn","title":"describe_state_machine_for_execution","content":"pub fn describe_state_machine_for_execution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sfn.describe_state_machine_for_execution\naws_api/sfn describe_state_machine_for_execution","url":"aws_api/sfn.html#describe_state_machine_for_execution"},{"doc":"aws_api/sfn","title":"get_activity_task","content":"pub fn get_activity_task(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sfn.get_activity_task\naws_api/sfn get_activity_task","url":"aws_api/sfn.html#get_activity_task"},{"doc":"aws_api/sfn","title":"get_execution_history","content":"pub fn get_execution_history(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sfn.get_execution_history\naws_api/sfn get_execution_history","url":"aws_api/sfn.html#get_execution_history"},{"doc":"aws_api/sfn","title":"list_activities","content":"pub fn list_activities(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sfn.list_activities\naws_api/sfn list_activities","url":"aws_api/sfn.html#list_activities"},{"doc":"aws_api/sfn","title":"list_executions","content":"pub fn list_executions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sfn.list_executions\naws_api/sfn list_executions","url":"aws_api/sfn.html#list_executions"},{"doc":"aws_api/sfn","title":"list_map_runs","content":"pub fn list_map_runs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sfn.list_map_runs\naws_api/sfn list_map_runs","url":"aws_api/sfn.html#list_map_runs"},{"doc":"aws_api/sfn","title":"list_state_machine_aliases","content":"pub fn list_state_machine_aliases(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sfn.list_state_machine_aliases\naws_api/sfn list_state_machine_aliases","url":"aws_api/sfn.html#list_state_machine_aliases"},{"doc":"aws_api/sfn","title":"list_state_machine_versions","content":"pub fn list_state_machine_versions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sfn.list_state_machine_versions\naws_api/sfn list_state_machine_versions","url":"aws_api/sfn.html#list_state_machine_versions"},{"doc":"aws_api/sfn","title":"list_state_machines","content":"pub fn list_state_machines(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sfn.list_state_machines\naws_api/sfn list_state_machines","url":"aws_api/sfn.html#list_state_machines"},{"doc":"aws_api/sfn","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sfn.list_tags_for_resource\naws_api/sfn list_tags_for_resource","url":"aws_api/sfn.html#list_tags_for_resource"},{"doc":"aws_api/sfn","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/sfn.new\naws_api/sfn new","url":"aws_api/sfn.html#new"},{"doc":"aws_api/sfn","title":"publish_state_machine_version","content":"pub fn publish_state_machine_version(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sfn.publish_state_machine_version\naws_api/sfn publish_state_machine_version","url":"aws_api/sfn.html#publish_state_machine_version"},{"doc":"aws_api/sfn","title":"redrive_execution","content":"pub fn redrive_execution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sfn.redrive_execution\naws_api/sfn redrive_execution","url":"aws_api/sfn.html#redrive_execution"},{"doc":"aws_api/sfn","title":"send_task_failure","content":"pub fn send_task_failure(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sfn.send_task_failure\naws_api/sfn send_task_failure","url":"aws_api/sfn.html#send_task_failure"},{"doc":"aws_api/sfn","title":"send_task_heartbeat","content":"pub fn send_task_heartbeat(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sfn.send_task_heartbeat\naws_api/sfn send_task_heartbeat","url":"aws_api/sfn.html#send_task_heartbeat"},{"doc":"aws_api/sfn","title":"send_task_success","content":"pub fn send_task_success(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sfn.send_task_success\naws_api/sfn send_task_success","url":"aws_api/sfn.html#send_task_success"},{"doc":"aws_api/sfn","title":"start_execution","content":"pub fn start_execution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sfn.start_execution\naws_api/sfn start_execution","url":"aws_api/sfn.html#start_execution"},{"doc":"aws_api/sfn","title":"start_sync_execution","content":"pub fn start_sync_execution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sfn.start_sync_execution\naws_api/sfn start_sync_execution","url":"aws_api/sfn.html#start_sync_execution"},{"doc":"aws_api/sfn","title":"stop_execution","content":"pub fn stop_execution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sfn.stop_execution\naws_api/sfn stop_execution","url":"aws_api/sfn.html#stop_execution"},{"doc":"aws_api/sfn","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sfn.tag_resource\naws_api/sfn tag_resource","url":"aws_api/sfn.html#tag_resource"},{"doc":"aws_api/sfn","title":"test_state","content":"pub fn test_state(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sfn.test_state\naws_api/sfn test_state","url":"aws_api/sfn.html#test_state"},{"doc":"aws_api/sfn","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sfn.untag_resource\naws_api/sfn untag_resource","url":"aws_api/sfn.html#untag_resource"},{"doc":"aws_api/sfn","title":"update_map_run","content":"pub fn update_map_run(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sfn.update_map_run\naws_api/sfn update_map_run","url":"aws_api/sfn.html#update_map_run"},{"doc":"aws_api/sfn","title":"update_state_machine","content":"pub fn update_state_machine(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sfn.update_state_machine\naws_api/sfn update_state_machine","url":"aws_api/sfn.html#update_state_machine"},{"doc":"aws_api/sfn","title":"update_state_machine_alias","content":"pub fn update_state_machine_alias(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sfn.update_state_machine_alias\naws_api/sfn update_state_machine_alias","url":"aws_api/sfn.html#update_state_machine_alias"},{"doc":"aws_api/sfn","title":"validate_state_machine_definition","content":"pub fn validate_state_machine_definition(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sfn.validate_state_machine_definition\naws_api/sfn validate_state_machine_definition","url":"aws_api/sfn.html#validate_state_machine_definition"},{"doc":"aws_api/sfn","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/sfn.with_custom_endpoint\naws_api/sfn with_custom_endpoint","url":"aws_api/sfn.html#with_custom_endpoint"},{"doc":"aws_api/sfn","title":"aws_api/sfn","content":"","url":"aws_api/sfn.html"},{"doc":"aws_api/shield","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/shield.Client\naws_api/shield Client","url":"aws_api/shield.html#Client"},{"doc":"aws_api/shield","title":"associate_drt_log_bucket","content":"pub fn associate_drt_log_bucket(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/shield.associate_drt_log_bucket\naws_api/shield associate_drt_log_bucket","url":"aws_api/shield.html#associate_drt_log_bucket"},{"doc":"aws_api/shield","title":"associate_drt_role","content":"pub fn associate_drt_role(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/shield.associate_drt_role\naws_api/shield associate_drt_role","url":"aws_api/shield.html#associate_drt_role"},{"doc":"aws_api/shield","title":"associate_health_check","content":"pub fn associate_health_check(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/shield.associate_health_check\naws_api/shield associate_health_check","url":"aws_api/shield.html#associate_health_check"},{"doc":"aws_api/shield","title":"associate_proactive_engagement_details","content":"pub fn associate_proactive_engagement_details(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/shield.associate_proactive_engagement_details\naws_api/shield associate_proactive_engagement_details","url":"aws_api/shield.html#associate_proactive_engagement_details"},{"doc":"aws_api/shield","title":"create_protection","content":"pub fn create_protection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/shield.create_protection\naws_api/shield create_protection","url":"aws_api/shield.html#create_protection"},{"doc":"aws_api/shield","title":"create_protection_group","content":"pub fn create_protection_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/shield.create_protection_group\naws_api/shield create_protection_group","url":"aws_api/shield.html#create_protection_group"},{"doc":"aws_api/shield","title":"create_subscription","content":"pub fn create_subscription(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/shield.create_subscription\naws_api/shield create_subscription","url":"aws_api/shield.html#create_subscription"},{"doc":"aws_api/shield","title":"delete_protection","content":"pub fn delete_protection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/shield.delete_protection\naws_api/shield delete_protection","url":"aws_api/shield.html#delete_protection"},{"doc":"aws_api/shield","title":"delete_protection_group","content":"pub fn delete_protection_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/shield.delete_protection_group\naws_api/shield delete_protection_group","url":"aws_api/shield.html#delete_protection_group"},{"doc":"aws_api/shield","title":"delete_subscription","content":"pub fn delete_subscription(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/shield.delete_subscription\naws_api/shield delete_subscription","url":"aws_api/shield.html#delete_subscription"},{"doc":"aws_api/shield","title":"describe_attack","content":"pub fn describe_attack(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/shield.describe_attack\naws_api/shield describe_attack","url":"aws_api/shield.html#describe_attack"},{"doc":"aws_api/shield","title":"describe_attack_statistics","content":"pub fn describe_attack_statistics(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/shield.describe_attack_statistics\naws_api/shield describe_attack_statistics","url":"aws_api/shield.html#describe_attack_statistics"},{"doc":"aws_api/shield","title":"describe_drt_access","content":"pub fn describe_drt_access(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/shield.describe_drt_access\naws_api/shield describe_drt_access","url":"aws_api/shield.html#describe_drt_access"},{"doc":"aws_api/shield","title":"describe_emergency_contact_settings","content":"pub fn describe_emergency_contact_settings(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/shield.describe_emergency_contact_settings\naws_api/shield describe_emergency_contact_settings","url":"aws_api/shield.html#describe_emergency_contact_settings"},{"doc":"aws_api/shield","title":"describe_protection","content":"pub fn describe_protection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/shield.describe_protection\naws_api/shield describe_protection","url":"aws_api/shield.html#describe_protection"},{"doc":"aws_api/shield","title":"describe_protection_group","content":"pub fn describe_protection_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/shield.describe_protection_group\naws_api/shield describe_protection_group","url":"aws_api/shield.html#describe_protection_group"},{"doc":"aws_api/shield","title":"describe_subscription","content":"pub fn describe_subscription(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/shield.describe_subscription\naws_api/shield describe_subscription","url":"aws_api/shield.html#describe_subscription"},{"doc":"aws_api/shield","title":"disable_application_layer_automatic_response","content":"pub fn disable_application_layer_automatic_response(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/shield.disable_application_layer_automatic_response\naws_api/shield disable_application_layer_automatic_response","url":"aws_api/shield.html#disable_application_layer_automatic_response"},{"doc":"aws_api/shield","title":"disable_proactive_engagement","content":"pub fn disable_proactive_engagement(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/shield.disable_proactive_engagement\naws_api/shield disable_proactive_engagement","url":"aws_api/shield.html#disable_proactive_engagement"},{"doc":"aws_api/shield","title":"disassociate_drt_log_bucket","content":"pub fn disassociate_drt_log_bucket(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/shield.disassociate_drt_log_bucket\naws_api/shield disassociate_drt_log_bucket","url":"aws_api/shield.html#disassociate_drt_log_bucket"},{"doc":"aws_api/shield","title":"disassociate_drt_role","content":"pub fn disassociate_drt_role(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/shield.disassociate_drt_role\naws_api/shield disassociate_drt_role","url":"aws_api/shield.html#disassociate_drt_role"},{"doc":"aws_api/shield","title":"disassociate_health_check","content":"pub fn disassociate_health_check(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/shield.disassociate_health_check\naws_api/shield disassociate_health_check","url":"aws_api/shield.html#disassociate_health_check"},{"doc":"aws_api/shield","title":"enable_application_layer_automatic_response","content":"pub fn enable_application_layer_automatic_response(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/shield.enable_application_layer_automatic_response\naws_api/shield enable_application_layer_automatic_response","url":"aws_api/shield.html#enable_application_layer_automatic_response"},{"doc":"aws_api/shield","title":"enable_proactive_engagement","content":"pub fn enable_proactive_engagement(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/shield.enable_proactive_engagement\naws_api/shield enable_proactive_engagement","url":"aws_api/shield.html#enable_proactive_engagement"},{"doc":"aws_api/shield","title":"get_subscription_state","content":"pub fn get_subscription_state(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/shield.get_subscription_state\naws_api/shield get_subscription_state","url":"aws_api/shield.html#get_subscription_state"},{"doc":"aws_api/shield","title":"list_attacks","content":"pub fn list_attacks(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/shield.list_attacks\naws_api/shield list_attacks","url":"aws_api/shield.html#list_attacks"},{"doc":"aws_api/shield","title":"list_protection_groups","content":"pub fn list_protection_groups(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/shield.list_protection_groups\naws_api/shield list_protection_groups","url":"aws_api/shield.html#list_protection_groups"},{"doc":"aws_api/shield","title":"list_protections","content":"pub fn list_protections(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/shield.list_protections\naws_api/shield list_protections","url":"aws_api/shield.html#list_protections"},{"doc":"aws_api/shield","title":"list_resources_in_protection_group","content":"pub fn list_resources_in_protection_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/shield.list_resources_in_protection_group\naws_api/shield list_resources_in_protection_group","url":"aws_api/shield.html#list_resources_in_protection_group"},{"doc":"aws_api/shield","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/shield.list_tags_for_resource\naws_api/shield list_tags_for_resource","url":"aws_api/shield.html#list_tags_for_resource"},{"doc":"aws_api/shield","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/shield.new\naws_api/shield new","url":"aws_api/shield.html#new"},{"doc":"aws_api/shield","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/shield.tag_resource\naws_api/shield tag_resource","url":"aws_api/shield.html#tag_resource"},{"doc":"aws_api/shield","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/shield.untag_resource\naws_api/shield untag_resource","url":"aws_api/shield.html#untag_resource"},{"doc":"aws_api/shield","title":"update_application_layer_automatic_response","content":"pub fn update_application_layer_automatic_response(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/shield.update_application_layer_automatic_response\naws_api/shield update_application_layer_automatic_response","url":"aws_api/shield.html#update_application_layer_automatic_response"},{"doc":"aws_api/shield","title":"update_emergency_contact_settings","content":"pub fn update_emergency_contact_settings(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/shield.update_emergency_contact_settings\naws_api/shield update_emergency_contact_settings","url":"aws_api/shield.html#update_emergency_contact_settings"},{"doc":"aws_api/shield","title":"update_protection_group","content":"pub fn update_protection_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/shield.update_protection_group\naws_api/shield update_protection_group","url":"aws_api/shield.html#update_protection_group"},{"doc":"aws_api/shield","title":"update_subscription","content":"pub fn update_subscription(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/shield.update_subscription\naws_api/shield update_subscription","url":"aws_api/shield.html#update_subscription"},{"doc":"aws_api/shield","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/shield.with_custom_endpoint\naws_api/shield with_custom_endpoint","url":"aws_api/shield.html#with_custom_endpoint"},{"doc":"aws_api/shield","title":"aws_api/shield","content":"","url":"aws_api/shield.html"},{"doc":"aws_api/signer","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/signer.Client\naws_api/signer Client","url":"aws_api/signer.html#Client"},{"doc":"aws_api/signer","title":"add_profile_permission","content":"pub fn add_profile_permission(\n  client: Client,\n  profile_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/signer.add_profile_permission\naws_api/signer add_profile_permission","url":"aws_api/signer.html#add_profile_permission"},{"doc":"aws_api/signer","title":"cancel_signing_profile","content":"pub fn cancel_signing_profile(\n  client: Client,\n  profile_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/signer.cancel_signing_profile\naws_api/signer cancel_signing_profile","url":"aws_api/signer.html#cancel_signing_profile"},{"doc":"aws_api/signer","title":"describe_signing_job","content":"pub fn describe_signing_job(\n  client: Client,\n  job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/signer.describe_signing_job\naws_api/signer describe_signing_job","url":"aws_api/signer.html#describe_signing_job"},{"doc":"aws_api/signer","title":"get_revocation_status","content":"pub fn get_revocation_status(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/signer.get_revocation_status\naws_api/signer get_revocation_status","url":"aws_api/signer.html#get_revocation_status"},{"doc":"aws_api/signer","title":"get_signing_platform","content":"pub fn get_signing_platform(\n  client: Client,\n  platform_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/signer.get_signing_platform\naws_api/signer get_signing_platform","url":"aws_api/signer.html#get_signing_platform"},{"doc":"aws_api/signer","title":"get_signing_profile","content":"pub fn get_signing_profile(\n  client: Client,\n  profile_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/signer.get_signing_profile\naws_api/signer get_signing_profile","url":"aws_api/signer.html#get_signing_profile"},{"doc":"aws_api/signer","title":"list_profile_permissions","content":"pub fn list_profile_permissions(\n  client: Client,\n  profile_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/signer.list_profile_permissions\naws_api/signer list_profile_permissions","url":"aws_api/signer.html#list_profile_permissions"},{"doc":"aws_api/signer","title":"list_signing_jobs","content":"pub fn list_signing_jobs(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/signer.list_signing_jobs\naws_api/signer list_signing_jobs","url":"aws_api/signer.html#list_signing_jobs"},{"doc":"aws_api/signer","title":"list_signing_platforms","content":"pub fn list_signing_platforms(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/signer.list_signing_platforms\naws_api/signer list_signing_platforms","url":"aws_api/signer.html#list_signing_platforms"},{"doc":"aws_api/signer","title":"list_signing_profiles","content":"pub fn list_signing_profiles(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/signer.list_signing_profiles\naws_api/signer list_signing_profiles","url":"aws_api/signer.html#list_signing_profiles"},{"doc":"aws_api/signer","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/signer.list_tags_for_resource\naws_api/signer list_tags_for_resource","url":"aws_api/signer.html#list_tags_for_resource"},{"doc":"aws_api/signer","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/signer.new\naws_api/signer new","url":"aws_api/signer.html#new"},{"doc":"aws_api/signer","title":"put_signing_profile","content":"pub fn put_signing_profile(\n  client: Client,\n  profile_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/signer.put_signing_profile\naws_api/signer put_signing_profile","url":"aws_api/signer.html#put_signing_profile"},{"doc":"aws_api/signer","title":"remove_profile_permission","content":"pub fn remove_profile_permission(\n  client: Client,\n  profile_name: String,\n  statement_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/signer.remove_profile_permission\naws_api/signer remove_profile_permission","url":"aws_api/signer.html#remove_profile_permission"},{"doc":"aws_api/signer","title":"revoke_signature","content":"pub fn revoke_signature(\n  client: Client,\n  job_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/signer.revoke_signature\naws_api/signer revoke_signature","url":"aws_api/signer.html#revoke_signature"},{"doc":"aws_api/signer","title":"revoke_signing_profile","content":"pub fn revoke_signing_profile(\n  client: Client,\n  profile_name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/signer.revoke_signing_profile\naws_api/signer revoke_signing_profile","url":"aws_api/signer.html#revoke_signing_profile"},{"doc":"aws_api/signer","title":"sign_payload","content":"pub fn sign_payload(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/signer.sign_payload\naws_api/signer sign_payload","url":"aws_api/signer.html#sign_payload"},{"doc":"aws_api/signer","title":"start_signing_job","content":"pub fn start_signing_job(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/signer.start_signing_job\naws_api/signer start_signing_job","url":"aws_api/signer.html#start_signing_job"},{"doc":"aws_api/signer","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/signer.tag_resource\naws_api/signer tag_resource","url":"aws_api/signer.html#tag_resource"},{"doc":"aws_api/signer","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/signer.untag_resource\naws_api/signer untag_resource","url":"aws_api/signer.html#untag_resource"},{"doc":"aws_api/signer","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/signer.with_custom_endpoint\naws_api/signer with_custom_endpoint","url":"aws_api/signer.html#with_custom_endpoint"},{"doc":"aws_api/signer","title":"aws_api/signer","content":"","url":"aws_api/signer.html"},{"doc":"aws_api/simspaceweaver","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/simspaceweaver.Client\naws_api/simspaceweaver Client","url":"aws_api/simspaceweaver.html#Client"},{"doc":"aws_api/simspaceweaver","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/simspaceweaver.list_tags_for_resource\naws_api/simspaceweaver list_tags_for_resource","url":"aws_api/simspaceweaver.html#list_tags_for_resource"},{"doc":"aws_api/simspaceweaver","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/simspaceweaver.new\naws_api/simspaceweaver new","url":"aws_api/simspaceweaver.html#new"},{"doc":"aws_api/simspaceweaver","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/simspaceweaver.tag_resource\naws_api/simspaceweaver tag_resource","url":"aws_api/simspaceweaver.html#tag_resource"},{"doc":"aws_api/simspaceweaver","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/simspaceweaver.untag_resource\naws_api/simspaceweaver untag_resource","url":"aws_api/simspaceweaver.html#untag_resource"},{"doc":"aws_api/simspaceweaver","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/simspaceweaver.with_custom_endpoint\naws_api/simspaceweaver with_custom_endpoint","url":"aws_api/simspaceweaver.html#with_custom_endpoint"},{"doc":"aws_api/simspaceweaver","title":"aws_api/simspaceweaver","content":"","url":"aws_api/simspaceweaver.html"},{"doc":"aws_api/sms","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/sms.Client\naws_api/sms Client","url":"aws_api/sms.html#Client"},{"doc":"aws_api/sms","title":"create_app","content":"pub fn create_app(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sms.create_app\naws_api/sms create_app","url":"aws_api/sms.html#create_app"},{"doc":"aws_api/sms","title":"create_replication_job","content":"pub fn create_replication_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sms.create_replication_job\naws_api/sms create_replication_job","url":"aws_api/sms.html#create_replication_job"},{"doc":"aws_api/sms","title":"delete_app","content":"pub fn delete_app(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sms.delete_app\naws_api/sms delete_app","url":"aws_api/sms.html#delete_app"},{"doc":"aws_api/sms","title":"delete_app_launch_configuration","content":"pub fn delete_app_launch_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sms.delete_app_launch_configuration\naws_api/sms delete_app_launch_configuration","url":"aws_api/sms.html#delete_app_launch_configuration"},{"doc":"aws_api/sms","title":"delete_app_replication_configuration","content":"pub fn delete_app_replication_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sms.delete_app_replication_configuration\naws_api/sms delete_app_replication_configuration","url":"aws_api/sms.html#delete_app_replication_configuration"},{"doc":"aws_api/sms","title":"delete_app_validation_configuration","content":"pub fn delete_app_validation_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sms.delete_app_validation_configuration\naws_api/sms delete_app_validation_configuration","url":"aws_api/sms.html#delete_app_validation_configuration"},{"doc":"aws_api/sms","title":"delete_replication_job","content":"pub fn delete_replication_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sms.delete_replication_job\naws_api/sms delete_replication_job","url":"aws_api/sms.html#delete_replication_job"},{"doc":"aws_api/sms","title":"delete_server_catalog","content":"pub fn delete_server_catalog(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sms.delete_server_catalog\naws_api/sms delete_server_catalog","url":"aws_api/sms.html#delete_server_catalog"},{"doc":"aws_api/sms","title":"disassociate_connector","content":"pub fn disassociate_connector(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sms.disassociate_connector\naws_api/sms disassociate_connector","url":"aws_api/sms.html#disassociate_connector"},{"doc":"aws_api/sms","title":"generate_change_set","content":"pub fn generate_change_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sms.generate_change_set\naws_api/sms generate_change_set","url":"aws_api/sms.html#generate_change_set"},{"doc":"aws_api/sms","title":"generate_template","content":"pub fn generate_template(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sms.generate_template\naws_api/sms generate_template","url":"aws_api/sms.html#generate_template"},{"doc":"aws_api/sms","title":"get_app","content":"pub fn get_app(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sms.get_app\naws_api/sms get_app","url":"aws_api/sms.html#get_app"},{"doc":"aws_api/sms","title":"get_app_launch_configuration","content":"pub fn get_app_launch_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sms.get_app_launch_configuration\naws_api/sms get_app_launch_configuration","url":"aws_api/sms.html#get_app_launch_configuration"},{"doc":"aws_api/sms","title":"get_app_replication_configuration","content":"pub fn get_app_replication_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sms.get_app_replication_configuration\naws_api/sms get_app_replication_configuration","url":"aws_api/sms.html#get_app_replication_configuration"},{"doc":"aws_api/sms","title":"get_app_validation_configuration","content":"pub fn get_app_validation_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sms.get_app_validation_configuration\naws_api/sms get_app_validation_configuration","url":"aws_api/sms.html#get_app_validation_configuration"},{"doc":"aws_api/sms","title":"get_app_validation_output","content":"pub fn get_app_validation_output(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sms.get_app_validation_output\naws_api/sms get_app_validation_output","url":"aws_api/sms.html#get_app_validation_output"},{"doc":"aws_api/sms","title":"get_connectors","content":"pub fn get_connectors(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sms.get_connectors\naws_api/sms get_connectors","url":"aws_api/sms.html#get_connectors"},{"doc":"aws_api/sms","title":"get_replication_jobs","content":"pub fn get_replication_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sms.get_replication_jobs\naws_api/sms get_replication_jobs","url":"aws_api/sms.html#get_replication_jobs"},{"doc":"aws_api/sms","title":"get_replication_runs","content":"pub fn get_replication_runs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sms.get_replication_runs\naws_api/sms get_replication_runs","url":"aws_api/sms.html#get_replication_runs"},{"doc":"aws_api/sms","title":"get_servers","content":"pub fn get_servers(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sms.get_servers\naws_api/sms get_servers","url":"aws_api/sms.html#get_servers"},{"doc":"aws_api/sms","title":"import_app_catalog","content":"pub fn import_app_catalog(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sms.import_app_catalog\naws_api/sms import_app_catalog","url":"aws_api/sms.html#import_app_catalog"},{"doc":"aws_api/sms","title":"import_server_catalog","content":"pub fn import_server_catalog(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sms.import_server_catalog\naws_api/sms import_server_catalog","url":"aws_api/sms.html#import_server_catalog"},{"doc":"aws_api/sms","title":"launch_app","content":"pub fn launch_app(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sms.launch_app\naws_api/sms launch_app","url":"aws_api/sms.html#launch_app"},{"doc":"aws_api/sms","title":"list_apps","content":"pub fn list_apps(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sms.list_apps\naws_api/sms list_apps","url":"aws_api/sms.html#list_apps"},{"doc":"aws_api/sms","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/sms.new\naws_api/sms new","url":"aws_api/sms.html#new"},{"doc":"aws_api/sms","title":"notify_app_validation_output","content":"pub fn notify_app_validation_output(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sms.notify_app_validation_output\naws_api/sms notify_app_validation_output","url":"aws_api/sms.html#notify_app_validation_output"},{"doc":"aws_api/sms","title":"put_app_launch_configuration","content":"pub fn put_app_launch_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sms.put_app_launch_configuration\naws_api/sms put_app_launch_configuration","url":"aws_api/sms.html#put_app_launch_configuration"},{"doc":"aws_api/sms","title":"put_app_replication_configuration","content":"pub fn put_app_replication_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sms.put_app_replication_configuration\naws_api/sms put_app_replication_configuration","url":"aws_api/sms.html#put_app_replication_configuration"},{"doc":"aws_api/sms","title":"put_app_validation_configuration","content":"pub fn put_app_validation_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sms.put_app_validation_configuration\naws_api/sms put_app_validation_configuration","url":"aws_api/sms.html#put_app_validation_configuration"},{"doc":"aws_api/sms","title":"start_app_replication","content":"pub fn start_app_replication(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sms.start_app_replication\naws_api/sms start_app_replication","url":"aws_api/sms.html#start_app_replication"},{"doc":"aws_api/sms","title":"start_on_demand_app_replication","content":"pub fn start_on_demand_app_replication(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sms.start_on_demand_app_replication\naws_api/sms start_on_demand_app_replication","url":"aws_api/sms.html#start_on_demand_app_replication"},{"doc":"aws_api/sms","title":"start_on_demand_replication_run","content":"pub fn start_on_demand_replication_run(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sms.start_on_demand_replication_run\naws_api/sms start_on_demand_replication_run","url":"aws_api/sms.html#start_on_demand_replication_run"},{"doc":"aws_api/sms","title":"stop_app_replication","content":"pub fn stop_app_replication(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sms.stop_app_replication\naws_api/sms stop_app_replication","url":"aws_api/sms.html#stop_app_replication"},{"doc":"aws_api/sms","title":"terminate_app","content":"pub fn terminate_app(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sms.terminate_app\naws_api/sms terminate_app","url":"aws_api/sms.html#terminate_app"},{"doc":"aws_api/sms","title":"update_app","content":"pub fn update_app(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sms.update_app\naws_api/sms update_app","url":"aws_api/sms.html#update_app"},{"doc":"aws_api/sms","title":"update_replication_job","content":"pub fn update_replication_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sms.update_replication_job\naws_api/sms update_replication_job","url":"aws_api/sms.html#update_replication_job"},{"doc":"aws_api/sms","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/sms.with_custom_endpoint\naws_api/sms with_custom_endpoint","url":"aws_api/sms.html#with_custom_endpoint"},{"doc":"aws_api/sms","title":"aws_api/sms","content":"","url":"aws_api/sms.html"},{"doc":"aws_api/snowball","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/snowball.Client\naws_api/snowball Client","url":"aws_api/snowball.html#Client"},{"doc":"aws_api/snowball","title":"cancel_cluster","content":"pub fn cancel_cluster(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/snowball.cancel_cluster\naws_api/snowball cancel_cluster","url":"aws_api/snowball.html#cancel_cluster"},{"doc":"aws_api/snowball","title":"cancel_job","content":"pub fn cancel_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/snowball.cancel_job\naws_api/snowball cancel_job","url":"aws_api/snowball.html#cancel_job"},{"doc":"aws_api/snowball","title":"create_address","content":"pub fn create_address(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/snowball.create_address\naws_api/snowball create_address","url":"aws_api/snowball.html#create_address"},{"doc":"aws_api/snowball","title":"create_cluster","content":"pub fn create_cluster(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/snowball.create_cluster\naws_api/snowball create_cluster","url":"aws_api/snowball.html#create_cluster"},{"doc":"aws_api/snowball","title":"create_job","content":"pub fn create_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/snowball.create_job\naws_api/snowball create_job","url":"aws_api/snowball.html#create_job"},{"doc":"aws_api/snowball","title":"create_long_term_pricing","content":"pub fn create_long_term_pricing(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/snowball.create_long_term_pricing\naws_api/snowball create_long_term_pricing","url":"aws_api/snowball.html#create_long_term_pricing"},{"doc":"aws_api/snowball","title":"create_return_shipping_label","content":"pub fn create_return_shipping_label(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/snowball.create_return_shipping_label\naws_api/snowball create_return_shipping_label","url":"aws_api/snowball.html#create_return_shipping_label"},{"doc":"aws_api/snowball","title":"describe_address","content":"pub fn describe_address(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/snowball.describe_address\naws_api/snowball describe_address","url":"aws_api/snowball.html#describe_address"},{"doc":"aws_api/snowball","title":"describe_addresses","content":"pub fn describe_addresses(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/snowball.describe_addresses\naws_api/snowball describe_addresses","url":"aws_api/snowball.html#describe_addresses"},{"doc":"aws_api/snowball","title":"describe_cluster","content":"pub fn describe_cluster(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/snowball.describe_cluster\naws_api/snowball describe_cluster","url":"aws_api/snowball.html#describe_cluster"},{"doc":"aws_api/snowball","title":"describe_job","content":"pub fn describe_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/snowball.describe_job\naws_api/snowball describe_job","url":"aws_api/snowball.html#describe_job"},{"doc":"aws_api/snowball","title":"describe_return_shipping_label","content":"pub fn describe_return_shipping_label(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/snowball.describe_return_shipping_label\naws_api/snowball describe_return_shipping_label","url":"aws_api/snowball.html#describe_return_shipping_label"},{"doc":"aws_api/snowball","title":"get_job_manifest","content":"pub fn get_job_manifest(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/snowball.get_job_manifest\naws_api/snowball get_job_manifest","url":"aws_api/snowball.html#get_job_manifest"},{"doc":"aws_api/snowball","title":"get_job_unlock_code","content":"pub fn get_job_unlock_code(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/snowball.get_job_unlock_code\naws_api/snowball get_job_unlock_code","url":"aws_api/snowball.html#get_job_unlock_code"},{"doc":"aws_api/snowball","title":"get_snowball_usage","content":"pub fn get_snowball_usage(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/snowball.get_snowball_usage\naws_api/snowball get_snowball_usage","url":"aws_api/snowball.html#get_snowball_usage"},{"doc":"aws_api/snowball","title":"get_software_updates","content":"pub fn get_software_updates(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/snowball.get_software_updates\naws_api/snowball get_software_updates","url":"aws_api/snowball.html#get_software_updates"},{"doc":"aws_api/snowball","title":"list_cluster_jobs","content":"pub fn list_cluster_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/snowball.list_cluster_jobs\naws_api/snowball list_cluster_jobs","url":"aws_api/snowball.html#list_cluster_jobs"},{"doc":"aws_api/snowball","title":"list_clusters","content":"pub fn list_clusters(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/snowball.list_clusters\naws_api/snowball list_clusters","url":"aws_api/snowball.html#list_clusters"},{"doc":"aws_api/snowball","title":"list_compatible_images","content":"pub fn list_compatible_images(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/snowball.list_compatible_images\naws_api/snowball list_compatible_images","url":"aws_api/snowball.html#list_compatible_images"},{"doc":"aws_api/snowball","title":"list_jobs","content":"pub fn list_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/snowball.list_jobs\naws_api/snowball list_jobs","url":"aws_api/snowball.html#list_jobs"},{"doc":"aws_api/snowball","title":"list_long_term_pricing","content":"pub fn list_long_term_pricing(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/snowball.list_long_term_pricing\naws_api/snowball list_long_term_pricing","url":"aws_api/snowball.html#list_long_term_pricing"},{"doc":"aws_api/snowball","title":"list_pickup_locations","content":"pub fn list_pickup_locations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/snowball.list_pickup_locations\naws_api/snowball list_pickup_locations","url":"aws_api/snowball.html#list_pickup_locations"},{"doc":"aws_api/snowball","title":"list_service_versions","content":"pub fn list_service_versions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/snowball.list_service_versions\naws_api/snowball list_service_versions","url":"aws_api/snowball.html#list_service_versions"},{"doc":"aws_api/snowball","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/snowball.new\naws_api/snowball new","url":"aws_api/snowball.html#new"},{"doc":"aws_api/snowball","title":"update_cluster","content":"pub fn update_cluster(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/snowball.update_cluster\naws_api/snowball update_cluster","url":"aws_api/snowball.html#update_cluster"},{"doc":"aws_api/snowball","title":"update_job","content":"pub fn update_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/snowball.update_job\naws_api/snowball update_job","url":"aws_api/snowball.html#update_job"},{"doc":"aws_api/snowball","title":"update_job_shipment_state","content":"pub fn update_job_shipment_state(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/snowball.update_job_shipment_state\naws_api/snowball update_job_shipment_state","url":"aws_api/snowball.html#update_job_shipment_state"},{"doc":"aws_api/snowball","title":"update_long_term_pricing","content":"pub fn update_long_term_pricing(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/snowball.update_long_term_pricing\naws_api/snowball update_long_term_pricing","url":"aws_api/snowball.html#update_long_term_pricing"},{"doc":"aws_api/snowball","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/snowball.with_custom_endpoint\naws_api/snowball with_custom_endpoint","url":"aws_api/snowball.html#with_custom_endpoint"},{"doc":"aws_api/snowball","title":"aws_api/snowball","content":"","url":"aws_api/snowball.html"},{"doc":"aws_api/sns","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/sns.Client\naws_api/sns Client","url":"aws_api/sns.html#Client"},{"doc":"aws_api/sns","title":"add_permission","content":"pub fn add_permission(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sns.add_permission\naws_api/sns add_permission","url":"aws_api/sns.html#add_permission"},{"doc":"aws_api/sns","title":"check_if_phone_number_is_opted_out","content":"pub fn check_if_phone_number_is_opted_out(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sns.check_if_phone_number_is_opted_out\naws_api/sns check_if_phone_number_is_opted_out","url":"aws_api/sns.html#check_if_phone_number_is_opted_out"},{"doc":"aws_api/sns","title":"confirm_subscription","content":"pub fn confirm_subscription(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sns.confirm_subscription\naws_api/sns confirm_subscription","url":"aws_api/sns.html#confirm_subscription"},{"doc":"aws_api/sns","title":"create_platform_application","content":"pub fn create_platform_application(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sns.create_platform_application\naws_api/sns create_platform_application","url":"aws_api/sns.html#create_platform_application"},{"doc":"aws_api/sns","title":"create_platform_endpoint","content":"pub fn create_platform_endpoint(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sns.create_platform_endpoint\naws_api/sns create_platform_endpoint","url":"aws_api/sns.html#create_platform_endpoint"},{"doc":"aws_api/sns","title":"create_sms_sandbox_phone_number","content":"pub fn create_sms_sandbox_phone_number(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sns.create_sms_sandbox_phone_number\naws_api/sns create_sms_sandbox_phone_number","url":"aws_api/sns.html#create_sms_sandbox_phone_number"},{"doc":"aws_api/sns","title":"create_topic","content":"pub fn create_topic(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sns.create_topic\naws_api/sns create_topic","url":"aws_api/sns.html#create_topic"},{"doc":"aws_api/sns","title":"delete_endpoint","content":"pub fn delete_endpoint(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sns.delete_endpoint\naws_api/sns delete_endpoint","url":"aws_api/sns.html#delete_endpoint"},{"doc":"aws_api/sns","title":"delete_platform_application","content":"pub fn delete_platform_application(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sns.delete_platform_application\naws_api/sns delete_platform_application","url":"aws_api/sns.html#delete_platform_application"},{"doc":"aws_api/sns","title":"delete_sms_sandbox_phone_number","content":"pub fn delete_sms_sandbox_phone_number(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sns.delete_sms_sandbox_phone_number\naws_api/sns delete_sms_sandbox_phone_number","url":"aws_api/sns.html#delete_sms_sandbox_phone_number"},{"doc":"aws_api/sns","title":"delete_topic","content":"pub fn delete_topic(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sns.delete_topic\naws_api/sns delete_topic","url":"aws_api/sns.html#delete_topic"},{"doc":"aws_api/sns","title":"get_data_protection_policy","content":"pub fn get_data_protection_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sns.get_data_protection_policy\naws_api/sns get_data_protection_policy","url":"aws_api/sns.html#get_data_protection_policy"},{"doc":"aws_api/sns","title":"get_endpoint_attributes","content":"pub fn get_endpoint_attributes(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sns.get_endpoint_attributes\naws_api/sns get_endpoint_attributes","url":"aws_api/sns.html#get_endpoint_attributes"},{"doc":"aws_api/sns","title":"get_platform_application_attributes","content":"pub fn get_platform_application_attributes(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sns.get_platform_application_attributes\naws_api/sns get_platform_application_attributes","url":"aws_api/sns.html#get_platform_application_attributes"},{"doc":"aws_api/sns","title":"get_sms_attributes","content":"pub fn get_sms_attributes(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sns.get_sms_attributes\naws_api/sns get_sms_attributes","url":"aws_api/sns.html#get_sms_attributes"},{"doc":"aws_api/sns","title":"get_sms_sandbox_account_status","content":"pub fn get_sms_sandbox_account_status(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sns.get_sms_sandbox_account_status\naws_api/sns get_sms_sandbox_account_status","url":"aws_api/sns.html#get_sms_sandbox_account_status"},{"doc":"aws_api/sns","title":"get_subscription_attributes","content":"pub fn get_subscription_attributes(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sns.get_subscription_attributes\naws_api/sns get_subscription_attributes","url":"aws_api/sns.html#get_subscription_attributes"},{"doc":"aws_api/sns","title":"get_topic_attributes","content":"pub fn get_topic_attributes(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sns.get_topic_attributes\naws_api/sns get_topic_attributes","url":"aws_api/sns.html#get_topic_attributes"},{"doc":"aws_api/sns","title":"list_endpoints_by_platform_application","content":"pub fn list_endpoints_by_platform_application(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sns.list_endpoints_by_platform_application\naws_api/sns list_endpoints_by_platform_application","url":"aws_api/sns.html#list_endpoints_by_platform_application"},{"doc":"aws_api/sns","title":"list_origination_numbers","content":"pub fn list_origination_numbers(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sns.list_origination_numbers\naws_api/sns list_origination_numbers","url":"aws_api/sns.html#list_origination_numbers"},{"doc":"aws_api/sns","title":"list_phone_numbers_opted_out","content":"pub fn list_phone_numbers_opted_out(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sns.list_phone_numbers_opted_out\naws_api/sns list_phone_numbers_opted_out","url":"aws_api/sns.html#list_phone_numbers_opted_out"},{"doc":"aws_api/sns","title":"list_platform_applications","content":"pub fn list_platform_applications(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sns.list_platform_applications\naws_api/sns list_platform_applications","url":"aws_api/sns.html#list_platform_applications"},{"doc":"aws_api/sns","title":"list_sms_sandbox_phone_numbers","content":"pub fn list_sms_sandbox_phone_numbers(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sns.list_sms_sandbox_phone_numbers\naws_api/sns list_sms_sandbox_phone_numbers","url":"aws_api/sns.html#list_sms_sandbox_phone_numbers"},{"doc":"aws_api/sns","title":"list_subscriptions","content":"pub fn list_subscriptions(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sns.list_subscriptions\naws_api/sns list_subscriptions","url":"aws_api/sns.html#list_subscriptions"},{"doc":"aws_api/sns","title":"list_subscriptions_by_topic","content":"pub fn list_subscriptions_by_topic(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sns.list_subscriptions_by_topic\naws_api/sns list_subscriptions_by_topic","url":"aws_api/sns.html#list_subscriptions_by_topic"},{"doc":"aws_api/sns","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sns.list_tags_for_resource\naws_api/sns list_tags_for_resource","url":"aws_api/sns.html#list_tags_for_resource"},{"doc":"aws_api/sns","title":"list_topics","content":"pub fn list_topics(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sns.list_topics\naws_api/sns list_topics","url":"aws_api/sns.html#list_topics"},{"doc":"aws_api/sns","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/sns.new\naws_api/sns new","url":"aws_api/sns.html#new"},{"doc":"aws_api/sns","title":"opt_in_phone_number","content":"pub fn opt_in_phone_number(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sns.opt_in_phone_number\naws_api/sns opt_in_phone_number","url":"aws_api/sns.html#opt_in_phone_number"},{"doc":"aws_api/sns","title":"publish","content":"pub fn publish(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sns.publish\naws_api/sns publish","url":"aws_api/sns.html#publish"},{"doc":"aws_api/sns","title":"publish_batch","content":"pub fn publish_batch(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sns.publish_batch\naws_api/sns publish_batch","url":"aws_api/sns.html#publish_batch"},{"doc":"aws_api/sns","title":"put_data_protection_policy","content":"pub fn put_data_protection_policy(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sns.put_data_protection_policy\naws_api/sns put_data_protection_policy","url":"aws_api/sns.html#put_data_protection_policy"},{"doc":"aws_api/sns","title":"remove_permission","content":"pub fn remove_permission(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sns.remove_permission\naws_api/sns remove_permission","url":"aws_api/sns.html#remove_permission"},{"doc":"aws_api/sns","title":"set_endpoint_attributes","content":"pub fn set_endpoint_attributes(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sns.set_endpoint_attributes\naws_api/sns set_endpoint_attributes","url":"aws_api/sns.html#set_endpoint_attributes"},{"doc":"aws_api/sns","title":"set_platform_application_attributes","content":"pub fn set_platform_application_attributes(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sns.set_platform_application_attributes\naws_api/sns set_platform_application_attributes","url":"aws_api/sns.html#set_platform_application_attributes"},{"doc":"aws_api/sns","title":"set_sms_attributes","content":"pub fn set_sms_attributes(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sns.set_sms_attributes\naws_api/sns set_sms_attributes","url":"aws_api/sns.html#set_sms_attributes"},{"doc":"aws_api/sns","title":"set_subscription_attributes","content":"pub fn set_subscription_attributes(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sns.set_subscription_attributes\naws_api/sns set_subscription_attributes","url":"aws_api/sns.html#set_subscription_attributes"},{"doc":"aws_api/sns","title":"set_topic_attributes","content":"pub fn set_topic_attributes(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sns.set_topic_attributes\naws_api/sns set_topic_attributes","url":"aws_api/sns.html#set_topic_attributes"},{"doc":"aws_api/sns","title":"subscribe","content":"pub fn subscribe(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sns.subscribe\naws_api/sns subscribe","url":"aws_api/sns.html#subscribe"},{"doc":"aws_api/sns","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sns.tag_resource\naws_api/sns tag_resource","url":"aws_api/sns.html#tag_resource"},{"doc":"aws_api/sns","title":"unsubscribe","content":"pub fn unsubscribe(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sns.unsubscribe\naws_api/sns unsubscribe","url":"aws_api/sns.html#unsubscribe"},{"doc":"aws_api/sns","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sns.untag_resource\naws_api/sns untag_resource","url":"aws_api/sns.html#untag_resource"},{"doc":"aws_api/sns","title":"verify_sms_sandbox_phone_number","content":"pub fn verify_sms_sandbox_phone_number(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sns.verify_sms_sandbox_phone_number\naws_api/sns verify_sms_sandbox_phone_number","url":"aws_api/sns.html#verify_sms_sandbox_phone_number"},{"doc":"aws_api/sns","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/sns.with_custom_endpoint\naws_api/sns with_custom_endpoint","url":"aws_api/sns.html#with_custom_endpoint"},{"doc":"aws_api/sns","title":"aws_api/sns","content":"","url":"aws_api/sns.html"},{"doc":"aws_api/sqs","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/sqs.Client\naws_api/sqs Client","url":"aws_api/sqs.html#Client"},{"doc":"aws_api/sqs","title":"add_permission","content":"pub fn add_permission(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sqs.add_permission\naws_api/sqs add_permission","url":"aws_api/sqs.html#add_permission"},{"doc":"aws_api/sqs","title":"cancel_message_move_task","content":"pub fn cancel_message_move_task(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sqs.cancel_message_move_task\naws_api/sqs cancel_message_move_task","url":"aws_api/sqs.html#cancel_message_move_task"},{"doc":"aws_api/sqs","title":"change_message_visibility","content":"pub fn change_message_visibility(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sqs.change_message_visibility\naws_api/sqs change_message_visibility","url":"aws_api/sqs.html#change_message_visibility"},{"doc":"aws_api/sqs","title":"change_message_visibility_batch","content":"pub fn change_message_visibility_batch(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sqs.change_message_visibility_batch\naws_api/sqs change_message_visibility_batch","url":"aws_api/sqs.html#change_message_visibility_batch"},{"doc":"aws_api/sqs","title":"create_queue","content":"pub fn create_queue(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sqs.create_queue\naws_api/sqs create_queue","url":"aws_api/sqs.html#create_queue"},{"doc":"aws_api/sqs","title":"delete_message","content":"pub fn delete_message(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sqs.delete_message\naws_api/sqs delete_message","url":"aws_api/sqs.html#delete_message"},{"doc":"aws_api/sqs","title":"delete_message_batch","content":"pub fn delete_message_batch(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sqs.delete_message_batch\naws_api/sqs delete_message_batch","url":"aws_api/sqs.html#delete_message_batch"},{"doc":"aws_api/sqs","title":"delete_queue","content":"pub fn delete_queue(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sqs.delete_queue\naws_api/sqs delete_queue","url":"aws_api/sqs.html#delete_queue"},{"doc":"aws_api/sqs","title":"get_queue_attributes","content":"pub fn get_queue_attributes(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sqs.get_queue_attributes\naws_api/sqs get_queue_attributes","url":"aws_api/sqs.html#get_queue_attributes"},{"doc":"aws_api/sqs","title":"get_queue_url","content":"pub fn get_queue_url(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sqs.get_queue_url\naws_api/sqs get_queue_url","url":"aws_api/sqs.html#get_queue_url"},{"doc":"aws_api/sqs","title":"list_dead_letter_source_queues","content":"pub fn list_dead_letter_source_queues(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sqs.list_dead_letter_source_queues\naws_api/sqs list_dead_letter_source_queues","url":"aws_api/sqs.html#list_dead_letter_source_queues"},{"doc":"aws_api/sqs","title":"list_message_move_tasks","content":"pub fn list_message_move_tasks(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sqs.list_message_move_tasks\naws_api/sqs list_message_move_tasks","url":"aws_api/sqs.html#list_message_move_tasks"},{"doc":"aws_api/sqs","title":"list_queue_tags","content":"pub fn list_queue_tags(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sqs.list_queue_tags\naws_api/sqs list_queue_tags","url":"aws_api/sqs.html#list_queue_tags"},{"doc":"aws_api/sqs","title":"list_queues","content":"pub fn list_queues(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sqs.list_queues\naws_api/sqs list_queues","url":"aws_api/sqs.html#list_queues"},{"doc":"aws_api/sqs","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/sqs.new\naws_api/sqs new","url":"aws_api/sqs.html#new"},{"doc":"aws_api/sqs","title":"purge_queue","content":"pub fn purge_queue(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sqs.purge_queue\naws_api/sqs purge_queue","url":"aws_api/sqs.html#purge_queue"},{"doc":"aws_api/sqs","title":"receive_message","content":"pub fn receive_message(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sqs.receive_message\naws_api/sqs receive_message","url":"aws_api/sqs.html#receive_message"},{"doc":"aws_api/sqs","title":"remove_permission","content":"pub fn remove_permission(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sqs.remove_permission\naws_api/sqs remove_permission","url":"aws_api/sqs.html#remove_permission"},{"doc":"aws_api/sqs","title":"send_message","content":"pub fn send_message(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sqs.send_message\naws_api/sqs send_message","url":"aws_api/sqs.html#send_message"},{"doc":"aws_api/sqs","title":"send_message_batch","content":"pub fn send_message_batch(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sqs.send_message_batch\naws_api/sqs send_message_batch","url":"aws_api/sqs.html#send_message_batch"},{"doc":"aws_api/sqs","title":"set_queue_attributes","content":"pub fn set_queue_attributes(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sqs.set_queue_attributes\naws_api/sqs set_queue_attributes","url":"aws_api/sqs.html#set_queue_attributes"},{"doc":"aws_api/sqs","title":"start_message_move_task","content":"pub fn start_message_move_task(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sqs.start_message_move_task\naws_api/sqs start_message_move_task","url":"aws_api/sqs.html#start_message_move_task"},{"doc":"aws_api/sqs","title":"tag_queue","content":"pub fn tag_queue(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sqs.tag_queue\naws_api/sqs tag_queue","url":"aws_api/sqs.html#tag_queue"},{"doc":"aws_api/sqs","title":"untag_queue","content":"pub fn untag_queue(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sqs.untag_queue\naws_api/sqs untag_queue","url":"aws_api/sqs.html#untag_queue"},{"doc":"aws_api/sqs","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/sqs.with_custom_endpoint\naws_api/sqs with_custom_endpoint","url":"aws_api/sqs.html#with_custom_endpoint"},{"doc":"aws_api/sqs","title":"aws_api/sqs","content":"","url":"aws_api/sqs.html"},{"doc":"aws_api/ssm","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/ssm.Client\naws_api/ssm Client","url":"aws_api/ssm.html#Client"},{"doc":"aws_api/ssm","title":"add_tags_to_resource","content":"pub fn add_tags_to_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.add_tags_to_resource\naws_api/ssm add_tags_to_resource","url":"aws_api/ssm.html#add_tags_to_resource"},{"doc":"aws_api/ssm","title":"associate_ops_item_related_item","content":"pub fn associate_ops_item_related_item(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.associate_ops_item_related_item\naws_api/ssm associate_ops_item_related_item","url":"aws_api/ssm.html#associate_ops_item_related_item"},{"doc":"aws_api/ssm","title":"cancel_command","content":"pub fn cancel_command(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.cancel_command\naws_api/ssm cancel_command","url":"aws_api/ssm.html#cancel_command"},{"doc":"aws_api/ssm","title":"cancel_maintenance_window_execution","content":"pub fn cancel_maintenance_window_execution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.cancel_maintenance_window_execution\naws_api/ssm cancel_maintenance_window_execution","url":"aws_api/ssm.html#cancel_maintenance_window_execution"},{"doc":"aws_api/ssm","title":"create_activation","content":"pub fn create_activation(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.create_activation\naws_api/ssm create_activation","url":"aws_api/ssm.html#create_activation"},{"doc":"aws_api/ssm","title":"create_association","content":"pub fn create_association(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.create_association\naws_api/ssm create_association","url":"aws_api/ssm.html#create_association"},{"doc":"aws_api/ssm","title":"create_association_batch","content":"pub fn create_association_batch(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.create_association_batch\naws_api/ssm create_association_batch","url":"aws_api/ssm.html#create_association_batch"},{"doc":"aws_api/ssm","title":"create_document","content":"pub fn create_document(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.create_document\naws_api/ssm create_document","url":"aws_api/ssm.html#create_document"},{"doc":"aws_api/ssm","title":"create_maintenance_window","content":"pub fn create_maintenance_window(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.create_maintenance_window\naws_api/ssm create_maintenance_window","url":"aws_api/ssm.html#create_maintenance_window"},{"doc":"aws_api/ssm","title":"create_ops_item","content":"pub fn create_ops_item(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.create_ops_item\naws_api/ssm create_ops_item","url":"aws_api/ssm.html#create_ops_item"},{"doc":"aws_api/ssm","title":"create_ops_metadata","content":"pub fn create_ops_metadata(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.create_ops_metadata\naws_api/ssm create_ops_metadata","url":"aws_api/ssm.html#create_ops_metadata"},{"doc":"aws_api/ssm","title":"create_patch_baseline","content":"pub fn create_patch_baseline(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.create_patch_baseline\naws_api/ssm create_patch_baseline","url":"aws_api/ssm.html#create_patch_baseline"},{"doc":"aws_api/ssm","title":"create_resource_data_sync","content":"pub fn create_resource_data_sync(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.create_resource_data_sync\naws_api/ssm create_resource_data_sync","url":"aws_api/ssm.html#create_resource_data_sync"},{"doc":"aws_api/ssm","title":"delete_activation","content":"pub fn delete_activation(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.delete_activation\naws_api/ssm delete_activation","url":"aws_api/ssm.html#delete_activation"},{"doc":"aws_api/ssm","title":"delete_association","content":"pub fn delete_association(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.delete_association\naws_api/ssm delete_association","url":"aws_api/ssm.html#delete_association"},{"doc":"aws_api/ssm","title":"delete_document","content":"pub fn delete_document(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.delete_document\naws_api/ssm delete_document","url":"aws_api/ssm.html#delete_document"},{"doc":"aws_api/ssm","title":"delete_inventory","content":"pub fn delete_inventory(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.delete_inventory\naws_api/ssm delete_inventory","url":"aws_api/ssm.html#delete_inventory"},{"doc":"aws_api/ssm","title":"delete_maintenance_window","content":"pub fn delete_maintenance_window(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.delete_maintenance_window\naws_api/ssm delete_maintenance_window","url":"aws_api/ssm.html#delete_maintenance_window"},{"doc":"aws_api/ssm","title":"delete_ops_item","content":"pub fn delete_ops_item(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.delete_ops_item\naws_api/ssm delete_ops_item","url":"aws_api/ssm.html#delete_ops_item"},{"doc":"aws_api/ssm","title":"delete_ops_metadata","content":"pub fn delete_ops_metadata(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.delete_ops_metadata\naws_api/ssm delete_ops_metadata","url":"aws_api/ssm.html#delete_ops_metadata"},{"doc":"aws_api/ssm","title":"delete_parameter","content":"pub fn delete_parameter(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.delete_parameter\naws_api/ssm delete_parameter","url":"aws_api/ssm.html#delete_parameter"},{"doc":"aws_api/ssm","title":"delete_parameters","content":"pub fn delete_parameters(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.delete_parameters\naws_api/ssm delete_parameters","url":"aws_api/ssm.html#delete_parameters"},{"doc":"aws_api/ssm","title":"delete_patch_baseline","content":"pub fn delete_patch_baseline(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.delete_patch_baseline\naws_api/ssm delete_patch_baseline","url":"aws_api/ssm.html#delete_patch_baseline"},{"doc":"aws_api/ssm","title":"delete_resource_data_sync","content":"pub fn delete_resource_data_sync(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.delete_resource_data_sync\naws_api/ssm delete_resource_data_sync","url":"aws_api/ssm.html#delete_resource_data_sync"},{"doc":"aws_api/ssm","title":"delete_resource_policy","content":"pub fn delete_resource_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.delete_resource_policy\naws_api/ssm delete_resource_policy","url":"aws_api/ssm.html#delete_resource_policy"},{"doc":"aws_api/ssm","title":"deregister_managed_instance","content":"pub fn deregister_managed_instance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.deregister_managed_instance\naws_api/ssm deregister_managed_instance","url":"aws_api/ssm.html#deregister_managed_instance"},{"doc":"aws_api/ssm","title":"deregister_patch_baseline_for_patch_group","content":"pub fn deregister_patch_baseline_for_patch_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.deregister_patch_baseline_for_patch_group\naws_api/ssm deregister_patch_baseline_for_patch_group","url":"aws_api/ssm.html#deregister_patch_baseline_for_patch_group"},{"doc":"aws_api/ssm","title":"deregister_target_from_maintenance_window","content":"pub fn deregister_target_from_maintenance_window(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.deregister_target_from_maintenance_window\naws_api/ssm deregister_target_from_maintenance_window","url":"aws_api/ssm.html#deregister_target_from_maintenance_window"},{"doc":"aws_api/ssm","title":"deregister_task_from_maintenance_window","content":"pub fn deregister_task_from_maintenance_window(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.deregister_task_from_maintenance_window\naws_api/ssm deregister_task_from_maintenance_window","url":"aws_api/ssm.html#deregister_task_from_maintenance_window"},{"doc":"aws_api/ssm","title":"describe_activations","content":"pub fn describe_activations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.describe_activations\naws_api/ssm describe_activations","url":"aws_api/ssm.html#describe_activations"},{"doc":"aws_api/ssm","title":"describe_association","content":"pub fn describe_association(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.describe_association\naws_api/ssm describe_association","url":"aws_api/ssm.html#describe_association"},{"doc":"aws_api/ssm","title":"describe_association_execution_targets","content":"pub fn describe_association_execution_targets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.describe_association_execution_targets\naws_api/ssm describe_association_execution_targets","url":"aws_api/ssm.html#describe_association_execution_targets"},{"doc":"aws_api/ssm","title":"describe_association_executions","content":"pub fn describe_association_executions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.describe_association_executions\naws_api/ssm describe_association_executions","url":"aws_api/ssm.html#describe_association_executions"},{"doc":"aws_api/ssm","title":"describe_automation_executions","content":"pub fn describe_automation_executions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.describe_automation_executions\naws_api/ssm describe_automation_executions","url":"aws_api/ssm.html#describe_automation_executions"},{"doc":"aws_api/ssm","title":"describe_automation_step_executions","content":"pub fn describe_automation_step_executions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.describe_automation_step_executions\naws_api/ssm describe_automation_step_executions","url":"aws_api/ssm.html#describe_automation_step_executions"},{"doc":"aws_api/ssm","title":"describe_available_patches","content":"pub fn describe_available_patches(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.describe_available_patches\naws_api/ssm describe_available_patches","url":"aws_api/ssm.html#describe_available_patches"},{"doc":"aws_api/ssm","title":"describe_document","content":"pub fn describe_document(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.describe_document\naws_api/ssm describe_document","url":"aws_api/ssm.html#describe_document"},{"doc":"aws_api/ssm","title":"describe_document_permission","content":"pub fn describe_document_permission(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.describe_document_permission\naws_api/ssm describe_document_permission","url":"aws_api/ssm.html#describe_document_permission"},{"doc":"aws_api/ssm","title":"describe_effective_instance_associations","content":"pub fn describe_effective_instance_associations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.describe_effective_instance_associations\naws_api/ssm describe_effective_instance_associations","url":"aws_api/ssm.html#describe_effective_instance_associations"},{"doc":"aws_api/ssm","title":"describe_effective_patches_for_patch_baseline","content":"pub fn describe_effective_patches_for_patch_baseline(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.describe_effective_patches_for_patch_baseline\naws_api/ssm describe_effective_patches_for_patch_baseline","url":"aws_api/ssm.html#describe_effective_patches_for_patch_baseline"},{"doc":"aws_api/ssm","title":"describe_instance_associations_status","content":"pub fn describe_instance_associations_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.describe_instance_associations_status\naws_api/ssm describe_instance_associations_status","url":"aws_api/ssm.html#describe_instance_associations_status"},{"doc":"aws_api/ssm","title":"describe_instance_information","content":"pub fn describe_instance_information(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.describe_instance_information\naws_api/ssm describe_instance_information","url":"aws_api/ssm.html#describe_instance_information"},{"doc":"aws_api/ssm","title":"describe_instance_patch_states","content":"pub fn describe_instance_patch_states(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.describe_instance_patch_states\naws_api/ssm describe_instance_patch_states","url":"aws_api/ssm.html#describe_instance_patch_states"},{"doc":"aws_api/ssm","title":"describe_instance_patch_states_for_patch_group","content":"pub fn describe_instance_patch_states_for_patch_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.describe_instance_patch_states_for_patch_group\naws_api/ssm describe_instance_patch_states_for_patch_group","url":"aws_api/ssm.html#describe_instance_patch_states_for_patch_group"},{"doc":"aws_api/ssm","title":"describe_instance_patches","content":"pub fn describe_instance_patches(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.describe_instance_patches\naws_api/ssm describe_instance_patches","url":"aws_api/ssm.html#describe_instance_patches"},{"doc":"aws_api/ssm","title":"describe_instance_properties","content":"pub fn describe_instance_properties(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.describe_instance_properties\naws_api/ssm describe_instance_properties","url":"aws_api/ssm.html#describe_instance_properties"},{"doc":"aws_api/ssm","title":"describe_inventory_deletions","content":"pub fn describe_inventory_deletions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.describe_inventory_deletions\naws_api/ssm describe_inventory_deletions","url":"aws_api/ssm.html#describe_inventory_deletions"},{"doc":"aws_api/ssm","title":"describe_maintenance_window_execution_task_invocations","content":"pub fn describe_maintenance_window_execution_task_invocations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.describe_maintenance_window_execution_task_invocations\naws_api/ssm describe_maintenance_window_execution_task_invocations","url":"aws_api/ssm.html#describe_maintenance_window_execution_task_invocations"},{"doc":"aws_api/ssm","title":"describe_maintenance_window_execution_tasks","content":"pub fn describe_maintenance_window_execution_tasks(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.describe_maintenance_window_execution_tasks\naws_api/ssm describe_maintenance_window_execution_tasks","url":"aws_api/ssm.html#describe_maintenance_window_execution_tasks"},{"doc":"aws_api/ssm","title":"describe_maintenance_window_executions","content":"pub fn describe_maintenance_window_executions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.describe_maintenance_window_executions\naws_api/ssm describe_maintenance_window_executions","url":"aws_api/ssm.html#describe_maintenance_window_executions"},{"doc":"aws_api/ssm","title":"describe_maintenance_window_schedule","content":"pub fn describe_maintenance_window_schedule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.describe_maintenance_window_schedule\naws_api/ssm describe_maintenance_window_schedule","url":"aws_api/ssm.html#describe_maintenance_window_schedule"},{"doc":"aws_api/ssm","title":"describe_maintenance_window_targets","content":"pub fn describe_maintenance_window_targets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.describe_maintenance_window_targets\naws_api/ssm describe_maintenance_window_targets","url":"aws_api/ssm.html#describe_maintenance_window_targets"},{"doc":"aws_api/ssm","title":"describe_maintenance_window_tasks","content":"pub fn describe_maintenance_window_tasks(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.describe_maintenance_window_tasks\naws_api/ssm describe_maintenance_window_tasks","url":"aws_api/ssm.html#describe_maintenance_window_tasks"},{"doc":"aws_api/ssm","title":"describe_maintenance_windows","content":"pub fn describe_maintenance_windows(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.describe_maintenance_windows\naws_api/ssm describe_maintenance_windows","url":"aws_api/ssm.html#describe_maintenance_windows"},{"doc":"aws_api/ssm","title":"describe_maintenance_windows_for_target","content":"pub fn describe_maintenance_windows_for_target(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.describe_maintenance_windows_for_target\naws_api/ssm describe_maintenance_windows_for_target","url":"aws_api/ssm.html#describe_maintenance_windows_for_target"},{"doc":"aws_api/ssm","title":"describe_ops_items","content":"pub fn describe_ops_items(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.describe_ops_items\naws_api/ssm describe_ops_items","url":"aws_api/ssm.html#describe_ops_items"},{"doc":"aws_api/ssm","title":"describe_parameters","content":"pub fn describe_parameters(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.describe_parameters\naws_api/ssm describe_parameters","url":"aws_api/ssm.html#describe_parameters"},{"doc":"aws_api/ssm","title":"describe_patch_baselines","content":"pub fn describe_patch_baselines(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.describe_patch_baselines\naws_api/ssm describe_patch_baselines","url":"aws_api/ssm.html#describe_patch_baselines"},{"doc":"aws_api/ssm","title":"describe_patch_group_state","content":"pub fn describe_patch_group_state(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.describe_patch_group_state\naws_api/ssm describe_patch_group_state","url":"aws_api/ssm.html#describe_patch_group_state"},{"doc":"aws_api/ssm","title":"describe_patch_groups","content":"pub fn describe_patch_groups(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.describe_patch_groups\naws_api/ssm describe_patch_groups","url":"aws_api/ssm.html#describe_patch_groups"},{"doc":"aws_api/ssm","title":"describe_patch_properties","content":"pub fn describe_patch_properties(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.describe_patch_properties\naws_api/ssm describe_patch_properties","url":"aws_api/ssm.html#describe_patch_properties"},{"doc":"aws_api/ssm","title":"describe_sessions","content":"pub fn describe_sessions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.describe_sessions\naws_api/ssm describe_sessions","url":"aws_api/ssm.html#describe_sessions"},{"doc":"aws_api/ssm","title":"disassociate_ops_item_related_item","content":"pub fn disassociate_ops_item_related_item(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.disassociate_ops_item_related_item\naws_api/ssm disassociate_ops_item_related_item","url":"aws_api/ssm.html#disassociate_ops_item_related_item"},{"doc":"aws_api/ssm","title":"get_automation_execution","content":"pub fn get_automation_execution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.get_automation_execution\naws_api/ssm get_automation_execution","url":"aws_api/ssm.html#get_automation_execution"},{"doc":"aws_api/ssm","title":"get_calendar_state","content":"pub fn get_calendar_state(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.get_calendar_state\naws_api/ssm get_calendar_state","url":"aws_api/ssm.html#get_calendar_state"},{"doc":"aws_api/ssm","title":"get_command_invocation","content":"pub fn get_command_invocation(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.get_command_invocation\naws_api/ssm get_command_invocation","url":"aws_api/ssm.html#get_command_invocation"},{"doc":"aws_api/ssm","title":"get_connection_status","content":"pub fn get_connection_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.get_connection_status\naws_api/ssm get_connection_status","url":"aws_api/ssm.html#get_connection_status"},{"doc":"aws_api/ssm","title":"get_default_patch_baseline","content":"pub fn get_default_patch_baseline(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.get_default_patch_baseline\naws_api/ssm get_default_patch_baseline","url":"aws_api/ssm.html#get_default_patch_baseline"},{"doc":"aws_api/ssm","title":"get_deployable_patch_snapshot_for_instance","content":"pub fn get_deployable_patch_snapshot_for_instance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.get_deployable_patch_snapshot_for_instance\naws_api/ssm get_deployable_patch_snapshot_for_instance","url":"aws_api/ssm.html#get_deployable_patch_snapshot_for_instance"},{"doc":"aws_api/ssm","title":"get_document","content":"pub fn get_document(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.get_document\naws_api/ssm get_document","url":"aws_api/ssm.html#get_document"},{"doc":"aws_api/ssm","title":"get_inventory","content":"pub fn get_inventory(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.get_inventory\naws_api/ssm get_inventory","url":"aws_api/ssm.html#get_inventory"},{"doc":"aws_api/ssm","title":"get_inventory_schema","content":"pub fn get_inventory_schema(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.get_inventory_schema\naws_api/ssm get_inventory_schema","url":"aws_api/ssm.html#get_inventory_schema"},{"doc":"aws_api/ssm","title":"get_maintenance_window","content":"pub fn get_maintenance_window(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.get_maintenance_window\naws_api/ssm get_maintenance_window","url":"aws_api/ssm.html#get_maintenance_window"},{"doc":"aws_api/ssm","title":"get_maintenance_window_execution","content":"pub fn get_maintenance_window_execution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.get_maintenance_window_execution\naws_api/ssm get_maintenance_window_execution","url":"aws_api/ssm.html#get_maintenance_window_execution"},{"doc":"aws_api/ssm","title":"get_maintenance_window_execution_task","content":"pub fn get_maintenance_window_execution_task(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.get_maintenance_window_execution_task\naws_api/ssm get_maintenance_window_execution_task","url":"aws_api/ssm.html#get_maintenance_window_execution_task"},{"doc":"aws_api/ssm","title":"get_maintenance_window_execution_task_invocation","content":"pub fn get_maintenance_window_execution_task_invocation(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.get_maintenance_window_execution_task_invocation\naws_api/ssm get_maintenance_window_execution_task_invocation","url":"aws_api/ssm.html#get_maintenance_window_execution_task_invocation"},{"doc":"aws_api/ssm","title":"get_maintenance_window_task","content":"pub fn get_maintenance_window_task(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.get_maintenance_window_task\naws_api/ssm get_maintenance_window_task","url":"aws_api/ssm.html#get_maintenance_window_task"},{"doc":"aws_api/ssm","title":"get_ops_item","content":"pub fn get_ops_item(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.get_ops_item\naws_api/ssm get_ops_item","url":"aws_api/ssm.html#get_ops_item"},{"doc":"aws_api/ssm","title":"get_ops_metadata","content":"pub fn get_ops_metadata(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.get_ops_metadata\naws_api/ssm get_ops_metadata","url":"aws_api/ssm.html#get_ops_metadata"},{"doc":"aws_api/ssm","title":"get_ops_summary","content":"pub fn get_ops_summary(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.get_ops_summary\naws_api/ssm get_ops_summary","url":"aws_api/ssm.html#get_ops_summary"},{"doc":"aws_api/ssm","title":"get_parameter","content":"pub fn get_parameter(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.get_parameter\naws_api/ssm get_parameter","url":"aws_api/ssm.html#get_parameter"},{"doc":"aws_api/ssm","title":"get_parameter_history","content":"pub fn get_parameter_history(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.get_parameter_history\naws_api/ssm get_parameter_history","url":"aws_api/ssm.html#get_parameter_history"},{"doc":"aws_api/ssm","title":"get_parameters","content":"pub fn get_parameters(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.get_parameters\naws_api/ssm get_parameters","url":"aws_api/ssm.html#get_parameters"},{"doc":"aws_api/ssm","title":"get_parameters_by_path","content":"pub fn get_parameters_by_path(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.get_parameters_by_path\naws_api/ssm get_parameters_by_path","url":"aws_api/ssm.html#get_parameters_by_path"},{"doc":"aws_api/ssm","title":"get_patch_baseline","content":"pub fn get_patch_baseline(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.get_patch_baseline\naws_api/ssm get_patch_baseline","url":"aws_api/ssm.html#get_patch_baseline"},{"doc":"aws_api/ssm","title":"get_patch_baseline_for_patch_group","content":"pub fn get_patch_baseline_for_patch_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.get_patch_baseline_for_patch_group\naws_api/ssm get_patch_baseline_for_patch_group","url":"aws_api/ssm.html#get_patch_baseline_for_patch_group"},{"doc":"aws_api/ssm","title":"get_resource_policies","content":"pub fn get_resource_policies(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.get_resource_policies\naws_api/ssm get_resource_policies","url":"aws_api/ssm.html#get_resource_policies"},{"doc":"aws_api/ssm","title":"get_service_setting","content":"pub fn get_service_setting(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.get_service_setting\naws_api/ssm get_service_setting","url":"aws_api/ssm.html#get_service_setting"},{"doc":"aws_api/ssm","title":"label_parameter_version","content":"pub fn label_parameter_version(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.label_parameter_version\naws_api/ssm label_parameter_version","url":"aws_api/ssm.html#label_parameter_version"},{"doc":"aws_api/ssm","title":"list_association_versions","content":"pub fn list_association_versions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.list_association_versions\naws_api/ssm list_association_versions","url":"aws_api/ssm.html#list_association_versions"},{"doc":"aws_api/ssm","title":"list_associations","content":"pub fn list_associations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.list_associations\naws_api/ssm list_associations","url":"aws_api/ssm.html#list_associations"},{"doc":"aws_api/ssm","title":"list_command_invocations","content":"pub fn list_command_invocations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.list_command_invocations\naws_api/ssm list_command_invocations","url":"aws_api/ssm.html#list_command_invocations"},{"doc":"aws_api/ssm","title":"list_commands","content":"pub fn list_commands(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.list_commands\naws_api/ssm list_commands","url":"aws_api/ssm.html#list_commands"},{"doc":"aws_api/ssm","title":"list_compliance_items","content":"pub fn list_compliance_items(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.list_compliance_items\naws_api/ssm list_compliance_items","url":"aws_api/ssm.html#list_compliance_items"},{"doc":"aws_api/ssm","title":"list_compliance_summaries","content":"pub fn list_compliance_summaries(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.list_compliance_summaries\naws_api/ssm list_compliance_summaries","url":"aws_api/ssm.html#list_compliance_summaries"},{"doc":"aws_api/ssm","title":"list_document_metadata_history","content":"pub fn list_document_metadata_history(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.list_document_metadata_history\naws_api/ssm list_document_metadata_history","url":"aws_api/ssm.html#list_document_metadata_history"},{"doc":"aws_api/ssm","title":"list_document_versions","content":"pub fn list_document_versions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.list_document_versions\naws_api/ssm list_document_versions","url":"aws_api/ssm.html#list_document_versions"},{"doc":"aws_api/ssm","title":"list_documents","content":"pub fn list_documents(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.list_documents\naws_api/ssm list_documents","url":"aws_api/ssm.html#list_documents"},{"doc":"aws_api/ssm","title":"list_inventory_entries","content":"pub fn list_inventory_entries(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.list_inventory_entries\naws_api/ssm list_inventory_entries","url":"aws_api/ssm.html#list_inventory_entries"},{"doc":"aws_api/ssm","title":"list_ops_item_events","content":"pub fn list_ops_item_events(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.list_ops_item_events\naws_api/ssm list_ops_item_events","url":"aws_api/ssm.html#list_ops_item_events"},{"doc":"aws_api/ssm","title":"list_ops_item_related_items","content":"pub fn list_ops_item_related_items(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.list_ops_item_related_items\naws_api/ssm list_ops_item_related_items","url":"aws_api/ssm.html#list_ops_item_related_items"},{"doc":"aws_api/ssm","title":"list_ops_metadata","content":"pub fn list_ops_metadata(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.list_ops_metadata\naws_api/ssm list_ops_metadata","url":"aws_api/ssm.html#list_ops_metadata"},{"doc":"aws_api/ssm","title":"list_resource_compliance_summaries","content":"pub fn list_resource_compliance_summaries(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.list_resource_compliance_summaries\naws_api/ssm list_resource_compliance_summaries","url":"aws_api/ssm.html#list_resource_compliance_summaries"},{"doc":"aws_api/ssm","title":"list_resource_data_sync","content":"pub fn list_resource_data_sync(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.list_resource_data_sync\naws_api/ssm list_resource_data_sync","url":"aws_api/ssm.html#list_resource_data_sync"},{"doc":"aws_api/ssm","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.list_tags_for_resource\naws_api/ssm list_tags_for_resource","url":"aws_api/ssm.html#list_tags_for_resource"},{"doc":"aws_api/ssm","title":"modify_document_permission","content":"pub fn modify_document_permission(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.modify_document_permission\naws_api/ssm modify_document_permission","url":"aws_api/ssm.html#modify_document_permission"},{"doc":"aws_api/ssm","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/ssm.new\naws_api/ssm new","url":"aws_api/ssm.html#new"},{"doc":"aws_api/ssm","title":"put_compliance_items","content":"pub fn put_compliance_items(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.put_compliance_items\naws_api/ssm put_compliance_items","url":"aws_api/ssm.html#put_compliance_items"},{"doc":"aws_api/ssm","title":"put_inventory","content":"pub fn put_inventory(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.put_inventory\naws_api/ssm put_inventory","url":"aws_api/ssm.html#put_inventory"},{"doc":"aws_api/ssm","title":"put_parameter","content":"pub fn put_parameter(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.put_parameter\naws_api/ssm put_parameter","url":"aws_api/ssm.html#put_parameter"},{"doc":"aws_api/ssm","title":"put_resource_policy","content":"pub fn put_resource_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.put_resource_policy\naws_api/ssm put_resource_policy","url":"aws_api/ssm.html#put_resource_policy"},{"doc":"aws_api/ssm","title":"register_default_patch_baseline","content":"pub fn register_default_patch_baseline(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.register_default_patch_baseline\naws_api/ssm register_default_patch_baseline","url":"aws_api/ssm.html#register_default_patch_baseline"},{"doc":"aws_api/ssm","title":"register_patch_baseline_for_patch_group","content":"pub fn register_patch_baseline_for_patch_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.register_patch_baseline_for_patch_group\naws_api/ssm register_patch_baseline_for_patch_group","url":"aws_api/ssm.html#register_patch_baseline_for_patch_group"},{"doc":"aws_api/ssm","title":"register_target_with_maintenance_window","content":"pub fn register_target_with_maintenance_window(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.register_target_with_maintenance_window\naws_api/ssm register_target_with_maintenance_window","url":"aws_api/ssm.html#register_target_with_maintenance_window"},{"doc":"aws_api/ssm","title":"register_task_with_maintenance_window","content":"pub fn register_task_with_maintenance_window(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.register_task_with_maintenance_window\naws_api/ssm register_task_with_maintenance_window","url":"aws_api/ssm.html#register_task_with_maintenance_window"},{"doc":"aws_api/ssm","title":"remove_tags_from_resource","content":"pub fn remove_tags_from_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.remove_tags_from_resource\naws_api/ssm remove_tags_from_resource","url":"aws_api/ssm.html#remove_tags_from_resource"},{"doc":"aws_api/ssm","title":"reset_service_setting","content":"pub fn reset_service_setting(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.reset_service_setting\naws_api/ssm reset_service_setting","url":"aws_api/ssm.html#reset_service_setting"},{"doc":"aws_api/ssm","title":"resume_session","content":"pub fn resume_session(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.resume_session\naws_api/ssm resume_session","url":"aws_api/ssm.html#resume_session"},{"doc":"aws_api/ssm","title":"send_automation_signal","content":"pub fn send_automation_signal(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.send_automation_signal\naws_api/ssm send_automation_signal","url":"aws_api/ssm.html#send_automation_signal"},{"doc":"aws_api/ssm","title":"send_command","content":"pub fn send_command(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.send_command\naws_api/ssm send_command","url":"aws_api/ssm.html#send_command"},{"doc":"aws_api/ssm","title":"start_associations_once","content":"pub fn start_associations_once(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.start_associations_once\naws_api/ssm start_associations_once","url":"aws_api/ssm.html#start_associations_once"},{"doc":"aws_api/ssm","title":"start_automation_execution","content":"pub fn start_automation_execution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.start_automation_execution\naws_api/ssm start_automation_execution","url":"aws_api/ssm.html#start_automation_execution"},{"doc":"aws_api/ssm","title":"start_change_request_execution","content":"pub fn start_change_request_execution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.start_change_request_execution\naws_api/ssm start_change_request_execution","url":"aws_api/ssm.html#start_change_request_execution"},{"doc":"aws_api/ssm","title":"start_session","content":"pub fn start_session(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.start_session\naws_api/ssm start_session","url":"aws_api/ssm.html#start_session"},{"doc":"aws_api/ssm","title":"stop_automation_execution","content":"pub fn stop_automation_execution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.stop_automation_execution\naws_api/ssm stop_automation_execution","url":"aws_api/ssm.html#stop_automation_execution"},{"doc":"aws_api/ssm","title":"terminate_session","content":"pub fn terminate_session(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.terminate_session\naws_api/ssm terminate_session","url":"aws_api/ssm.html#terminate_session"},{"doc":"aws_api/ssm","title":"unlabel_parameter_version","content":"pub fn unlabel_parameter_version(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.unlabel_parameter_version\naws_api/ssm unlabel_parameter_version","url":"aws_api/ssm.html#unlabel_parameter_version"},{"doc":"aws_api/ssm","title":"update_association","content":"pub fn update_association(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.update_association\naws_api/ssm update_association","url":"aws_api/ssm.html#update_association"},{"doc":"aws_api/ssm","title":"update_association_status","content":"pub fn update_association_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.update_association_status\naws_api/ssm update_association_status","url":"aws_api/ssm.html#update_association_status"},{"doc":"aws_api/ssm","title":"update_document","content":"pub fn update_document(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.update_document\naws_api/ssm update_document","url":"aws_api/ssm.html#update_document"},{"doc":"aws_api/ssm","title":"update_document_default_version","content":"pub fn update_document_default_version(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.update_document_default_version\naws_api/ssm update_document_default_version","url":"aws_api/ssm.html#update_document_default_version"},{"doc":"aws_api/ssm","title":"update_document_metadata","content":"pub fn update_document_metadata(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.update_document_metadata\naws_api/ssm update_document_metadata","url":"aws_api/ssm.html#update_document_metadata"},{"doc":"aws_api/ssm","title":"update_maintenance_window","content":"pub fn update_maintenance_window(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.update_maintenance_window\naws_api/ssm update_maintenance_window","url":"aws_api/ssm.html#update_maintenance_window"},{"doc":"aws_api/ssm","title":"update_maintenance_window_target","content":"pub fn update_maintenance_window_target(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.update_maintenance_window_target\naws_api/ssm update_maintenance_window_target","url":"aws_api/ssm.html#update_maintenance_window_target"},{"doc":"aws_api/ssm","title":"update_maintenance_window_task","content":"pub fn update_maintenance_window_task(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.update_maintenance_window_task\naws_api/ssm update_maintenance_window_task","url":"aws_api/ssm.html#update_maintenance_window_task"},{"doc":"aws_api/ssm","title":"update_managed_instance_role","content":"pub fn update_managed_instance_role(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.update_managed_instance_role\naws_api/ssm update_managed_instance_role","url":"aws_api/ssm.html#update_managed_instance_role"},{"doc":"aws_api/ssm","title":"update_ops_item","content":"pub fn update_ops_item(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.update_ops_item\naws_api/ssm update_ops_item","url":"aws_api/ssm.html#update_ops_item"},{"doc":"aws_api/ssm","title":"update_ops_metadata","content":"pub fn update_ops_metadata(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.update_ops_metadata\naws_api/ssm update_ops_metadata","url":"aws_api/ssm.html#update_ops_metadata"},{"doc":"aws_api/ssm","title":"update_patch_baseline","content":"pub fn update_patch_baseline(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.update_patch_baseline\naws_api/ssm update_patch_baseline","url":"aws_api/ssm.html#update_patch_baseline"},{"doc":"aws_api/ssm","title":"update_resource_data_sync","content":"pub fn update_resource_data_sync(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.update_resource_data_sync\naws_api/ssm update_resource_data_sync","url":"aws_api/ssm.html#update_resource_data_sync"},{"doc":"aws_api/ssm","title":"update_service_setting","content":"pub fn update_service_setting(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm.update_service_setting\naws_api/ssm update_service_setting","url":"aws_api/ssm.html#update_service_setting"},{"doc":"aws_api/ssm","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/ssm.with_custom_endpoint\naws_api/ssm with_custom_endpoint","url":"aws_api/ssm.html#with_custom_endpoint"},{"doc":"aws_api/ssm","title":"aws_api/ssm","content":"","url":"aws_api/ssm.html"},{"doc":"aws_api/ssm_contacts","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/ssm_contacts.Client\naws_api/ssm_contacts Client","url":"aws_api/ssm_contacts.html#Client"},{"doc":"aws_api/ssm_contacts","title":"accept_page","content":"pub fn accept_page(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_contacts.accept_page\naws_api/ssm_contacts accept_page","url":"aws_api/ssm_contacts.html#accept_page"},{"doc":"aws_api/ssm_contacts","title":"activate_contact_channel","content":"pub fn activate_contact_channel(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_contacts.activate_contact_channel\naws_api/ssm_contacts activate_contact_channel","url":"aws_api/ssm_contacts.html#activate_contact_channel"},{"doc":"aws_api/ssm_contacts","title":"create_contact","content":"pub fn create_contact(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_contacts.create_contact\naws_api/ssm_contacts create_contact","url":"aws_api/ssm_contacts.html#create_contact"},{"doc":"aws_api/ssm_contacts","title":"create_contact_channel","content":"pub fn create_contact_channel(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_contacts.create_contact_channel\naws_api/ssm_contacts create_contact_channel","url":"aws_api/ssm_contacts.html#create_contact_channel"},{"doc":"aws_api/ssm_contacts","title":"create_rotation","content":"pub fn create_rotation(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_contacts.create_rotation\naws_api/ssm_contacts create_rotation","url":"aws_api/ssm_contacts.html#create_rotation"},{"doc":"aws_api/ssm_contacts","title":"create_rotation_override","content":"pub fn create_rotation_override(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_contacts.create_rotation_override\naws_api/ssm_contacts create_rotation_override","url":"aws_api/ssm_contacts.html#create_rotation_override"},{"doc":"aws_api/ssm_contacts","title":"deactivate_contact_channel","content":"pub fn deactivate_contact_channel(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_contacts.deactivate_contact_channel\naws_api/ssm_contacts deactivate_contact_channel","url":"aws_api/ssm_contacts.html#deactivate_contact_channel"},{"doc":"aws_api/ssm_contacts","title":"delete_contact","content":"pub fn delete_contact(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_contacts.delete_contact\naws_api/ssm_contacts delete_contact","url":"aws_api/ssm_contacts.html#delete_contact"},{"doc":"aws_api/ssm_contacts","title":"delete_contact_channel","content":"pub fn delete_contact_channel(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_contacts.delete_contact_channel\naws_api/ssm_contacts delete_contact_channel","url":"aws_api/ssm_contacts.html#delete_contact_channel"},{"doc":"aws_api/ssm_contacts","title":"delete_rotation","content":"pub fn delete_rotation(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_contacts.delete_rotation\naws_api/ssm_contacts delete_rotation","url":"aws_api/ssm_contacts.html#delete_rotation"},{"doc":"aws_api/ssm_contacts","title":"delete_rotation_override","content":"pub fn delete_rotation_override(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_contacts.delete_rotation_override\naws_api/ssm_contacts delete_rotation_override","url":"aws_api/ssm_contacts.html#delete_rotation_override"},{"doc":"aws_api/ssm_contacts","title":"describe_engagement","content":"pub fn describe_engagement(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_contacts.describe_engagement\naws_api/ssm_contacts describe_engagement","url":"aws_api/ssm_contacts.html#describe_engagement"},{"doc":"aws_api/ssm_contacts","title":"describe_page","content":"pub fn describe_page(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_contacts.describe_page\naws_api/ssm_contacts describe_page","url":"aws_api/ssm_contacts.html#describe_page"},{"doc":"aws_api/ssm_contacts","title":"get_contact","content":"pub fn get_contact(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_contacts.get_contact\naws_api/ssm_contacts get_contact","url":"aws_api/ssm_contacts.html#get_contact"},{"doc":"aws_api/ssm_contacts","title":"get_contact_channel","content":"pub fn get_contact_channel(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_contacts.get_contact_channel\naws_api/ssm_contacts get_contact_channel","url":"aws_api/ssm_contacts.html#get_contact_channel"},{"doc":"aws_api/ssm_contacts","title":"get_contact_policy","content":"pub fn get_contact_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_contacts.get_contact_policy\naws_api/ssm_contacts get_contact_policy","url":"aws_api/ssm_contacts.html#get_contact_policy"},{"doc":"aws_api/ssm_contacts","title":"get_rotation","content":"pub fn get_rotation(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_contacts.get_rotation\naws_api/ssm_contacts get_rotation","url":"aws_api/ssm_contacts.html#get_rotation"},{"doc":"aws_api/ssm_contacts","title":"get_rotation_override","content":"pub fn get_rotation_override(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_contacts.get_rotation_override\naws_api/ssm_contacts get_rotation_override","url":"aws_api/ssm_contacts.html#get_rotation_override"},{"doc":"aws_api/ssm_contacts","title":"list_contact_channels","content":"pub fn list_contact_channels(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_contacts.list_contact_channels\naws_api/ssm_contacts list_contact_channels","url":"aws_api/ssm_contacts.html#list_contact_channels"},{"doc":"aws_api/ssm_contacts","title":"list_contacts","content":"pub fn list_contacts(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_contacts.list_contacts\naws_api/ssm_contacts list_contacts","url":"aws_api/ssm_contacts.html#list_contacts"},{"doc":"aws_api/ssm_contacts","title":"list_engagements","content":"pub fn list_engagements(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_contacts.list_engagements\naws_api/ssm_contacts list_engagements","url":"aws_api/ssm_contacts.html#list_engagements"},{"doc":"aws_api/ssm_contacts","title":"list_page_receipts","content":"pub fn list_page_receipts(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_contacts.list_page_receipts\naws_api/ssm_contacts list_page_receipts","url":"aws_api/ssm_contacts.html#list_page_receipts"},{"doc":"aws_api/ssm_contacts","title":"list_page_resolutions","content":"pub fn list_page_resolutions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_contacts.list_page_resolutions\naws_api/ssm_contacts list_page_resolutions","url":"aws_api/ssm_contacts.html#list_page_resolutions"},{"doc":"aws_api/ssm_contacts","title":"list_pages_by_contact","content":"pub fn list_pages_by_contact(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_contacts.list_pages_by_contact\naws_api/ssm_contacts list_pages_by_contact","url":"aws_api/ssm_contacts.html#list_pages_by_contact"},{"doc":"aws_api/ssm_contacts","title":"list_pages_by_engagement","content":"pub fn list_pages_by_engagement(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_contacts.list_pages_by_engagement\naws_api/ssm_contacts list_pages_by_engagement","url":"aws_api/ssm_contacts.html#list_pages_by_engagement"},{"doc":"aws_api/ssm_contacts","title":"list_preview_rotation_shifts","content":"pub fn list_preview_rotation_shifts(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_contacts.list_preview_rotation_shifts\naws_api/ssm_contacts list_preview_rotation_shifts","url":"aws_api/ssm_contacts.html#list_preview_rotation_shifts"},{"doc":"aws_api/ssm_contacts","title":"list_rotation_overrides","content":"pub fn list_rotation_overrides(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_contacts.list_rotation_overrides\naws_api/ssm_contacts list_rotation_overrides","url":"aws_api/ssm_contacts.html#list_rotation_overrides"},{"doc":"aws_api/ssm_contacts","title":"list_rotation_shifts","content":"pub fn list_rotation_shifts(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_contacts.list_rotation_shifts\naws_api/ssm_contacts list_rotation_shifts","url":"aws_api/ssm_contacts.html#list_rotation_shifts"},{"doc":"aws_api/ssm_contacts","title":"list_rotations","content":"pub fn list_rotations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_contacts.list_rotations\naws_api/ssm_contacts list_rotations","url":"aws_api/ssm_contacts.html#list_rotations"},{"doc":"aws_api/ssm_contacts","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_contacts.list_tags_for_resource\naws_api/ssm_contacts list_tags_for_resource","url":"aws_api/ssm_contacts.html#list_tags_for_resource"},{"doc":"aws_api/ssm_contacts","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/ssm_contacts.new\naws_api/ssm_contacts new","url":"aws_api/ssm_contacts.html#new"},{"doc":"aws_api/ssm_contacts","title":"put_contact_policy","content":"pub fn put_contact_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_contacts.put_contact_policy\naws_api/ssm_contacts put_contact_policy","url":"aws_api/ssm_contacts.html#put_contact_policy"},{"doc":"aws_api/ssm_contacts","title":"send_activation_code","content":"pub fn send_activation_code(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_contacts.send_activation_code\naws_api/ssm_contacts send_activation_code","url":"aws_api/ssm_contacts.html#send_activation_code"},{"doc":"aws_api/ssm_contacts","title":"start_engagement","content":"pub fn start_engagement(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_contacts.start_engagement\naws_api/ssm_contacts start_engagement","url":"aws_api/ssm_contacts.html#start_engagement"},{"doc":"aws_api/ssm_contacts","title":"stop_engagement","content":"pub fn stop_engagement(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_contacts.stop_engagement\naws_api/ssm_contacts stop_engagement","url":"aws_api/ssm_contacts.html#stop_engagement"},{"doc":"aws_api/ssm_contacts","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_contacts.tag_resource\naws_api/ssm_contacts tag_resource","url":"aws_api/ssm_contacts.html#tag_resource"},{"doc":"aws_api/ssm_contacts","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_contacts.untag_resource\naws_api/ssm_contacts untag_resource","url":"aws_api/ssm_contacts.html#untag_resource"},{"doc":"aws_api/ssm_contacts","title":"update_contact","content":"pub fn update_contact(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_contacts.update_contact\naws_api/ssm_contacts update_contact","url":"aws_api/ssm_contacts.html#update_contact"},{"doc":"aws_api/ssm_contacts","title":"update_contact_channel","content":"pub fn update_contact_channel(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_contacts.update_contact_channel\naws_api/ssm_contacts update_contact_channel","url":"aws_api/ssm_contacts.html#update_contact_channel"},{"doc":"aws_api/ssm_contacts","title":"update_rotation","content":"pub fn update_rotation(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_contacts.update_rotation\naws_api/ssm_contacts update_rotation","url":"aws_api/ssm_contacts.html#update_rotation"},{"doc":"aws_api/ssm_contacts","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/ssm_contacts.with_custom_endpoint\naws_api/ssm_contacts with_custom_endpoint","url":"aws_api/ssm_contacts.html#with_custom_endpoint"},{"doc":"aws_api/ssm_contacts","title":"aws_api/ssm_contacts","content":"","url":"aws_api/ssm_contacts.html"},{"doc":"aws_api/ssm_incidents","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/ssm_incidents.Client\naws_api/ssm_incidents Client","url":"aws_api/ssm_incidents.html#Client"},{"doc":"aws_api/ssm_incidents","title":"batch_get_incident_findings","content":"pub fn batch_get_incident_findings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_incidents.batch_get_incident_findings\naws_api/ssm_incidents batch_get_incident_findings","url":"aws_api/ssm_incidents.html#batch_get_incident_findings"},{"doc":"aws_api/ssm_incidents","title":"create_replication_set","content":"pub fn create_replication_set(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_incidents.create_replication_set\naws_api/ssm_incidents create_replication_set","url":"aws_api/ssm_incidents.html#create_replication_set"},{"doc":"aws_api/ssm_incidents","title":"create_response_plan","content":"pub fn create_response_plan(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_incidents.create_response_plan\naws_api/ssm_incidents create_response_plan","url":"aws_api/ssm_incidents.html#create_response_plan"},{"doc":"aws_api/ssm_incidents","title":"create_timeline_event","content":"pub fn create_timeline_event(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_incidents.create_timeline_event\naws_api/ssm_incidents create_timeline_event","url":"aws_api/ssm_incidents.html#create_timeline_event"},{"doc":"aws_api/ssm_incidents","title":"delete_incident_record","content":"pub fn delete_incident_record(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_incidents.delete_incident_record\naws_api/ssm_incidents delete_incident_record","url":"aws_api/ssm_incidents.html#delete_incident_record"},{"doc":"aws_api/ssm_incidents","title":"delete_replication_set","content":"pub fn delete_replication_set(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_incidents.delete_replication_set\naws_api/ssm_incidents delete_replication_set","url":"aws_api/ssm_incidents.html#delete_replication_set"},{"doc":"aws_api/ssm_incidents","title":"delete_resource_policy","content":"pub fn delete_resource_policy(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_incidents.delete_resource_policy\naws_api/ssm_incidents delete_resource_policy","url":"aws_api/ssm_incidents.html#delete_resource_policy"},{"doc":"aws_api/ssm_incidents","title":"delete_response_plan","content":"pub fn delete_response_plan(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_incidents.delete_response_plan\naws_api/ssm_incidents delete_response_plan","url":"aws_api/ssm_incidents.html#delete_response_plan"},{"doc":"aws_api/ssm_incidents","title":"delete_timeline_event","content":"pub fn delete_timeline_event(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_incidents.delete_timeline_event\naws_api/ssm_incidents delete_timeline_event","url":"aws_api/ssm_incidents.html#delete_timeline_event"},{"doc":"aws_api/ssm_incidents","title":"get_incident_record","content":"pub fn get_incident_record(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_incidents.get_incident_record\naws_api/ssm_incidents get_incident_record","url":"aws_api/ssm_incidents.html#get_incident_record"},{"doc":"aws_api/ssm_incidents","title":"get_replication_set","content":"pub fn get_replication_set(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_incidents.get_replication_set\naws_api/ssm_incidents get_replication_set","url":"aws_api/ssm_incidents.html#get_replication_set"},{"doc":"aws_api/ssm_incidents","title":"get_resource_policies","content":"pub fn get_resource_policies(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_incidents.get_resource_policies\naws_api/ssm_incidents get_resource_policies","url":"aws_api/ssm_incidents.html#get_resource_policies"},{"doc":"aws_api/ssm_incidents","title":"get_response_plan","content":"pub fn get_response_plan(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_incidents.get_response_plan\naws_api/ssm_incidents get_response_plan","url":"aws_api/ssm_incidents.html#get_response_plan"},{"doc":"aws_api/ssm_incidents","title":"get_timeline_event","content":"pub fn get_timeline_event(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_incidents.get_timeline_event\naws_api/ssm_incidents get_timeline_event","url":"aws_api/ssm_incidents.html#get_timeline_event"},{"doc":"aws_api/ssm_incidents","title":"list_incident_findings","content":"pub fn list_incident_findings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_incidents.list_incident_findings\naws_api/ssm_incidents list_incident_findings","url":"aws_api/ssm_incidents.html#list_incident_findings"},{"doc":"aws_api/ssm_incidents","title":"list_incident_records","content":"pub fn list_incident_records(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_incidents.list_incident_records\naws_api/ssm_incidents list_incident_records","url":"aws_api/ssm_incidents.html#list_incident_records"},{"doc":"aws_api/ssm_incidents","title":"list_related_items","content":"pub fn list_related_items(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_incidents.list_related_items\naws_api/ssm_incidents list_related_items","url":"aws_api/ssm_incidents.html#list_related_items"},{"doc":"aws_api/ssm_incidents","title":"list_replication_sets","content":"pub fn list_replication_sets(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_incidents.list_replication_sets\naws_api/ssm_incidents list_replication_sets","url":"aws_api/ssm_incidents.html#list_replication_sets"},{"doc":"aws_api/ssm_incidents","title":"list_response_plans","content":"pub fn list_response_plans(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_incidents.list_response_plans\naws_api/ssm_incidents list_response_plans","url":"aws_api/ssm_incidents.html#list_response_plans"},{"doc":"aws_api/ssm_incidents","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_incidents.list_tags_for_resource\naws_api/ssm_incidents list_tags_for_resource","url":"aws_api/ssm_incidents.html#list_tags_for_resource"},{"doc":"aws_api/ssm_incidents","title":"list_timeline_events","content":"pub fn list_timeline_events(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_incidents.list_timeline_events\naws_api/ssm_incidents list_timeline_events","url":"aws_api/ssm_incidents.html#list_timeline_events"},{"doc":"aws_api/ssm_incidents","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/ssm_incidents.new\naws_api/ssm_incidents new","url":"aws_api/ssm_incidents.html#new"},{"doc":"aws_api/ssm_incidents","title":"put_resource_policy","content":"pub fn put_resource_policy(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_incidents.put_resource_policy\naws_api/ssm_incidents put_resource_policy","url":"aws_api/ssm_incidents.html#put_resource_policy"},{"doc":"aws_api/ssm_incidents","title":"start_incident","content":"pub fn start_incident(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_incidents.start_incident\naws_api/ssm_incidents start_incident","url":"aws_api/ssm_incidents.html#start_incident"},{"doc":"aws_api/ssm_incidents","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_incidents.tag_resource\naws_api/ssm_incidents tag_resource","url":"aws_api/ssm_incidents.html#tag_resource"},{"doc":"aws_api/ssm_incidents","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_incidents.untag_resource\naws_api/ssm_incidents untag_resource","url":"aws_api/ssm_incidents.html#untag_resource"},{"doc":"aws_api/ssm_incidents","title":"update_deletion_protection","content":"pub fn update_deletion_protection(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_incidents.update_deletion_protection\naws_api/ssm_incidents update_deletion_protection","url":"aws_api/ssm_incidents.html#update_deletion_protection"},{"doc":"aws_api/ssm_incidents","title":"update_incident_record","content":"pub fn update_incident_record(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_incidents.update_incident_record\naws_api/ssm_incidents update_incident_record","url":"aws_api/ssm_incidents.html#update_incident_record"},{"doc":"aws_api/ssm_incidents","title":"update_related_items","content":"pub fn update_related_items(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_incidents.update_related_items\naws_api/ssm_incidents update_related_items","url":"aws_api/ssm_incidents.html#update_related_items"},{"doc":"aws_api/ssm_incidents","title":"update_replication_set","content":"pub fn update_replication_set(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_incidents.update_replication_set\naws_api/ssm_incidents update_replication_set","url":"aws_api/ssm_incidents.html#update_replication_set"},{"doc":"aws_api/ssm_incidents","title":"update_response_plan","content":"pub fn update_response_plan(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_incidents.update_response_plan\naws_api/ssm_incidents update_response_plan","url":"aws_api/ssm_incidents.html#update_response_plan"},{"doc":"aws_api/ssm_incidents","title":"update_timeline_event","content":"pub fn update_timeline_event(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_incidents.update_timeline_event\naws_api/ssm_incidents update_timeline_event","url":"aws_api/ssm_incidents.html#update_timeline_event"},{"doc":"aws_api/ssm_incidents","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/ssm_incidents.with_custom_endpoint\naws_api/ssm_incidents with_custom_endpoint","url":"aws_api/ssm_incidents.html#with_custom_endpoint"},{"doc":"aws_api/ssm_incidents","title":"aws_api/ssm_incidents","content":"","url":"aws_api/ssm_incidents.html"},{"doc":"aws_api/ssm_sap","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/ssm_sap.Client\naws_api/ssm_sap Client","url":"aws_api/ssm_sap.html#Client"},{"doc":"aws_api/ssm_sap","title":"delete_resource_permission","content":"pub fn delete_resource_permission(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_sap.delete_resource_permission\naws_api/ssm_sap delete_resource_permission","url":"aws_api/ssm_sap.html#delete_resource_permission"},{"doc":"aws_api/ssm_sap","title":"deregister_application","content":"pub fn deregister_application(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_sap.deregister_application\naws_api/ssm_sap deregister_application","url":"aws_api/ssm_sap.html#deregister_application"},{"doc":"aws_api/ssm_sap","title":"get_application","content":"pub fn get_application(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_sap.get_application\naws_api/ssm_sap get_application","url":"aws_api/ssm_sap.html#get_application"},{"doc":"aws_api/ssm_sap","title":"get_component","content":"pub fn get_component(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_sap.get_component\naws_api/ssm_sap get_component","url":"aws_api/ssm_sap.html#get_component"},{"doc":"aws_api/ssm_sap","title":"get_database","content":"pub fn get_database(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_sap.get_database\naws_api/ssm_sap get_database","url":"aws_api/ssm_sap.html#get_database"},{"doc":"aws_api/ssm_sap","title":"get_operation","content":"pub fn get_operation(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_sap.get_operation\naws_api/ssm_sap get_operation","url":"aws_api/ssm_sap.html#get_operation"},{"doc":"aws_api/ssm_sap","title":"get_resource_permission","content":"pub fn get_resource_permission(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_sap.get_resource_permission\naws_api/ssm_sap get_resource_permission","url":"aws_api/ssm_sap.html#get_resource_permission"},{"doc":"aws_api/ssm_sap","title":"list_applications","content":"pub fn list_applications(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_sap.list_applications\naws_api/ssm_sap list_applications","url":"aws_api/ssm_sap.html#list_applications"},{"doc":"aws_api/ssm_sap","title":"list_components","content":"pub fn list_components(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_sap.list_components\naws_api/ssm_sap list_components","url":"aws_api/ssm_sap.html#list_components"},{"doc":"aws_api/ssm_sap","title":"list_databases","content":"pub fn list_databases(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_sap.list_databases\naws_api/ssm_sap list_databases","url":"aws_api/ssm_sap.html#list_databases"},{"doc":"aws_api/ssm_sap","title":"list_operation_events","content":"pub fn list_operation_events(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_sap.list_operation_events\naws_api/ssm_sap list_operation_events","url":"aws_api/ssm_sap.html#list_operation_events"},{"doc":"aws_api/ssm_sap","title":"list_operations","content":"pub fn list_operations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_sap.list_operations\naws_api/ssm_sap list_operations","url":"aws_api/ssm_sap.html#list_operations"},{"doc":"aws_api/ssm_sap","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_sap.list_tags_for_resource\naws_api/ssm_sap list_tags_for_resource","url":"aws_api/ssm_sap.html#list_tags_for_resource"},{"doc":"aws_api/ssm_sap","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/ssm_sap.new\naws_api/ssm_sap new","url":"aws_api/ssm_sap.html#new"},{"doc":"aws_api/ssm_sap","title":"put_resource_permission","content":"pub fn put_resource_permission(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_sap.put_resource_permission\naws_api/ssm_sap put_resource_permission","url":"aws_api/ssm_sap.html#put_resource_permission"},{"doc":"aws_api/ssm_sap","title":"register_application","content":"pub fn register_application(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_sap.register_application\naws_api/ssm_sap register_application","url":"aws_api/ssm_sap.html#register_application"},{"doc":"aws_api/ssm_sap","title":"start_application","content":"pub fn start_application(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_sap.start_application\naws_api/ssm_sap start_application","url":"aws_api/ssm_sap.html#start_application"},{"doc":"aws_api/ssm_sap","title":"start_application_refresh","content":"pub fn start_application_refresh(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_sap.start_application_refresh\naws_api/ssm_sap start_application_refresh","url":"aws_api/ssm_sap.html#start_application_refresh"},{"doc":"aws_api/ssm_sap","title":"stop_application","content":"pub fn stop_application(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_sap.stop_application\naws_api/ssm_sap stop_application","url":"aws_api/ssm_sap.html#stop_application"},{"doc":"aws_api/ssm_sap","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_sap.tag_resource\naws_api/ssm_sap tag_resource","url":"aws_api/ssm_sap.html#tag_resource"},{"doc":"aws_api/ssm_sap","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_sap.untag_resource\naws_api/ssm_sap untag_resource","url":"aws_api/ssm_sap.html#untag_resource"},{"doc":"aws_api/ssm_sap","title":"update_application_settings","content":"pub fn update_application_settings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/ssm_sap.update_application_settings\naws_api/ssm_sap update_application_settings","url":"aws_api/ssm_sap.html#update_application_settings"},{"doc":"aws_api/ssm_sap","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/ssm_sap.with_custom_endpoint\naws_api/ssm_sap with_custom_endpoint","url":"aws_api/ssm_sap.html#with_custom_endpoint"},{"doc":"aws_api/ssm_sap","title":"aws_api/ssm_sap","content":"","url":"aws_api/ssm_sap.html"},{"doc":"aws_api/sso","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/sso.Client\naws_api/sso Client","url":"aws_api/sso.html#Client"},{"doc":"aws_api/sso","title":"get_role_credentials","content":"pub fn get_role_credentials(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso.get_role_credentials\naws_api/sso get_role_credentials","url":"aws_api/sso.html#get_role_credentials"},{"doc":"aws_api/sso","title":"list_account_roles","content":"pub fn list_account_roles(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso.list_account_roles\naws_api/sso list_account_roles","url":"aws_api/sso.html#list_account_roles"},{"doc":"aws_api/sso","title":"list_accounts","content":"pub fn list_accounts(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso.list_accounts\naws_api/sso list_accounts","url":"aws_api/sso.html#list_accounts"},{"doc":"aws_api/sso","title":"logout","content":"pub fn logout(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso.logout\naws_api/sso logout","url":"aws_api/sso.html#logout"},{"doc":"aws_api/sso","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/sso.new\naws_api/sso new","url":"aws_api/sso.html#new"},{"doc":"aws_api/sso","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/sso.with_custom_endpoint\naws_api/sso with_custom_endpoint","url":"aws_api/sso.html#with_custom_endpoint"},{"doc":"aws_api/sso","title":"aws_api/sso","content":"","url":"aws_api/sso.html"},{"doc":"aws_api/sso_admin","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/sso_admin.Client\naws_api/sso_admin Client","url":"aws_api/sso_admin.html#Client"},{"doc":"aws_api/sso_admin","title":"attach_customer_managed_policy_reference_to_permission_set","content":"pub fn attach_customer_managed_policy_reference_to_permission_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.attach_customer_managed_policy_reference_to_permission_set\naws_api/sso_admin attach_customer_managed_policy_reference_to_permission_set","url":"aws_api/sso_admin.html#attach_customer_managed_policy_reference_to_permission_set"},{"doc":"aws_api/sso_admin","title":"attach_managed_policy_to_permission_set","content":"pub fn attach_managed_policy_to_permission_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.attach_managed_policy_to_permission_set\naws_api/sso_admin attach_managed_policy_to_permission_set","url":"aws_api/sso_admin.html#attach_managed_policy_to_permission_set"},{"doc":"aws_api/sso_admin","title":"create_account_assignment","content":"pub fn create_account_assignment(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.create_account_assignment\naws_api/sso_admin create_account_assignment","url":"aws_api/sso_admin.html#create_account_assignment"},{"doc":"aws_api/sso_admin","title":"create_application","content":"pub fn create_application(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.create_application\naws_api/sso_admin create_application","url":"aws_api/sso_admin.html#create_application"},{"doc":"aws_api/sso_admin","title":"create_application_assignment","content":"pub fn create_application_assignment(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.create_application_assignment\naws_api/sso_admin create_application_assignment","url":"aws_api/sso_admin.html#create_application_assignment"},{"doc":"aws_api/sso_admin","title":"create_instance","content":"pub fn create_instance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.create_instance\naws_api/sso_admin create_instance","url":"aws_api/sso_admin.html#create_instance"},{"doc":"aws_api/sso_admin","title":"create_instance_access_control_attribute_configuration","content":"pub fn create_instance_access_control_attribute_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.create_instance_access_control_attribute_configuration\naws_api/sso_admin create_instance_access_control_attribute_configuration","url":"aws_api/sso_admin.html#create_instance_access_control_attribute_configuration"},{"doc":"aws_api/sso_admin","title":"create_permission_set","content":"pub fn create_permission_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.create_permission_set\naws_api/sso_admin create_permission_set","url":"aws_api/sso_admin.html#create_permission_set"},{"doc":"aws_api/sso_admin","title":"create_trusted_token_issuer","content":"pub fn create_trusted_token_issuer(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.create_trusted_token_issuer\naws_api/sso_admin create_trusted_token_issuer","url":"aws_api/sso_admin.html#create_trusted_token_issuer"},{"doc":"aws_api/sso_admin","title":"delete_account_assignment","content":"pub fn delete_account_assignment(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.delete_account_assignment\naws_api/sso_admin delete_account_assignment","url":"aws_api/sso_admin.html#delete_account_assignment"},{"doc":"aws_api/sso_admin","title":"delete_application","content":"pub fn delete_application(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.delete_application\naws_api/sso_admin delete_application","url":"aws_api/sso_admin.html#delete_application"},{"doc":"aws_api/sso_admin","title":"delete_application_assignment","content":"pub fn delete_application_assignment(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.delete_application_assignment\naws_api/sso_admin delete_application_assignment","url":"aws_api/sso_admin.html#delete_application_assignment"},{"doc":"aws_api/sso_admin","title":"delete_inline_policy_from_permission_set","content":"pub fn delete_inline_policy_from_permission_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.delete_inline_policy_from_permission_set\naws_api/sso_admin delete_inline_policy_from_permission_set","url":"aws_api/sso_admin.html#delete_inline_policy_from_permission_set"},{"doc":"aws_api/sso_admin","title":"delete_instance","content":"pub fn delete_instance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.delete_instance\naws_api/sso_admin delete_instance","url":"aws_api/sso_admin.html#delete_instance"},{"doc":"aws_api/sso_admin","title":"delete_instance_access_control_attribute_configuration","content":"pub fn delete_instance_access_control_attribute_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.delete_instance_access_control_attribute_configuration\naws_api/sso_admin delete_instance_access_control_attribute_configuration","url":"aws_api/sso_admin.html#delete_instance_access_control_attribute_configuration"},{"doc":"aws_api/sso_admin","title":"delete_permission_set","content":"pub fn delete_permission_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.delete_permission_set\naws_api/sso_admin delete_permission_set","url":"aws_api/sso_admin.html#delete_permission_set"},{"doc":"aws_api/sso_admin","title":"delete_permissions_boundary_from_permission_set","content":"pub fn delete_permissions_boundary_from_permission_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.delete_permissions_boundary_from_permission_set\naws_api/sso_admin delete_permissions_boundary_from_permission_set","url":"aws_api/sso_admin.html#delete_permissions_boundary_from_permission_set"},{"doc":"aws_api/sso_admin","title":"delete_trusted_token_issuer","content":"pub fn delete_trusted_token_issuer(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.delete_trusted_token_issuer\naws_api/sso_admin delete_trusted_token_issuer","url":"aws_api/sso_admin.html#delete_trusted_token_issuer"},{"doc":"aws_api/sso_admin","title":"describe_account_assignment_creation_status","content":"pub fn describe_account_assignment_creation_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.describe_account_assignment_creation_status\naws_api/sso_admin describe_account_assignment_creation_status","url":"aws_api/sso_admin.html#describe_account_assignment_creation_status"},{"doc":"aws_api/sso_admin","title":"describe_account_assignment_deletion_status","content":"pub fn describe_account_assignment_deletion_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.describe_account_assignment_deletion_status\naws_api/sso_admin describe_account_assignment_deletion_status","url":"aws_api/sso_admin.html#describe_account_assignment_deletion_status"},{"doc":"aws_api/sso_admin","title":"describe_application","content":"pub fn describe_application(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.describe_application\naws_api/sso_admin describe_application","url":"aws_api/sso_admin.html#describe_application"},{"doc":"aws_api/sso_admin","title":"describe_application_assignment","content":"pub fn describe_application_assignment(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.describe_application_assignment\naws_api/sso_admin describe_application_assignment","url":"aws_api/sso_admin.html#describe_application_assignment"},{"doc":"aws_api/sso_admin","title":"describe_application_provider","content":"pub fn describe_application_provider(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.describe_application_provider\naws_api/sso_admin describe_application_provider","url":"aws_api/sso_admin.html#describe_application_provider"},{"doc":"aws_api/sso_admin","title":"describe_instance","content":"pub fn describe_instance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.describe_instance\naws_api/sso_admin describe_instance","url":"aws_api/sso_admin.html#describe_instance"},{"doc":"aws_api/sso_admin","title":"describe_instance_access_control_attribute_configuration","content":"pub fn describe_instance_access_control_attribute_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.describe_instance_access_control_attribute_configuration\naws_api/sso_admin describe_instance_access_control_attribute_configuration","url":"aws_api/sso_admin.html#describe_instance_access_control_attribute_configuration"},{"doc":"aws_api/sso_admin","title":"describe_permission_set","content":"pub fn describe_permission_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.describe_permission_set\naws_api/sso_admin describe_permission_set","url":"aws_api/sso_admin.html#describe_permission_set"},{"doc":"aws_api/sso_admin","title":"describe_permission_set_provisioning_status","content":"pub fn describe_permission_set_provisioning_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.describe_permission_set_provisioning_status\naws_api/sso_admin describe_permission_set_provisioning_status","url":"aws_api/sso_admin.html#describe_permission_set_provisioning_status"},{"doc":"aws_api/sso_admin","title":"describe_trusted_token_issuer","content":"pub fn describe_trusted_token_issuer(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.describe_trusted_token_issuer\naws_api/sso_admin describe_trusted_token_issuer","url":"aws_api/sso_admin.html#describe_trusted_token_issuer"},{"doc":"aws_api/sso_admin","title":"detach_customer_managed_policy_reference_from_permission_set","content":"pub fn detach_customer_managed_policy_reference_from_permission_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.detach_customer_managed_policy_reference_from_permission_set\naws_api/sso_admin detach_customer_managed_policy_reference_from_permission_set","url":"aws_api/sso_admin.html#detach_customer_managed_policy_reference_from_permission_set"},{"doc":"aws_api/sso_admin","title":"detach_managed_policy_from_permission_set","content":"pub fn detach_managed_policy_from_permission_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.detach_managed_policy_from_permission_set\naws_api/sso_admin detach_managed_policy_from_permission_set","url":"aws_api/sso_admin.html#detach_managed_policy_from_permission_set"},{"doc":"aws_api/sso_admin","title":"get_application_assignment_configuration","content":"pub fn get_application_assignment_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.get_application_assignment_configuration\naws_api/sso_admin get_application_assignment_configuration","url":"aws_api/sso_admin.html#get_application_assignment_configuration"},{"doc":"aws_api/sso_admin","title":"get_inline_policy_for_permission_set","content":"pub fn get_inline_policy_for_permission_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.get_inline_policy_for_permission_set\naws_api/sso_admin get_inline_policy_for_permission_set","url":"aws_api/sso_admin.html#get_inline_policy_for_permission_set"},{"doc":"aws_api/sso_admin","title":"get_permissions_boundary_for_permission_set","content":"pub fn get_permissions_boundary_for_permission_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.get_permissions_boundary_for_permission_set\naws_api/sso_admin get_permissions_boundary_for_permission_set","url":"aws_api/sso_admin.html#get_permissions_boundary_for_permission_set"},{"doc":"aws_api/sso_admin","title":"list_account_assignment_creation_status","content":"pub fn list_account_assignment_creation_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.list_account_assignment_creation_status\naws_api/sso_admin list_account_assignment_creation_status","url":"aws_api/sso_admin.html#list_account_assignment_creation_status"},{"doc":"aws_api/sso_admin","title":"list_account_assignment_deletion_status","content":"pub fn list_account_assignment_deletion_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.list_account_assignment_deletion_status\naws_api/sso_admin list_account_assignment_deletion_status","url":"aws_api/sso_admin.html#list_account_assignment_deletion_status"},{"doc":"aws_api/sso_admin","title":"list_account_assignments","content":"pub fn list_account_assignments(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.list_account_assignments\naws_api/sso_admin list_account_assignments","url":"aws_api/sso_admin.html#list_account_assignments"},{"doc":"aws_api/sso_admin","title":"list_account_assignments_for_principal","content":"pub fn list_account_assignments_for_principal(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.list_account_assignments_for_principal\naws_api/sso_admin list_account_assignments_for_principal","url":"aws_api/sso_admin.html#list_account_assignments_for_principal"},{"doc":"aws_api/sso_admin","title":"list_accounts_for_provisioned_permission_set","content":"pub fn list_accounts_for_provisioned_permission_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.list_accounts_for_provisioned_permission_set\naws_api/sso_admin list_accounts_for_provisioned_permission_set","url":"aws_api/sso_admin.html#list_accounts_for_provisioned_permission_set"},{"doc":"aws_api/sso_admin","title":"list_application_assignments","content":"pub fn list_application_assignments(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.list_application_assignments\naws_api/sso_admin list_application_assignments","url":"aws_api/sso_admin.html#list_application_assignments"},{"doc":"aws_api/sso_admin","title":"list_application_assignments_for_principal","content":"pub fn list_application_assignments_for_principal(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.list_application_assignments_for_principal\naws_api/sso_admin list_application_assignments_for_principal","url":"aws_api/sso_admin.html#list_application_assignments_for_principal"},{"doc":"aws_api/sso_admin","title":"list_application_providers","content":"pub fn list_application_providers(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.list_application_providers\naws_api/sso_admin list_application_providers","url":"aws_api/sso_admin.html#list_application_providers"},{"doc":"aws_api/sso_admin","title":"list_applications","content":"pub fn list_applications(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.list_applications\naws_api/sso_admin list_applications","url":"aws_api/sso_admin.html#list_applications"},{"doc":"aws_api/sso_admin","title":"list_customer_managed_policy_references_in_permission_set","content":"pub fn list_customer_managed_policy_references_in_permission_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.list_customer_managed_policy_references_in_permission_set\naws_api/sso_admin list_customer_managed_policy_references_in_permission_set","url":"aws_api/sso_admin.html#list_customer_managed_policy_references_in_permission_set"},{"doc":"aws_api/sso_admin","title":"list_instances","content":"pub fn list_instances(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.list_instances\naws_api/sso_admin list_instances","url":"aws_api/sso_admin.html#list_instances"},{"doc":"aws_api/sso_admin","title":"list_managed_policies_in_permission_set","content":"pub fn list_managed_policies_in_permission_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.list_managed_policies_in_permission_set\naws_api/sso_admin list_managed_policies_in_permission_set","url":"aws_api/sso_admin.html#list_managed_policies_in_permission_set"},{"doc":"aws_api/sso_admin","title":"list_permission_set_provisioning_status","content":"pub fn list_permission_set_provisioning_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.list_permission_set_provisioning_status\naws_api/sso_admin list_permission_set_provisioning_status","url":"aws_api/sso_admin.html#list_permission_set_provisioning_status"},{"doc":"aws_api/sso_admin","title":"list_permission_sets","content":"pub fn list_permission_sets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.list_permission_sets\naws_api/sso_admin list_permission_sets","url":"aws_api/sso_admin.html#list_permission_sets"},{"doc":"aws_api/sso_admin","title":"list_permission_sets_provisioned_to_account","content":"pub fn list_permission_sets_provisioned_to_account(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.list_permission_sets_provisioned_to_account\naws_api/sso_admin list_permission_sets_provisioned_to_account","url":"aws_api/sso_admin.html#list_permission_sets_provisioned_to_account"},{"doc":"aws_api/sso_admin","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.list_tags_for_resource\naws_api/sso_admin list_tags_for_resource","url":"aws_api/sso_admin.html#list_tags_for_resource"},{"doc":"aws_api/sso_admin","title":"list_trusted_token_issuers","content":"pub fn list_trusted_token_issuers(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.list_trusted_token_issuers\naws_api/sso_admin list_trusted_token_issuers","url":"aws_api/sso_admin.html#list_trusted_token_issuers"},{"doc":"aws_api/sso_admin","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/sso_admin.new\naws_api/sso_admin new","url":"aws_api/sso_admin.html#new"},{"doc":"aws_api/sso_admin","title":"provision_permission_set","content":"pub fn provision_permission_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.provision_permission_set\naws_api/sso_admin provision_permission_set","url":"aws_api/sso_admin.html#provision_permission_set"},{"doc":"aws_api/sso_admin","title":"put_application_assignment_configuration","content":"pub fn put_application_assignment_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.put_application_assignment_configuration\naws_api/sso_admin put_application_assignment_configuration","url":"aws_api/sso_admin.html#put_application_assignment_configuration"},{"doc":"aws_api/sso_admin","title":"put_inline_policy_to_permission_set","content":"pub fn put_inline_policy_to_permission_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.put_inline_policy_to_permission_set\naws_api/sso_admin put_inline_policy_to_permission_set","url":"aws_api/sso_admin.html#put_inline_policy_to_permission_set"},{"doc":"aws_api/sso_admin","title":"put_permissions_boundary_to_permission_set","content":"pub fn put_permissions_boundary_to_permission_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.put_permissions_boundary_to_permission_set\naws_api/sso_admin put_permissions_boundary_to_permission_set","url":"aws_api/sso_admin.html#put_permissions_boundary_to_permission_set"},{"doc":"aws_api/sso_admin","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.tag_resource\naws_api/sso_admin tag_resource","url":"aws_api/sso_admin.html#tag_resource"},{"doc":"aws_api/sso_admin","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.untag_resource\naws_api/sso_admin untag_resource","url":"aws_api/sso_admin.html#untag_resource"},{"doc":"aws_api/sso_admin","title":"update_application","content":"pub fn update_application(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.update_application\naws_api/sso_admin update_application","url":"aws_api/sso_admin.html#update_application"},{"doc":"aws_api/sso_admin","title":"update_instance","content":"pub fn update_instance(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.update_instance\naws_api/sso_admin update_instance","url":"aws_api/sso_admin.html#update_instance"},{"doc":"aws_api/sso_admin","title":"update_instance_access_control_attribute_configuration","content":"pub fn update_instance_access_control_attribute_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.update_instance_access_control_attribute_configuration\naws_api/sso_admin update_instance_access_control_attribute_configuration","url":"aws_api/sso_admin.html#update_instance_access_control_attribute_configuration"},{"doc":"aws_api/sso_admin","title":"update_permission_set","content":"pub fn update_permission_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.update_permission_set\naws_api/sso_admin update_permission_set","url":"aws_api/sso_admin.html#update_permission_set"},{"doc":"aws_api/sso_admin","title":"update_trusted_token_issuer","content":"pub fn update_trusted_token_issuer(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_admin.update_trusted_token_issuer\naws_api/sso_admin update_trusted_token_issuer","url":"aws_api/sso_admin.html#update_trusted_token_issuer"},{"doc":"aws_api/sso_admin","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/sso_admin.with_custom_endpoint\naws_api/sso_admin with_custom_endpoint","url":"aws_api/sso_admin.html#with_custom_endpoint"},{"doc":"aws_api/sso_admin","title":"aws_api/sso_admin","content":"","url":"aws_api/sso_admin.html"},{"doc":"aws_api/sso_oidc","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/sso_oidc.Client\naws_api/sso_oidc Client","url":"aws_api/sso_oidc.html#Client"},{"doc":"aws_api/sso_oidc","title":"create_token","content":"pub fn create_token(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_oidc.create_token\naws_api/sso_oidc create_token","url":"aws_api/sso_oidc.html#create_token"},{"doc":"aws_api/sso_oidc","title":"create_token_with_iam","content":"pub fn create_token_with_iam(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_oidc.create_token_with_iam\naws_api/sso_oidc create_token_with_iam","url":"aws_api/sso_oidc.html#create_token_with_iam"},{"doc":"aws_api/sso_oidc","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/sso_oidc.new\naws_api/sso_oidc new","url":"aws_api/sso_oidc.html#new"},{"doc":"aws_api/sso_oidc","title":"register_client","content":"pub fn register_client(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_oidc.register_client\naws_api/sso_oidc register_client","url":"aws_api/sso_oidc.html#register_client"},{"doc":"aws_api/sso_oidc","title":"start_device_authorization","content":"pub fn start_device_authorization(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sso_oidc.start_device_authorization\naws_api/sso_oidc start_device_authorization","url":"aws_api/sso_oidc.html#start_device_authorization"},{"doc":"aws_api/sso_oidc","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/sso_oidc.with_custom_endpoint\naws_api/sso_oidc with_custom_endpoint","url":"aws_api/sso_oidc.html#with_custom_endpoint"},{"doc":"aws_api/sso_oidc","title":"aws_api/sso_oidc","content":"","url":"aws_api/sso_oidc.html"},{"doc":"aws_api/storage_gateway","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/storage_gateway.Client\naws_api/storage_gateway Client","url":"aws_api/storage_gateway.html#Client"},{"doc":"aws_api/storage_gateway","title":"activate_gateway","content":"pub fn activate_gateway(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.activate_gateway\naws_api/storage_gateway activate_gateway","url":"aws_api/storage_gateway.html#activate_gateway"},{"doc":"aws_api/storage_gateway","title":"add_cache","content":"pub fn add_cache(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.add_cache\naws_api/storage_gateway add_cache","url":"aws_api/storage_gateway.html#add_cache"},{"doc":"aws_api/storage_gateway","title":"add_tags_to_resource","content":"pub fn add_tags_to_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.add_tags_to_resource\naws_api/storage_gateway add_tags_to_resource","url":"aws_api/storage_gateway.html#add_tags_to_resource"},{"doc":"aws_api/storage_gateway","title":"add_upload_buffer","content":"pub fn add_upload_buffer(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.add_upload_buffer\naws_api/storage_gateway add_upload_buffer","url":"aws_api/storage_gateway.html#add_upload_buffer"},{"doc":"aws_api/storage_gateway","title":"add_working_storage","content":"pub fn add_working_storage(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.add_working_storage\naws_api/storage_gateway add_working_storage","url":"aws_api/storage_gateway.html#add_working_storage"},{"doc":"aws_api/storage_gateway","title":"assign_tape_pool","content":"pub fn assign_tape_pool(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.assign_tape_pool\naws_api/storage_gateway assign_tape_pool","url":"aws_api/storage_gateway.html#assign_tape_pool"},{"doc":"aws_api/storage_gateway","title":"associate_file_system","content":"pub fn associate_file_system(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.associate_file_system\naws_api/storage_gateway associate_file_system","url":"aws_api/storage_gateway.html#associate_file_system"},{"doc":"aws_api/storage_gateway","title":"attach_volume","content":"pub fn attach_volume(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.attach_volume\naws_api/storage_gateway attach_volume","url":"aws_api/storage_gateway.html#attach_volume"},{"doc":"aws_api/storage_gateway","title":"cancel_archival","content":"pub fn cancel_archival(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.cancel_archival\naws_api/storage_gateway cancel_archival","url":"aws_api/storage_gateway.html#cancel_archival"},{"doc":"aws_api/storage_gateway","title":"cancel_retrieval","content":"pub fn cancel_retrieval(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.cancel_retrieval\naws_api/storage_gateway cancel_retrieval","url":"aws_api/storage_gateway.html#cancel_retrieval"},{"doc":"aws_api/storage_gateway","title":"create_cachedi_scsi_volume","content":"pub fn create_cachedi_scsi_volume(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.create_cachedi_scsi_volume\naws_api/storage_gateway create_cachedi_scsi_volume","url":"aws_api/storage_gateway.html#create_cachedi_scsi_volume"},{"doc":"aws_api/storage_gateway","title":"create_nfs_file_share","content":"pub fn create_nfs_file_share(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.create_nfs_file_share\naws_api/storage_gateway create_nfs_file_share","url":"aws_api/storage_gateway.html#create_nfs_file_share"},{"doc":"aws_api/storage_gateway","title":"create_smb_file_share","content":"pub fn create_smb_file_share(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.create_smb_file_share\naws_api/storage_gateway create_smb_file_share","url":"aws_api/storage_gateway.html#create_smb_file_share"},{"doc":"aws_api/storage_gateway","title":"create_snapshot","content":"pub fn create_snapshot(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.create_snapshot\naws_api/storage_gateway create_snapshot","url":"aws_api/storage_gateway.html#create_snapshot"},{"doc":"aws_api/storage_gateway","title":"create_snapshot_from_volume_recovery_point","content":"pub fn create_snapshot_from_volume_recovery_point(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.create_snapshot_from_volume_recovery_point\naws_api/storage_gateway create_snapshot_from_volume_recovery_point","url":"aws_api/storage_gateway.html#create_snapshot_from_volume_recovery_point"},{"doc":"aws_api/storage_gateway","title":"create_storedi_scsi_volume","content":"pub fn create_storedi_scsi_volume(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.create_storedi_scsi_volume\naws_api/storage_gateway create_storedi_scsi_volume","url":"aws_api/storage_gateway.html#create_storedi_scsi_volume"},{"doc":"aws_api/storage_gateway","title":"create_tape_pool","content":"pub fn create_tape_pool(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.create_tape_pool\naws_api/storage_gateway create_tape_pool","url":"aws_api/storage_gateway.html#create_tape_pool"},{"doc":"aws_api/storage_gateway","title":"create_tape_with_barcode","content":"pub fn create_tape_with_barcode(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.create_tape_with_barcode\naws_api/storage_gateway create_tape_with_barcode","url":"aws_api/storage_gateway.html#create_tape_with_barcode"},{"doc":"aws_api/storage_gateway","title":"create_tapes","content":"pub fn create_tapes(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.create_tapes\naws_api/storage_gateway create_tapes","url":"aws_api/storage_gateway.html#create_tapes"},{"doc":"aws_api/storage_gateway","title":"delete_automatic_tape_creation_policy","content":"pub fn delete_automatic_tape_creation_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.delete_automatic_tape_creation_policy\naws_api/storage_gateway delete_automatic_tape_creation_policy","url":"aws_api/storage_gateway.html#delete_automatic_tape_creation_policy"},{"doc":"aws_api/storage_gateway","title":"delete_bandwidth_rate_limit","content":"pub fn delete_bandwidth_rate_limit(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.delete_bandwidth_rate_limit\naws_api/storage_gateway delete_bandwidth_rate_limit","url":"aws_api/storage_gateway.html#delete_bandwidth_rate_limit"},{"doc":"aws_api/storage_gateway","title":"delete_chap_credentials","content":"pub fn delete_chap_credentials(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.delete_chap_credentials\naws_api/storage_gateway delete_chap_credentials","url":"aws_api/storage_gateway.html#delete_chap_credentials"},{"doc":"aws_api/storage_gateway","title":"delete_file_share","content":"pub fn delete_file_share(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.delete_file_share\naws_api/storage_gateway delete_file_share","url":"aws_api/storage_gateway.html#delete_file_share"},{"doc":"aws_api/storage_gateway","title":"delete_gateway","content":"pub fn delete_gateway(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.delete_gateway\naws_api/storage_gateway delete_gateway","url":"aws_api/storage_gateway.html#delete_gateway"},{"doc":"aws_api/storage_gateway","title":"delete_snapshot_schedule","content":"pub fn delete_snapshot_schedule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.delete_snapshot_schedule\naws_api/storage_gateway delete_snapshot_schedule","url":"aws_api/storage_gateway.html#delete_snapshot_schedule"},{"doc":"aws_api/storage_gateway","title":"delete_tape","content":"pub fn delete_tape(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.delete_tape\naws_api/storage_gateway delete_tape","url":"aws_api/storage_gateway.html#delete_tape"},{"doc":"aws_api/storage_gateway","title":"delete_tape_archive","content":"pub fn delete_tape_archive(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.delete_tape_archive\naws_api/storage_gateway delete_tape_archive","url":"aws_api/storage_gateway.html#delete_tape_archive"},{"doc":"aws_api/storage_gateway","title":"delete_tape_pool","content":"pub fn delete_tape_pool(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.delete_tape_pool\naws_api/storage_gateway delete_tape_pool","url":"aws_api/storage_gateway.html#delete_tape_pool"},{"doc":"aws_api/storage_gateway","title":"delete_volume","content":"pub fn delete_volume(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.delete_volume\naws_api/storage_gateway delete_volume","url":"aws_api/storage_gateway.html#delete_volume"},{"doc":"aws_api/storage_gateway","title":"describe_availability_monitor_test","content":"pub fn describe_availability_monitor_test(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.describe_availability_monitor_test\naws_api/storage_gateway describe_availability_monitor_test","url":"aws_api/storage_gateway.html#describe_availability_monitor_test"},{"doc":"aws_api/storage_gateway","title":"describe_bandwidth_rate_limit","content":"pub fn describe_bandwidth_rate_limit(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.describe_bandwidth_rate_limit\naws_api/storage_gateway describe_bandwidth_rate_limit","url":"aws_api/storage_gateway.html#describe_bandwidth_rate_limit"},{"doc":"aws_api/storage_gateway","title":"describe_bandwidth_rate_limit_schedule","content":"pub fn describe_bandwidth_rate_limit_schedule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.describe_bandwidth_rate_limit_schedule\naws_api/storage_gateway describe_bandwidth_rate_limit_schedule","url":"aws_api/storage_gateway.html#describe_bandwidth_rate_limit_schedule"},{"doc":"aws_api/storage_gateway","title":"describe_cache","content":"pub fn describe_cache(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.describe_cache\naws_api/storage_gateway describe_cache","url":"aws_api/storage_gateway.html#describe_cache"},{"doc":"aws_api/storage_gateway","title":"describe_cachedi_scsi_volumes","content":"pub fn describe_cachedi_scsi_volumes(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.describe_cachedi_scsi_volumes\naws_api/storage_gateway describe_cachedi_scsi_volumes","url":"aws_api/storage_gateway.html#describe_cachedi_scsi_volumes"},{"doc":"aws_api/storage_gateway","title":"describe_chap_credentials","content":"pub fn describe_chap_credentials(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.describe_chap_credentials\naws_api/storage_gateway describe_chap_credentials","url":"aws_api/storage_gateway.html#describe_chap_credentials"},{"doc":"aws_api/storage_gateway","title":"describe_file_system_associations","content":"pub fn describe_file_system_associations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.describe_file_system_associations\naws_api/storage_gateway describe_file_system_associations","url":"aws_api/storage_gateway.html#describe_file_system_associations"},{"doc":"aws_api/storage_gateway","title":"describe_gateway_information","content":"pub fn describe_gateway_information(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.describe_gateway_information\naws_api/storage_gateway describe_gateway_information","url":"aws_api/storage_gateway.html#describe_gateway_information"},{"doc":"aws_api/storage_gateway","title":"describe_maintenance_start_time","content":"pub fn describe_maintenance_start_time(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.describe_maintenance_start_time\naws_api/storage_gateway describe_maintenance_start_time","url":"aws_api/storage_gateway.html#describe_maintenance_start_time"},{"doc":"aws_api/storage_gateway","title":"describe_nfs_file_shares","content":"pub fn describe_nfs_file_shares(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.describe_nfs_file_shares\naws_api/storage_gateway describe_nfs_file_shares","url":"aws_api/storage_gateway.html#describe_nfs_file_shares"},{"doc":"aws_api/storage_gateway","title":"describe_smb_file_shares","content":"pub fn describe_smb_file_shares(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.describe_smb_file_shares\naws_api/storage_gateway describe_smb_file_shares","url":"aws_api/storage_gateway.html#describe_smb_file_shares"},{"doc":"aws_api/storage_gateway","title":"describe_smb_settings","content":"pub fn describe_smb_settings(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.describe_smb_settings\naws_api/storage_gateway describe_smb_settings","url":"aws_api/storage_gateway.html#describe_smb_settings"},{"doc":"aws_api/storage_gateway","title":"describe_snapshot_schedule","content":"pub fn describe_snapshot_schedule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.describe_snapshot_schedule\naws_api/storage_gateway describe_snapshot_schedule","url":"aws_api/storage_gateway.html#describe_snapshot_schedule"},{"doc":"aws_api/storage_gateway","title":"describe_storedi_scsi_volumes","content":"pub fn describe_storedi_scsi_volumes(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.describe_storedi_scsi_volumes\naws_api/storage_gateway describe_storedi_scsi_volumes","url":"aws_api/storage_gateway.html#describe_storedi_scsi_volumes"},{"doc":"aws_api/storage_gateway","title":"describe_tape_archives","content":"pub fn describe_tape_archives(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.describe_tape_archives\naws_api/storage_gateway describe_tape_archives","url":"aws_api/storage_gateway.html#describe_tape_archives"},{"doc":"aws_api/storage_gateway","title":"describe_tape_recovery_points","content":"pub fn describe_tape_recovery_points(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.describe_tape_recovery_points\naws_api/storage_gateway describe_tape_recovery_points","url":"aws_api/storage_gateway.html#describe_tape_recovery_points"},{"doc":"aws_api/storage_gateway","title":"describe_tapes","content":"pub fn describe_tapes(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.describe_tapes\naws_api/storage_gateway describe_tapes","url":"aws_api/storage_gateway.html#describe_tapes"},{"doc":"aws_api/storage_gateway","title":"describe_upload_buffer","content":"pub fn describe_upload_buffer(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.describe_upload_buffer\naws_api/storage_gateway describe_upload_buffer","url":"aws_api/storage_gateway.html#describe_upload_buffer"},{"doc":"aws_api/storage_gateway","title":"describe_vtl_devices","content":"pub fn describe_vtl_devices(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.describe_vtl_devices\naws_api/storage_gateway describe_vtl_devices","url":"aws_api/storage_gateway.html#describe_vtl_devices"},{"doc":"aws_api/storage_gateway","title":"describe_working_storage","content":"pub fn describe_working_storage(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.describe_working_storage\naws_api/storage_gateway describe_working_storage","url":"aws_api/storage_gateway.html#describe_working_storage"},{"doc":"aws_api/storage_gateway","title":"detach_volume","content":"pub fn detach_volume(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.detach_volume\naws_api/storage_gateway detach_volume","url":"aws_api/storage_gateway.html#detach_volume"},{"doc":"aws_api/storage_gateway","title":"disable_gateway","content":"pub fn disable_gateway(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.disable_gateway\naws_api/storage_gateway disable_gateway","url":"aws_api/storage_gateway.html#disable_gateway"},{"doc":"aws_api/storage_gateway","title":"disassociate_file_system","content":"pub fn disassociate_file_system(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.disassociate_file_system\naws_api/storage_gateway disassociate_file_system","url":"aws_api/storage_gateway.html#disassociate_file_system"},{"doc":"aws_api/storage_gateway","title":"join_domain","content":"pub fn join_domain(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.join_domain\naws_api/storage_gateway join_domain","url":"aws_api/storage_gateway.html#join_domain"},{"doc":"aws_api/storage_gateway","title":"list_automatic_tape_creation_policies","content":"pub fn list_automatic_tape_creation_policies(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.list_automatic_tape_creation_policies\naws_api/storage_gateway list_automatic_tape_creation_policies","url":"aws_api/storage_gateway.html#list_automatic_tape_creation_policies"},{"doc":"aws_api/storage_gateway","title":"list_file_shares","content":"pub fn list_file_shares(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.list_file_shares\naws_api/storage_gateway list_file_shares","url":"aws_api/storage_gateway.html#list_file_shares"},{"doc":"aws_api/storage_gateway","title":"list_file_system_associations","content":"pub fn list_file_system_associations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.list_file_system_associations\naws_api/storage_gateway list_file_system_associations","url":"aws_api/storage_gateway.html#list_file_system_associations"},{"doc":"aws_api/storage_gateway","title":"list_gateways","content":"pub fn list_gateways(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.list_gateways\naws_api/storage_gateway list_gateways","url":"aws_api/storage_gateway.html#list_gateways"},{"doc":"aws_api/storage_gateway","title":"list_local_disks","content":"pub fn list_local_disks(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.list_local_disks\naws_api/storage_gateway list_local_disks","url":"aws_api/storage_gateway.html#list_local_disks"},{"doc":"aws_api/storage_gateway","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.list_tags_for_resource\naws_api/storage_gateway list_tags_for_resource","url":"aws_api/storage_gateway.html#list_tags_for_resource"},{"doc":"aws_api/storage_gateway","title":"list_tape_pools","content":"pub fn list_tape_pools(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.list_tape_pools\naws_api/storage_gateway list_tape_pools","url":"aws_api/storage_gateway.html#list_tape_pools"},{"doc":"aws_api/storage_gateway","title":"list_tapes","content":"pub fn list_tapes(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.list_tapes\naws_api/storage_gateway list_tapes","url":"aws_api/storage_gateway.html#list_tapes"},{"doc":"aws_api/storage_gateway","title":"list_volume_initiators","content":"pub fn list_volume_initiators(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.list_volume_initiators\naws_api/storage_gateway list_volume_initiators","url":"aws_api/storage_gateway.html#list_volume_initiators"},{"doc":"aws_api/storage_gateway","title":"list_volume_recovery_points","content":"pub fn list_volume_recovery_points(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.list_volume_recovery_points\naws_api/storage_gateway list_volume_recovery_points","url":"aws_api/storage_gateway.html#list_volume_recovery_points"},{"doc":"aws_api/storage_gateway","title":"list_volumes","content":"pub fn list_volumes(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.list_volumes\naws_api/storage_gateway list_volumes","url":"aws_api/storage_gateway.html#list_volumes"},{"doc":"aws_api/storage_gateway","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/storage_gateway.new\naws_api/storage_gateway new","url":"aws_api/storage_gateway.html#new"},{"doc":"aws_api/storage_gateway","title":"notify_when_uploaded","content":"pub fn notify_when_uploaded(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.notify_when_uploaded\naws_api/storage_gateway notify_when_uploaded","url":"aws_api/storage_gateway.html#notify_when_uploaded"},{"doc":"aws_api/storage_gateway","title":"refresh_cache","content":"pub fn refresh_cache(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.refresh_cache\naws_api/storage_gateway refresh_cache","url":"aws_api/storage_gateway.html#refresh_cache"},{"doc":"aws_api/storage_gateway","title":"remove_tags_from_resource","content":"pub fn remove_tags_from_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.remove_tags_from_resource\naws_api/storage_gateway remove_tags_from_resource","url":"aws_api/storage_gateway.html#remove_tags_from_resource"},{"doc":"aws_api/storage_gateway","title":"reset_cache","content":"pub fn reset_cache(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.reset_cache\naws_api/storage_gateway reset_cache","url":"aws_api/storage_gateway.html#reset_cache"},{"doc":"aws_api/storage_gateway","title":"retrieve_tape_archive","content":"pub fn retrieve_tape_archive(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.retrieve_tape_archive\naws_api/storage_gateway retrieve_tape_archive","url":"aws_api/storage_gateway.html#retrieve_tape_archive"},{"doc":"aws_api/storage_gateway","title":"retrieve_tape_recovery_point","content":"pub fn retrieve_tape_recovery_point(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.retrieve_tape_recovery_point\naws_api/storage_gateway retrieve_tape_recovery_point","url":"aws_api/storage_gateway.html#retrieve_tape_recovery_point"},{"doc":"aws_api/storage_gateway","title":"set_local_console_password","content":"pub fn set_local_console_password(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.set_local_console_password\naws_api/storage_gateway set_local_console_password","url":"aws_api/storage_gateway.html#set_local_console_password"},{"doc":"aws_api/storage_gateway","title":"set_smb_guest_password","content":"pub fn set_smb_guest_password(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.set_smb_guest_password\naws_api/storage_gateway set_smb_guest_password","url":"aws_api/storage_gateway.html#set_smb_guest_password"},{"doc":"aws_api/storage_gateway","title":"shutdown_gateway","content":"pub fn shutdown_gateway(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.shutdown_gateway\naws_api/storage_gateway shutdown_gateway","url":"aws_api/storage_gateway.html#shutdown_gateway"},{"doc":"aws_api/storage_gateway","title":"start_availability_monitor_test","content":"pub fn start_availability_monitor_test(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.start_availability_monitor_test\naws_api/storage_gateway start_availability_monitor_test","url":"aws_api/storage_gateway.html#start_availability_monitor_test"},{"doc":"aws_api/storage_gateway","title":"start_gateway","content":"pub fn start_gateway(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.start_gateway\naws_api/storage_gateway start_gateway","url":"aws_api/storage_gateway.html#start_gateway"},{"doc":"aws_api/storage_gateway","title":"update_automatic_tape_creation_policy","content":"pub fn update_automatic_tape_creation_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.update_automatic_tape_creation_policy\naws_api/storage_gateway update_automatic_tape_creation_policy","url":"aws_api/storage_gateway.html#update_automatic_tape_creation_policy"},{"doc":"aws_api/storage_gateway","title":"update_bandwidth_rate_limit","content":"pub fn update_bandwidth_rate_limit(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.update_bandwidth_rate_limit\naws_api/storage_gateway update_bandwidth_rate_limit","url":"aws_api/storage_gateway.html#update_bandwidth_rate_limit"},{"doc":"aws_api/storage_gateway","title":"update_bandwidth_rate_limit_schedule","content":"pub fn update_bandwidth_rate_limit_schedule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.update_bandwidth_rate_limit_schedule\naws_api/storage_gateway update_bandwidth_rate_limit_schedule","url":"aws_api/storage_gateway.html#update_bandwidth_rate_limit_schedule"},{"doc":"aws_api/storage_gateway","title":"update_chap_credentials","content":"pub fn update_chap_credentials(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.update_chap_credentials\naws_api/storage_gateway update_chap_credentials","url":"aws_api/storage_gateway.html#update_chap_credentials"},{"doc":"aws_api/storage_gateway","title":"update_file_system_association","content":"pub fn update_file_system_association(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.update_file_system_association\naws_api/storage_gateway update_file_system_association","url":"aws_api/storage_gateway.html#update_file_system_association"},{"doc":"aws_api/storage_gateway","title":"update_gateway_information","content":"pub fn update_gateway_information(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.update_gateway_information\naws_api/storage_gateway update_gateway_information","url":"aws_api/storage_gateway.html#update_gateway_information"},{"doc":"aws_api/storage_gateway","title":"update_gateway_software_now","content":"pub fn update_gateway_software_now(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.update_gateway_software_now\naws_api/storage_gateway update_gateway_software_now","url":"aws_api/storage_gateway.html#update_gateway_software_now"},{"doc":"aws_api/storage_gateway","title":"update_maintenance_start_time","content":"pub fn update_maintenance_start_time(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.update_maintenance_start_time\naws_api/storage_gateway update_maintenance_start_time","url":"aws_api/storage_gateway.html#update_maintenance_start_time"},{"doc":"aws_api/storage_gateway","title":"update_nfs_file_share","content":"pub fn update_nfs_file_share(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.update_nfs_file_share\naws_api/storage_gateway update_nfs_file_share","url":"aws_api/storage_gateway.html#update_nfs_file_share"},{"doc":"aws_api/storage_gateway","title":"update_smb_file_share","content":"pub fn update_smb_file_share(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.update_smb_file_share\naws_api/storage_gateway update_smb_file_share","url":"aws_api/storage_gateway.html#update_smb_file_share"},{"doc":"aws_api/storage_gateway","title":"update_smb_file_share_visibility","content":"pub fn update_smb_file_share_visibility(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.update_smb_file_share_visibility\naws_api/storage_gateway update_smb_file_share_visibility","url":"aws_api/storage_gateway.html#update_smb_file_share_visibility"},{"doc":"aws_api/storage_gateway","title":"update_smb_local_groups","content":"pub fn update_smb_local_groups(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.update_smb_local_groups\naws_api/storage_gateway update_smb_local_groups","url":"aws_api/storage_gateway.html#update_smb_local_groups"},{"doc":"aws_api/storage_gateway","title":"update_smb_security_strategy","content":"pub fn update_smb_security_strategy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.update_smb_security_strategy\naws_api/storage_gateway update_smb_security_strategy","url":"aws_api/storage_gateway.html#update_smb_security_strategy"},{"doc":"aws_api/storage_gateway","title":"update_snapshot_schedule","content":"pub fn update_snapshot_schedule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.update_snapshot_schedule\naws_api/storage_gateway update_snapshot_schedule","url":"aws_api/storage_gateway.html#update_snapshot_schedule"},{"doc":"aws_api/storage_gateway","title":"update_vtl_device_type","content":"pub fn update_vtl_device_type(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/storage_gateway.update_vtl_device_type\naws_api/storage_gateway update_vtl_device_type","url":"aws_api/storage_gateway.html#update_vtl_device_type"},{"doc":"aws_api/storage_gateway","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/storage_gateway.with_custom_endpoint\naws_api/storage_gateway with_custom_endpoint","url":"aws_api/storage_gateway.html#with_custom_endpoint"},{"doc":"aws_api/storage_gateway","title":"aws_api/storage_gateway","content":"","url":"aws_api/storage_gateway.html"},{"doc":"aws_api/sts","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/sts.Client\naws_api/sts Client","url":"aws_api/sts.html#Client"},{"doc":"aws_api/sts","title":"assume_role","content":"pub fn assume_role(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sts.assume_role\naws_api/sts assume_role","url":"aws_api/sts.html#assume_role"},{"doc":"aws_api/sts","title":"assume_role_with_saml","content":"pub fn assume_role_with_saml(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sts.assume_role_with_saml\naws_api/sts assume_role_with_saml","url":"aws_api/sts.html#assume_role_with_saml"},{"doc":"aws_api/sts","title":"assume_role_with_web_identity","content":"pub fn assume_role_with_web_identity(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sts.assume_role_with_web_identity\naws_api/sts assume_role_with_web_identity","url":"aws_api/sts.html#assume_role_with_web_identity"},{"doc":"aws_api/sts","title":"decode_authorization_message","content":"pub fn decode_authorization_message(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sts.decode_authorization_message\naws_api/sts decode_authorization_message","url":"aws_api/sts.html#decode_authorization_message"},{"doc":"aws_api/sts","title":"get_access_key_info","content":"pub fn get_access_key_info(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sts.get_access_key_info\naws_api/sts get_access_key_info","url":"aws_api/sts.html#get_access_key_info"},{"doc":"aws_api/sts","title":"get_caller_identity","content":"pub fn get_caller_identity(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sts.get_caller_identity\naws_api/sts get_caller_identity","url":"aws_api/sts.html#get_caller_identity"},{"doc":"aws_api/sts","title":"get_federation_token","content":"pub fn get_federation_token(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sts.get_federation_token\naws_api/sts get_federation_token","url":"aws_api/sts.html#get_federation_token"},{"doc":"aws_api/sts","title":"get_session_token","content":"pub fn get_session_token(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/sts.get_session_token\naws_api/sts get_session_token","url":"aws_api/sts.html#get_session_token"},{"doc":"aws_api/sts","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/sts.new\naws_api/sts new","url":"aws_api/sts.html#new"},{"doc":"aws_api/sts","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/sts.with_custom_endpoint\naws_api/sts with_custom_endpoint","url":"aws_api/sts.html#with_custom_endpoint"},{"doc":"aws_api/sts","title":"aws_api/sts","content":"","url":"aws_api/sts.html"},{"doc":"aws_api/support","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/support.Client\naws_api/support Client","url":"aws_api/support.html#Client"},{"doc":"aws_api/support","title":"add_attachments_to_set","content":"pub fn add_attachments_to_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/support.add_attachments_to_set\naws_api/support add_attachments_to_set","url":"aws_api/support.html#add_attachments_to_set"},{"doc":"aws_api/support","title":"add_communication_to_case","content":"pub fn add_communication_to_case(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/support.add_communication_to_case\naws_api/support add_communication_to_case","url":"aws_api/support.html#add_communication_to_case"},{"doc":"aws_api/support","title":"create_case","content":"pub fn create_case(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/support.create_case\naws_api/support create_case","url":"aws_api/support.html#create_case"},{"doc":"aws_api/support","title":"describe_attachment","content":"pub fn describe_attachment(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/support.describe_attachment\naws_api/support describe_attachment","url":"aws_api/support.html#describe_attachment"},{"doc":"aws_api/support","title":"describe_cases","content":"pub fn describe_cases(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/support.describe_cases\naws_api/support describe_cases","url":"aws_api/support.html#describe_cases"},{"doc":"aws_api/support","title":"describe_communications","content":"pub fn describe_communications(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/support.describe_communications\naws_api/support describe_communications","url":"aws_api/support.html#describe_communications"},{"doc":"aws_api/support","title":"describe_create_case_options","content":"pub fn describe_create_case_options(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/support.describe_create_case_options\naws_api/support describe_create_case_options","url":"aws_api/support.html#describe_create_case_options"},{"doc":"aws_api/support","title":"describe_services","content":"pub fn describe_services(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/support.describe_services\naws_api/support describe_services","url":"aws_api/support.html#describe_services"},{"doc":"aws_api/support","title":"describe_severity_levels","content":"pub fn describe_severity_levels(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/support.describe_severity_levels\naws_api/support describe_severity_levels","url":"aws_api/support.html#describe_severity_levels"},{"doc":"aws_api/support","title":"describe_supported_languages","content":"pub fn describe_supported_languages(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/support.describe_supported_languages\naws_api/support describe_supported_languages","url":"aws_api/support.html#describe_supported_languages"},{"doc":"aws_api/support","title":"describe_trusted_advisor_check_refresh_statuses","content":"pub fn describe_trusted_advisor_check_refresh_statuses(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/support.describe_trusted_advisor_check_refresh_statuses\naws_api/support describe_trusted_advisor_check_refresh_statuses","url":"aws_api/support.html#describe_trusted_advisor_check_refresh_statuses"},{"doc":"aws_api/support","title":"describe_trusted_advisor_check_result","content":"pub fn describe_trusted_advisor_check_result(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/support.describe_trusted_advisor_check_result\naws_api/support describe_trusted_advisor_check_result","url":"aws_api/support.html#describe_trusted_advisor_check_result"},{"doc":"aws_api/support","title":"describe_trusted_advisor_check_summaries","content":"pub fn describe_trusted_advisor_check_summaries(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/support.describe_trusted_advisor_check_summaries\naws_api/support describe_trusted_advisor_check_summaries","url":"aws_api/support.html#describe_trusted_advisor_check_summaries"},{"doc":"aws_api/support","title":"describe_trusted_advisor_checks","content":"pub fn describe_trusted_advisor_checks(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/support.describe_trusted_advisor_checks\naws_api/support describe_trusted_advisor_checks","url":"aws_api/support.html#describe_trusted_advisor_checks"},{"doc":"aws_api/support","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/support.new\naws_api/support new","url":"aws_api/support.html#new"},{"doc":"aws_api/support","title":"refresh_trusted_advisor_check","content":"pub fn refresh_trusted_advisor_check(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/support.refresh_trusted_advisor_check\naws_api/support refresh_trusted_advisor_check","url":"aws_api/support.html#refresh_trusted_advisor_check"},{"doc":"aws_api/support","title":"resolve_case","content":"pub fn resolve_case(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/support.resolve_case\naws_api/support resolve_case","url":"aws_api/support.html#resolve_case"},{"doc":"aws_api/support","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/support.with_custom_endpoint\naws_api/support with_custom_endpoint","url":"aws_api/support.html#with_custom_endpoint"},{"doc":"aws_api/support","title":"aws_api/support","content":"","url":"aws_api/support.html"},{"doc":"aws_api/support_app","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/support_app.Client\naws_api/support_app Client","url":"aws_api/support_app.html#Client"},{"doc":"aws_api/support_app","title":"create_slack_channel_configuration","content":"pub fn create_slack_channel_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/support_app.create_slack_channel_configuration\naws_api/support_app create_slack_channel_configuration","url":"aws_api/support_app.html#create_slack_channel_configuration"},{"doc":"aws_api/support_app","title":"delete_account_alias","content":"pub fn delete_account_alias(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/support_app.delete_account_alias\naws_api/support_app delete_account_alias","url":"aws_api/support_app.html#delete_account_alias"},{"doc":"aws_api/support_app","title":"delete_slack_channel_configuration","content":"pub fn delete_slack_channel_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/support_app.delete_slack_channel_configuration\naws_api/support_app delete_slack_channel_configuration","url":"aws_api/support_app.html#delete_slack_channel_configuration"},{"doc":"aws_api/support_app","title":"delete_slack_workspace_configuration","content":"pub fn delete_slack_workspace_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/support_app.delete_slack_workspace_configuration\naws_api/support_app delete_slack_workspace_configuration","url":"aws_api/support_app.html#delete_slack_workspace_configuration"},{"doc":"aws_api/support_app","title":"get_account_alias","content":"pub fn get_account_alias(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/support_app.get_account_alias\naws_api/support_app get_account_alias","url":"aws_api/support_app.html#get_account_alias"},{"doc":"aws_api/support_app","title":"list_slack_channel_configurations","content":"pub fn list_slack_channel_configurations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/support_app.list_slack_channel_configurations\naws_api/support_app list_slack_channel_configurations","url":"aws_api/support_app.html#list_slack_channel_configurations"},{"doc":"aws_api/support_app","title":"list_slack_workspace_configurations","content":"pub fn list_slack_workspace_configurations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/support_app.list_slack_workspace_configurations\naws_api/support_app list_slack_workspace_configurations","url":"aws_api/support_app.html#list_slack_workspace_configurations"},{"doc":"aws_api/support_app","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/support_app.new\naws_api/support_app new","url":"aws_api/support_app.html#new"},{"doc":"aws_api/support_app","title":"put_account_alias","content":"pub fn put_account_alias(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/support_app.put_account_alias\naws_api/support_app put_account_alias","url":"aws_api/support_app.html#put_account_alias"},{"doc":"aws_api/support_app","title":"register_slack_workspace_for_organization","content":"pub fn register_slack_workspace_for_organization(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/support_app.register_slack_workspace_for_organization\naws_api/support_app register_slack_workspace_for_organization","url":"aws_api/support_app.html#register_slack_workspace_for_organization"},{"doc":"aws_api/support_app","title":"update_slack_channel_configuration","content":"pub fn update_slack_channel_configuration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/support_app.update_slack_channel_configuration\naws_api/support_app update_slack_channel_configuration","url":"aws_api/support_app.html#update_slack_channel_configuration"},{"doc":"aws_api/support_app","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/support_app.with_custom_endpoint\naws_api/support_app with_custom_endpoint","url":"aws_api/support_app.html#with_custom_endpoint"},{"doc":"aws_api/support_app","title":"aws_api/support_app","content":"","url":"aws_api/support_app.html"},{"doc":"aws_api/swf","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/swf.Client\naws_api/swf Client","url":"aws_api/swf.html#Client"},{"doc":"aws_api/swf","title":"count_closed_workflow_executions","content":"pub fn count_closed_workflow_executions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/swf.count_closed_workflow_executions\naws_api/swf count_closed_workflow_executions","url":"aws_api/swf.html#count_closed_workflow_executions"},{"doc":"aws_api/swf","title":"count_open_workflow_executions","content":"pub fn count_open_workflow_executions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/swf.count_open_workflow_executions\naws_api/swf count_open_workflow_executions","url":"aws_api/swf.html#count_open_workflow_executions"},{"doc":"aws_api/swf","title":"count_pending_activity_tasks","content":"pub fn count_pending_activity_tasks(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/swf.count_pending_activity_tasks\naws_api/swf count_pending_activity_tasks","url":"aws_api/swf.html#count_pending_activity_tasks"},{"doc":"aws_api/swf","title":"count_pending_decision_tasks","content":"pub fn count_pending_decision_tasks(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/swf.count_pending_decision_tasks\naws_api/swf count_pending_decision_tasks","url":"aws_api/swf.html#count_pending_decision_tasks"},{"doc":"aws_api/swf","title":"delete_activity_type","content":"pub fn delete_activity_type(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/swf.delete_activity_type\naws_api/swf delete_activity_type","url":"aws_api/swf.html#delete_activity_type"},{"doc":"aws_api/swf","title":"delete_workflow_type","content":"pub fn delete_workflow_type(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/swf.delete_workflow_type\naws_api/swf delete_workflow_type","url":"aws_api/swf.html#delete_workflow_type"},{"doc":"aws_api/swf","title":"deprecate_activity_type","content":"pub fn deprecate_activity_type(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/swf.deprecate_activity_type\naws_api/swf deprecate_activity_type","url":"aws_api/swf.html#deprecate_activity_type"},{"doc":"aws_api/swf","title":"deprecate_domain","content":"pub fn deprecate_domain(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/swf.deprecate_domain\naws_api/swf deprecate_domain","url":"aws_api/swf.html#deprecate_domain"},{"doc":"aws_api/swf","title":"deprecate_workflow_type","content":"pub fn deprecate_workflow_type(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/swf.deprecate_workflow_type\naws_api/swf deprecate_workflow_type","url":"aws_api/swf.html#deprecate_workflow_type"},{"doc":"aws_api/swf","title":"describe_activity_type","content":"pub fn describe_activity_type(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/swf.describe_activity_type\naws_api/swf describe_activity_type","url":"aws_api/swf.html#describe_activity_type"},{"doc":"aws_api/swf","title":"describe_domain","content":"pub fn describe_domain(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/swf.describe_domain\naws_api/swf describe_domain","url":"aws_api/swf.html#describe_domain"},{"doc":"aws_api/swf","title":"describe_workflow_execution","content":"pub fn describe_workflow_execution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/swf.describe_workflow_execution\naws_api/swf describe_workflow_execution","url":"aws_api/swf.html#describe_workflow_execution"},{"doc":"aws_api/swf","title":"describe_workflow_type","content":"pub fn describe_workflow_type(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/swf.describe_workflow_type\naws_api/swf describe_workflow_type","url":"aws_api/swf.html#describe_workflow_type"},{"doc":"aws_api/swf","title":"get_workflow_execution_history","content":"pub fn get_workflow_execution_history(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/swf.get_workflow_execution_history\naws_api/swf get_workflow_execution_history","url":"aws_api/swf.html#get_workflow_execution_history"},{"doc":"aws_api/swf","title":"list_activity_types","content":"pub fn list_activity_types(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/swf.list_activity_types\naws_api/swf list_activity_types","url":"aws_api/swf.html#list_activity_types"},{"doc":"aws_api/swf","title":"list_closed_workflow_executions","content":"pub fn list_closed_workflow_executions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/swf.list_closed_workflow_executions\naws_api/swf list_closed_workflow_executions","url":"aws_api/swf.html#list_closed_workflow_executions"},{"doc":"aws_api/swf","title":"list_domains","content":"pub fn list_domains(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/swf.list_domains\naws_api/swf list_domains","url":"aws_api/swf.html#list_domains"},{"doc":"aws_api/swf","title":"list_open_workflow_executions","content":"pub fn list_open_workflow_executions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/swf.list_open_workflow_executions\naws_api/swf list_open_workflow_executions","url":"aws_api/swf.html#list_open_workflow_executions"},{"doc":"aws_api/swf","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/swf.list_tags_for_resource\naws_api/swf list_tags_for_resource","url":"aws_api/swf.html#list_tags_for_resource"},{"doc":"aws_api/swf","title":"list_workflow_types","content":"pub fn list_workflow_types(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/swf.list_workflow_types\naws_api/swf list_workflow_types","url":"aws_api/swf.html#list_workflow_types"},{"doc":"aws_api/swf","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/swf.new\naws_api/swf new","url":"aws_api/swf.html#new"},{"doc":"aws_api/swf","title":"poll_for_activity_task","content":"pub fn poll_for_activity_task(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/swf.poll_for_activity_task\naws_api/swf poll_for_activity_task","url":"aws_api/swf.html#poll_for_activity_task"},{"doc":"aws_api/swf","title":"poll_for_decision_task","content":"pub fn poll_for_decision_task(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/swf.poll_for_decision_task\naws_api/swf poll_for_decision_task","url":"aws_api/swf.html#poll_for_decision_task"},{"doc":"aws_api/swf","title":"record_activity_task_heartbeat","content":"pub fn record_activity_task_heartbeat(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/swf.record_activity_task_heartbeat\naws_api/swf record_activity_task_heartbeat","url":"aws_api/swf.html#record_activity_task_heartbeat"},{"doc":"aws_api/swf","title":"register_activity_type","content":"pub fn register_activity_type(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/swf.register_activity_type\naws_api/swf register_activity_type","url":"aws_api/swf.html#register_activity_type"},{"doc":"aws_api/swf","title":"register_domain","content":"pub fn register_domain(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/swf.register_domain\naws_api/swf register_domain","url":"aws_api/swf.html#register_domain"},{"doc":"aws_api/swf","title":"register_workflow_type","content":"pub fn register_workflow_type(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/swf.register_workflow_type\naws_api/swf register_workflow_type","url":"aws_api/swf.html#register_workflow_type"},{"doc":"aws_api/swf","title":"request_cancel_workflow_execution","content":"pub fn request_cancel_workflow_execution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/swf.request_cancel_workflow_execution\naws_api/swf request_cancel_workflow_execution","url":"aws_api/swf.html#request_cancel_workflow_execution"},{"doc":"aws_api/swf","title":"respond_activity_task_canceled","content":"pub fn respond_activity_task_canceled(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/swf.respond_activity_task_canceled\naws_api/swf respond_activity_task_canceled","url":"aws_api/swf.html#respond_activity_task_canceled"},{"doc":"aws_api/swf","title":"respond_activity_task_completed","content":"pub fn respond_activity_task_completed(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/swf.respond_activity_task_completed\naws_api/swf respond_activity_task_completed","url":"aws_api/swf.html#respond_activity_task_completed"},{"doc":"aws_api/swf","title":"respond_activity_task_failed","content":"pub fn respond_activity_task_failed(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/swf.respond_activity_task_failed\naws_api/swf respond_activity_task_failed","url":"aws_api/swf.html#respond_activity_task_failed"},{"doc":"aws_api/swf","title":"respond_decision_task_completed","content":"pub fn respond_decision_task_completed(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/swf.respond_decision_task_completed\naws_api/swf respond_decision_task_completed","url":"aws_api/swf.html#respond_decision_task_completed"},{"doc":"aws_api/swf","title":"signal_workflow_execution","content":"pub fn signal_workflow_execution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/swf.signal_workflow_execution\naws_api/swf signal_workflow_execution","url":"aws_api/swf.html#signal_workflow_execution"},{"doc":"aws_api/swf","title":"start_workflow_execution","content":"pub fn start_workflow_execution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/swf.start_workflow_execution\naws_api/swf start_workflow_execution","url":"aws_api/swf.html#start_workflow_execution"},{"doc":"aws_api/swf","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/swf.tag_resource\naws_api/swf tag_resource","url":"aws_api/swf.html#tag_resource"},{"doc":"aws_api/swf","title":"terminate_workflow_execution","content":"pub fn terminate_workflow_execution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/swf.terminate_workflow_execution\naws_api/swf terminate_workflow_execution","url":"aws_api/swf.html#terminate_workflow_execution"},{"doc":"aws_api/swf","title":"undeprecate_activity_type","content":"pub fn undeprecate_activity_type(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/swf.undeprecate_activity_type\naws_api/swf undeprecate_activity_type","url":"aws_api/swf.html#undeprecate_activity_type"},{"doc":"aws_api/swf","title":"undeprecate_domain","content":"pub fn undeprecate_domain(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/swf.undeprecate_domain\naws_api/swf undeprecate_domain","url":"aws_api/swf.html#undeprecate_domain"},{"doc":"aws_api/swf","title":"undeprecate_workflow_type","content":"pub fn undeprecate_workflow_type(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/swf.undeprecate_workflow_type\naws_api/swf undeprecate_workflow_type","url":"aws_api/swf.html#undeprecate_workflow_type"},{"doc":"aws_api/swf","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/swf.untag_resource\naws_api/swf untag_resource","url":"aws_api/swf.html#untag_resource"},{"doc":"aws_api/swf","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/swf.with_custom_endpoint\naws_api/swf with_custom_endpoint","url":"aws_api/swf.html#with_custom_endpoint"},{"doc":"aws_api/swf","title":"aws_api/swf","content":"","url":"aws_api/swf.html"},{"doc":"aws_api/synthetics","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/synthetics.Client\naws_api/synthetics Client","url":"aws_api/synthetics.html#Client"},{"doc":"aws_api/synthetics","title":"associate_resource","content":"pub fn associate_resource(\n  client: Client,\n  group_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/synthetics.associate_resource\naws_api/synthetics associate_resource","url":"aws_api/synthetics.html#associate_resource"},{"doc":"aws_api/synthetics","title":"create_canary","content":"pub fn create_canary(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/synthetics.create_canary\naws_api/synthetics create_canary","url":"aws_api/synthetics.html#create_canary"},{"doc":"aws_api/synthetics","title":"create_group","content":"pub fn create_group(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/synthetics.create_group\naws_api/synthetics create_group","url":"aws_api/synthetics.html#create_group"},{"doc":"aws_api/synthetics","title":"delete_canary","content":"pub fn delete_canary(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/synthetics.delete_canary\naws_api/synthetics delete_canary","url":"aws_api/synthetics.html#delete_canary"},{"doc":"aws_api/synthetics","title":"delete_group","content":"pub fn delete_group(\n  client: Client,\n  group_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/synthetics.delete_group\naws_api/synthetics delete_group","url":"aws_api/synthetics.html#delete_group"},{"doc":"aws_api/synthetics","title":"describe_canaries","content":"pub fn describe_canaries(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/synthetics.describe_canaries\naws_api/synthetics describe_canaries","url":"aws_api/synthetics.html#describe_canaries"},{"doc":"aws_api/synthetics","title":"describe_canaries_last_run","content":"pub fn describe_canaries_last_run(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/synthetics.describe_canaries_last_run\naws_api/synthetics describe_canaries_last_run","url":"aws_api/synthetics.html#describe_canaries_last_run"},{"doc":"aws_api/synthetics","title":"describe_runtime_versions","content":"pub fn describe_runtime_versions(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/synthetics.describe_runtime_versions\naws_api/synthetics describe_runtime_versions","url":"aws_api/synthetics.html#describe_runtime_versions"},{"doc":"aws_api/synthetics","title":"disassociate_resource","content":"pub fn disassociate_resource(\n  client: Client,\n  group_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/synthetics.disassociate_resource\naws_api/synthetics disassociate_resource","url":"aws_api/synthetics.html#disassociate_resource"},{"doc":"aws_api/synthetics","title":"get_canary","content":"pub fn get_canary(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/synthetics.get_canary\naws_api/synthetics get_canary","url":"aws_api/synthetics.html#get_canary"},{"doc":"aws_api/synthetics","title":"get_canary_runs","content":"pub fn get_canary_runs(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/synthetics.get_canary_runs\naws_api/synthetics get_canary_runs","url":"aws_api/synthetics.html#get_canary_runs"},{"doc":"aws_api/synthetics","title":"get_group","content":"pub fn get_group(\n  client: Client,\n  group_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/synthetics.get_group\naws_api/synthetics get_group","url":"aws_api/synthetics.html#get_group"},{"doc":"aws_api/synthetics","title":"list_associated_groups","content":"pub fn list_associated_groups(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/synthetics.list_associated_groups\naws_api/synthetics list_associated_groups","url":"aws_api/synthetics.html#list_associated_groups"},{"doc":"aws_api/synthetics","title":"list_group_resources","content":"pub fn list_group_resources(\n  client: Client,\n  group_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/synthetics.list_group_resources\naws_api/synthetics list_group_resources","url":"aws_api/synthetics.html#list_group_resources"},{"doc":"aws_api/synthetics","title":"list_groups","content":"pub fn list_groups(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/synthetics.list_groups\naws_api/synthetics list_groups","url":"aws_api/synthetics.html#list_groups"},{"doc":"aws_api/synthetics","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/synthetics.list_tags_for_resource\naws_api/synthetics list_tags_for_resource","url":"aws_api/synthetics.html#list_tags_for_resource"},{"doc":"aws_api/synthetics","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/synthetics.new\naws_api/synthetics new","url":"aws_api/synthetics.html#new"},{"doc":"aws_api/synthetics","title":"start_canary","content":"pub fn start_canary(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/synthetics.start_canary\naws_api/synthetics start_canary","url":"aws_api/synthetics.html#start_canary"},{"doc":"aws_api/synthetics","title":"stop_canary","content":"pub fn stop_canary(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/synthetics.stop_canary\naws_api/synthetics stop_canary","url":"aws_api/synthetics.html#stop_canary"},{"doc":"aws_api/synthetics","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/synthetics.tag_resource\naws_api/synthetics tag_resource","url":"aws_api/synthetics.html#tag_resource"},{"doc":"aws_api/synthetics","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/synthetics.untag_resource\naws_api/synthetics untag_resource","url":"aws_api/synthetics.html#untag_resource"},{"doc":"aws_api/synthetics","title":"update_canary","content":"pub fn update_canary(\n  client: Client,\n  name: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/synthetics.update_canary\naws_api/synthetics update_canary","url":"aws_api/synthetics.html#update_canary"},{"doc":"aws_api/synthetics","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/synthetics.with_custom_endpoint\naws_api/synthetics with_custom_endpoint","url":"aws_api/synthetics.html#with_custom_endpoint"},{"doc":"aws_api/synthetics","title":"aws_api/synthetics","content":"","url":"aws_api/synthetics.html"},{"doc":"aws_api/taxsettings","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/taxsettings.Client\naws_api/taxsettings Client","url":"aws_api/taxsettings.html#Client"},{"doc":"aws_api/taxsettings","title":"batch_delete_tax_registration","content":"pub fn batch_delete_tax_registration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/taxsettings.batch_delete_tax_registration\naws_api/taxsettings batch_delete_tax_registration","url":"aws_api/taxsettings.html#batch_delete_tax_registration"},{"doc":"aws_api/taxsettings","title":"batch_put_tax_registration","content":"pub fn batch_put_tax_registration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/taxsettings.batch_put_tax_registration\naws_api/taxsettings batch_put_tax_registration","url":"aws_api/taxsettings.html#batch_put_tax_registration"},{"doc":"aws_api/taxsettings","title":"delete_tax_registration","content":"pub fn delete_tax_registration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/taxsettings.delete_tax_registration\naws_api/taxsettings delete_tax_registration","url":"aws_api/taxsettings.html#delete_tax_registration"},{"doc":"aws_api/taxsettings","title":"get_tax_registration","content":"pub fn get_tax_registration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/taxsettings.get_tax_registration\naws_api/taxsettings get_tax_registration","url":"aws_api/taxsettings.html#get_tax_registration"},{"doc":"aws_api/taxsettings","title":"get_tax_registration_document","content":"pub fn get_tax_registration_document(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/taxsettings.get_tax_registration_document\naws_api/taxsettings get_tax_registration_document","url":"aws_api/taxsettings.html#get_tax_registration_document"},{"doc":"aws_api/taxsettings","title":"list_tax_registrations","content":"pub fn list_tax_registrations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/taxsettings.list_tax_registrations\naws_api/taxsettings list_tax_registrations","url":"aws_api/taxsettings.html#list_tax_registrations"},{"doc":"aws_api/taxsettings","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/taxsettings.new\naws_api/taxsettings new","url":"aws_api/taxsettings.html#new"},{"doc":"aws_api/taxsettings","title":"put_tax_registration","content":"pub fn put_tax_registration(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/taxsettings.put_tax_registration\naws_api/taxsettings put_tax_registration","url":"aws_api/taxsettings.html#put_tax_registration"},{"doc":"aws_api/taxsettings","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/taxsettings.with_custom_endpoint\naws_api/taxsettings with_custom_endpoint","url":"aws_api/taxsettings.html#with_custom_endpoint"},{"doc":"aws_api/taxsettings","title":"aws_api/taxsettings","content":"","url":"aws_api/taxsettings.html"},{"doc":"aws_api/textract","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/textract.Client\naws_api/textract Client","url":"aws_api/textract.html#Client"},{"doc":"aws_api/textract","title":"analyze_document","content":"pub fn analyze_document(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/textract.analyze_document\naws_api/textract analyze_document","url":"aws_api/textract.html#analyze_document"},{"doc":"aws_api/textract","title":"analyze_expense","content":"pub fn analyze_expense(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/textract.analyze_expense\naws_api/textract analyze_expense","url":"aws_api/textract.html#analyze_expense"},{"doc":"aws_api/textract","title":"analyze_id","content":"pub fn analyze_id(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/textract.analyze_id\naws_api/textract analyze_id","url":"aws_api/textract.html#analyze_id"},{"doc":"aws_api/textract","title":"create_adapter","content":"pub fn create_adapter(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/textract.create_adapter\naws_api/textract create_adapter","url":"aws_api/textract.html#create_adapter"},{"doc":"aws_api/textract","title":"create_adapter_version","content":"pub fn create_adapter_version(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/textract.create_adapter_version\naws_api/textract create_adapter_version","url":"aws_api/textract.html#create_adapter_version"},{"doc":"aws_api/textract","title":"delete_adapter","content":"pub fn delete_adapter(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/textract.delete_adapter\naws_api/textract delete_adapter","url":"aws_api/textract.html#delete_adapter"},{"doc":"aws_api/textract","title":"delete_adapter_version","content":"pub fn delete_adapter_version(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/textract.delete_adapter_version\naws_api/textract delete_adapter_version","url":"aws_api/textract.html#delete_adapter_version"},{"doc":"aws_api/textract","title":"detect_document_text","content":"pub fn detect_document_text(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/textract.detect_document_text\naws_api/textract detect_document_text","url":"aws_api/textract.html#detect_document_text"},{"doc":"aws_api/textract","title":"get_adapter","content":"pub fn get_adapter(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/textract.get_adapter\naws_api/textract get_adapter","url":"aws_api/textract.html#get_adapter"},{"doc":"aws_api/textract","title":"get_adapter_version","content":"pub fn get_adapter_version(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/textract.get_adapter_version\naws_api/textract get_adapter_version","url":"aws_api/textract.html#get_adapter_version"},{"doc":"aws_api/textract","title":"get_document_analysis","content":"pub fn get_document_analysis(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/textract.get_document_analysis\naws_api/textract get_document_analysis","url":"aws_api/textract.html#get_document_analysis"},{"doc":"aws_api/textract","title":"get_document_text_detection","content":"pub fn get_document_text_detection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/textract.get_document_text_detection\naws_api/textract get_document_text_detection","url":"aws_api/textract.html#get_document_text_detection"},{"doc":"aws_api/textract","title":"get_expense_analysis","content":"pub fn get_expense_analysis(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/textract.get_expense_analysis\naws_api/textract get_expense_analysis","url":"aws_api/textract.html#get_expense_analysis"},{"doc":"aws_api/textract","title":"get_lending_analysis","content":"pub fn get_lending_analysis(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/textract.get_lending_analysis\naws_api/textract get_lending_analysis","url":"aws_api/textract.html#get_lending_analysis"},{"doc":"aws_api/textract","title":"get_lending_analysis_summary","content":"pub fn get_lending_analysis_summary(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/textract.get_lending_analysis_summary\naws_api/textract get_lending_analysis_summary","url":"aws_api/textract.html#get_lending_analysis_summary"},{"doc":"aws_api/textract","title":"list_adapter_versions","content":"pub fn list_adapter_versions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/textract.list_adapter_versions\naws_api/textract list_adapter_versions","url":"aws_api/textract.html#list_adapter_versions"},{"doc":"aws_api/textract","title":"list_adapters","content":"pub fn list_adapters(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/textract.list_adapters\naws_api/textract list_adapters","url":"aws_api/textract.html#list_adapters"},{"doc":"aws_api/textract","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/textract.list_tags_for_resource\naws_api/textract list_tags_for_resource","url":"aws_api/textract.html#list_tags_for_resource"},{"doc":"aws_api/textract","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/textract.new\naws_api/textract new","url":"aws_api/textract.html#new"},{"doc":"aws_api/textract","title":"start_document_analysis","content":"pub fn start_document_analysis(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/textract.start_document_analysis\naws_api/textract start_document_analysis","url":"aws_api/textract.html#start_document_analysis"},{"doc":"aws_api/textract","title":"start_document_text_detection","content":"pub fn start_document_text_detection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/textract.start_document_text_detection\naws_api/textract start_document_text_detection","url":"aws_api/textract.html#start_document_text_detection"},{"doc":"aws_api/textract","title":"start_expense_analysis","content":"pub fn start_expense_analysis(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/textract.start_expense_analysis\naws_api/textract start_expense_analysis","url":"aws_api/textract.html#start_expense_analysis"},{"doc":"aws_api/textract","title":"start_lending_analysis","content":"pub fn start_lending_analysis(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/textract.start_lending_analysis\naws_api/textract start_lending_analysis","url":"aws_api/textract.html#start_lending_analysis"},{"doc":"aws_api/textract","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/textract.tag_resource\naws_api/textract tag_resource","url":"aws_api/textract.html#tag_resource"},{"doc":"aws_api/textract","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/textract.untag_resource\naws_api/textract untag_resource","url":"aws_api/textract.html#untag_resource"},{"doc":"aws_api/textract","title":"update_adapter","content":"pub fn update_adapter(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/textract.update_adapter\naws_api/textract update_adapter","url":"aws_api/textract.html#update_adapter"},{"doc":"aws_api/textract","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/textract.with_custom_endpoint\naws_api/textract with_custom_endpoint","url":"aws_api/textract.html#with_custom_endpoint"},{"doc":"aws_api/textract","title":"aws_api/textract","content":"","url":"aws_api/textract.html"},{"doc":"aws_api/timestream_write","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/timestream_write.Client\naws_api/timestream_write Client","url":"aws_api/timestream_write.html#Client"},{"doc":"aws_api/timestream_write","title":"create_batch_load_task","content":"pub fn create_batch_load_task(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/timestream_write.create_batch_load_task\naws_api/timestream_write create_batch_load_task","url":"aws_api/timestream_write.html#create_batch_load_task"},{"doc":"aws_api/timestream_write","title":"create_database","content":"pub fn create_database(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/timestream_write.create_database\naws_api/timestream_write create_database","url":"aws_api/timestream_write.html#create_database"},{"doc":"aws_api/timestream_write","title":"create_table","content":"pub fn create_table(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/timestream_write.create_table\naws_api/timestream_write create_table","url":"aws_api/timestream_write.html#create_table"},{"doc":"aws_api/timestream_write","title":"delete_database","content":"pub fn delete_database(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/timestream_write.delete_database\naws_api/timestream_write delete_database","url":"aws_api/timestream_write.html#delete_database"},{"doc":"aws_api/timestream_write","title":"delete_table","content":"pub fn delete_table(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/timestream_write.delete_table\naws_api/timestream_write delete_table","url":"aws_api/timestream_write.html#delete_table"},{"doc":"aws_api/timestream_write","title":"describe_batch_load_task","content":"pub fn describe_batch_load_task(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/timestream_write.describe_batch_load_task\naws_api/timestream_write describe_batch_load_task","url":"aws_api/timestream_write.html#describe_batch_load_task"},{"doc":"aws_api/timestream_write","title":"describe_database","content":"pub fn describe_database(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/timestream_write.describe_database\naws_api/timestream_write describe_database","url":"aws_api/timestream_write.html#describe_database"},{"doc":"aws_api/timestream_write","title":"describe_endpoints","content":"pub fn describe_endpoints(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/timestream_write.describe_endpoints\naws_api/timestream_write describe_endpoints","url":"aws_api/timestream_write.html#describe_endpoints"},{"doc":"aws_api/timestream_write","title":"describe_table","content":"pub fn describe_table(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/timestream_write.describe_table\naws_api/timestream_write describe_table","url":"aws_api/timestream_write.html#describe_table"},{"doc":"aws_api/timestream_write","title":"list_batch_load_tasks","content":"pub fn list_batch_load_tasks(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/timestream_write.list_batch_load_tasks\naws_api/timestream_write list_batch_load_tasks","url":"aws_api/timestream_write.html#list_batch_load_tasks"},{"doc":"aws_api/timestream_write","title":"list_databases","content":"pub fn list_databases(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/timestream_write.list_databases\naws_api/timestream_write list_databases","url":"aws_api/timestream_write.html#list_databases"},{"doc":"aws_api/timestream_write","title":"list_tables","content":"pub fn list_tables(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/timestream_write.list_tables\naws_api/timestream_write list_tables","url":"aws_api/timestream_write.html#list_tables"},{"doc":"aws_api/timestream_write","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/timestream_write.list_tags_for_resource\naws_api/timestream_write list_tags_for_resource","url":"aws_api/timestream_write.html#list_tags_for_resource"},{"doc":"aws_api/timestream_write","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/timestream_write.new\naws_api/timestream_write new","url":"aws_api/timestream_write.html#new"},{"doc":"aws_api/timestream_write","title":"resume_batch_load_task","content":"pub fn resume_batch_load_task(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/timestream_write.resume_batch_load_task\naws_api/timestream_write resume_batch_load_task","url":"aws_api/timestream_write.html#resume_batch_load_task"},{"doc":"aws_api/timestream_write","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/timestream_write.tag_resource\naws_api/timestream_write tag_resource","url":"aws_api/timestream_write.html#tag_resource"},{"doc":"aws_api/timestream_write","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/timestream_write.untag_resource\naws_api/timestream_write untag_resource","url":"aws_api/timestream_write.html#untag_resource"},{"doc":"aws_api/timestream_write","title":"update_database","content":"pub fn update_database(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/timestream_write.update_database\naws_api/timestream_write update_database","url":"aws_api/timestream_write.html#update_database"},{"doc":"aws_api/timestream_write","title":"update_table","content":"pub fn update_table(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/timestream_write.update_table\naws_api/timestream_write update_table","url":"aws_api/timestream_write.html#update_table"},{"doc":"aws_api/timestream_write","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/timestream_write.with_custom_endpoint\naws_api/timestream_write with_custom_endpoint","url":"aws_api/timestream_write.html#with_custom_endpoint"},{"doc":"aws_api/timestream_write","title":"write_records","content":"pub fn write_records(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/timestream_write.write_records\naws_api/timestream_write write_records","url":"aws_api/timestream_write.html#write_records"},{"doc":"aws_api/timestream_write","title":"aws_api/timestream_write","content":"","url":"aws_api/timestream_write.html"},{"doc":"aws_api/tnb","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/tnb.Client\naws_api/tnb Client","url":"aws_api/tnb.html#Client"},{"doc":"aws_api/tnb","title":"cancel_sol_network_operation","content":"pub fn cancel_sol_network_operation(\n  client: Client,\n  ns_lcm_op_occ_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/tnb.cancel_sol_network_operation\naws_api/tnb cancel_sol_network_operation","url":"aws_api/tnb.html#cancel_sol_network_operation"},{"doc":"aws_api/tnb","title":"create_sol_function_package","content":"pub fn create_sol_function_package(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/tnb.create_sol_function_package\naws_api/tnb create_sol_function_package","url":"aws_api/tnb.html#create_sol_function_package"},{"doc":"aws_api/tnb","title":"create_sol_network_instance","content":"pub fn create_sol_network_instance(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/tnb.create_sol_network_instance\naws_api/tnb create_sol_network_instance","url":"aws_api/tnb.html#create_sol_network_instance"},{"doc":"aws_api/tnb","title":"create_sol_network_package","content":"pub fn create_sol_network_package(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/tnb.create_sol_network_package\naws_api/tnb create_sol_network_package","url":"aws_api/tnb.html#create_sol_network_package"},{"doc":"aws_api/tnb","title":"delete_sol_function_package","content":"pub fn delete_sol_function_package(\n  client: Client,\n  vnf_pkg_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/tnb.delete_sol_function_package\naws_api/tnb delete_sol_function_package","url":"aws_api/tnb.html#delete_sol_function_package"},{"doc":"aws_api/tnb","title":"delete_sol_network_instance","content":"pub fn delete_sol_network_instance(\n  client: Client,\n  ns_instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/tnb.delete_sol_network_instance\naws_api/tnb delete_sol_network_instance","url":"aws_api/tnb.html#delete_sol_network_instance"},{"doc":"aws_api/tnb","title":"delete_sol_network_package","content":"pub fn delete_sol_network_package(\n  client: Client,\n  nsd_info_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/tnb.delete_sol_network_package\naws_api/tnb delete_sol_network_package","url":"aws_api/tnb.html#delete_sol_network_package"},{"doc":"aws_api/tnb","title":"get_sol_function_instance","content":"pub fn get_sol_function_instance(\n  client: Client,\n  vnf_instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/tnb.get_sol_function_instance\naws_api/tnb get_sol_function_instance","url":"aws_api/tnb.html#get_sol_function_instance"},{"doc":"aws_api/tnb","title":"get_sol_function_package","content":"pub fn get_sol_function_package(\n  client: Client,\n  vnf_pkg_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/tnb.get_sol_function_package\naws_api/tnb get_sol_function_package","url":"aws_api/tnb.html#get_sol_function_package"},{"doc":"aws_api/tnb","title":"get_sol_function_package_content","content":"pub fn get_sol_function_package_content(\n  client: Client,\n  vnf_pkg_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/tnb.get_sol_function_package_content\naws_api/tnb get_sol_function_package_content","url":"aws_api/tnb.html#get_sol_function_package_content"},{"doc":"aws_api/tnb","title":"get_sol_function_package_descriptor","content":"pub fn get_sol_function_package_descriptor(\n  client: Client,\n  vnf_pkg_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/tnb.get_sol_function_package_descriptor\naws_api/tnb get_sol_function_package_descriptor","url":"aws_api/tnb.html#get_sol_function_package_descriptor"},{"doc":"aws_api/tnb","title":"get_sol_network_instance","content":"pub fn get_sol_network_instance(\n  client: Client,\n  ns_instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/tnb.get_sol_network_instance\naws_api/tnb get_sol_network_instance","url":"aws_api/tnb.html#get_sol_network_instance"},{"doc":"aws_api/tnb","title":"get_sol_network_operation","content":"pub fn get_sol_network_operation(\n  client: Client,\n  ns_lcm_op_occ_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/tnb.get_sol_network_operation\naws_api/tnb get_sol_network_operation","url":"aws_api/tnb.html#get_sol_network_operation"},{"doc":"aws_api/tnb","title":"get_sol_network_package","content":"pub fn get_sol_network_package(\n  client: Client,\n  nsd_info_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/tnb.get_sol_network_package\naws_api/tnb get_sol_network_package","url":"aws_api/tnb.html#get_sol_network_package"},{"doc":"aws_api/tnb","title":"get_sol_network_package_content","content":"pub fn get_sol_network_package_content(\n  client: Client,\n  nsd_info_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/tnb.get_sol_network_package_content\naws_api/tnb get_sol_network_package_content","url":"aws_api/tnb.html#get_sol_network_package_content"},{"doc":"aws_api/tnb","title":"get_sol_network_package_descriptor","content":"pub fn get_sol_network_package_descriptor(\n  client: Client,\n  nsd_info_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/tnb.get_sol_network_package_descriptor\naws_api/tnb get_sol_network_package_descriptor","url":"aws_api/tnb.html#get_sol_network_package_descriptor"},{"doc":"aws_api/tnb","title":"instantiate_sol_network_instance","content":"pub fn instantiate_sol_network_instance(\n  client: Client,\n  ns_instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/tnb.instantiate_sol_network_instance\naws_api/tnb instantiate_sol_network_instance","url":"aws_api/tnb.html#instantiate_sol_network_instance"},{"doc":"aws_api/tnb","title":"list_sol_function_instances","content":"pub fn list_sol_function_instances(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/tnb.list_sol_function_instances\naws_api/tnb list_sol_function_instances","url":"aws_api/tnb.html#list_sol_function_instances"},{"doc":"aws_api/tnb","title":"list_sol_function_packages","content":"pub fn list_sol_function_packages(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/tnb.list_sol_function_packages\naws_api/tnb list_sol_function_packages","url":"aws_api/tnb.html#list_sol_function_packages"},{"doc":"aws_api/tnb","title":"list_sol_network_instances","content":"pub fn list_sol_network_instances(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/tnb.list_sol_network_instances\naws_api/tnb list_sol_network_instances","url":"aws_api/tnb.html#list_sol_network_instances"},{"doc":"aws_api/tnb","title":"list_sol_network_operations","content":"pub fn list_sol_network_operations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/tnb.list_sol_network_operations\naws_api/tnb list_sol_network_operations","url":"aws_api/tnb.html#list_sol_network_operations"},{"doc":"aws_api/tnb","title":"list_sol_network_packages","content":"pub fn list_sol_network_packages(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/tnb.list_sol_network_packages\naws_api/tnb list_sol_network_packages","url":"aws_api/tnb.html#list_sol_network_packages"},{"doc":"aws_api/tnb","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/tnb.list_tags_for_resource\naws_api/tnb list_tags_for_resource","url":"aws_api/tnb.html#list_tags_for_resource"},{"doc":"aws_api/tnb","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/tnb.new\naws_api/tnb new","url":"aws_api/tnb.html#new"},{"doc":"aws_api/tnb","title":"put_sol_function_package_content","content":"pub fn put_sol_function_package_content(\n  client: Client,\n  vnf_pkg_id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/tnb.put_sol_function_package_content\naws_api/tnb put_sol_function_package_content","url":"aws_api/tnb.html#put_sol_function_package_content"},{"doc":"aws_api/tnb","title":"put_sol_network_package_content","content":"pub fn put_sol_network_package_content(\n  client: Client,\n  nsd_info_id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/tnb.put_sol_network_package_content\naws_api/tnb put_sol_network_package_content","url":"aws_api/tnb.html#put_sol_network_package_content"},{"doc":"aws_api/tnb","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/tnb.tag_resource\naws_api/tnb tag_resource","url":"aws_api/tnb.html#tag_resource"},{"doc":"aws_api/tnb","title":"terminate_sol_network_instance","content":"pub fn terminate_sol_network_instance(\n  client: Client,\n  ns_instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/tnb.terminate_sol_network_instance\naws_api/tnb terminate_sol_network_instance","url":"aws_api/tnb.html#terminate_sol_network_instance"},{"doc":"aws_api/tnb","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/tnb.untag_resource\naws_api/tnb untag_resource","url":"aws_api/tnb.html#untag_resource"},{"doc":"aws_api/tnb","title":"update_sol_function_package","content":"pub fn update_sol_function_package(\n  client: Client,\n  vnf_pkg_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/tnb.update_sol_function_package\naws_api/tnb update_sol_function_package","url":"aws_api/tnb.html#update_sol_function_package"},{"doc":"aws_api/tnb","title":"update_sol_network_instance","content":"pub fn update_sol_network_instance(\n  client: Client,\n  ns_instance_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/tnb.update_sol_network_instance\naws_api/tnb update_sol_network_instance","url":"aws_api/tnb.html#update_sol_network_instance"},{"doc":"aws_api/tnb","title":"update_sol_network_package","content":"pub fn update_sol_network_package(\n  client: Client,\n  nsd_info_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/tnb.update_sol_network_package\naws_api/tnb update_sol_network_package","url":"aws_api/tnb.html#update_sol_network_package"},{"doc":"aws_api/tnb","title":"validate_sol_function_package_content","content":"pub fn validate_sol_function_package_content(\n  client: Client,\n  vnf_pkg_id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/tnb.validate_sol_function_package_content\naws_api/tnb validate_sol_function_package_content","url":"aws_api/tnb.html#validate_sol_function_package_content"},{"doc":"aws_api/tnb","title":"validate_sol_network_package_content","content":"pub fn validate_sol_network_package_content(\n  client: Client,\n  nsd_info_id: String,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/tnb.validate_sol_network_package_content\naws_api/tnb validate_sol_network_package_content","url":"aws_api/tnb.html#validate_sol_network_package_content"},{"doc":"aws_api/tnb","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/tnb.with_custom_endpoint\naws_api/tnb with_custom_endpoint","url":"aws_api/tnb.html#with_custom_endpoint"},{"doc":"aws_api/tnb","title":"aws_api/tnb","content":"","url":"aws_api/tnb.html"},{"doc":"aws_api/transcribe","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/transcribe.Client\naws_api/transcribe Client","url":"aws_api/transcribe.html#Client"},{"doc":"aws_api/transcribe","title":"create_call_analytics_category","content":"pub fn create_call_analytics_category(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transcribe.create_call_analytics_category\naws_api/transcribe create_call_analytics_category","url":"aws_api/transcribe.html#create_call_analytics_category"},{"doc":"aws_api/transcribe","title":"create_language_model","content":"pub fn create_language_model(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transcribe.create_language_model\naws_api/transcribe create_language_model","url":"aws_api/transcribe.html#create_language_model"},{"doc":"aws_api/transcribe","title":"create_medical_vocabulary","content":"pub fn create_medical_vocabulary(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transcribe.create_medical_vocabulary\naws_api/transcribe create_medical_vocabulary","url":"aws_api/transcribe.html#create_medical_vocabulary"},{"doc":"aws_api/transcribe","title":"create_vocabulary","content":"pub fn create_vocabulary(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transcribe.create_vocabulary\naws_api/transcribe create_vocabulary","url":"aws_api/transcribe.html#create_vocabulary"},{"doc":"aws_api/transcribe","title":"create_vocabulary_filter","content":"pub fn create_vocabulary_filter(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transcribe.create_vocabulary_filter\naws_api/transcribe create_vocabulary_filter","url":"aws_api/transcribe.html#create_vocabulary_filter"},{"doc":"aws_api/transcribe","title":"delete_call_analytics_category","content":"pub fn delete_call_analytics_category(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transcribe.delete_call_analytics_category\naws_api/transcribe delete_call_analytics_category","url":"aws_api/transcribe.html#delete_call_analytics_category"},{"doc":"aws_api/transcribe","title":"delete_call_analytics_job","content":"pub fn delete_call_analytics_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transcribe.delete_call_analytics_job\naws_api/transcribe delete_call_analytics_job","url":"aws_api/transcribe.html#delete_call_analytics_job"},{"doc":"aws_api/transcribe","title":"delete_language_model","content":"pub fn delete_language_model(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transcribe.delete_language_model\naws_api/transcribe delete_language_model","url":"aws_api/transcribe.html#delete_language_model"},{"doc":"aws_api/transcribe","title":"delete_medical_scribe_job","content":"pub fn delete_medical_scribe_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transcribe.delete_medical_scribe_job\naws_api/transcribe delete_medical_scribe_job","url":"aws_api/transcribe.html#delete_medical_scribe_job"},{"doc":"aws_api/transcribe","title":"delete_medical_transcription_job","content":"pub fn delete_medical_transcription_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transcribe.delete_medical_transcription_job\naws_api/transcribe delete_medical_transcription_job","url":"aws_api/transcribe.html#delete_medical_transcription_job"},{"doc":"aws_api/transcribe","title":"delete_medical_vocabulary","content":"pub fn delete_medical_vocabulary(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transcribe.delete_medical_vocabulary\naws_api/transcribe delete_medical_vocabulary","url":"aws_api/transcribe.html#delete_medical_vocabulary"},{"doc":"aws_api/transcribe","title":"delete_transcription_job","content":"pub fn delete_transcription_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transcribe.delete_transcription_job\naws_api/transcribe delete_transcription_job","url":"aws_api/transcribe.html#delete_transcription_job"},{"doc":"aws_api/transcribe","title":"delete_vocabulary","content":"pub fn delete_vocabulary(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transcribe.delete_vocabulary\naws_api/transcribe delete_vocabulary","url":"aws_api/transcribe.html#delete_vocabulary"},{"doc":"aws_api/transcribe","title":"delete_vocabulary_filter","content":"pub fn delete_vocabulary_filter(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transcribe.delete_vocabulary_filter\naws_api/transcribe delete_vocabulary_filter","url":"aws_api/transcribe.html#delete_vocabulary_filter"},{"doc":"aws_api/transcribe","title":"describe_language_model","content":"pub fn describe_language_model(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transcribe.describe_language_model\naws_api/transcribe describe_language_model","url":"aws_api/transcribe.html#describe_language_model"},{"doc":"aws_api/transcribe","title":"get_call_analytics_category","content":"pub fn get_call_analytics_category(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transcribe.get_call_analytics_category\naws_api/transcribe get_call_analytics_category","url":"aws_api/transcribe.html#get_call_analytics_category"},{"doc":"aws_api/transcribe","title":"get_call_analytics_job","content":"pub fn get_call_analytics_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transcribe.get_call_analytics_job\naws_api/transcribe get_call_analytics_job","url":"aws_api/transcribe.html#get_call_analytics_job"},{"doc":"aws_api/transcribe","title":"get_medical_scribe_job","content":"pub fn get_medical_scribe_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transcribe.get_medical_scribe_job\naws_api/transcribe get_medical_scribe_job","url":"aws_api/transcribe.html#get_medical_scribe_job"},{"doc":"aws_api/transcribe","title":"get_medical_transcription_job","content":"pub fn get_medical_transcription_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transcribe.get_medical_transcription_job\naws_api/transcribe get_medical_transcription_job","url":"aws_api/transcribe.html#get_medical_transcription_job"},{"doc":"aws_api/transcribe","title":"get_medical_vocabulary","content":"pub fn get_medical_vocabulary(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transcribe.get_medical_vocabulary\naws_api/transcribe get_medical_vocabulary","url":"aws_api/transcribe.html#get_medical_vocabulary"},{"doc":"aws_api/transcribe","title":"get_transcription_job","content":"pub fn get_transcription_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transcribe.get_transcription_job\naws_api/transcribe get_transcription_job","url":"aws_api/transcribe.html#get_transcription_job"},{"doc":"aws_api/transcribe","title":"get_vocabulary","content":"pub fn get_vocabulary(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transcribe.get_vocabulary\naws_api/transcribe get_vocabulary","url":"aws_api/transcribe.html#get_vocabulary"},{"doc":"aws_api/transcribe","title":"get_vocabulary_filter","content":"pub fn get_vocabulary_filter(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transcribe.get_vocabulary_filter\naws_api/transcribe get_vocabulary_filter","url":"aws_api/transcribe.html#get_vocabulary_filter"},{"doc":"aws_api/transcribe","title":"list_call_analytics_categories","content":"pub fn list_call_analytics_categories(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transcribe.list_call_analytics_categories\naws_api/transcribe list_call_analytics_categories","url":"aws_api/transcribe.html#list_call_analytics_categories"},{"doc":"aws_api/transcribe","title":"list_call_analytics_jobs","content":"pub fn list_call_analytics_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transcribe.list_call_analytics_jobs\naws_api/transcribe list_call_analytics_jobs","url":"aws_api/transcribe.html#list_call_analytics_jobs"},{"doc":"aws_api/transcribe","title":"list_language_models","content":"pub fn list_language_models(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transcribe.list_language_models\naws_api/transcribe list_language_models","url":"aws_api/transcribe.html#list_language_models"},{"doc":"aws_api/transcribe","title":"list_medical_scribe_jobs","content":"pub fn list_medical_scribe_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transcribe.list_medical_scribe_jobs\naws_api/transcribe list_medical_scribe_jobs","url":"aws_api/transcribe.html#list_medical_scribe_jobs"},{"doc":"aws_api/transcribe","title":"list_medical_transcription_jobs","content":"pub fn list_medical_transcription_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transcribe.list_medical_transcription_jobs\naws_api/transcribe list_medical_transcription_jobs","url":"aws_api/transcribe.html#list_medical_transcription_jobs"},{"doc":"aws_api/transcribe","title":"list_medical_vocabularies","content":"pub fn list_medical_vocabularies(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transcribe.list_medical_vocabularies\naws_api/transcribe list_medical_vocabularies","url":"aws_api/transcribe.html#list_medical_vocabularies"},{"doc":"aws_api/transcribe","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transcribe.list_tags_for_resource\naws_api/transcribe list_tags_for_resource","url":"aws_api/transcribe.html#list_tags_for_resource"},{"doc":"aws_api/transcribe","title":"list_transcription_jobs","content":"pub fn list_transcription_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transcribe.list_transcription_jobs\naws_api/transcribe list_transcription_jobs","url":"aws_api/transcribe.html#list_transcription_jobs"},{"doc":"aws_api/transcribe","title":"list_vocabularies","content":"pub fn list_vocabularies(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transcribe.list_vocabularies\naws_api/transcribe list_vocabularies","url":"aws_api/transcribe.html#list_vocabularies"},{"doc":"aws_api/transcribe","title":"list_vocabulary_filters","content":"pub fn list_vocabulary_filters(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transcribe.list_vocabulary_filters\naws_api/transcribe list_vocabulary_filters","url":"aws_api/transcribe.html#list_vocabulary_filters"},{"doc":"aws_api/transcribe","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/transcribe.new\naws_api/transcribe new","url":"aws_api/transcribe.html#new"},{"doc":"aws_api/transcribe","title":"start_call_analytics_job","content":"pub fn start_call_analytics_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transcribe.start_call_analytics_job\naws_api/transcribe start_call_analytics_job","url":"aws_api/transcribe.html#start_call_analytics_job"},{"doc":"aws_api/transcribe","title":"start_medical_scribe_job","content":"pub fn start_medical_scribe_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transcribe.start_medical_scribe_job\naws_api/transcribe start_medical_scribe_job","url":"aws_api/transcribe.html#start_medical_scribe_job"},{"doc":"aws_api/transcribe","title":"start_medical_transcription_job","content":"pub fn start_medical_transcription_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transcribe.start_medical_transcription_job\naws_api/transcribe start_medical_transcription_job","url":"aws_api/transcribe.html#start_medical_transcription_job"},{"doc":"aws_api/transcribe","title":"start_transcription_job","content":"pub fn start_transcription_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transcribe.start_transcription_job\naws_api/transcribe start_transcription_job","url":"aws_api/transcribe.html#start_transcription_job"},{"doc":"aws_api/transcribe","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transcribe.tag_resource\naws_api/transcribe tag_resource","url":"aws_api/transcribe.html#tag_resource"},{"doc":"aws_api/transcribe","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transcribe.untag_resource\naws_api/transcribe untag_resource","url":"aws_api/transcribe.html#untag_resource"},{"doc":"aws_api/transcribe","title":"update_call_analytics_category","content":"pub fn update_call_analytics_category(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transcribe.update_call_analytics_category\naws_api/transcribe update_call_analytics_category","url":"aws_api/transcribe.html#update_call_analytics_category"},{"doc":"aws_api/transcribe","title":"update_medical_vocabulary","content":"pub fn update_medical_vocabulary(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transcribe.update_medical_vocabulary\naws_api/transcribe update_medical_vocabulary","url":"aws_api/transcribe.html#update_medical_vocabulary"},{"doc":"aws_api/transcribe","title":"update_vocabulary","content":"pub fn update_vocabulary(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transcribe.update_vocabulary\naws_api/transcribe update_vocabulary","url":"aws_api/transcribe.html#update_vocabulary"},{"doc":"aws_api/transcribe","title":"update_vocabulary_filter","content":"pub fn update_vocabulary_filter(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transcribe.update_vocabulary_filter\naws_api/transcribe update_vocabulary_filter","url":"aws_api/transcribe.html#update_vocabulary_filter"},{"doc":"aws_api/transcribe","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/transcribe.with_custom_endpoint\naws_api/transcribe with_custom_endpoint","url":"aws_api/transcribe.html#with_custom_endpoint"},{"doc":"aws_api/transcribe","title":"aws_api/transcribe","content":"","url":"aws_api/transcribe.html"},{"doc":"aws_api/transcribe_streaming","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/transcribe_streaming.Client\naws_api/transcribe_streaming Client","url":"aws_api/transcribe_streaming.html#Client"},{"doc":"aws_api/transcribe_streaming","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/transcribe_streaming.new\naws_api/transcribe_streaming new","url":"aws_api/transcribe_streaming.html#new"},{"doc":"aws_api/transcribe_streaming","title":"start_call_analytics_stream_transcription","content":"pub fn start_call_analytics_stream_transcription(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transcribe_streaming.start_call_analytics_stream_transcription\naws_api/transcribe_streaming start_call_analytics_stream_transcription","url":"aws_api/transcribe_streaming.html#start_call_analytics_stream_transcription"},{"doc":"aws_api/transcribe_streaming","title":"start_medical_stream_transcription","content":"pub fn start_medical_stream_transcription(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transcribe_streaming.start_medical_stream_transcription\naws_api/transcribe_streaming start_medical_stream_transcription","url":"aws_api/transcribe_streaming.html#start_medical_stream_transcription"},{"doc":"aws_api/transcribe_streaming","title":"start_stream_transcription","content":"pub fn start_stream_transcription(\n  client: Client,\n  body: BitArray,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transcribe_streaming.start_stream_transcription\naws_api/transcribe_streaming start_stream_transcription","url":"aws_api/transcribe_streaming.html#start_stream_transcription"},{"doc":"aws_api/transcribe_streaming","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/transcribe_streaming.with_custom_endpoint\naws_api/transcribe_streaming with_custom_endpoint","url":"aws_api/transcribe_streaming.html#with_custom_endpoint"},{"doc":"aws_api/transcribe_streaming","title":"aws_api/transcribe_streaming","content":"","url":"aws_api/transcribe_streaming.html"},{"doc":"aws_api/transfer","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/transfer.Client\naws_api/transfer Client","url":"aws_api/transfer.html#Client"},{"doc":"aws_api/transfer","title":"create_access","content":"pub fn create_access(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transfer.create_access\naws_api/transfer create_access","url":"aws_api/transfer.html#create_access"},{"doc":"aws_api/transfer","title":"delete_access","content":"pub fn delete_access(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transfer.delete_access\naws_api/transfer delete_access","url":"aws_api/transfer.html#delete_access"},{"doc":"aws_api/transfer","title":"delete_host_key","content":"pub fn delete_host_key(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transfer.delete_host_key\naws_api/transfer delete_host_key","url":"aws_api/transfer.html#delete_host_key"},{"doc":"aws_api/transfer","title":"delete_ssh_public_key","content":"pub fn delete_ssh_public_key(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transfer.delete_ssh_public_key\naws_api/transfer delete_ssh_public_key","url":"aws_api/transfer.html#delete_ssh_public_key"},{"doc":"aws_api/transfer","title":"describe_access","content":"pub fn describe_access(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transfer.describe_access\naws_api/transfer describe_access","url":"aws_api/transfer.html#describe_access"},{"doc":"aws_api/transfer","title":"describe_execution","content":"pub fn describe_execution(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transfer.describe_execution\naws_api/transfer describe_execution","url":"aws_api/transfer.html#describe_execution"},{"doc":"aws_api/transfer","title":"describe_host_key","content":"pub fn describe_host_key(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transfer.describe_host_key\naws_api/transfer describe_host_key","url":"aws_api/transfer.html#describe_host_key"},{"doc":"aws_api/transfer","title":"describe_security_policy","content":"pub fn describe_security_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transfer.describe_security_policy\naws_api/transfer describe_security_policy","url":"aws_api/transfer.html#describe_security_policy"},{"doc":"aws_api/transfer","title":"import_host_key","content":"pub fn import_host_key(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transfer.import_host_key\naws_api/transfer import_host_key","url":"aws_api/transfer.html#import_host_key"},{"doc":"aws_api/transfer","title":"import_ssh_public_key","content":"pub fn import_ssh_public_key(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transfer.import_ssh_public_key\naws_api/transfer import_ssh_public_key","url":"aws_api/transfer.html#import_ssh_public_key"},{"doc":"aws_api/transfer","title":"list_accesses","content":"pub fn list_accesses(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transfer.list_accesses\naws_api/transfer list_accesses","url":"aws_api/transfer.html#list_accesses"},{"doc":"aws_api/transfer","title":"list_executions","content":"pub fn list_executions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transfer.list_executions\naws_api/transfer list_executions","url":"aws_api/transfer.html#list_executions"},{"doc":"aws_api/transfer","title":"list_host_keys","content":"pub fn list_host_keys(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transfer.list_host_keys\naws_api/transfer list_host_keys","url":"aws_api/transfer.html#list_host_keys"},{"doc":"aws_api/transfer","title":"list_security_policies","content":"pub fn list_security_policies(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transfer.list_security_policies\naws_api/transfer list_security_policies","url":"aws_api/transfer.html#list_security_policies"},{"doc":"aws_api/transfer","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transfer.list_tags_for_resource\naws_api/transfer list_tags_for_resource","url":"aws_api/transfer.html#list_tags_for_resource"},{"doc":"aws_api/transfer","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/transfer.new\naws_api/transfer new","url":"aws_api/transfer.html#new"},{"doc":"aws_api/transfer","title":"send_workflow_step_state","content":"pub fn send_workflow_step_state(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transfer.send_workflow_step_state\naws_api/transfer send_workflow_step_state","url":"aws_api/transfer.html#send_workflow_step_state"},{"doc":"aws_api/transfer","title":"start_directory_listing","content":"pub fn start_directory_listing(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transfer.start_directory_listing\naws_api/transfer start_directory_listing","url":"aws_api/transfer.html#start_directory_listing"},{"doc":"aws_api/transfer","title":"start_file_transfer","content":"pub fn start_file_transfer(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transfer.start_file_transfer\naws_api/transfer start_file_transfer","url":"aws_api/transfer.html#start_file_transfer"},{"doc":"aws_api/transfer","title":"start_server","content":"pub fn start_server(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transfer.start_server\naws_api/transfer start_server","url":"aws_api/transfer.html#start_server"},{"doc":"aws_api/transfer","title":"stop_server","content":"pub fn stop_server(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transfer.stop_server\naws_api/transfer stop_server","url":"aws_api/transfer.html#stop_server"},{"doc":"aws_api/transfer","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transfer.tag_resource\naws_api/transfer tag_resource","url":"aws_api/transfer.html#tag_resource"},{"doc":"aws_api/transfer","title":"test_connection","content":"pub fn test_connection(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transfer.test_connection\naws_api/transfer test_connection","url":"aws_api/transfer.html#test_connection"},{"doc":"aws_api/transfer","title":"test_identity_provider","content":"pub fn test_identity_provider(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transfer.test_identity_provider\naws_api/transfer test_identity_provider","url":"aws_api/transfer.html#test_identity_provider"},{"doc":"aws_api/transfer","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transfer.untag_resource\naws_api/transfer untag_resource","url":"aws_api/transfer.html#untag_resource"},{"doc":"aws_api/transfer","title":"update_access","content":"pub fn update_access(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transfer.update_access\naws_api/transfer update_access","url":"aws_api/transfer.html#update_access"},{"doc":"aws_api/transfer","title":"update_host_key","content":"pub fn update_host_key(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/transfer.update_host_key\naws_api/transfer update_host_key","url":"aws_api/transfer.html#update_host_key"},{"doc":"aws_api/transfer","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/transfer.with_custom_endpoint\naws_api/transfer with_custom_endpoint","url":"aws_api/transfer.html#with_custom_endpoint"},{"doc":"aws_api/transfer","title":"aws_api/transfer","content":"","url":"aws_api/transfer.html"},{"doc":"aws_api/translate","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/translate.Client\naws_api/translate Client","url":"aws_api/translate.html#Client"},{"doc":"aws_api/translate","title":"create_parallel_data","content":"pub fn create_parallel_data(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/translate.create_parallel_data\naws_api/translate create_parallel_data","url":"aws_api/translate.html#create_parallel_data"},{"doc":"aws_api/translate","title":"delete_parallel_data","content":"pub fn delete_parallel_data(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/translate.delete_parallel_data\naws_api/translate delete_parallel_data","url":"aws_api/translate.html#delete_parallel_data"},{"doc":"aws_api/translate","title":"delete_terminology","content":"pub fn delete_terminology(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/translate.delete_terminology\naws_api/translate delete_terminology","url":"aws_api/translate.html#delete_terminology"},{"doc":"aws_api/translate","title":"describe_text_translation_job","content":"pub fn describe_text_translation_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/translate.describe_text_translation_job\naws_api/translate describe_text_translation_job","url":"aws_api/translate.html#describe_text_translation_job"},{"doc":"aws_api/translate","title":"get_parallel_data","content":"pub fn get_parallel_data(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/translate.get_parallel_data\naws_api/translate get_parallel_data","url":"aws_api/translate.html#get_parallel_data"},{"doc":"aws_api/translate","title":"get_terminology","content":"pub fn get_terminology(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/translate.get_terminology\naws_api/translate get_terminology","url":"aws_api/translate.html#get_terminology"},{"doc":"aws_api/translate","title":"import_terminology","content":"pub fn import_terminology(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/translate.import_terminology\naws_api/translate import_terminology","url":"aws_api/translate.html#import_terminology"},{"doc":"aws_api/translate","title":"list_languages","content":"pub fn list_languages(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/translate.list_languages\naws_api/translate list_languages","url":"aws_api/translate.html#list_languages"},{"doc":"aws_api/translate","title":"list_parallel_data","content":"pub fn list_parallel_data(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/translate.list_parallel_data\naws_api/translate list_parallel_data","url":"aws_api/translate.html#list_parallel_data"},{"doc":"aws_api/translate","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/translate.list_tags_for_resource\naws_api/translate list_tags_for_resource","url":"aws_api/translate.html#list_tags_for_resource"},{"doc":"aws_api/translate","title":"list_terminologies","content":"pub fn list_terminologies(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/translate.list_terminologies\naws_api/translate list_terminologies","url":"aws_api/translate.html#list_terminologies"},{"doc":"aws_api/translate","title":"list_text_translation_jobs","content":"pub fn list_text_translation_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/translate.list_text_translation_jobs\naws_api/translate list_text_translation_jobs","url":"aws_api/translate.html#list_text_translation_jobs"},{"doc":"aws_api/translate","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/translate.new\naws_api/translate new","url":"aws_api/translate.html#new"},{"doc":"aws_api/translate","title":"start_text_translation_job","content":"pub fn start_text_translation_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/translate.start_text_translation_job\naws_api/translate start_text_translation_job","url":"aws_api/translate.html#start_text_translation_job"},{"doc":"aws_api/translate","title":"stop_text_translation_job","content":"pub fn stop_text_translation_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/translate.stop_text_translation_job\naws_api/translate stop_text_translation_job","url":"aws_api/translate.html#stop_text_translation_job"},{"doc":"aws_api/translate","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/translate.tag_resource\naws_api/translate tag_resource","url":"aws_api/translate.html#tag_resource"},{"doc":"aws_api/translate","title":"translate_document","content":"pub fn translate_document(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/translate.translate_document\naws_api/translate translate_document","url":"aws_api/translate.html#translate_document"},{"doc":"aws_api/translate","title":"translate_text","content":"pub fn translate_text(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/translate.translate_text\naws_api/translate translate_text","url":"aws_api/translate.html#translate_text"},{"doc":"aws_api/translate","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/translate.untag_resource\naws_api/translate untag_resource","url":"aws_api/translate.html#untag_resource"},{"doc":"aws_api/translate","title":"update_parallel_data","content":"pub fn update_parallel_data(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/translate.update_parallel_data\naws_api/translate update_parallel_data","url":"aws_api/translate.html#update_parallel_data"},{"doc":"aws_api/translate","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/translate.with_custom_endpoint\naws_api/translate with_custom_endpoint","url":"aws_api/translate.html#with_custom_endpoint"},{"doc":"aws_api/translate","title":"aws_api/translate","content":"","url":"aws_api/translate.html"},{"doc":"aws_api/voice_id","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/voice_id.Client\naws_api/voice_id Client","url":"aws_api/voice_id.html#Client"},{"doc":"aws_api/voice_id","title":"associate_fraudster","content":"pub fn associate_fraudster(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/voice_id.associate_fraudster\naws_api/voice_id associate_fraudster","url":"aws_api/voice_id.html#associate_fraudster"},{"doc":"aws_api/voice_id","title":"create_watchlist","content":"pub fn create_watchlist(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/voice_id.create_watchlist\naws_api/voice_id create_watchlist","url":"aws_api/voice_id.html#create_watchlist"},{"doc":"aws_api/voice_id","title":"delete_fraudster","content":"pub fn delete_fraudster(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/voice_id.delete_fraudster\naws_api/voice_id delete_fraudster","url":"aws_api/voice_id.html#delete_fraudster"},{"doc":"aws_api/voice_id","title":"delete_speaker","content":"pub fn delete_speaker(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/voice_id.delete_speaker\naws_api/voice_id delete_speaker","url":"aws_api/voice_id.html#delete_speaker"},{"doc":"aws_api/voice_id","title":"delete_watchlist","content":"pub fn delete_watchlist(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/voice_id.delete_watchlist\naws_api/voice_id delete_watchlist","url":"aws_api/voice_id.html#delete_watchlist"},{"doc":"aws_api/voice_id","title":"describe_fraudster","content":"pub fn describe_fraudster(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/voice_id.describe_fraudster\naws_api/voice_id describe_fraudster","url":"aws_api/voice_id.html#describe_fraudster"},{"doc":"aws_api/voice_id","title":"describe_fraudster_registration_job","content":"pub fn describe_fraudster_registration_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/voice_id.describe_fraudster_registration_job\naws_api/voice_id describe_fraudster_registration_job","url":"aws_api/voice_id.html#describe_fraudster_registration_job"},{"doc":"aws_api/voice_id","title":"describe_speaker","content":"pub fn describe_speaker(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/voice_id.describe_speaker\naws_api/voice_id describe_speaker","url":"aws_api/voice_id.html#describe_speaker"},{"doc":"aws_api/voice_id","title":"describe_speaker_enrollment_job","content":"pub fn describe_speaker_enrollment_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/voice_id.describe_speaker_enrollment_job\naws_api/voice_id describe_speaker_enrollment_job","url":"aws_api/voice_id.html#describe_speaker_enrollment_job"},{"doc":"aws_api/voice_id","title":"describe_watchlist","content":"pub fn describe_watchlist(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/voice_id.describe_watchlist\naws_api/voice_id describe_watchlist","url":"aws_api/voice_id.html#describe_watchlist"},{"doc":"aws_api/voice_id","title":"disassociate_fraudster","content":"pub fn disassociate_fraudster(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/voice_id.disassociate_fraudster\naws_api/voice_id disassociate_fraudster","url":"aws_api/voice_id.html#disassociate_fraudster"},{"doc":"aws_api/voice_id","title":"evaluate_session","content":"pub fn evaluate_session(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/voice_id.evaluate_session\naws_api/voice_id evaluate_session","url":"aws_api/voice_id.html#evaluate_session"},{"doc":"aws_api/voice_id","title":"list_fraudster_registration_jobs","content":"pub fn list_fraudster_registration_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/voice_id.list_fraudster_registration_jobs\naws_api/voice_id list_fraudster_registration_jobs","url":"aws_api/voice_id.html#list_fraudster_registration_jobs"},{"doc":"aws_api/voice_id","title":"list_fraudsters","content":"pub fn list_fraudsters(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/voice_id.list_fraudsters\naws_api/voice_id list_fraudsters","url":"aws_api/voice_id.html#list_fraudsters"},{"doc":"aws_api/voice_id","title":"list_speaker_enrollment_jobs","content":"pub fn list_speaker_enrollment_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/voice_id.list_speaker_enrollment_jobs\naws_api/voice_id list_speaker_enrollment_jobs","url":"aws_api/voice_id.html#list_speaker_enrollment_jobs"},{"doc":"aws_api/voice_id","title":"list_speakers","content":"pub fn list_speakers(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/voice_id.list_speakers\naws_api/voice_id list_speakers","url":"aws_api/voice_id.html#list_speakers"},{"doc":"aws_api/voice_id","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/voice_id.list_tags_for_resource\naws_api/voice_id list_tags_for_resource","url":"aws_api/voice_id.html#list_tags_for_resource"},{"doc":"aws_api/voice_id","title":"list_watchlists","content":"pub fn list_watchlists(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/voice_id.list_watchlists\naws_api/voice_id list_watchlists","url":"aws_api/voice_id.html#list_watchlists"},{"doc":"aws_api/voice_id","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/voice_id.new\naws_api/voice_id new","url":"aws_api/voice_id.html#new"},{"doc":"aws_api/voice_id","title":"opt_out_speaker","content":"pub fn opt_out_speaker(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/voice_id.opt_out_speaker\naws_api/voice_id opt_out_speaker","url":"aws_api/voice_id.html#opt_out_speaker"},{"doc":"aws_api/voice_id","title":"start_fraudster_registration_job","content":"pub fn start_fraudster_registration_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/voice_id.start_fraudster_registration_job\naws_api/voice_id start_fraudster_registration_job","url":"aws_api/voice_id.html#start_fraudster_registration_job"},{"doc":"aws_api/voice_id","title":"start_speaker_enrollment_job","content":"pub fn start_speaker_enrollment_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/voice_id.start_speaker_enrollment_job\naws_api/voice_id start_speaker_enrollment_job","url":"aws_api/voice_id.html#start_speaker_enrollment_job"},{"doc":"aws_api/voice_id","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/voice_id.tag_resource\naws_api/voice_id tag_resource","url":"aws_api/voice_id.html#tag_resource"},{"doc":"aws_api/voice_id","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/voice_id.untag_resource\naws_api/voice_id untag_resource","url":"aws_api/voice_id.html#untag_resource"},{"doc":"aws_api/voice_id","title":"update_watchlist","content":"pub fn update_watchlist(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/voice_id.update_watchlist\naws_api/voice_id update_watchlist","url":"aws_api/voice_id.html#update_watchlist"},{"doc":"aws_api/voice_id","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/voice_id.with_custom_endpoint\naws_api/voice_id with_custom_endpoint","url":"aws_api/voice_id.html#with_custom_endpoint"},{"doc":"aws_api/voice_id","title":"aws_api/voice_id","content":"","url":"aws_api/voice_id.html"},{"doc":"aws_api/vpc_lattice","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/vpc_lattice.Client\naws_api/vpc_lattice Client","url":"aws_api/vpc_lattice.html#Client"},{"doc":"aws_api/vpc_lattice","title":"batch_update_rule","content":"pub fn batch_update_rule(\n  client: Client,\n  service_identifier: String,\n  listener_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/vpc_lattice.batch_update_rule\naws_api/vpc_lattice batch_update_rule","url":"aws_api/vpc_lattice.html#batch_update_rule"},{"doc":"aws_api/vpc_lattice","title":"delete_auth_policy","content":"pub fn delete_auth_policy(\n  client: Client,\n  resource_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/vpc_lattice.delete_auth_policy\naws_api/vpc_lattice delete_auth_policy","url":"aws_api/vpc_lattice.html#delete_auth_policy"},{"doc":"aws_api/vpc_lattice","title":"delete_resource_policy","content":"pub fn delete_resource_policy(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/vpc_lattice.delete_resource_policy\naws_api/vpc_lattice delete_resource_policy","url":"aws_api/vpc_lattice.html#delete_resource_policy"},{"doc":"aws_api/vpc_lattice","title":"get_auth_policy","content":"pub fn get_auth_policy(\n  client: Client,\n  resource_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/vpc_lattice.get_auth_policy\naws_api/vpc_lattice get_auth_policy","url":"aws_api/vpc_lattice.html#get_auth_policy"},{"doc":"aws_api/vpc_lattice","title":"get_resource_policy","content":"pub fn get_resource_policy(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/vpc_lattice.get_resource_policy\naws_api/vpc_lattice get_resource_policy","url":"aws_api/vpc_lattice.html#get_resource_policy"},{"doc":"aws_api/vpc_lattice","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/vpc_lattice.list_tags_for_resource\naws_api/vpc_lattice list_tags_for_resource","url":"aws_api/vpc_lattice.html#list_tags_for_resource"},{"doc":"aws_api/vpc_lattice","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/vpc_lattice.new\naws_api/vpc_lattice new","url":"aws_api/vpc_lattice.html#new"},{"doc":"aws_api/vpc_lattice","title":"put_auth_policy","content":"pub fn put_auth_policy(\n  client: Client,\n  resource_identifier: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/vpc_lattice.put_auth_policy\naws_api/vpc_lattice put_auth_policy","url":"aws_api/vpc_lattice.html#put_auth_policy"},{"doc":"aws_api/vpc_lattice","title":"put_resource_policy","content":"pub fn put_resource_policy(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/vpc_lattice.put_resource_policy\naws_api/vpc_lattice put_resource_policy","url":"aws_api/vpc_lattice.html#put_resource_policy"},{"doc":"aws_api/vpc_lattice","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/vpc_lattice.tag_resource\naws_api/vpc_lattice tag_resource","url":"aws_api/vpc_lattice.html#tag_resource"},{"doc":"aws_api/vpc_lattice","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/vpc_lattice.untag_resource\naws_api/vpc_lattice untag_resource","url":"aws_api/vpc_lattice.html#untag_resource"},{"doc":"aws_api/vpc_lattice","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/vpc_lattice.with_custom_endpoint\naws_api/vpc_lattice with_custom_endpoint","url":"aws_api/vpc_lattice.html#with_custom_endpoint"},{"doc":"aws_api/vpc_lattice","title":"aws_api/vpc_lattice","content":"","url":"aws_api/vpc_lattice.html"},{"doc":"aws_api/waf","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/waf.Client\naws_api/waf Client","url":"aws_api/waf.html#Client"},{"doc":"aws_api/waf","title":"create_byte_match_set","content":"pub fn create_byte_match_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.create_byte_match_set\naws_api/waf create_byte_match_set","url":"aws_api/waf.html#create_byte_match_set"},{"doc":"aws_api/waf","title":"create_geo_match_set","content":"pub fn create_geo_match_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.create_geo_match_set\naws_api/waf create_geo_match_set","url":"aws_api/waf.html#create_geo_match_set"},{"doc":"aws_api/waf","title":"create_ip_set","content":"pub fn create_ip_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.create_ip_set\naws_api/waf create_ip_set","url":"aws_api/waf.html#create_ip_set"},{"doc":"aws_api/waf","title":"create_rate_based_rule","content":"pub fn create_rate_based_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.create_rate_based_rule\naws_api/waf create_rate_based_rule","url":"aws_api/waf.html#create_rate_based_rule"},{"doc":"aws_api/waf","title":"create_regex_match_set","content":"pub fn create_regex_match_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.create_regex_match_set\naws_api/waf create_regex_match_set","url":"aws_api/waf.html#create_regex_match_set"},{"doc":"aws_api/waf","title":"create_regex_pattern_set","content":"pub fn create_regex_pattern_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.create_regex_pattern_set\naws_api/waf create_regex_pattern_set","url":"aws_api/waf.html#create_regex_pattern_set"},{"doc":"aws_api/waf","title":"create_rule","content":"pub fn create_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.create_rule\naws_api/waf create_rule","url":"aws_api/waf.html#create_rule"},{"doc":"aws_api/waf","title":"create_rule_group","content":"pub fn create_rule_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.create_rule_group\naws_api/waf create_rule_group","url":"aws_api/waf.html#create_rule_group"},{"doc":"aws_api/waf","title":"create_size_constraint_set","content":"pub fn create_size_constraint_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.create_size_constraint_set\naws_api/waf create_size_constraint_set","url":"aws_api/waf.html#create_size_constraint_set"},{"doc":"aws_api/waf","title":"create_sql_injection_match_set","content":"pub fn create_sql_injection_match_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.create_sql_injection_match_set\naws_api/waf create_sql_injection_match_set","url":"aws_api/waf.html#create_sql_injection_match_set"},{"doc":"aws_api/waf","title":"create_web_acl","content":"pub fn create_web_acl(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.create_web_acl\naws_api/waf create_web_acl","url":"aws_api/waf.html#create_web_acl"},{"doc":"aws_api/waf","title":"create_web_acl_migration_stack","content":"pub fn create_web_acl_migration_stack(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.create_web_acl_migration_stack\naws_api/waf create_web_acl_migration_stack","url":"aws_api/waf.html#create_web_acl_migration_stack"},{"doc":"aws_api/waf","title":"create_xss_match_set","content":"pub fn create_xss_match_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.create_xss_match_set\naws_api/waf create_xss_match_set","url":"aws_api/waf.html#create_xss_match_set"},{"doc":"aws_api/waf","title":"delete_byte_match_set","content":"pub fn delete_byte_match_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.delete_byte_match_set\naws_api/waf delete_byte_match_set","url":"aws_api/waf.html#delete_byte_match_set"},{"doc":"aws_api/waf","title":"delete_geo_match_set","content":"pub fn delete_geo_match_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.delete_geo_match_set\naws_api/waf delete_geo_match_set","url":"aws_api/waf.html#delete_geo_match_set"},{"doc":"aws_api/waf","title":"delete_ip_set","content":"pub fn delete_ip_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.delete_ip_set\naws_api/waf delete_ip_set","url":"aws_api/waf.html#delete_ip_set"},{"doc":"aws_api/waf","title":"delete_logging_configuration","content":"pub fn delete_logging_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.delete_logging_configuration\naws_api/waf delete_logging_configuration","url":"aws_api/waf.html#delete_logging_configuration"},{"doc":"aws_api/waf","title":"delete_permission_policy","content":"pub fn delete_permission_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.delete_permission_policy\naws_api/waf delete_permission_policy","url":"aws_api/waf.html#delete_permission_policy"},{"doc":"aws_api/waf","title":"delete_rate_based_rule","content":"pub fn delete_rate_based_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.delete_rate_based_rule\naws_api/waf delete_rate_based_rule","url":"aws_api/waf.html#delete_rate_based_rule"},{"doc":"aws_api/waf","title":"delete_regex_match_set","content":"pub fn delete_regex_match_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.delete_regex_match_set\naws_api/waf delete_regex_match_set","url":"aws_api/waf.html#delete_regex_match_set"},{"doc":"aws_api/waf","title":"delete_regex_pattern_set","content":"pub fn delete_regex_pattern_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.delete_regex_pattern_set\naws_api/waf delete_regex_pattern_set","url":"aws_api/waf.html#delete_regex_pattern_set"},{"doc":"aws_api/waf","title":"delete_rule","content":"pub fn delete_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.delete_rule\naws_api/waf delete_rule","url":"aws_api/waf.html#delete_rule"},{"doc":"aws_api/waf","title":"delete_rule_group","content":"pub fn delete_rule_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.delete_rule_group\naws_api/waf delete_rule_group","url":"aws_api/waf.html#delete_rule_group"},{"doc":"aws_api/waf","title":"delete_size_constraint_set","content":"pub fn delete_size_constraint_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.delete_size_constraint_set\naws_api/waf delete_size_constraint_set","url":"aws_api/waf.html#delete_size_constraint_set"},{"doc":"aws_api/waf","title":"delete_sql_injection_match_set","content":"pub fn delete_sql_injection_match_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.delete_sql_injection_match_set\naws_api/waf delete_sql_injection_match_set","url":"aws_api/waf.html#delete_sql_injection_match_set"},{"doc":"aws_api/waf","title":"delete_web_acl","content":"pub fn delete_web_acl(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.delete_web_acl\naws_api/waf delete_web_acl","url":"aws_api/waf.html#delete_web_acl"},{"doc":"aws_api/waf","title":"delete_xss_match_set","content":"pub fn delete_xss_match_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.delete_xss_match_set\naws_api/waf delete_xss_match_set","url":"aws_api/waf.html#delete_xss_match_set"},{"doc":"aws_api/waf","title":"get_byte_match_set","content":"pub fn get_byte_match_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.get_byte_match_set\naws_api/waf get_byte_match_set","url":"aws_api/waf.html#get_byte_match_set"},{"doc":"aws_api/waf","title":"get_change_token","content":"pub fn get_change_token(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.get_change_token\naws_api/waf get_change_token","url":"aws_api/waf.html#get_change_token"},{"doc":"aws_api/waf","title":"get_change_token_status","content":"pub fn get_change_token_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.get_change_token_status\naws_api/waf get_change_token_status","url":"aws_api/waf.html#get_change_token_status"},{"doc":"aws_api/waf","title":"get_geo_match_set","content":"pub fn get_geo_match_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.get_geo_match_set\naws_api/waf get_geo_match_set","url":"aws_api/waf.html#get_geo_match_set"},{"doc":"aws_api/waf","title":"get_ip_set","content":"pub fn get_ip_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.get_ip_set\naws_api/waf get_ip_set","url":"aws_api/waf.html#get_ip_set"},{"doc":"aws_api/waf","title":"get_logging_configuration","content":"pub fn get_logging_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.get_logging_configuration\naws_api/waf get_logging_configuration","url":"aws_api/waf.html#get_logging_configuration"},{"doc":"aws_api/waf","title":"get_permission_policy","content":"pub fn get_permission_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.get_permission_policy\naws_api/waf get_permission_policy","url":"aws_api/waf.html#get_permission_policy"},{"doc":"aws_api/waf","title":"get_rate_based_rule","content":"pub fn get_rate_based_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.get_rate_based_rule\naws_api/waf get_rate_based_rule","url":"aws_api/waf.html#get_rate_based_rule"},{"doc":"aws_api/waf","title":"get_rate_based_rule_managed_keys","content":"pub fn get_rate_based_rule_managed_keys(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.get_rate_based_rule_managed_keys\naws_api/waf get_rate_based_rule_managed_keys","url":"aws_api/waf.html#get_rate_based_rule_managed_keys"},{"doc":"aws_api/waf","title":"get_regex_match_set","content":"pub fn get_regex_match_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.get_regex_match_set\naws_api/waf get_regex_match_set","url":"aws_api/waf.html#get_regex_match_set"},{"doc":"aws_api/waf","title":"get_regex_pattern_set","content":"pub fn get_regex_pattern_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.get_regex_pattern_set\naws_api/waf get_regex_pattern_set","url":"aws_api/waf.html#get_regex_pattern_set"},{"doc":"aws_api/waf","title":"get_rule","content":"pub fn get_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.get_rule\naws_api/waf get_rule","url":"aws_api/waf.html#get_rule"},{"doc":"aws_api/waf","title":"get_rule_group","content":"pub fn get_rule_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.get_rule_group\naws_api/waf get_rule_group","url":"aws_api/waf.html#get_rule_group"},{"doc":"aws_api/waf","title":"get_sampled_requests","content":"pub fn get_sampled_requests(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.get_sampled_requests\naws_api/waf get_sampled_requests","url":"aws_api/waf.html#get_sampled_requests"},{"doc":"aws_api/waf","title":"get_size_constraint_set","content":"pub fn get_size_constraint_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.get_size_constraint_set\naws_api/waf get_size_constraint_set","url":"aws_api/waf.html#get_size_constraint_set"},{"doc":"aws_api/waf","title":"get_sql_injection_match_set","content":"pub fn get_sql_injection_match_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.get_sql_injection_match_set\naws_api/waf get_sql_injection_match_set","url":"aws_api/waf.html#get_sql_injection_match_set"},{"doc":"aws_api/waf","title":"get_web_acl","content":"pub fn get_web_acl(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.get_web_acl\naws_api/waf get_web_acl","url":"aws_api/waf.html#get_web_acl"},{"doc":"aws_api/waf","title":"get_xss_match_set","content":"pub fn get_xss_match_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.get_xss_match_set\naws_api/waf get_xss_match_set","url":"aws_api/waf.html#get_xss_match_set"},{"doc":"aws_api/waf","title":"list_activated_rules_in_rule_group","content":"pub fn list_activated_rules_in_rule_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.list_activated_rules_in_rule_group\naws_api/waf list_activated_rules_in_rule_group","url":"aws_api/waf.html#list_activated_rules_in_rule_group"},{"doc":"aws_api/waf","title":"list_byte_match_sets","content":"pub fn list_byte_match_sets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.list_byte_match_sets\naws_api/waf list_byte_match_sets","url":"aws_api/waf.html#list_byte_match_sets"},{"doc":"aws_api/waf","title":"list_geo_match_sets","content":"pub fn list_geo_match_sets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.list_geo_match_sets\naws_api/waf list_geo_match_sets","url":"aws_api/waf.html#list_geo_match_sets"},{"doc":"aws_api/waf","title":"list_ip_sets","content":"pub fn list_ip_sets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.list_ip_sets\naws_api/waf list_ip_sets","url":"aws_api/waf.html#list_ip_sets"},{"doc":"aws_api/waf","title":"list_logging_configurations","content":"pub fn list_logging_configurations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.list_logging_configurations\naws_api/waf list_logging_configurations","url":"aws_api/waf.html#list_logging_configurations"},{"doc":"aws_api/waf","title":"list_rate_based_rules","content":"pub fn list_rate_based_rules(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.list_rate_based_rules\naws_api/waf list_rate_based_rules","url":"aws_api/waf.html#list_rate_based_rules"},{"doc":"aws_api/waf","title":"list_regex_match_sets","content":"pub fn list_regex_match_sets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.list_regex_match_sets\naws_api/waf list_regex_match_sets","url":"aws_api/waf.html#list_regex_match_sets"},{"doc":"aws_api/waf","title":"list_regex_pattern_sets","content":"pub fn list_regex_pattern_sets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.list_regex_pattern_sets\naws_api/waf list_regex_pattern_sets","url":"aws_api/waf.html#list_regex_pattern_sets"},{"doc":"aws_api/waf","title":"list_rule_groups","content":"pub fn list_rule_groups(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.list_rule_groups\naws_api/waf list_rule_groups","url":"aws_api/waf.html#list_rule_groups"},{"doc":"aws_api/waf","title":"list_rules","content":"pub fn list_rules(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.list_rules\naws_api/waf list_rules","url":"aws_api/waf.html#list_rules"},{"doc":"aws_api/waf","title":"list_size_constraint_sets","content":"pub fn list_size_constraint_sets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.list_size_constraint_sets\naws_api/waf list_size_constraint_sets","url":"aws_api/waf.html#list_size_constraint_sets"},{"doc":"aws_api/waf","title":"list_sql_injection_match_sets","content":"pub fn list_sql_injection_match_sets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.list_sql_injection_match_sets\naws_api/waf list_sql_injection_match_sets","url":"aws_api/waf.html#list_sql_injection_match_sets"},{"doc":"aws_api/waf","title":"list_subscribed_rule_groups","content":"pub fn list_subscribed_rule_groups(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.list_subscribed_rule_groups\naws_api/waf list_subscribed_rule_groups","url":"aws_api/waf.html#list_subscribed_rule_groups"},{"doc":"aws_api/waf","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.list_tags_for_resource\naws_api/waf list_tags_for_resource","url":"aws_api/waf.html#list_tags_for_resource"},{"doc":"aws_api/waf","title":"list_web_ac_ls","content":"pub fn list_web_ac_ls(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.list_web_ac_ls\naws_api/waf list_web_ac_ls","url":"aws_api/waf.html#list_web_ac_ls"},{"doc":"aws_api/waf","title":"list_xss_match_sets","content":"pub fn list_xss_match_sets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.list_xss_match_sets\naws_api/waf list_xss_match_sets","url":"aws_api/waf.html#list_xss_match_sets"},{"doc":"aws_api/waf","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/waf.new\naws_api/waf new","url":"aws_api/waf.html#new"},{"doc":"aws_api/waf","title":"put_logging_configuration","content":"pub fn put_logging_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.put_logging_configuration\naws_api/waf put_logging_configuration","url":"aws_api/waf.html#put_logging_configuration"},{"doc":"aws_api/waf","title":"put_permission_policy","content":"pub fn put_permission_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.put_permission_policy\naws_api/waf put_permission_policy","url":"aws_api/waf.html#put_permission_policy"},{"doc":"aws_api/waf","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.tag_resource\naws_api/waf tag_resource","url":"aws_api/waf.html#tag_resource"},{"doc":"aws_api/waf","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.untag_resource\naws_api/waf untag_resource","url":"aws_api/waf.html#untag_resource"},{"doc":"aws_api/waf","title":"update_byte_match_set","content":"pub fn update_byte_match_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.update_byte_match_set\naws_api/waf update_byte_match_set","url":"aws_api/waf.html#update_byte_match_set"},{"doc":"aws_api/waf","title":"update_geo_match_set","content":"pub fn update_geo_match_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.update_geo_match_set\naws_api/waf update_geo_match_set","url":"aws_api/waf.html#update_geo_match_set"},{"doc":"aws_api/waf","title":"update_ip_set","content":"pub fn update_ip_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.update_ip_set\naws_api/waf update_ip_set","url":"aws_api/waf.html#update_ip_set"},{"doc":"aws_api/waf","title":"update_rate_based_rule","content":"pub fn update_rate_based_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.update_rate_based_rule\naws_api/waf update_rate_based_rule","url":"aws_api/waf.html#update_rate_based_rule"},{"doc":"aws_api/waf","title":"update_regex_match_set","content":"pub fn update_regex_match_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.update_regex_match_set\naws_api/waf update_regex_match_set","url":"aws_api/waf.html#update_regex_match_set"},{"doc":"aws_api/waf","title":"update_regex_pattern_set","content":"pub fn update_regex_pattern_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.update_regex_pattern_set\naws_api/waf update_regex_pattern_set","url":"aws_api/waf.html#update_regex_pattern_set"},{"doc":"aws_api/waf","title":"update_rule","content":"pub fn update_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.update_rule\naws_api/waf update_rule","url":"aws_api/waf.html#update_rule"},{"doc":"aws_api/waf","title":"update_rule_group","content":"pub fn update_rule_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.update_rule_group\naws_api/waf update_rule_group","url":"aws_api/waf.html#update_rule_group"},{"doc":"aws_api/waf","title":"update_size_constraint_set","content":"pub fn update_size_constraint_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.update_size_constraint_set\naws_api/waf update_size_constraint_set","url":"aws_api/waf.html#update_size_constraint_set"},{"doc":"aws_api/waf","title":"update_sql_injection_match_set","content":"pub fn update_sql_injection_match_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.update_sql_injection_match_set\naws_api/waf update_sql_injection_match_set","url":"aws_api/waf.html#update_sql_injection_match_set"},{"doc":"aws_api/waf","title":"update_web_acl","content":"pub fn update_web_acl(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.update_web_acl\naws_api/waf update_web_acl","url":"aws_api/waf.html#update_web_acl"},{"doc":"aws_api/waf","title":"update_xss_match_set","content":"pub fn update_xss_match_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf.update_xss_match_set\naws_api/waf update_xss_match_set","url":"aws_api/waf.html#update_xss_match_set"},{"doc":"aws_api/waf","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/waf.with_custom_endpoint\naws_api/waf with_custom_endpoint","url":"aws_api/waf.html#with_custom_endpoint"},{"doc":"aws_api/waf","title":"aws_api/waf","content":"","url":"aws_api/waf.html"},{"doc":"aws_api/waf_regional","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/waf_regional.Client\naws_api/waf_regional Client","url":"aws_api/waf_regional.html#Client"},{"doc":"aws_api/waf_regional","title":"associate_web_acl","content":"pub fn associate_web_acl(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.associate_web_acl\naws_api/waf_regional associate_web_acl","url":"aws_api/waf_regional.html#associate_web_acl"},{"doc":"aws_api/waf_regional","title":"create_byte_match_set","content":"pub fn create_byte_match_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.create_byte_match_set\naws_api/waf_regional create_byte_match_set","url":"aws_api/waf_regional.html#create_byte_match_set"},{"doc":"aws_api/waf_regional","title":"create_geo_match_set","content":"pub fn create_geo_match_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.create_geo_match_set\naws_api/waf_regional create_geo_match_set","url":"aws_api/waf_regional.html#create_geo_match_set"},{"doc":"aws_api/waf_regional","title":"create_ip_set","content":"pub fn create_ip_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.create_ip_set\naws_api/waf_regional create_ip_set","url":"aws_api/waf_regional.html#create_ip_set"},{"doc":"aws_api/waf_regional","title":"create_rate_based_rule","content":"pub fn create_rate_based_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.create_rate_based_rule\naws_api/waf_regional create_rate_based_rule","url":"aws_api/waf_regional.html#create_rate_based_rule"},{"doc":"aws_api/waf_regional","title":"create_regex_match_set","content":"pub fn create_regex_match_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.create_regex_match_set\naws_api/waf_regional create_regex_match_set","url":"aws_api/waf_regional.html#create_regex_match_set"},{"doc":"aws_api/waf_regional","title":"create_regex_pattern_set","content":"pub fn create_regex_pattern_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.create_regex_pattern_set\naws_api/waf_regional create_regex_pattern_set","url":"aws_api/waf_regional.html#create_regex_pattern_set"},{"doc":"aws_api/waf_regional","title":"create_rule","content":"pub fn create_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.create_rule\naws_api/waf_regional create_rule","url":"aws_api/waf_regional.html#create_rule"},{"doc":"aws_api/waf_regional","title":"create_rule_group","content":"pub fn create_rule_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.create_rule_group\naws_api/waf_regional create_rule_group","url":"aws_api/waf_regional.html#create_rule_group"},{"doc":"aws_api/waf_regional","title":"create_size_constraint_set","content":"pub fn create_size_constraint_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.create_size_constraint_set\naws_api/waf_regional create_size_constraint_set","url":"aws_api/waf_regional.html#create_size_constraint_set"},{"doc":"aws_api/waf_regional","title":"create_sql_injection_match_set","content":"pub fn create_sql_injection_match_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.create_sql_injection_match_set\naws_api/waf_regional create_sql_injection_match_set","url":"aws_api/waf_regional.html#create_sql_injection_match_set"},{"doc":"aws_api/waf_regional","title":"create_web_acl","content":"pub fn create_web_acl(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.create_web_acl\naws_api/waf_regional create_web_acl","url":"aws_api/waf_regional.html#create_web_acl"},{"doc":"aws_api/waf_regional","title":"create_web_acl_migration_stack","content":"pub fn create_web_acl_migration_stack(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.create_web_acl_migration_stack\naws_api/waf_regional create_web_acl_migration_stack","url":"aws_api/waf_regional.html#create_web_acl_migration_stack"},{"doc":"aws_api/waf_regional","title":"create_xss_match_set","content":"pub fn create_xss_match_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.create_xss_match_set\naws_api/waf_regional create_xss_match_set","url":"aws_api/waf_regional.html#create_xss_match_set"},{"doc":"aws_api/waf_regional","title":"delete_byte_match_set","content":"pub fn delete_byte_match_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.delete_byte_match_set\naws_api/waf_regional delete_byte_match_set","url":"aws_api/waf_regional.html#delete_byte_match_set"},{"doc":"aws_api/waf_regional","title":"delete_geo_match_set","content":"pub fn delete_geo_match_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.delete_geo_match_set\naws_api/waf_regional delete_geo_match_set","url":"aws_api/waf_regional.html#delete_geo_match_set"},{"doc":"aws_api/waf_regional","title":"delete_ip_set","content":"pub fn delete_ip_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.delete_ip_set\naws_api/waf_regional delete_ip_set","url":"aws_api/waf_regional.html#delete_ip_set"},{"doc":"aws_api/waf_regional","title":"delete_logging_configuration","content":"pub fn delete_logging_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.delete_logging_configuration\naws_api/waf_regional delete_logging_configuration","url":"aws_api/waf_regional.html#delete_logging_configuration"},{"doc":"aws_api/waf_regional","title":"delete_permission_policy","content":"pub fn delete_permission_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.delete_permission_policy\naws_api/waf_regional delete_permission_policy","url":"aws_api/waf_regional.html#delete_permission_policy"},{"doc":"aws_api/waf_regional","title":"delete_rate_based_rule","content":"pub fn delete_rate_based_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.delete_rate_based_rule\naws_api/waf_regional delete_rate_based_rule","url":"aws_api/waf_regional.html#delete_rate_based_rule"},{"doc":"aws_api/waf_regional","title":"delete_regex_match_set","content":"pub fn delete_regex_match_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.delete_regex_match_set\naws_api/waf_regional delete_regex_match_set","url":"aws_api/waf_regional.html#delete_regex_match_set"},{"doc":"aws_api/waf_regional","title":"delete_regex_pattern_set","content":"pub fn delete_regex_pattern_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.delete_regex_pattern_set\naws_api/waf_regional delete_regex_pattern_set","url":"aws_api/waf_regional.html#delete_regex_pattern_set"},{"doc":"aws_api/waf_regional","title":"delete_rule","content":"pub fn delete_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.delete_rule\naws_api/waf_regional delete_rule","url":"aws_api/waf_regional.html#delete_rule"},{"doc":"aws_api/waf_regional","title":"delete_rule_group","content":"pub fn delete_rule_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.delete_rule_group\naws_api/waf_regional delete_rule_group","url":"aws_api/waf_regional.html#delete_rule_group"},{"doc":"aws_api/waf_regional","title":"delete_size_constraint_set","content":"pub fn delete_size_constraint_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.delete_size_constraint_set\naws_api/waf_regional delete_size_constraint_set","url":"aws_api/waf_regional.html#delete_size_constraint_set"},{"doc":"aws_api/waf_regional","title":"delete_sql_injection_match_set","content":"pub fn delete_sql_injection_match_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.delete_sql_injection_match_set\naws_api/waf_regional delete_sql_injection_match_set","url":"aws_api/waf_regional.html#delete_sql_injection_match_set"},{"doc":"aws_api/waf_regional","title":"delete_web_acl","content":"pub fn delete_web_acl(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.delete_web_acl\naws_api/waf_regional delete_web_acl","url":"aws_api/waf_regional.html#delete_web_acl"},{"doc":"aws_api/waf_regional","title":"delete_xss_match_set","content":"pub fn delete_xss_match_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.delete_xss_match_set\naws_api/waf_regional delete_xss_match_set","url":"aws_api/waf_regional.html#delete_xss_match_set"},{"doc":"aws_api/waf_regional","title":"disassociate_web_acl","content":"pub fn disassociate_web_acl(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.disassociate_web_acl\naws_api/waf_regional disassociate_web_acl","url":"aws_api/waf_regional.html#disassociate_web_acl"},{"doc":"aws_api/waf_regional","title":"get_byte_match_set","content":"pub fn get_byte_match_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.get_byte_match_set\naws_api/waf_regional get_byte_match_set","url":"aws_api/waf_regional.html#get_byte_match_set"},{"doc":"aws_api/waf_regional","title":"get_change_token","content":"pub fn get_change_token(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.get_change_token\naws_api/waf_regional get_change_token","url":"aws_api/waf_regional.html#get_change_token"},{"doc":"aws_api/waf_regional","title":"get_change_token_status","content":"pub fn get_change_token_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.get_change_token_status\naws_api/waf_regional get_change_token_status","url":"aws_api/waf_regional.html#get_change_token_status"},{"doc":"aws_api/waf_regional","title":"get_geo_match_set","content":"pub fn get_geo_match_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.get_geo_match_set\naws_api/waf_regional get_geo_match_set","url":"aws_api/waf_regional.html#get_geo_match_set"},{"doc":"aws_api/waf_regional","title":"get_ip_set","content":"pub fn get_ip_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.get_ip_set\naws_api/waf_regional get_ip_set","url":"aws_api/waf_regional.html#get_ip_set"},{"doc":"aws_api/waf_regional","title":"get_logging_configuration","content":"pub fn get_logging_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.get_logging_configuration\naws_api/waf_regional get_logging_configuration","url":"aws_api/waf_regional.html#get_logging_configuration"},{"doc":"aws_api/waf_regional","title":"get_permission_policy","content":"pub fn get_permission_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.get_permission_policy\naws_api/waf_regional get_permission_policy","url":"aws_api/waf_regional.html#get_permission_policy"},{"doc":"aws_api/waf_regional","title":"get_rate_based_rule","content":"pub fn get_rate_based_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.get_rate_based_rule\naws_api/waf_regional get_rate_based_rule","url":"aws_api/waf_regional.html#get_rate_based_rule"},{"doc":"aws_api/waf_regional","title":"get_rate_based_rule_managed_keys","content":"pub fn get_rate_based_rule_managed_keys(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.get_rate_based_rule_managed_keys\naws_api/waf_regional get_rate_based_rule_managed_keys","url":"aws_api/waf_regional.html#get_rate_based_rule_managed_keys"},{"doc":"aws_api/waf_regional","title":"get_regex_match_set","content":"pub fn get_regex_match_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.get_regex_match_set\naws_api/waf_regional get_regex_match_set","url":"aws_api/waf_regional.html#get_regex_match_set"},{"doc":"aws_api/waf_regional","title":"get_regex_pattern_set","content":"pub fn get_regex_pattern_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.get_regex_pattern_set\naws_api/waf_regional get_regex_pattern_set","url":"aws_api/waf_regional.html#get_regex_pattern_set"},{"doc":"aws_api/waf_regional","title":"get_rule","content":"pub fn get_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.get_rule\naws_api/waf_regional get_rule","url":"aws_api/waf_regional.html#get_rule"},{"doc":"aws_api/waf_regional","title":"get_rule_group","content":"pub fn get_rule_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.get_rule_group\naws_api/waf_regional get_rule_group","url":"aws_api/waf_regional.html#get_rule_group"},{"doc":"aws_api/waf_regional","title":"get_sampled_requests","content":"pub fn get_sampled_requests(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.get_sampled_requests\naws_api/waf_regional get_sampled_requests","url":"aws_api/waf_regional.html#get_sampled_requests"},{"doc":"aws_api/waf_regional","title":"get_size_constraint_set","content":"pub fn get_size_constraint_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.get_size_constraint_set\naws_api/waf_regional get_size_constraint_set","url":"aws_api/waf_regional.html#get_size_constraint_set"},{"doc":"aws_api/waf_regional","title":"get_sql_injection_match_set","content":"pub fn get_sql_injection_match_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.get_sql_injection_match_set\naws_api/waf_regional get_sql_injection_match_set","url":"aws_api/waf_regional.html#get_sql_injection_match_set"},{"doc":"aws_api/waf_regional","title":"get_web_acl","content":"pub fn get_web_acl(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.get_web_acl\naws_api/waf_regional get_web_acl","url":"aws_api/waf_regional.html#get_web_acl"},{"doc":"aws_api/waf_regional","title":"get_web_acl_for_resource","content":"pub fn get_web_acl_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.get_web_acl_for_resource\naws_api/waf_regional get_web_acl_for_resource","url":"aws_api/waf_regional.html#get_web_acl_for_resource"},{"doc":"aws_api/waf_regional","title":"get_xss_match_set","content":"pub fn get_xss_match_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.get_xss_match_set\naws_api/waf_regional get_xss_match_set","url":"aws_api/waf_regional.html#get_xss_match_set"},{"doc":"aws_api/waf_regional","title":"list_activated_rules_in_rule_group","content":"pub fn list_activated_rules_in_rule_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.list_activated_rules_in_rule_group\naws_api/waf_regional list_activated_rules_in_rule_group","url":"aws_api/waf_regional.html#list_activated_rules_in_rule_group"},{"doc":"aws_api/waf_regional","title":"list_byte_match_sets","content":"pub fn list_byte_match_sets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.list_byte_match_sets\naws_api/waf_regional list_byte_match_sets","url":"aws_api/waf_regional.html#list_byte_match_sets"},{"doc":"aws_api/waf_regional","title":"list_geo_match_sets","content":"pub fn list_geo_match_sets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.list_geo_match_sets\naws_api/waf_regional list_geo_match_sets","url":"aws_api/waf_regional.html#list_geo_match_sets"},{"doc":"aws_api/waf_regional","title":"list_ip_sets","content":"pub fn list_ip_sets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.list_ip_sets\naws_api/waf_regional list_ip_sets","url":"aws_api/waf_regional.html#list_ip_sets"},{"doc":"aws_api/waf_regional","title":"list_logging_configurations","content":"pub fn list_logging_configurations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.list_logging_configurations\naws_api/waf_regional list_logging_configurations","url":"aws_api/waf_regional.html#list_logging_configurations"},{"doc":"aws_api/waf_regional","title":"list_rate_based_rules","content":"pub fn list_rate_based_rules(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.list_rate_based_rules\naws_api/waf_regional list_rate_based_rules","url":"aws_api/waf_regional.html#list_rate_based_rules"},{"doc":"aws_api/waf_regional","title":"list_regex_match_sets","content":"pub fn list_regex_match_sets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.list_regex_match_sets\naws_api/waf_regional list_regex_match_sets","url":"aws_api/waf_regional.html#list_regex_match_sets"},{"doc":"aws_api/waf_regional","title":"list_regex_pattern_sets","content":"pub fn list_regex_pattern_sets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.list_regex_pattern_sets\naws_api/waf_regional list_regex_pattern_sets","url":"aws_api/waf_regional.html#list_regex_pattern_sets"},{"doc":"aws_api/waf_regional","title":"list_resources_for_web_acl","content":"pub fn list_resources_for_web_acl(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.list_resources_for_web_acl\naws_api/waf_regional list_resources_for_web_acl","url":"aws_api/waf_regional.html#list_resources_for_web_acl"},{"doc":"aws_api/waf_regional","title":"list_rule_groups","content":"pub fn list_rule_groups(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.list_rule_groups\naws_api/waf_regional list_rule_groups","url":"aws_api/waf_regional.html#list_rule_groups"},{"doc":"aws_api/waf_regional","title":"list_rules","content":"pub fn list_rules(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.list_rules\naws_api/waf_regional list_rules","url":"aws_api/waf_regional.html#list_rules"},{"doc":"aws_api/waf_regional","title":"list_size_constraint_sets","content":"pub fn list_size_constraint_sets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.list_size_constraint_sets\naws_api/waf_regional list_size_constraint_sets","url":"aws_api/waf_regional.html#list_size_constraint_sets"},{"doc":"aws_api/waf_regional","title":"list_sql_injection_match_sets","content":"pub fn list_sql_injection_match_sets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.list_sql_injection_match_sets\naws_api/waf_regional list_sql_injection_match_sets","url":"aws_api/waf_regional.html#list_sql_injection_match_sets"},{"doc":"aws_api/waf_regional","title":"list_subscribed_rule_groups","content":"pub fn list_subscribed_rule_groups(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.list_subscribed_rule_groups\naws_api/waf_regional list_subscribed_rule_groups","url":"aws_api/waf_regional.html#list_subscribed_rule_groups"},{"doc":"aws_api/waf_regional","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.list_tags_for_resource\naws_api/waf_regional list_tags_for_resource","url":"aws_api/waf_regional.html#list_tags_for_resource"},{"doc":"aws_api/waf_regional","title":"list_web_ac_ls","content":"pub fn list_web_ac_ls(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.list_web_ac_ls\naws_api/waf_regional list_web_ac_ls","url":"aws_api/waf_regional.html#list_web_ac_ls"},{"doc":"aws_api/waf_regional","title":"list_xss_match_sets","content":"pub fn list_xss_match_sets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.list_xss_match_sets\naws_api/waf_regional list_xss_match_sets","url":"aws_api/waf_regional.html#list_xss_match_sets"},{"doc":"aws_api/waf_regional","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/waf_regional.new\naws_api/waf_regional new","url":"aws_api/waf_regional.html#new"},{"doc":"aws_api/waf_regional","title":"put_logging_configuration","content":"pub fn put_logging_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.put_logging_configuration\naws_api/waf_regional put_logging_configuration","url":"aws_api/waf_regional.html#put_logging_configuration"},{"doc":"aws_api/waf_regional","title":"put_permission_policy","content":"pub fn put_permission_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.put_permission_policy\naws_api/waf_regional put_permission_policy","url":"aws_api/waf_regional.html#put_permission_policy"},{"doc":"aws_api/waf_regional","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.tag_resource\naws_api/waf_regional tag_resource","url":"aws_api/waf_regional.html#tag_resource"},{"doc":"aws_api/waf_regional","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.untag_resource\naws_api/waf_regional untag_resource","url":"aws_api/waf_regional.html#untag_resource"},{"doc":"aws_api/waf_regional","title":"update_byte_match_set","content":"pub fn update_byte_match_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.update_byte_match_set\naws_api/waf_regional update_byte_match_set","url":"aws_api/waf_regional.html#update_byte_match_set"},{"doc":"aws_api/waf_regional","title":"update_geo_match_set","content":"pub fn update_geo_match_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.update_geo_match_set\naws_api/waf_regional update_geo_match_set","url":"aws_api/waf_regional.html#update_geo_match_set"},{"doc":"aws_api/waf_regional","title":"update_ip_set","content":"pub fn update_ip_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.update_ip_set\naws_api/waf_regional update_ip_set","url":"aws_api/waf_regional.html#update_ip_set"},{"doc":"aws_api/waf_regional","title":"update_rate_based_rule","content":"pub fn update_rate_based_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.update_rate_based_rule\naws_api/waf_regional update_rate_based_rule","url":"aws_api/waf_regional.html#update_rate_based_rule"},{"doc":"aws_api/waf_regional","title":"update_regex_match_set","content":"pub fn update_regex_match_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.update_regex_match_set\naws_api/waf_regional update_regex_match_set","url":"aws_api/waf_regional.html#update_regex_match_set"},{"doc":"aws_api/waf_regional","title":"update_regex_pattern_set","content":"pub fn update_regex_pattern_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.update_regex_pattern_set\naws_api/waf_regional update_regex_pattern_set","url":"aws_api/waf_regional.html#update_regex_pattern_set"},{"doc":"aws_api/waf_regional","title":"update_rule","content":"pub fn update_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.update_rule\naws_api/waf_regional update_rule","url":"aws_api/waf_regional.html#update_rule"},{"doc":"aws_api/waf_regional","title":"update_rule_group","content":"pub fn update_rule_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.update_rule_group\naws_api/waf_regional update_rule_group","url":"aws_api/waf_regional.html#update_rule_group"},{"doc":"aws_api/waf_regional","title":"update_size_constraint_set","content":"pub fn update_size_constraint_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.update_size_constraint_set\naws_api/waf_regional update_size_constraint_set","url":"aws_api/waf_regional.html#update_size_constraint_set"},{"doc":"aws_api/waf_regional","title":"update_sql_injection_match_set","content":"pub fn update_sql_injection_match_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.update_sql_injection_match_set\naws_api/waf_regional update_sql_injection_match_set","url":"aws_api/waf_regional.html#update_sql_injection_match_set"},{"doc":"aws_api/waf_regional","title":"update_web_acl","content":"pub fn update_web_acl(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.update_web_acl\naws_api/waf_regional update_web_acl","url":"aws_api/waf_regional.html#update_web_acl"},{"doc":"aws_api/waf_regional","title":"update_xss_match_set","content":"pub fn update_xss_match_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/waf_regional.update_xss_match_set\naws_api/waf_regional update_xss_match_set","url":"aws_api/waf_regional.html#update_xss_match_set"},{"doc":"aws_api/waf_regional","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/waf_regional.with_custom_endpoint\naws_api/waf_regional with_custom_endpoint","url":"aws_api/waf_regional.html#with_custom_endpoint"},{"doc":"aws_api/waf_regional","title":"aws_api/waf_regional","content":"","url":"aws_api/waf_regional.html"},{"doc":"aws_api/wafv2","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/wafv2.Client\naws_api/wafv2 Client","url":"aws_api/wafv2.html#Client"},{"doc":"aws_api/wafv2","title":"associate_web_acl","content":"pub fn associate_web_acl(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.associate_web_acl\naws_api/wafv2 associate_web_acl","url":"aws_api/wafv2.html#associate_web_acl"},{"doc":"aws_api/wafv2","title":"check_capacity","content":"pub fn check_capacity(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.check_capacity\naws_api/wafv2 check_capacity","url":"aws_api/wafv2.html#check_capacity"},{"doc":"aws_api/wafv2","title":"create_api_key","content":"pub fn create_api_key(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.create_api_key\naws_api/wafv2 create_api_key","url":"aws_api/wafv2.html#create_api_key"},{"doc":"aws_api/wafv2","title":"create_ip_set","content":"pub fn create_ip_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.create_ip_set\naws_api/wafv2 create_ip_set","url":"aws_api/wafv2.html#create_ip_set"},{"doc":"aws_api/wafv2","title":"create_regex_pattern_set","content":"pub fn create_regex_pattern_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.create_regex_pattern_set\naws_api/wafv2 create_regex_pattern_set","url":"aws_api/wafv2.html#create_regex_pattern_set"},{"doc":"aws_api/wafv2","title":"create_rule_group","content":"pub fn create_rule_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.create_rule_group\naws_api/wafv2 create_rule_group","url":"aws_api/wafv2.html#create_rule_group"},{"doc":"aws_api/wafv2","title":"create_web_acl","content":"pub fn create_web_acl(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.create_web_acl\naws_api/wafv2 create_web_acl","url":"aws_api/wafv2.html#create_web_acl"},{"doc":"aws_api/wafv2","title":"delete_api_key","content":"pub fn delete_api_key(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.delete_api_key\naws_api/wafv2 delete_api_key","url":"aws_api/wafv2.html#delete_api_key"},{"doc":"aws_api/wafv2","title":"delete_firewall_manager_rule_groups","content":"pub fn delete_firewall_manager_rule_groups(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.delete_firewall_manager_rule_groups\naws_api/wafv2 delete_firewall_manager_rule_groups","url":"aws_api/wafv2.html#delete_firewall_manager_rule_groups"},{"doc":"aws_api/wafv2","title":"delete_ip_set","content":"pub fn delete_ip_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.delete_ip_set\naws_api/wafv2 delete_ip_set","url":"aws_api/wafv2.html#delete_ip_set"},{"doc":"aws_api/wafv2","title":"delete_logging_configuration","content":"pub fn delete_logging_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.delete_logging_configuration\naws_api/wafv2 delete_logging_configuration","url":"aws_api/wafv2.html#delete_logging_configuration"},{"doc":"aws_api/wafv2","title":"delete_permission_policy","content":"pub fn delete_permission_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.delete_permission_policy\naws_api/wafv2 delete_permission_policy","url":"aws_api/wafv2.html#delete_permission_policy"},{"doc":"aws_api/wafv2","title":"delete_regex_pattern_set","content":"pub fn delete_regex_pattern_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.delete_regex_pattern_set\naws_api/wafv2 delete_regex_pattern_set","url":"aws_api/wafv2.html#delete_regex_pattern_set"},{"doc":"aws_api/wafv2","title":"delete_rule_group","content":"pub fn delete_rule_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.delete_rule_group\naws_api/wafv2 delete_rule_group","url":"aws_api/wafv2.html#delete_rule_group"},{"doc":"aws_api/wafv2","title":"delete_web_acl","content":"pub fn delete_web_acl(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.delete_web_acl\naws_api/wafv2 delete_web_acl","url":"aws_api/wafv2.html#delete_web_acl"},{"doc":"aws_api/wafv2","title":"describe_all_managed_products","content":"pub fn describe_all_managed_products(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.describe_all_managed_products\naws_api/wafv2 describe_all_managed_products","url":"aws_api/wafv2.html#describe_all_managed_products"},{"doc":"aws_api/wafv2","title":"describe_managed_products_by_vendor","content":"pub fn describe_managed_products_by_vendor(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.describe_managed_products_by_vendor\naws_api/wafv2 describe_managed_products_by_vendor","url":"aws_api/wafv2.html#describe_managed_products_by_vendor"},{"doc":"aws_api/wafv2","title":"describe_managed_rule_group","content":"pub fn describe_managed_rule_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.describe_managed_rule_group\naws_api/wafv2 describe_managed_rule_group","url":"aws_api/wafv2.html#describe_managed_rule_group"},{"doc":"aws_api/wafv2","title":"disassociate_web_acl","content":"pub fn disassociate_web_acl(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.disassociate_web_acl\naws_api/wafv2 disassociate_web_acl","url":"aws_api/wafv2.html#disassociate_web_acl"},{"doc":"aws_api/wafv2","title":"generate_mobile_sdk_release_url","content":"pub fn generate_mobile_sdk_release_url(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.generate_mobile_sdk_release_url\naws_api/wafv2 generate_mobile_sdk_release_url","url":"aws_api/wafv2.html#generate_mobile_sdk_release_url"},{"doc":"aws_api/wafv2","title":"get_decrypted_api_key","content":"pub fn get_decrypted_api_key(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.get_decrypted_api_key\naws_api/wafv2 get_decrypted_api_key","url":"aws_api/wafv2.html#get_decrypted_api_key"},{"doc":"aws_api/wafv2","title":"get_ip_set","content":"pub fn get_ip_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.get_ip_set\naws_api/wafv2 get_ip_set","url":"aws_api/wafv2.html#get_ip_set"},{"doc":"aws_api/wafv2","title":"get_logging_configuration","content":"pub fn get_logging_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.get_logging_configuration\naws_api/wafv2 get_logging_configuration","url":"aws_api/wafv2.html#get_logging_configuration"},{"doc":"aws_api/wafv2","title":"get_managed_rule_set","content":"pub fn get_managed_rule_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.get_managed_rule_set\naws_api/wafv2 get_managed_rule_set","url":"aws_api/wafv2.html#get_managed_rule_set"},{"doc":"aws_api/wafv2","title":"get_mobile_sdk_release","content":"pub fn get_mobile_sdk_release(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.get_mobile_sdk_release\naws_api/wafv2 get_mobile_sdk_release","url":"aws_api/wafv2.html#get_mobile_sdk_release"},{"doc":"aws_api/wafv2","title":"get_permission_policy","content":"pub fn get_permission_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.get_permission_policy\naws_api/wafv2 get_permission_policy","url":"aws_api/wafv2.html#get_permission_policy"},{"doc":"aws_api/wafv2","title":"get_rate_based_statement_managed_keys","content":"pub fn get_rate_based_statement_managed_keys(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.get_rate_based_statement_managed_keys\naws_api/wafv2 get_rate_based_statement_managed_keys","url":"aws_api/wafv2.html#get_rate_based_statement_managed_keys"},{"doc":"aws_api/wafv2","title":"get_regex_pattern_set","content":"pub fn get_regex_pattern_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.get_regex_pattern_set\naws_api/wafv2 get_regex_pattern_set","url":"aws_api/wafv2.html#get_regex_pattern_set"},{"doc":"aws_api/wafv2","title":"get_rule_group","content":"pub fn get_rule_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.get_rule_group\naws_api/wafv2 get_rule_group","url":"aws_api/wafv2.html#get_rule_group"},{"doc":"aws_api/wafv2","title":"get_sampled_requests","content":"pub fn get_sampled_requests(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.get_sampled_requests\naws_api/wafv2 get_sampled_requests","url":"aws_api/wafv2.html#get_sampled_requests"},{"doc":"aws_api/wafv2","title":"get_web_acl","content":"pub fn get_web_acl(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.get_web_acl\naws_api/wafv2 get_web_acl","url":"aws_api/wafv2.html#get_web_acl"},{"doc":"aws_api/wafv2","title":"get_web_acl_for_resource","content":"pub fn get_web_acl_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.get_web_acl_for_resource\naws_api/wafv2 get_web_acl_for_resource","url":"aws_api/wafv2.html#get_web_acl_for_resource"},{"doc":"aws_api/wafv2","title":"list_api_keys","content":"pub fn list_api_keys(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.list_api_keys\naws_api/wafv2 list_api_keys","url":"aws_api/wafv2.html#list_api_keys"},{"doc":"aws_api/wafv2","title":"list_available_managed_rule_group_versions","content":"pub fn list_available_managed_rule_group_versions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.list_available_managed_rule_group_versions\naws_api/wafv2 list_available_managed_rule_group_versions","url":"aws_api/wafv2.html#list_available_managed_rule_group_versions"},{"doc":"aws_api/wafv2","title":"list_available_managed_rule_groups","content":"pub fn list_available_managed_rule_groups(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.list_available_managed_rule_groups\naws_api/wafv2 list_available_managed_rule_groups","url":"aws_api/wafv2.html#list_available_managed_rule_groups"},{"doc":"aws_api/wafv2","title":"list_ip_sets","content":"pub fn list_ip_sets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.list_ip_sets\naws_api/wafv2 list_ip_sets","url":"aws_api/wafv2.html#list_ip_sets"},{"doc":"aws_api/wafv2","title":"list_logging_configurations","content":"pub fn list_logging_configurations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.list_logging_configurations\naws_api/wafv2 list_logging_configurations","url":"aws_api/wafv2.html#list_logging_configurations"},{"doc":"aws_api/wafv2","title":"list_managed_rule_sets","content":"pub fn list_managed_rule_sets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.list_managed_rule_sets\naws_api/wafv2 list_managed_rule_sets","url":"aws_api/wafv2.html#list_managed_rule_sets"},{"doc":"aws_api/wafv2","title":"list_mobile_sdk_releases","content":"pub fn list_mobile_sdk_releases(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.list_mobile_sdk_releases\naws_api/wafv2 list_mobile_sdk_releases","url":"aws_api/wafv2.html#list_mobile_sdk_releases"},{"doc":"aws_api/wafv2","title":"list_regex_pattern_sets","content":"pub fn list_regex_pattern_sets(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.list_regex_pattern_sets\naws_api/wafv2 list_regex_pattern_sets","url":"aws_api/wafv2.html#list_regex_pattern_sets"},{"doc":"aws_api/wafv2","title":"list_resources_for_web_acl","content":"pub fn list_resources_for_web_acl(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.list_resources_for_web_acl\naws_api/wafv2 list_resources_for_web_acl","url":"aws_api/wafv2.html#list_resources_for_web_acl"},{"doc":"aws_api/wafv2","title":"list_rule_groups","content":"pub fn list_rule_groups(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.list_rule_groups\naws_api/wafv2 list_rule_groups","url":"aws_api/wafv2.html#list_rule_groups"},{"doc":"aws_api/wafv2","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.list_tags_for_resource\naws_api/wafv2 list_tags_for_resource","url":"aws_api/wafv2.html#list_tags_for_resource"},{"doc":"aws_api/wafv2","title":"list_web_ac_ls","content":"pub fn list_web_ac_ls(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.list_web_ac_ls\naws_api/wafv2 list_web_ac_ls","url":"aws_api/wafv2.html#list_web_ac_ls"},{"doc":"aws_api/wafv2","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/wafv2.new\naws_api/wafv2 new","url":"aws_api/wafv2.html#new"},{"doc":"aws_api/wafv2","title":"put_logging_configuration","content":"pub fn put_logging_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.put_logging_configuration\naws_api/wafv2 put_logging_configuration","url":"aws_api/wafv2.html#put_logging_configuration"},{"doc":"aws_api/wafv2","title":"put_managed_rule_set_versions","content":"pub fn put_managed_rule_set_versions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.put_managed_rule_set_versions\naws_api/wafv2 put_managed_rule_set_versions","url":"aws_api/wafv2.html#put_managed_rule_set_versions"},{"doc":"aws_api/wafv2","title":"put_permission_policy","content":"pub fn put_permission_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.put_permission_policy\naws_api/wafv2 put_permission_policy","url":"aws_api/wafv2.html#put_permission_policy"},{"doc":"aws_api/wafv2","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.tag_resource\naws_api/wafv2 tag_resource","url":"aws_api/wafv2.html#tag_resource"},{"doc":"aws_api/wafv2","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.untag_resource\naws_api/wafv2 untag_resource","url":"aws_api/wafv2.html#untag_resource"},{"doc":"aws_api/wafv2","title":"update_ip_set","content":"pub fn update_ip_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.update_ip_set\naws_api/wafv2 update_ip_set","url":"aws_api/wafv2.html#update_ip_set"},{"doc":"aws_api/wafv2","title":"update_managed_rule_set_version_expiry_date","content":"pub fn update_managed_rule_set_version_expiry_date(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.update_managed_rule_set_version_expiry_date\naws_api/wafv2 update_managed_rule_set_version_expiry_date","url":"aws_api/wafv2.html#update_managed_rule_set_version_expiry_date"},{"doc":"aws_api/wafv2","title":"update_regex_pattern_set","content":"pub fn update_regex_pattern_set(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.update_regex_pattern_set\naws_api/wafv2 update_regex_pattern_set","url":"aws_api/wafv2.html#update_regex_pattern_set"},{"doc":"aws_api/wafv2","title":"update_rule_group","content":"pub fn update_rule_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.update_rule_group\naws_api/wafv2 update_rule_group","url":"aws_api/wafv2.html#update_rule_group"},{"doc":"aws_api/wafv2","title":"update_web_acl","content":"pub fn update_web_acl(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wafv2.update_web_acl\naws_api/wafv2 update_web_acl","url":"aws_api/wafv2.html#update_web_acl"},{"doc":"aws_api/wafv2","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/wafv2.with_custom_endpoint\naws_api/wafv2 with_custom_endpoint","url":"aws_api/wafv2.html#with_custom_endpoint"},{"doc":"aws_api/wafv2","title":"aws_api/wafv2","content":"","url":"aws_api/wafv2.html"},{"doc":"aws_api/wellarchitected","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/wellarchitected.Client\naws_api/wellarchitected Client","url":"aws_api/wellarchitected.html#Client"},{"doc":"aws_api/wellarchitected","title":"associate_lenses","content":"pub fn associate_lenses(\n  client: Client,\n  workload_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.associate_lenses\naws_api/wellarchitected associate_lenses","url":"aws_api/wellarchitected.html#associate_lenses"},{"doc":"aws_api/wellarchitected","title":"associate_profiles","content":"pub fn associate_profiles(\n  client: Client,\n  workload_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.associate_profiles\naws_api/wellarchitected associate_profiles","url":"aws_api/wellarchitected.html#associate_profiles"},{"doc":"aws_api/wellarchitected","title":"create_lens_share","content":"pub fn create_lens_share(\n  client: Client,\n  lens_alias: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.create_lens_share\naws_api/wellarchitected create_lens_share","url":"aws_api/wellarchitected.html#create_lens_share"},{"doc":"aws_api/wellarchitected","title":"create_lens_version","content":"pub fn create_lens_version(\n  client: Client,\n  lens_alias: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.create_lens_version\naws_api/wellarchitected create_lens_version","url":"aws_api/wellarchitected.html#create_lens_version"},{"doc":"aws_api/wellarchitected","title":"create_milestone","content":"pub fn create_milestone(\n  client: Client,\n  workload_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.create_milestone\naws_api/wellarchitected create_milestone","url":"aws_api/wellarchitected.html#create_milestone"},{"doc":"aws_api/wellarchitected","title":"create_profile","content":"pub fn create_profile(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.create_profile\naws_api/wellarchitected create_profile","url":"aws_api/wellarchitected.html#create_profile"},{"doc":"aws_api/wellarchitected","title":"create_profile_share","content":"pub fn create_profile_share(\n  client: Client,\n  profile_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.create_profile_share\naws_api/wellarchitected create_profile_share","url":"aws_api/wellarchitected.html#create_profile_share"},{"doc":"aws_api/wellarchitected","title":"create_review_template","content":"pub fn create_review_template(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.create_review_template\naws_api/wellarchitected create_review_template","url":"aws_api/wellarchitected.html#create_review_template"},{"doc":"aws_api/wellarchitected","title":"create_template_share","content":"pub fn create_template_share(\n  client: Client,\n  template_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.create_template_share\naws_api/wellarchitected create_template_share","url":"aws_api/wellarchitected.html#create_template_share"},{"doc":"aws_api/wellarchitected","title":"create_workload","content":"pub fn create_workload(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.create_workload\naws_api/wellarchitected create_workload","url":"aws_api/wellarchitected.html#create_workload"},{"doc":"aws_api/wellarchitected","title":"create_workload_share","content":"pub fn create_workload_share(\n  client: Client,\n  workload_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.create_workload_share\naws_api/wellarchitected create_workload_share","url":"aws_api/wellarchitected.html#create_workload_share"},{"doc":"aws_api/wellarchitected","title":"delete_lens","content":"pub fn delete_lens(\n  client: Client,\n  lens_alias: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.delete_lens\naws_api/wellarchitected delete_lens","url":"aws_api/wellarchitected.html#delete_lens"},{"doc":"aws_api/wellarchitected","title":"delete_lens_share","content":"pub fn delete_lens_share(\n  client: Client,\n  lens_alias: String,\n  share_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.delete_lens_share\naws_api/wellarchitected delete_lens_share","url":"aws_api/wellarchitected.html#delete_lens_share"},{"doc":"aws_api/wellarchitected","title":"delete_profile","content":"pub fn delete_profile(\n  client: Client,\n  profile_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.delete_profile\naws_api/wellarchitected delete_profile","url":"aws_api/wellarchitected.html#delete_profile"},{"doc":"aws_api/wellarchitected","title":"delete_profile_share","content":"pub fn delete_profile_share(\n  client: Client,\n  profile_arn: String,\n  share_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.delete_profile_share\naws_api/wellarchitected delete_profile_share","url":"aws_api/wellarchitected.html#delete_profile_share"},{"doc":"aws_api/wellarchitected","title":"delete_review_template","content":"pub fn delete_review_template(\n  client: Client,\n  template_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.delete_review_template\naws_api/wellarchitected delete_review_template","url":"aws_api/wellarchitected.html#delete_review_template"},{"doc":"aws_api/wellarchitected","title":"delete_template_share","content":"pub fn delete_template_share(\n  client: Client,\n  template_arn: String,\n  share_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.delete_template_share\naws_api/wellarchitected delete_template_share","url":"aws_api/wellarchitected.html#delete_template_share"},{"doc":"aws_api/wellarchitected","title":"delete_workload","content":"pub fn delete_workload(\n  client: Client,\n  workload_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.delete_workload\naws_api/wellarchitected delete_workload","url":"aws_api/wellarchitected.html#delete_workload"},{"doc":"aws_api/wellarchitected","title":"delete_workload_share","content":"pub fn delete_workload_share(\n  client: Client,\n  workload_id: String,\n  share_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.delete_workload_share\naws_api/wellarchitected delete_workload_share","url":"aws_api/wellarchitected.html#delete_workload_share"},{"doc":"aws_api/wellarchitected","title":"disassociate_lenses","content":"pub fn disassociate_lenses(\n  client: Client,\n  workload_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.disassociate_lenses\naws_api/wellarchitected disassociate_lenses","url":"aws_api/wellarchitected.html#disassociate_lenses"},{"doc":"aws_api/wellarchitected","title":"disassociate_profiles","content":"pub fn disassociate_profiles(\n  client: Client,\n  workload_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.disassociate_profiles\naws_api/wellarchitected disassociate_profiles","url":"aws_api/wellarchitected.html#disassociate_profiles"},{"doc":"aws_api/wellarchitected","title":"export_lens","content":"pub fn export_lens(\n  client: Client,\n  lens_alias: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.export_lens\naws_api/wellarchitected export_lens","url":"aws_api/wellarchitected.html#export_lens"},{"doc":"aws_api/wellarchitected","title":"get_answer","content":"pub fn get_answer(\n  client: Client,\n  workload_id: String,\n  lens_alias: String,\n  question_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.get_answer\naws_api/wellarchitected get_answer","url":"aws_api/wellarchitected.html#get_answer"},{"doc":"aws_api/wellarchitected","title":"get_consolidated_report","content":"pub fn get_consolidated_report(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.get_consolidated_report\naws_api/wellarchitected get_consolidated_report","url":"aws_api/wellarchitected.html#get_consolidated_report"},{"doc":"aws_api/wellarchitected","title":"get_global_settings","content":"pub fn get_global_settings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.get_global_settings\naws_api/wellarchitected get_global_settings","url":"aws_api/wellarchitected.html#get_global_settings"},{"doc":"aws_api/wellarchitected","title":"get_lens","content":"pub fn get_lens(\n  client: Client,\n  lens_alias: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.get_lens\naws_api/wellarchitected get_lens","url":"aws_api/wellarchitected.html#get_lens"},{"doc":"aws_api/wellarchitected","title":"get_lens_review","content":"pub fn get_lens_review(\n  client: Client,\n  workload_id: String,\n  lens_alias: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.get_lens_review\naws_api/wellarchitected get_lens_review","url":"aws_api/wellarchitected.html#get_lens_review"},{"doc":"aws_api/wellarchitected","title":"get_lens_review_report","content":"pub fn get_lens_review_report(\n  client: Client,\n  workload_id: String,\n  lens_alias: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.get_lens_review_report\naws_api/wellarchitected get_lens_review_report","url":"aws_api/wellarchitected.html#get_lens_review_report"},{"doc":"aws_api/wellarchitected","title":"get_lens_version_difference","content":"pub fn get_lens_version_difference(\n  client: Client,\n  lens_alias: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.get_lens_version_difference\naws_api/wellarchitected get_lens_version_difference","url":"aws_api/wellarchitected.html#get_lens_version_difference"},{"doc":"aws_api/wellarchitected","title":"get_milestone","content":"pub fn get_milestone(\n  client: Client,\n  workload_id: String,\n  milestone_number: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.get_milestone\naws_api/wellarchitected get_milestone","url":"aws_api/wellarchitected.html#get_milestone"},{"doc":"aws_api/wellarchitected","title":"get_profile","content":"pub fn get_profile(\n  client: Client,\n  profile_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.get_profile\naws_api/wellarchitected get_profile","url":"aws_api/wellarchitected.html#get_profile"},{"doc":"aws_api/wellarchitected","title":"get_profile_template","content":"pub fn get_profile_template(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.get_profile_template\naws_api/wellarchitected get_profile_template","url":"aws_api/wellarchitected.html#get_profile_template"},{"doc":"aws_api/wellarchitected","title":"get_review_template","content":"pub fn get_review_template(\n  client: Client,\n  template_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.get_review_template\naws_api/wellarchitected get_review_template","url":"aws_api/wellarchitected.html#get_review_template"},{"doc":"aws_api/wellarchitected","title":"get_review_template_answer","content":"pub fn get_review_template_answer(\n  client: Client,\n  template_arn: String,\n  lens_alias: String,\n  question_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.get_review_template_answer\naws_api/wellarchitected get_review_template_answer","url":"aws_api/wellarchitected.html#get_review_template_answer"},{"doc":"aws_api/wellarchitected","title":"get_review_template_lens_review","content":"pub fn get_review_template_lens_review(\n  client: Client,\n  template_arn: String,\n  lens_alias: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.get_review_template_lens_review\naws_api/wellarchitected get_review_template_lens_review","url":"aws_api/wellarchitected.html#get_review_template_lens_review"},{"doc":"aws_api/wellarchitected","title":"get_workload","content":"pub fn get_workload(\n  client: Client,\n  workload_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.get_workload\naws_api/wellarchitected get_workload","url":"aws_api/wellarchitected.html#get_workload"},{"doc":"aws_api/wellarchitected","title":"import_lens","content":"pub fn import_lens(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.import_lens\naws_api/wellarchitected import_lens","url":"aws_api/wellarchitected.html#import_lens"},{"doc":"aws_api/wellarchitected","title":"list_answers","content":"pub fn list_answers(\n  client: Client,\n  workload_id: String,\n  lens_alias: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.list_answers\naws_api/wellarchitected list_answers","url":"aws_api/wellarchitected.html#list_answers"},{"doc":"aws_api/wellarchitected","title":"list_check_details","content":"pub fn list_check_details(\n  client: Client,\n  workload_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.list_check_details\naws_api/wellarchitected list_check_details","url":"aws_api/wellarchitected.html#list_check_details"},{"doc":"aws_api/wellarchitected","title":"list_check_summaries","content":"pub fn list_check_summaries(\n  client: Client,\n  workload_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.list_check_summaries\naws_api/wellarchitected list_check_summaries","url":"aws_api/wellarchitected.html#list_check_summaries"},{"doc":"aws_api/wellarchitected","title":"list_lens_review_improvements","content":"pub fn list_lens_review_improvements(\n  client: Client,\n  workload_id: String,\n  lens_alias: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.list_lens_review_improvements\naws_api/wellarchitected list_lens_review_improvements","url":"aws_api/wellarchitected.html#list_lens_review_improvements"},{"doc":"aws_api/wellarchitected","title":"list_lens_reviews","content":"pub fn list_lens_reviews(\n  client: Client,\n  workload_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.list_lens_reviews\naws_api/wellarchitected list_lens_reviews","url":"aws_api/wellarchitected.html#list_lens_reviews"},{"doc":"aws_api/wellarchitected","title":"list_lens_shares","content":"pub fn list_lens_shares(\n  client: Client,\n  lens_alias: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.list_lens_shares\naws_api/wellarchitected list_lens_shares","url":"aws_api/wellarchitected.html#list_lens_shares"},{"doc":"aws_api/wellarchitected","title":"list_lenses","content":"pub fn list_lenses(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.list_lenses\naws_api/wellarchitected list_lenses","url":"aws_api/wellarchitected.html#list_lenses"},{"doc":"aws_api/wellarchitected","title":"list_milestones","content":"pub fn list_milestones(\n  client: Client,\n  workload_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.list_milestones\naws_api/wellarchitected list_milestones","url":"aws_api/wellarchitected.html#list_milestones"},{"doc":"aws_api/wellarchitected","title":"list_notifications","content":"pub fn list_notifications(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.list_notifications\naws_api/wellarchitected list_notifications","url":"aws_api/wellarchitected.html#list_notifications"},{"doc":"aws_api/wellarchitected","title":"list_profile_notifications","content":"pub fn list_profile_notifications(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.list_profile_notifications\naws_api/wellarchitected list_profile_notifications","url":"aws_api/wellarchitected.html#list_profile_notifications"},{"doc":"aws_api/wellarchitected","title":"list_profile_shares","content":"pub fn list_profile_shares(\n  client: Client,\n  profile_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.list_profile_shares\naws_api/wellarchitected list_profile_shares","url":"aws_api/wellarchitected.html#list_profile_shares"},{"doc":"aws_api/wellarchitected","title":"list_profiles","content":"pub fn list_profiles(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.list_profiles\naws_api/wellarchitected list_profiles","url":"aws_api/wellarchitected.html#list_profiles"},{"doc":"aws_api/wellarchitected","title":"list_review_template_answers","content":"pub fn list_review_template_answers(\n  client: Client,\n  template_arn: String,\n  lens_alias: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.list_review_template_answers\naws_api/wellarchitected list_review_template_answers","url":"aws_api/wellarchitected.html#list_review_template_answers"},{"doc":"aws_api/wellarchitected","title":"list_review_templates","content":"pub fn list_review_templates(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.list_review_templates\naws_api/wellarchitected list_review_templates","url":"aws_api/wellarchitected.html#list_review_templates"},{"doc":"aws_api/wellarchitected","title":"list_share_invitations","content":"pub fn list_share_invitations(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.list_share_invitations\naws_api/wellarchitected list_share_invitations","url":"aws_api/wellarchitected.html#list_share_invitations"},{"doc":"aws_api/wellarchitected","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  workload_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.list_tags_for_resource\naws_api/wellarchitected list_tags_for_resource","url":"aws_api/wellarchitected.html#list_tags_for_resource"},{"doc":"aws_api/wellarchitected","title":"list_template_shares","content":"pub fn list_template_shares(\n  client: Client,\n  template_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.list_template_shares\naws_api/wellarchitected list_template_shares","url":"aws_api/wellarchitected.html#list_template_shares"},{"doc":"aws_api/wellarchitected","title":"list_workload_shares","content":"pub fn list_workload_shares(\n  client: Client,\n  workload_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.list_workload_shares\naws_api/wellarchitected list_workload_shares","url":"aws_api/wellarchitected.html#list_workload_shares"},{"doc":"aws_api/wellarchitected","title":"list_workloads","content":"pub fn list_workloads(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.list_workloads\naws_api/wellarchitected list_workloads","url":"aws_api/wellarchitected.html#list_workloads"},{"doc":"aws_api/wellarchitected","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/wellarchitected.new\naws_api/wellarchitected new","url":"aws_api/wellarchitected.html#new"},{"doc":"aws_api/wellarchitected","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  workload_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.tag_resource\naws_api/wellarchitected tag_resource","url":"aws_api/wellarchitected.html#tag_resource"},{"doc":"aws_api/wellarchitected","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  workload_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.untag_resource\naws_api/wellarchitected untag_resource","url":"aws_api/wellarchitected.html#untag_resource"},{"doc":"aws_api/wellarchitected","title":"update_answer","content":"pub fn update_answer(\n  client: Client,\n  workload_id: String,\n  lens_alias: String,\n  question_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.update_answer\naws_api/wellarchitected update_answer","url":"aws_api/wellarchitected.html#update_answer"},{"doc":"aws_api/wellarchitected","title":"update_global_settings","content":"pub fn update_global_settings(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.update_global_settings\naws_api/wellarchitected update_global_settings","url":"aws_api/wellarchitected.html#update_global_settings"},{"doc":"aws_api/wellarchitected","title":"update_integration","content":"pub fn update_integration(\n  client: Client,\n  workload_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.update_integration\naws_api/wellarchitected update_integration","url":"aws_api/wellarchitected.html#update_integration"},{"doc":"aws_api/wellarchitected","title":"update_lens_review","content":"pub fn update_lens_review(\n  client: Client,\n  workload_id: String,\n  lens_alias: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.update_lens_review\naws_api/wellarchitected update_lens_review","url":"aws_api/wellarchitected.html#update_lens_review"},{"doc":"aws_api/wellarchitected","title":"update_profile","content":"pub fn update_profile(\n  client: Client,\n  profile_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.update_profile\naws_api/wellarchitected update_profile","url":"aws_api/wellarchitected.html#update_profile"},{"doc":"aws_api/wellarchitected","title":"update_review_template","content":"pub fn update_review_template(\n  client: Client,\n  template_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.update_review_template\naws_api/wellarchitected update_review_template","url":"aws_api/wellarchitected.html#update_review_template"},{"doc":"aws_api/wellarchitected","title":"update_review_template_answer","content":"pub fn update_review_template_answer(\n  client: Client,\n  template_arn: String,\n  lens_alias: String,\n  question_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.update_review_template_answer\naws_api/wellarchitected update_review_template_answer","url":"aws_api/wellarchitected.html#update_review_template_answer"},{"doc":"aws_api/wellarchitected","title":"update_review_template_lens_review","content":"pub fn update_review_template_lens_review(\n  client: Client,\n  template_arn: String,\n  lens_alias: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.update_review_template_lens_review\naws_api/wellarchitected update_review_template_lens_review","url":"aws_api/wellarchitected.html#update_review_template_lens_review"},{"doc":"aws_api/wellarchitected","title":"update_share_invitation","content":"pub fn update_share_invitation(\n  client: Client,\n  share_invitation_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.update_share_invitation\naws_api/wellarchitected update_share_invitation","url":"aws_api/wellarchitected.html#update_share_invitation"},{"doc":"aws_api/wellarchitected","title":"update_workload","content":"pub fn update_workload(\n  client: Client,\n  workload_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.update_workload\naws_api/wellarchitected update_workload","url":"aws_api/wellarchitected.html#update_workload"},{"doc":"aws_api/wellarchitected","title":"update_workload_share","content":"pub fn update_workload_share(\n  client: Client,\n  workload_id: String,\n  share_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.update_workload_share\naws_api/wellarchitected update_workload_share","url":"aws_api/wellarchitected.html#update_workload_share"},{"doc":"aws_api/wellarchitected","title":"upgrade_lens_review","content":"pub fn upgrade_lens_review(\n  client: Client,\n  workload_id: String,\n  lens_alias: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.upgrade_lens_review\naws_api/wellarchitected upgrade_lens_review","url":"aws_api/wellarchitected.html#upgrade_lens_review"},{"doc":"aws_api/wellarchitected","title":"upgrade_profile_version","content":"pub fn upgrade_profile_version(\n  client: Client,\n  workload_id: String,\n  profile_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.upgrade_profile_version\naws_api/wellarchitected upgrade_profile_version","url":"aws_api/wellarchitected.html#upgrade_profile_version"},{"doc":"aws_api/wellarchitected","title":"upgrade_review_template_lens_review","content":"pub fn upgrade_review_template_lens_review(\n  client: Client,\n  template_arn: String,\n  lens_alias: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wellarchitected.upgrade_review_template_lens_review\naws_api/wellarchitected upgrade_review_template_lens_review","url":"aws_api/wellarchitected.html#upgrade_review_template_lens_review"},{"doc":"aws_api/wellarchitected","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/wellarchitected.with_custom_endpoint\naws_api/wellarchitected with_custom_endpoint","url":"aws_api/wellarchitected.html#with_custom_endpoint"},{"doc":"aws_api/wellarchitected","title":"aws_api/wellarchitected","content":"","url":"aws_api/wellarchitected.html"},{"doc":"aws_api/wisdom","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/wisdom.Client\naws_api/wisdom Client","url":"aws_api/wisdom.html#Client"},{"doc":"aws_api/wisdom","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wisdom.list_tags_for_resource\naws_api/wisdom list_tags_for_resource","url":"aws_api/wisdom.html#list_tags_for_resource"},{"doc":"aws_api/wisdom","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/wisdom.new\naws_api/wisdom new","url":"aws_api/wisdom.html#new"},{"doc":"aws_api/wisdom","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wisdom.tag_resource\naws_api/wisdom tag_resource","url":"aws_api/wisdom.html#tag_resource"},{"doc":"aws_api/wisdom","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/wisdom.untag_resource\naws_api/wisdom untag_resource","url":"aws_api/wisdom.html#untag_resource"},{"doc":"aws_api/wisdom","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/wisdom.with_custom_endpoint\naws_api/wisdom with_custom_endpoint","url":"aws_api/wisdom.html#with_custom_endpoint"},{"doc":"aws_api/wisdom","title":"aws_api/wisdom","content":"","url":"aws_api/wisdom.html"},{"doc":"aws_api/workdocs","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/workdocs.Client\naws_api/workdocs Client","url":"aws_api/workdocs.html#Client"},{"doc":"aws_api/workdocs","title":"abort_document_version_upload","content":"pub fn abort_document_version_upload(\n  client: Client,\n  document_id: String,\n  version_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workdocs.abort_document_version_upload\naws_api/workdocs abort_document_version_upload","url":"aws_api/workdocs.html#abort_document_version_upload"},{"doc":"aws_api/workdocs","title":"activate_user","content":"pub fn activate_user(\n  client: Client,\n  user_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workdocs.activate_user\naws_api/workdocs activate_user","url":"aws_api/workdocs.html#activate_user"},{"doc":"aws_api/workdocs","title":"add_resource_permissions","content":"pub fn add_resource_permissions(\n  client: Client,\n  resource_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workdocs.add_resource_permissions\naws_api/workdocs add_resource_permissions","url":"aws_api/workdocs.html#add_resource_permissions"},{"doc":"aws_api/workdocs","title":"create_comment","content":"pub fn create_comment(\n  client: Client,\n  document_id: String,\n  version_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workdocs.create_comment\naws_api/workdocs create_comment","url":"aws_api/workdocs.html#create_comment"},{"doc":"aws_api/workdocs","title":"create_custom_metadata","content":"pub fn create_custom_metadata(\n  client: Client,\n  resource_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workdocs.create_custom_metadata\naws_api/workdocs create_custom_metadata","url":"aws_api/workdocs.html#create_custom_metadata"},{"doc":"aws_api/workdocs","title":"create_folder","content":"pub fn create_folder(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workdocs.create_folder\naws_api/workdocs create_folder","url":"aws_api/workdocs.html#create_folder"},{"doc":"aws_api/workdocs","title":"create_labels","content":"pub fn create_labels(\n  client: Client,\n  resource_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workdocs.create_labels\naws_api/workdocs create_labels","url":"aws_api/workdocs.html#create_labels"},{"doc":"aws_api/workdocs","title":"create_notification_subscription","content":"pub fn create_notification_subscription(\n  client: Client,\n  organization_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workdocs.create_notification_subscription\naws_api/workdocs create_notification_subscription","url":"aws_api/workdocs.html#create_notification_subscription"},{"doc":"aws_api/workdocs","title":"create_user","content":"pub fn create_user(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workdocs.create_user\naws_api/workdocs create_user","url":"aws_api/workdocs.html#create_user"},{"doc":"aws_api/workdocs","title":"deactivate_user","content":"pub fn deactivate_user(\n  client: Client,\n  user_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workdocs.deactivate_user\naws_api/workdocs deactivate_user","url":"aws_api/workdocs.html#deactivate_user"},{"doc":"aws_api/workdocs","title":"delete_comment","content":"pub fn delete_comment(\n  client: Client,\n  document_id: String,\n  version_id: String,\n  comment_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workdocs.delete_comment\naws_api/workdocs delete_comment","url":"aws_api/workdocs.html#delete_comment"},{"doc":"aws_api/workdocs","title":"delete_custom_metadata","content":"pub fn delete_custom_metadata(\n  client: Client,\n  resource_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workdocs.delete_custom_metadata\naws_api/workdocs delete_custom_metadata","url":"aws_api/workdocs.html#delete_custom_metadata"},{"doc":"aws_api/workdocs","title":"delete_document","content":"pub fn delete_document(\n  client: Client,\n  document_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workdocs.delete_document\naws_api/workdocs delete_document","url":"aws_api/workdocs.html#delete_document"},{"doc":"aws_api/workdocs","title":"delete_document_version","content":"pub fn delete_document_version(\n  client: Client,\n  document_id: String,\n  version_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workdocs.delete_document_version\naws_api/workdocs delete_document_version","url":"aws_api/workdocs.html#delete_document_version"},{"doc":"aws_api/workdocs","title":"delete_folder","content":"pub fn delete_folder(\n  client: Client,\n  folder_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workdocs.delete_folder\naws_api/workdocs delete_folder","url":"aws_api/workdocs.html#delete_folder"},{"doc":"aws_api/workdocs","title":"delete_folder_contents","content":"pub fn delete_folder_contents(\n  client: Client,\n  folder_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workdocs.delete_folder_contents\naws_api/workdocs delete_folder_contents","url":"aws_api/workdocs.html#delete_folder_contents"},{"doc":"aws_api/workdocs","title":"delete_labels","content":"pub fn delete_labels(\n  client: Client,\n  resource_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workdocs.delete_labels\naws_api/workdocs delete_labels","url":"aws_api/workdocs.html#delete_labels"},{"doc":"aws_api/workdocs","title":"delete_notification_subscription","content":"pub fn delete_notification_subscription(\n  client: Client,\n  organization_id: String,\n  subscription_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workdocs.delete_notification_subscription\naws_api/workdocs delete_notification_subscription","url":"aws_api/workdocs.html#delete_notification_subscription"},{"doc":"aws_api/workdocs","title":"delete_user","content":"pub fn delete_user(\n  client: Client,\n  user_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workdocs.delete_user\naws_api/workdocs delete_user","url":"aws_api/workdocs.html#delete_user"},{"doc":"aws_api/workdocs","title":"describe_activities","content":"pub fn describe_activities(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workdocs.describe_activities\naws_api/workdocs describe_activities","url":"aws_api/workdocs.html#describe_activities"},{"doc":"aws_api/workdocs","title":"describe_comments","content":"pub fn describe_comments(\n  client: Client,\n  document_id: String,\n  version_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workdocs.describe_comments\naws_api/workdocs describe_comments","url":"aws_api/workdocs.html#describe_comments"},{"doc":"aws_api/workdocs","title":"describe_document_versions","content":"pub fn describe_document_versions(\n  client: Client,\n  document_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workdocs.describe_document_versions\naws_api/workdocs describe_document_versions","url":"aws_api/workdocs.html#describe_document_versions"},{"doc":"aws_api/workdocs","title":"describe_folder_contents","content":"pub fn describe_folder_contents(\n  client: Client,\n  folder_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workdocs.describe_folder_contents\naws_api/workdocs describe_folder_contents","url":"aws_api/workdocs.html#describe_folder_contents"},{"doc":"aws_api/workdocs","title":"describe_groups","content":"pub fn describe_groups(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workdocs.describe_groups\naws_api/workdocs describe_groups","url":"aws_api/workdocs.html#describe_groups"},{"doc":"aws_api/workdocs","title":"describe_notification_subscriptions","content":"pub fn describe_notification_subscriptions(\n  client: Client,\n  organization_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workdocs.describe_notification_subscriptions\naws_api/workdocs describe_notification_subscriptions","url":"aws_api/workdocs.html#describe_notification_subscriptions"},{"doc":"aws_api/workdocs","title":"describe_resource_permissions","content":"pub fn describe_resource_permissions(\n  client: Client,\n  resource_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workdocs.describe_resource_permissions\naws_api/workdocs describe_resource_permissions","url":"aws_api/workdocs.html#describe_resource_permissions"},{"doc":"aws_api/workdocs","title":"describe_root_folders","content":"pub fn describe_root_folders(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workdocs.describe_root_folders\naws_api/workdocs describe_root_folders","url":"aws_api/workdocs.html#describe_root_folders"},{"doc":"aws_api/workdocs","title":"describe_users","content":"pub fn describe_users(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workdocs.describe_users\naws_api/workdocs describe_users","url":"aws_api/workdocs.html#describe_users"},{"doc":"aws_api/workdocs","title":"get_current_user","content":"pub fn get_current_user(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workdocs.get_current_user\naws_api/workdocs get_current_user","url":"aws_api/workdocs.html#get_current_user"},{"doc":"aws_api/workdocs","title":"get_document","content":"pub fn get_document(\n  client: Client,\n  document_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workdocs.get_document\naws_api/workdocs get_document","url":"aws_api/workdocs.html#get_document"},{"doc":"aws_api/workdocs","title":"get_document_path","content":"pub fn get_document_path(\n  client: Client,\n  document_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workdocs.get_document_path\naws_api/workdocs get_document_path","url":"aws_api/workdocs.html#get_document_path"},{"doc":"aws_api/workdocs","title":"get_document_version","content":"pub fn get_document_version(\n  client: Client,\n  document_id: String,\n  version_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workdocs.get_document_version\naws_api/workdocs get_document_version","url":"aws_api/workdocs.html#get_document_version"},{"doc":"aws_api/workdocs","title":"get_folder","content":"pub fn get_folder(\n  client: Client,\n  folder_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workdocs.get_folder\naws_api/workdocs get_folder","url":"aws_api/workdocs.html#get_folder"},{"doc":"aws_api/workdocs","title":"get_folder_path","content":"pub fn get_folder_path(\n  client: Client,\n  folder_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workdocs.get_folder_path\naws_api/workdocs get_folder_path","url":"aws_api/workdocs.html#get_folder_path"},{"doc":"aws_api/workdocs","title":"get_resources","content":"pub fn get_resources(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workdocs.get_resources\naws_api/workdocs get_resources","url":"aws_api/workdocs.html#get_resources"},{"doc":"aws_api/workdocs","title":"initiate_document_version_upload","content":"pub fn initiate_document_version_upload(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workdocs.initiate_document_version_upload\naws_api/workdocs initiate_document_version_upload","url":"aws_api/workdocs.html#initiate_document_version_upload"},{"doc":"aws_api/workdocs","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/workdocs.new\naws_api/workdocs new","url":"aws_api/workdocs.html#new"},{"doc":"aws_api/workdocs","title":"remove_all_resource_permissions","content":"pub fn remove_all_resource_permissions(\n  client: Client,\n  resource_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workdocs.remove_all_resource_permissions\naws_api/workdocs remove_all_resource_permissions","url":"aws_api/workdocs.html#remove_all_resource_permissions"},{"doc":"aws_api/workdocs","title":"remove_resource_permission","content":"pub fn remove_resource_permission(\n  client: Client,\n  resource_id: String,\n  principal_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workdocs.remove_resource_permission\naws_api/workdocs remove_resource_permission","url":"aws_api/workdocs.html#remove_resource_permission"},{"doc":"aws_api/workdocs","title":"restore_document_versions","content":"pub fn restore_document_versions(\n  client: Client,\n  document_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workdocs.restore_document_versions\naws_api/workdocs restore_document_versions","url":"aws_api/workdocs.html#restore_document_versions"},{"doc":"aws_api/workdocs","title":"search_resources","content":"pub fn search_resources(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workdocs.search_resources\naws_api/workdocs search_resources","url":"aws_api/workdocs.html#search_resources"},{"doc":"aws_api/workdocs","title":"update_document","content":"pub fn update_document(\n  client: Client,\n  document_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workdocs.update_document\naws_api/workdocs update_document","url":"aws_api/workdocs.html#update_document"},{"doc":"aws_api/workdocs","title":"update_document_version","content":"pub fn update_document_version(\n  client: Client,\n  document_id: String,\n  version_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workdocs.update_document_version\naws_api/workdocs update_document_version","url":"aws_api/workdocs.html#update_document_version"},{"doc":"aws_api/workdocs","title":"update_folder","content":"pub fn update_folder(\n  client: Client,\n  folder_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workdocs.update_folder\naws_api/workdocs update_folder","url":"aws_api/workdocs.html#update_folder"},{"doc":"aws_api/workdocs","title":"update_user","content":"pub fn update_user(\n  client: Client,\n  user_id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workdocs.update_user\naws_api/workdocs update_user","url":"aws_api/workdocs.html#update_user"},{"doc":"aws_api/workdocs","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/workdocs.with_custom_endpoint\naws_api/workdocs with_custom_endpoint","url":"aws_api/workdocs.html#with_custom_endpoint"},{"doc":"aws_api/workdocs","title":"aws_api/workdocs","content":"","url":"aws_api/workdocs.html"},{"doc":"aws_api/workmail","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/workmail.Client\naws_api/workmail Client","url":"aws_api/workmail.html#Client"},{"doc":"aws_api/workmail","title":"associate_delegate_to_resource","content":"pub fn associate_delegate_to_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.associate_delegate_to_resource\naws_api/workmail associate_delegate_to_resource","url":"aws_api/workmail.html#associate_delegate_to_resource"},{"doc":"aws_api/workmail","title":"associate_member_to_group","content":"pub fn associate_member_to_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.associate_member_to_group\naws_api/workmail associate_member_to_group","url":"aws_api/workmail.html#associate_member_to_group"},{"doc":"aws_api/workmail","title":"assume_impersonation_role","content":"pub fn assume_impersonation_role(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.assume_impersonation_role\naws_api/workmail assume_impersonation_role","url":"aws_api/workmail.html#assume_impersonation_role"},{"doc":"aws_api/workmail","title":"cancel_mailbox_export_job","content":"pub fn cancel_mailbox_export_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.cancel_mailbox_export_job\naws_api/workmail cancel_mailbox_export_job","url":"aws_api/workmail.html#cancel_mailbox_export_job"},{"doc":"aws_api/workmail","title":"create_alias","content":"pub fn create_alias(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.create_alias\naws_api/workmail create_alias","url":"aws_api/workmail.html#create_alias"},{"doc":"aws_api/workmail","title":"create_availability_configuration","content":"pub fn create_availability_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.create_availability_configuration\naws_api/workmail create_availability_configuration","url":"aws_api/workmail.html#create_availability_configuration"},{"doc":"aws_api/workmail","title":"create_group","content":"pub fn create_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.create_group\naws_api/workmail create_group","url":"aws_api/workmail.html#create_group"},{"doc":"aws_api/workmail","title":"create_impersonation_role","content":"pub fn create_impersonation_role(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.create_impersonation_role\naws_api/workmail create_impersonation_role","url":"aws_api/workmail.html#create_impersonation_role"},{"doc":"aws_api/workmail","title":"create_mobile_device_access_rule","content":"pub fn create_mobile_device_access_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.create_mobile_device_access_rule\naws_api/workmail create_mobile_device_access_rule","url":"aws_api/workmail.html#create_mobile_device_access_rule"},{"doc":"aws_api/workmail","title":"create_organization","content":"pub fn create_organization(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.create_organization\naws_api/workmail create_organization","url":"aws_api/workmail.html#create_organization"},{"doc":"aws_api/workmail","title":"create_resource","content":"pub fn create_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.create_resource\naws_api/workmail create_resource","url":"aws_api/workmail.html#create_resource"},{"doc":"aws_api/workmail","title":"create_user","content":"pub fn create_user(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.create_user\naws_api/workmail create_user","url":"aws_api/workmail.html#create_user"},{"doc":"aws_api/workmail","title":"delete_access_control_rule","content":"pub fn delete_access_control_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.delete_access_control_rule\naws_api/workmail delete_access_control_rule","url":"aws_api/workmail.html#delete_access_control_rule"},{"doc":"aws_api/workmail","title":"delete_alias","content":"pub fn delete_alias(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.delete_alias\naws_api/workmail delete_alias","url":"aws_api/workmail.html#delete_alias"},{"doc":"aws_api/workmail","title":"delete_availability_configuration","content":"pub fn delete_availability_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.delete_availability_configuration\naws_api/workmail delete_availability_configuration","url":"aws_api/workmail.html#delete_availability_configuration"},{"doc":"aws_api/workmail","title":"delete_email_monitoring_configuration","content":"pub fn delete_email_monitoring_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.delete_email_monitoring_configuration\naws_api/workmail delete_email_monitoring_configuration","url":"aws_api/workmail.html#delete_email_monitoring_configuration"},{"doc":"aws_api/workmail","title":"delete_group","content":"pub fn delete_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.delete_group\naws_api/workmail delete_group","url":"aws_api/workmail.html#delete_group"},{"doc":"aws_api/workmail","title":"delete_impersonation_role","content":"pub fn delete_impersonation_role(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.delete_impersonation_role\naws_api/workmail delete_impersonation_role","url":"aws_api/workmail.html#delete_impersonation_role"},{"doc":"aws_api/workmail","title":"delete_mailbox_permissions","content":"pub fn delete_mailbox_permissions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.delete_mailbox_permissions\naws_api/workmail delete_mailbox_permissions","url":"aws_api/workmail.html#delete_mailbox_permissions"},{"doc":"aws_api/workmail","title":"delete_mobile_device_access_override","content":"pub fn delete_mobile_device_access_override(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.delete_mobile_device_access_override\naws_api/workmail delete_mobile_device_access_override","url":"aws_api/workmail.html#delete_mobile_device_access_override"},{"doc":"aws_api/workmail","title":"delete_mobile_device_access_rule","content":"pub fn delete_mobile_device_access_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.delete_mobile_device_access_rule\naws_api/workmail delete_mobile_device_access_rule","url":"aws_api/workmail.html#delete_mobile_device_access_rule"},{"doc":"aws_api/workmail","title":"delete_organization","content":"pub fn delete_organization(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.delete_organization\naws_api/workmail delete_organization","url":"aws_api/workmail.html#delete_organization"},{"doc":"aws_api/workmail","title":"delete_resource","content":"pub fn delete_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.delete_resource\naws_api/workmail delete_resource","url":"aws_api/workmail.html#delete_resource"},{"doc":"aws_api/workmail","title":"delete_retention_policy","content":"pub fn delete_retention_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.delete_retention_policy\naws_api/workmail delete_retention_policy","url":"aws_api/workmail.html#delete_retention_policy"},{"doc":"aws_api/workmail","title":"delete_user","content":"pub fn delete_user(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.delete_user\naws_api/workmail delete_user","url":"aws_api/workmail.html#delete_user"},{"doc":"aws_api/workmail","title":"deregister_from_work_mail","content":"pub fn deregister_from_work_mail(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.deregister_from_work_mail\naws_api/workmail deregister_from_work_mail","url":"aws_api/workmail.html#deregister_from_work_mail"},{"doc":"aws_api/workmail","title":"deregister_mail_domain","content":"pub fn deregister_mail_domain(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.deregister_mail_domain\naws_api/workmail deregister_mail_domain","url":"aws_api/workmail.html#deregister_mail_domain"},{"doc":"aws_api/workmail","title":"describe_email_monitoring_configuration","content":"pub fn describe_email_monitoring_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.describe_email_monitoring_configuration\naws_api/workmail describe_email_monitoring_configuration","url":"aws_api/workmail.html#describe_email_monitoring_configuration"},{"doc":"aws_api/workmail","title":"describe_entity","content":"pub fn describe_entity(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.describe_entity\naws_api/workmail describe_entity","url":"aws_api/workmail.html#describe_entity"},{"doc":"aws_api/workmail","title":"describe_group","content":"pub fn describe_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.describe_group\naws_api/workmail describe_group","url":"aws_api/workmail.html#describe_group"},{"doc":"aws_api/workmail","title":"describe_inbound_dmarc_settings","content":"pub fn describe_inbound_dmarc_settings(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.describe_inbound_dmarc_settings\naws_api/workmail describe_inbound_dmarc_settings","url":"aws_api/workmail.html#describe_inbound_dmarc_settings"},{"doc":"aws_api/workmail","title":"describe_mailbox_export_job","content":"pub fn describe_mailbox_export_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.describe_mailbox_export_job\naws_api/workmail describe_mailbox_export_job","url":"aws_api/workmail.html#describe_mailbox_export_job"},{"doc":"aws_api/workmail","title":"describe_organization","content":"pub fn describe_organization(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.describe_organization\naws_api/workmail describe_organization","url":"aws_api/workmail.html#describe_organization"},{"doc":"aws_api/workmail","title":"describe_resource","content":"pub fn describe_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.describe_resource\naws_api/workmail describe_resource","url":"aws_api/workmail.html#describe_resource"},{"doc":"aws_api/workmail","title":"describe_user","content":"pub fn describe_user(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.describe_user\naws_api/workmail describe_user","url":"aws_api/workmail.html#describe_user"},{"doc":"aws_api/workmail","title":"disassociate_delegate_from_resource","content":"pub fn disassociate_delegate_from_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.disassociate_delegate_from_resource\naws_api/workmail disassociate_delegate_from_resource","url":"aws_api/workmail.html#disassociate_delegate_from_resource"},{"doc":"aws_api/workmail","title":"disassociate_member_from_group","content":"pub fn disassociate_member_from_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.disassociate_member_from_group\naws_api/workmail disassociate_member_from_group","url":"aws_api/workmail.html#disassociate_member_from_group"},{"doc":"aws_api/workmail","title":"get_access_control_effect","content":"pub fn get_access_control_effect(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.get_access_control_effect\naws_api/workmail get_access_control_effect","url":"aws_api/workmail.html#get_access_control_effect"},{"doc":"aws_api/workmail","title":"get_default_retention_policy","content":"pub fn get_default_retention_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.get_default_retention_policy\naws_api/workmail get_default_retention_policy","url":"aws_api/workmail.html#get_default_retention_policy"},{"doc":"aws_api/workmail","title":"get_impersonation_role","content":"pub fn get_impersonation_role(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.get_impersonation_role\naws_api/workmail get_impersonation_role","url":"aws_api/workmail.html#get_impersonation_role"},{"doc":"aws_api/workmail","title":"get_impersonation_role_effect","content":"pub fn get_impersonation_role_effect(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.get_impersonation_role_effect\naws_api/workmail get_impersonation_role_effect","url":"aws_api/workmail.html#get_impersonation_role_effect"},{"doc":"aws_api/workmail","title":"get_mail_domain","content":"pub fn get_mail_domain(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.get_mail_domain\naws_api/workmail get_mail_domain","url":"aws_api/workmail.html#get_mail_domain"},{"doc":"aws_api/workmail","title":"get_mailbox_details","content":"pub fn get_mailbox_details(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.get_mailbox_details\naws_api/workmail get_mailbox_details","url":"aws_api/workmail.html#get_mailbox_details"},{"doc":"aws_api/workmail","title":"get_mobile_device_access_effect","content":"pub fn get_mobile_device_access_effect(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.get_mobile_device_access_effect\naws_api/workmail get_mobile_device_access_effect","url":"aws_api/workmail.html#get_mobile_device_access_effect"},{"doc":"aws_api/workmail","title":"get_mobile_device_access_override","content":"pub fn get_mobile_device_access_override(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.get_mobile_device_access_override\naws_api/workmail get_mobile_device_access_override","url":"aws_api/workmail.html#get_mobile_device_access_override"},{"doc":"aws_api/workmail","title":"list_access_control_rules","content":"pub fn list_access_control_rules(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.list_access_control_rules\naws_api/workmail list_access_control_rules","url":"aws_api/workmail.html#list_access_control_rules"},{"doc":"aws_api/workmail","title":"list_aliases","content":"pub fn list_aliases(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.list_aliases\naws_api/workmail list_aliases","url":"aws_api/workmail.html#list_aliases"},{"doc":"aws_api/workmail","title":"list_availability_configurations","content":"pub fn list_availability_configurations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.list_availability_configurations\naws_api/workmail list_availability_configurations","url":"aws_api/workmail.html#list_availability_configurations"},{"doc":"aws_api/workmail","title":"list_group_members","content":"pub fn list_group_members(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.list_group_members\naws_api/workmail list_group_members","url":"aws_api/workmail.html#list_group_members"},{"doc":"aws_api/workmail","title":"list_groups","content":"pub fn list_groups(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.list_groups\naws_api/workmail list_groups","url":"aws_api/workmail.html#list_groups"},{"doc":"aws_api/workmail","title":"list_groups_for_entity","content":"pub fn list_groups_for_entity(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.list_groups_for_entity\naws_api/workmail list_groups_for_entity","url":"aws_api/workmail.html#list_groups_for_entity"},{"doc":"aws_api/workmail","title":"list_impersonation_roles","content":"pub fn list_impersonation_roles(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.list_impersonation_roles\naws_api/workmail list_impersonation_roles","url":"aws_api/workmail.html#list_impersonation_roles"},{"doc":"aws_api/workmail","title":"list_mail_domains","content":"pub fn list_mail_domains(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.list_mail_domains\naws_api/workmail list_mail_domains","url":"aws_api/workmail.html#list_mail_domains"},{"doc":"aws_api/workmail","title":"list_mailbox_export_jobs","content":"pub fn list_mailbox_export_jobs(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.list_mailbox_export_jobs\naws_api/workmail list_mailbox_export_jobs","url":"aws_api/workmail.html#list_mailbox_export_jobs"},{"doc":"aws_api/workmail","title":"list_mailbox_permissions","content":"pub fn list_mailbox_permissions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.list_mailbox_permissions\naws_api/workmail list_mailbox_permissions","url":"aws_api/workmail.html#list_mailbox_permissions"},{"doc":"aws_api/workmail","title":"list_mobile_device_access_overrides","content":"pub fn list_mobile_device_access_overrides(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.list_mobile_device_access_overrides\naws_api/workmail list_mobile_device_access_overrides","url":"aws_api/workmail.html#list_mobile_device_access_overrides"},{"doc":"aws_api/workmail","title":"list_mobile_device_access_rules","content":"pub fn list_mobile_device_access_rules(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.list_mobile_device_access_rules\naws_api/workmail list_mobile_device_access_rules","url":"aws_api/workmail.html#list_mobile_device_access_rules"},{"doc":"aws_api/workmail","title":"list_organizations","content":"pub fn list_organizations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.list_organizations\naws_api/workmail list_organizations","url":"aws_api/workmail.html#list_organizations"},{"doc":"aws_api/workmail","title":"list_resource_delegates","content":"pub fn list_resource_delegates(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.list_resource_delegates\naws_api/workmail list_resource_delegates","url":"aws_api/workmail.html#list_resource_delegates"},{"doc":"aws_api/workmail","title":"list_resources","content":"pub fn list_resources(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.list_resources\naws_api/workmail list_resources","url":"aws_api/workmail.html#list_resources"},{"doc":"aws_api/workmail","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.list_tags_for_resource\naws_api/workmail list_tags_for_resource","url":"aws_api/workmail.html#list_tags_for_resource"},{"doc":"aws_api/workmail","title":"list_users","content":"pub fn list_users(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.list_users\naws_api/workmail list_users","url":"aws_api/workmail.html#list_users"},{"doc":"aws_api/workmail","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/workmail.new\naws_api/workmail new","url":"aws_api/workmail.html#new"},{"doc":"aws_api/workmail","title":"put_access_control_rule","content":"pub fn put_access_control_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.put_access_control_rule\naws_api/workmail put_access_control_rule","url":"aws_api/workmail.html#put_access_control_rule"},{"doc":"aws_api/workmail","title":"put_email_monitoring_configuration","content":"pub fn put_email_monitoring_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.put_email_monitoring_configuration\naws_api/workmail put_email_monitoring_configuration","url":"aws_api/workmail.html#put_email_monitoring_configuration"},{"doc":"aws_api/workmail","title":"put_inbound_dmarc_settings","content":"pub fn put_inbound_dmarc_settings(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.put_inbound_dmarc_settings\naws_api/workmail put_inbound_dmarc_settings","url":"aws_api/workmail.html#put_inbound_dmarc_settings"},{"doc":"aws_api/workmail","title":"put_mailbox_permissions","content":"pub fn put_mailbox_permissions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.put_mailbox_permissions\naws_api/workmail put_mailbox_permissions","url":"aws_api/workmail.html#put_mailbox_permissions"},{"doc":"aws_api/workmail","title":"put_mobile_device_access_override","content":"pub fn put_mobile_device_access_override(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.put_mobile_device_access_override\naws_api/workmail put_mobile_device_access_override","url":"aws_api/workmail.html#put_mobile_device_access_override"},{"doc":"aws_api/workmail","title":"put_retention_policy","content":"pub fn put_retention_policy(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.put_retention_policy\naws_api/workmail put_retention_policy","url":"aws_api/workmail.html#put_retention_policy"},{"doc":"aws_api/workmail","title":"register_mail_domain","content":"pub fn register_mail_domain(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.register_mail_domain\naws_api/workmail register_mail_domain","url":"aws_api/workmail.html#register_mail_domain"},{"doc":"aws_api/workmail","title":"register_to_work_mail","content":"pub fn register_to_work_mail(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.register_to_work_mail\naws_api/workmail register_to_work_mail","url":"aws_api/workmail.html#register_to_work_mail"},{"doc":"aws_api/workmail","title":"reset_password","content":"pub fn reset_password(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.reset_password\naws_api/workmail reset_password","url":"aws_api/workmail.html#reset_password"},{"doc":"aws_api/workmail","title":"start_mailbox_export_job","content":"pub fn start_mailbox_export_job(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.start_mailbox_export_job\naws_api/workmail start_mailbox_export_job","url":"aws_api/workmail.html#start_mailbox_export_job"},{"doc":"aws_api/workmail","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.tag_resource\naws_api/workmail tag_resource","url":"aws_api/workmail.html#tag_resource"},{"doc":"aws_api/workmail","title":"test_availability_configuration","content":"pub fn test_availability_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.test_availability_configuration\naws_api/workmail test_availability_configuration","url":"aws_api/workmail.html#test_availability_configuration"},{"doc":"aws_api/workmail","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.untag_resource\naws_api/workmail untag_resource","url":"aws_api/workmail.html#untag_resource"},{"doc":"aws_api/workmail","title":"update_availability_configuration","content":"pub fn update_availability_configuration(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.update_availability_configuration\naws_api/workmail update_availability_configuration","url":"aws_api/workmail.html#update_availability_configuration"},{"doc":"aws_api/workmail","title":"update_default_mail_domain","content":"pub fn update_default_mail_domain(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.update_default_mail_domain\naws_api/workmail update_default_mail_domain","url":"aws_api/workmail.html#update_default_mail_domain"},{"doc":"aws_api/workmail","title":"update_group","content":"pub fn update_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.update_group\naws_api/workmail update_group","url":"aws_api/workmail.html#update_group"},{"doc":"aws_api/workmail","title":"update_impersonation_role","content":"pub fn update_impersonation_role(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.update_impersonation_role\naws_api/workmail update_impersonation_role","url":"aws_api/workmail.html#update_impersonation_role"},{"doc":"aws_api/workmail","title":"update_mailbox_quota","content":"pub fn update_mailbox_quota(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.update_mailbox_quota\naws_api/workmail update_mailbox_quota","url":"aws_api/workmail.html#update_mailbox_quota"},{"doc":"aws_api/workmail","title":"update_mobile_device_access_rule","content":"pub fn update_mobile_device_access_rule(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.update_mobile_device_access_rule\naws_api/workmail update_mobile_device_access_rule","url":"aws_api/workmail.html#update_mobile_device_access_rule"},{"doc":"aws_api/workmail","title":"update_primary_email_address","content":"pub fn update_primary_email_address(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.update_primary_email_address\naws_api/workmail update_primary_email_address","url":"aws_api/workmail.html#update_primary_email_address"},{"doc":"aws_api/workmail","title":"update_resource","content":"pub fn update_resource(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.update_resource\naws_api/workmail update_resource","url":"aws_api/workmail.html#update_resource"},{"doc":"aws_api/workmail","title":"update_user","content":"pub fn update_user(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workmail.update_user\naws_api/workmail update_user","url":"aws_api/workmail.html#update_user"},{"doc":"aws_api/workmail","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/workmail.with_custom_endpoint\naws_api/workmail with_custom_endpoint","url":"aws_api/workmail.html#with_custom_endpoint"},{"doc":"aws_api/workmail","title":"aws_api/workmail","content":"","url":"aws_api/workmail.html"},{"doc":"aws_api/workspaces","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/workspaces.Client\naws_api/workspaces Client","url":"aws_api/workspaces.html#Client"},{"doc":"aws_api/workspaces","title":"accept_account_link_invitation","content":"pub fn accept_account_link_invitation(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.accept_account_link_invitation\naws_api/workspaces accept_account_link_invitation","url":"aws_api/workspaces.html#accept_account_link_invitation"},{"doc":"aws_api/workspaces","title":"associate_connection_alias","content":"pub fn associate_connection_alias(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.associate_connection_alias\naws_api/workspaces associate_connection_alias","url":"aws_api/workspaces.html#associate_connection_alias"},{"doc":"aws_api/workspaces","title":"associate_ip_groups","content":"pub fn associate_ip_groups(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.associate_ip_groups\naws_api/workspaces associate_ip_groups","url":"aws_api/workspaces.html#associate_ip_groups"},{"doc":"aws_api/workspaces","title":"associate_workspace_application","content":"pub fn associate_workspace_application(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.associate_workspace_application\naws_api/workspaces associate_workspace_application","url":"aws_api/workspaces.html#associate_workspace_application"},{"doc":"aws_api/workspaces","title":"authorize_ip_rules","content":"pub fn authorize_ip_rules(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.authorize_ip_rules\naws_api/workspaces authorize_ip_rules","url":"aws_api/workspaces.html#authorize_ip_rules"},{"doc":"aws_api/workspaces","title":"copy_workspace_image","content":"pub fn copy_workspace_image(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.copy_workspace_image\naws_api/workspaces copy_workspace_image","url":"aws_api/workspaces.html#copy_workspace_image"},{"doc":"aws_api/workspaces","title":"create_account_link_invitation","content":"pub fn create_account_link_invitation(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.create_account_link_invitation\naws_api/workspaces create_account_link_invitation","url":"aws_api/workspaces.html#create_account_link_invitation"},{"doc":"aws_api/workspaces","title":"create_connect_client_add_in","content":"pub fn create_connect_client_add_in(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.create_connect_client_add_in\naws_api/workspaces create_connect_client_add_in","url":"aws_api/workspaces.html#create_connect_client_add_in"},{"doc":"aws_api/workspaces","title":"create_connection_alias","content":"pub fn create_connection_alias(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.create_connection_alias\naws_api/workspaces create_connection_alias","url":"aws_api/workspaces.html#create_connection_alias"},{"doc":"aws_api/workspaces","title":"create_ip_group","content":"pub fn create_ip_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.create_ip_group\naws_api/workspaces create_ip_group","url":"aws_api/workspaces.html#create_ip_group"},{"doc":"aws_api/workspaces","title":"create_standby_workspaces","content":"pub fn create_standby_workspaces(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.create_standby_workspaces\naws_api/workspaces create_standby_workspaces","url":"aws_api/workspaces.html#create_standby_workspaces"},{"doc":"aws_api/workspaces","title":"create_tags","content":"pub fn create_tags(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.create_tags\naws_api/workspaces create_tags","url":"aws_api/workspaces.html#create_tags"},{"doc":"aws_api/workspaces","title":"create_updated_workspace_image","content":"pub fn create_updated_workspace_image(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.create_updated_workspace_image\naws_api/workspaces create_updated_workspace_image","url":"aws_api/workspaces.html#create_updated_workspace_image"},{"doc":"aws_api/workspaces","title":"create_workspace_bundle","content":"pub fn create_workspace_bundle(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.create_workspace_bundle\naws_api/workspaces create_workspace_bundle","url":"aws_api/workspaces.html#create_workspace_bundle"},{"doc":"aws_api/workspaces","title":"create_workspace_image","content":"pub fn create_workspace_image(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.create_workspace_image\naws_api/workspaces create_workspace_image","url":"aws_api/workspaces.html#create_workspace_image"},{"doc":"aws_api/workspaces","title":"create_workspaces","content":"pub fn create_workspaces(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.create_workspaces\naws_api/workspaces create_workspaces","url":"aws_api/workspaces.html#create_workspaces"},{"doc":"aws_api/workspaces","title":"create_workspaces_pool","content":"pub fn create_workspaces_pool(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.create_workspaces_pool\naws_api/workspaces create_workspaces_pool","url":"aws_api/workspaces.html#create_workspaces_pool"},{"doc":"aws_api/workspaces","title":"delete_account_link_invitation","content":"pub fn delete_account_link_invitation(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.delete_account_link_invitation\naws_api/workspaces delete_account_link_invitation","url":"aws_api/workspaces.html#delete_account_link_invitation"},{"doc":"aws_api/workspaces","title":"delete_client_branding","content":"pub fn delete_client_branding(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.delete_client_branding\naws_api/workspaces delete_client_branding","url":"aws_api/workspaces.html#delete_client_branding"},{"doc":"aws_api/workspaces","title":"delete_connect_client_add_in","content":"pub fn delete_connect_client_add_in(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.delete_connect_client_add_in\naws_api/workspaces delete_connect_client_add_in","url":"aws_api/workspaces.html#delete_connect_client_add_in"},{"doc":"aws_api/workspaces","title":"delete_connection_alias","content":"pub fn delete_connection_alias(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.delete_connection_alias\naws_api/workspaces delete_connection_alias","url":"aws_api/workspaces.html#delete_connection_alias"},{"doc":"aws_api/workspaces","title":"delete_ip_group","content":"pub fn delete_ip_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.delete_ip_group\naws_api/workspaces delete_ip_group","url":"aws_api/workspaces.html#delete_ip_group"},{"doc":"aws_api/workspaces","title":"delete_tags","content":"pub fn delete_tags(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.delete_tags\naws_api/workspaces delete_tags","url":"aws_api/workspaces.html#delete_tags"},{"doc":"aws_api/workspaces","title":"delete_workspace_bundle","content":"pub fn delete_workspace_bundle(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.delete_workspace_bundle\naws_api/workspaces delete_workspace_bundle","url":"aws_api/workspaces.html#delete_workspace_bundle"},{"doc":"aws_api/workspaces","title":"delete_workspace_image","content":"pub fn delete_workspace_image(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.delete_workspace_image\naws_api/workspaces delete_workspace_image","url":"aws_api/workspaces.html#delete_workspace_image"},{"doc":"aws_api/workspaces","title":"deploy_workspace_applications","content":"pub fn deploy_workspace_applications(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.deploy_workspace_applications\naws_api/workspaces deploy_workspace_applications","url":"aws_api/workspaces.html#deploy_workspace_applications"},{"doc":"aws_api/workspaces","title":"deregister_workspace_directory","content":"pub fn deregister_workspace_directory(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.deregister_workspace_directory\naws_api/workspaces deregister_workspace_directory","url":"aws_api/workspaces.html#deregister_workspace_directory"},{"doc":"aws_api/workspaces","title":"describe_account","content":"pub fn describe_account(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.describe_account\naws_api/workspaces describe_account","url":"aws_api/workspaces.html#describe_account"},{"doc":"aws_api/workspaces","title":"describe_account_modifications","content":"pub fn describe_account_modifications(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.describe_account_modifications\naws_api/workspaces describe_account_modifications","url":"aws_api/workspaces.html#describe_account_modifications"},{"doc":"aws_api/workspaces","title":"describe_application_associations","content":"pub fn describe_application_associations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.describe_application_associations\naws_api/workspaces describe_application_associations","url":"aws_api/workspaces.html#describe_application_associations"},{"doc":"aws_api/workspaces","title":"describe_applications","content":"pub fn describe_applications(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.describe_applications\naws_api/workspaces describe_applications","url":"aws_api/workspaces.html#describe_applications"},{"doc":"aws_api/workspaces","title":"describe_bundle_associations","content":"pub fn describe_bundle_associations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.describe_bundle_associations\naws_api/workspaces describe_bundle_associations","url":"aws_api/workspaces.html#describe_bundle_associations"},{"doc":"aws_api/workspaces","title":"describe_client_branding","content":"pub fn describe_client_branding(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.describe_client_branding\naws_api/workspaces describe_client_branding","url":"aws_api/workspaces.html#describe_client_branding"},{"doc":"aws_api/workspaces","title":"describe_client_properties","content":"pub fn describe_client_properties(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.describe_client_properties\naws_api/workspaces describe_client_properties","url":"aws_api/workspaces.html#describe_client_properties"},{"doc":"aws_api/workspaces","title":"describe_connect_client_add_ins","content":"pub fn describe_connect_client_add_ins(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.describe_connect_client_add_ins\naws_api/workspaces describe_connect_client_add_ins","url":"aws_api/workspaces.html#describe_connect_client_add_ins"},{"doc":"aws_api/workspaces","title":"describe_connection_alias_permissions","content":"pub fn describe_connection_alias_permissions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.describe_connection_alias_permissions\naws_api/workspaces describe_connection_alias_permissions","url":"aws_api/workspaces.html#describe_connection_alias_permissions"},{"doc":"aws_api/workspaces","title":"describe_connection_aliases","content":"pub fn describe_connection_aliases(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.describe_connection_aliases\naws_api/workspaces describe_connection_aliases","url":"aws_api/workspaces.html#describe_connection_aliases"},{"doc":"aws_api/workspaces","title":"describe_image_associations","content":"pub fn describe_image_associations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.describe_image_associations\naws_api/workspaces describe_image_associations","url":"aws_api/workspaces.html#describe_image_associations"},{"doc":"aws_api/workspaces","title":"describe_ip_groups","content":"pub fn describe_ip_groups(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.describe_ip_groups\naws_api/workspaces describe_ip_groups","url":"aws_api/workspaces.html#describe_ip_groups"},{"doc":"aws_api/workspaces","title":"describe_tags","content":"pub fn describe_tags(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.describe_tags\naws_api/workspaces describe_tags","url":"aws_api/workspaces.html#describe_tags"},{"doc":"aws_api/workspaces","title":"describe_workspace_associations","content":"pub fn describe_workspace_associations(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.describe_workspace_associations\naws_api/workspaces describe_workspace_associations","url":"aws_api/workspaces.html#describe_workspace_associations"},{"doc":"aws_api/workspaces","title":"describe_workspace_bundles","content":"pub fn describe_workspace_bundles(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.describe_workspace_bundles\naws_api/workspaces describe_workspace_bundles","url":"aws_api/workspaces.html#describe_workspace_bundles"},{"doc":"aws_api/workspaces","title":"describe_workspace_directories","content":"pub fn describe_workspace_directories(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.describe_workspace_directories\naws_api/workspaces describe_workspace_directories","url":"aws_api/workspaces.html#describe_workspace_directories"},{"doc":"aws_api/workspaces","title":"describe_workspace_image_permissions","content":"pub fn describe_workspace_image_permissions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.describe_workspace_image_permissions\naws_api/workspaces describe_workspace_image_permissions","url":"aws_api/workspaces.html#describe_workspace_image_permissions"},{"doc":"aws_api/workspaces","title":"describe_workspace_images","content":"pub fn describe_workspace_images(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.describe_workspace_images\naws_api/workspaces describe_workspace_images","url":"aws_api/workspaces.html#describe_workspace_images"},{"doc":"aws_api/workspaces","title":"describe_workspace_snapshots","content":"pub fn describe_workspace_snapshots(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.describe_workspace_snapshots\naws_api/workspaces describe_workspace_snapshots","url":"aws_api/workspaces.html#describe_workspace_snapshots"},{"doc":"aws_api/workspaces","title":"describe_workspaces","content":"pub fn describe_workspaces(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.describe_workspaces\naws_api/workspaces describe_workspaces","url":"aws_api/workspaces.html#describe_workspaces"},{"doc":"aws_api/workspaces","title":"describe_workspaces_connection_status","content":"pub fn describe_workspaces_connection_status(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.describe_workspaces_connection_status\naws_api/workspaces describe_workspaces_connection_status","url":"aws_api/workspaces.html#describe_workspaces_connection_status"},{"doc":"aws_api/workspaces","title":"describe_workspaces_pool_sessions","content":"pub fn describe_workspaces_pool_sessions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.describe_workspaces_pool_sessions\naws_api/workspaces describe_workspaces_pool_sessions","url":"aws_api/workspaces.html#describe_workspaces_pool_sessions"},{"doc":"aws_api/workspaces","title":"describe_workspaces_pools","content":"pub fn describe_workspaces_pools(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.describe_workspaces_pools\naws_api/workspaces describe_workspaces_pools","url":"aws_api/workspaces.html#describe_workspaces_pools"},{"doc":"aws_api/workspaces","title":"disassociate_connection_alias","content":"pub fn disassociate_connection_alias(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.disassociate_connection_alias\naws_api/workspaces disassociate_connection_alias","url":"aws_api/workspaces.html#disassociate_connection_alias"},{"doc":"aws_api/workspaces","title":"disassociate_ip_groups","content":"pub fn disassociate_ip_groups(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.disassociate_ip_groups\naws_api/workspaces disassociate_ip_groups","url":"aws_api/workspaces.html#disassociate_ip_groups"},{"doc":"aws_api/workspaces","title":"disassociate_workspace_application","content":"pub fn disassociate_workspace_application(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.disassociate_workspace_application\naws_api/workspaces disassociate_workspace_application","url":"aws_api/workspaces.html#disassociate_workspace_application"},{"doc":"aws_api/workspaces","title":"get_account_link","content":"pub fn get_account_link(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.get_account_link\naws_api/workspaces get_account_link","url":"aws_api/workspaces.html#get_account_link"},{"doc":"aws_api/workspaces","title":"import_client_branding","content":"pub fn import_client_branding(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.import_client_branding\naws_api/workspaces import_client_branding","url":"aws_api/workspaces.html#import_client_branding"},{"doc":"aws_api/workspaces","title":"import_workspace_image","content":"pub fn import_workspace_image(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.import_workspace_image\naws_api/workspaces import_workspace_image","url":"aws_api/workspaces.html#import_workspace_image"},{"doc":"aws_api/workspaces","title":"list_account_links","content":"pub fn list_account_links(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.list_account_links\naws_api/workspaces list_account_links","url":"aws_api/workspaces.html#list_account_links"},{"doc":"aws_api/workspaces","title":"list_available_management_cidr_ranges","content":"pub fn list_available_management_cidr_ranges(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.list_available_management_cidr_ranges\naws_api/workspaces list_available_management_cidr_ranges","url":"aws_api/workspaces.html#list_available_management_cidr_ranges"},{"doc":"aws_api/workspaces","title":"migrate_workspace","content":"pub fn migrate_workspace(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.migrate_workspace\naws_api/workspaces migrate_workspace","url":"aws_api/workspaces.html#migrate_workspace"},{"doc":"aws_api/workspaces","title":"modify_account","content":"pub fn modify_account(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.modify_account\naws_api/workspaces modify_account","url":"aws_api/workspaces.html#modify_account"},{"doc":"aws_api/workspaces","title":"modify_certificate_based_auth_properties","content":"pub fn modify_certificate_based_auth_properties(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.modify_certificate_based_auth_properties\naws_api/workspaces modify_certificate_based_auth_properties","url":"aws_api/workspaces.html#modify_certificate_based_auth_properties"},{"doc":"aws_api/workspaces","title":"modify_client_properties","content":"pub fn modify_client_properties(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.modify_client_properties\naws_api/workspaces modify_client_properties","url":"aws_api/workspaces.html#modify_client_properties"},{"doc":"aws_api/workspaces","title":"modify_saml_properties","content":"pub fn modify_saml_properties(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.modify_saml_properties\naws_api/workspaces modify_saml_properties","url":"aws_api/workspaces.html#modify_saml_properties"},{"doc":"aws_api/workspaces","title":"modify_selfservice_permissions","content":"pub fn modify_selfservice_permissions(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.modify_selfservice_permissions\naws_api/workspaces modify_selfservice_permissions","url":"aws_api/workspaces.html#modify_selfservice_permissions"},{"doc":"aws_api/workspaces","title":"modify_streaming_properties","content":"pub fn modify_streaming_properties(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.modify_streaming_properties\naws_api/workspaces modify_streaming_properties","url":"aws_api/workspaces.html#modify_streaming_properties"},{"doc":"aws_api/workspaces","title":"modify_workspace_access_properties","content":"pub fn modify_workspace_access_properties(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.modify_workspace_access_properties\naws_api/workspaces modify_workspace_access_properties","url":"aws_api/workspaces.html#modify_workspace_access_properties"},{"doc":"aws_api/workspaces","title":"modify_workspace_creation_properties","content":"pub fn modify_workspace_creation_properties(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.modify_workspace_creation_properties\naws_api/workspaces modify_workspace_creation_properties","url":"aws_api/workspaces.html#modify_workspace_creation_properties"},{"doc":"aws_api/workspaces","title":"modify_workspace_properties","content":"pub fn modify_workspace_properties(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.modify_workspace_properties\naws_api/workspaces modify_workspace_properties","url":"aws_api/workspaces.html#modify_workspace_properties"},{"doc":"aws_api/workspaces","title":"modify_workspace_state","content":"pub fn modify_workspace_state(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.modify_workspace_state\naws_api/workspaces modify_workspace_state","url":"aws_api/workspaces.html#modify_workspace_state"},{"doc":"aws_api/workspaces","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/workspaces.new\naws_api/workspaces new","url":"aws_api/workspaces.html#new"},{"doc":"aws_api/workspaces","title":"reboot_workspaces","content":"pub fn reboot_workspaces(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.reboot_workspaces\naws_api/workspaces reboot_workspaces","url":"aws_api/workspaces.html#reboot_workspaces"},{"doc":"aws_api/workspaces","title":"rebuild_workspaces","content":"pub fn rebuild_workspaces(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.rebuild_workspaces\naws_api/workspaces rebuild_workspaces","url":"aws_api/workspaces.html#rebuild_workspaces"},{"doc":"aws_api/workspaces","title":"register_workspace_directory","content":"pub fn register_workspace_directory(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.register_workspace_directory\naws_api/workspaces register_workspace_directory","url":"aws_api/workspaces.html#register_workspace_directory"},{"doc":"aws_api/workspaces","title":"reject_account_link_invitation","content":"pub fn reject_account_link_invitation(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.reject_account_link_invitation\naws_api/workspaces reject_account_link_invitation","url":"aws_api/workspaces.html#reject_account_link_invitation"},{"doc":"aws_api/workspaces","title":"restore_workspace","content":"pub fn restore_workspace(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.restore_workspace\naws_api/workspaces restore_workspace","url":"aws_api/workspaces.html#restore_workspace"},{"doc":"aws_api/workspaces","title":"revoke_ip_rules","content":"pub fn revoke_ip_rules(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.revoke_ip_rules\naws_api/workspaces revoke_ip_rules","url":"aws_api/workspaces.html#revoke_ip_rules"},{"doc":"aws_api/workspaces","title":"start_workspaces","content":"pub fn start_workspaces(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.start_workspaces\naws_api/workspaces start_workspaces","url":"aws_api/workspaces.html#start_workspaces"},{"doc":"aws_api/workspaces","title":"start_workspaces_pool","content":"pub fn start_workspaces_pool(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.start_workspaces_pool\naws_api/workspaces start_workspaces_pool","url":"aws_api/workspaces.html#start_workspaces_pool"},{"doc":"aws_api/workspaces","title":"stop_workspaces","content":"pub fn stop_workspaces(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.stop_workspaces\naws_api/workspaces stop_workspaces","url":"aws_api/workspaces.html#stop_workspaces"},{"doc":"aws_api/workspaces","title":"stop_workspaces_pool","content":"pub fn stop_workspaces_pool(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.stop_workspaces_pool\naws_api/workspaces stop_workspaces_pool","url":"aws_api/workspaces.html#stop_workspaces_pool"},{"doc":"aws_api/workspaces","title":"terminate_workspaces","content":"pub fn terminate_workspaces(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.terminate_workspaces\naws_api/workspaces terminate_workspaces","url":"aws_api/workspaces.html#terminate_workspaces"},{"doc":"aws_api/workspaces","title":"terminate_workspaces_pool","content":"pub fn terminate_workspaces_pool(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.terminate_workspaces_pool\naws_api/workspaces terminate_workspaces_pool","url":"aws_api/workspaces.html#terminate_workspaces_pool"},{"doc":"aws_api/workspaces","title":"terminate_workspaces_pool_session","content":"pub fn terminate_workspaces_pool_session(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.terminate_workspaces_pool_session\naws_api/workspaces terminate_workspaces_pool_session","url":"aws_api/workspaces.html#terminate_workspaces_pool_session"},{"doc":"aws_api/workspaces","title":"update_connect_client_add_in","content":"pub fn update_connect_client_add_in(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.update_connect_client_add_in\naws_api/workspaces update_connect_client_add_in","url":"aws_api/workspaces.html#update_connect_client_add_in"},{"doc":"aws_api/workspaces","title":"update_connection_alias_permission","content":"pub fn update_connection_alias_permission(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.update_connection_alias_permission\naws_api/workspaces update_connection_alias_permission","url":"aws_api/workspaces.html#update_connection_alias_permission"},{"doc":"aws_api/workspaces","title":"update_rules_of_ip_group","content":"pub fn update_rules_of_ip_group(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.update_rules_of_ip_group\naws_api/workspaces update_rules_of_ip_group","url":"aws_api/workspaces.html#update_rules_of_ip_group"},{"doc":"aws_api/workspaces","title":"update_workspace_bundle","content":"pub fn update_workspace_bundle(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.update_workspace_bundle\naws_api/workspaces update_workspace_bundle","url":"aws_api/workspaces.html#update_workspace_bundle"},{"doc":"aws_api/workspaces","title":"update_workspace_image_permission","content":"pub fn update_workspace_image_permission(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.update_workspace_image_permission\naws_api/workspaces update_workspace_image_permission","url":"aws_api/workspaces.html#update_workspace_image_permission"},{"doc":"aws_api/workspaces","title":"update_workspaces_pool","content":"pub fn update_workspaces_pool(\n  client: Client,\n  request_body: BitArray,\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces.update_workspaces_pool\naws_api/workspaces update_workspaces_pool","url":"aws_api/workspaces.html#update_workspaces_pool"},{"doc":"aws_api/workspaces","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/workspaces.with_custom_endpoint\naws_api/workspaces with_custom_endpoint","url":"aws_api/workspaces.html#with_custom_endpoint"},{"doc":"aws_api/workspaces","title":"aws_api/workspaces","content":"","url":"aws_api/workspaces.html"},{"doc":"aws_api/workspaces_thin_client","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/workspaces_thin_client.Client\naws_api/workspaces_thin_client Client","url":"aws_api/workspaces_thin_client.html#Client"},{"doc":"aws_api/workspaces_thin_client","title":"create_environment","content":"pub fn create_environment(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces_thin_client.create_environment\naws_api/workspaces_thin_client create_environment","url":"aws_api/workspaces_thin_client.html#create_environment"},{"doc":"aws_api/workspaces_thin_client","title":"delete_device","content":"pub fn delete_device(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces_thin_client.delete_device\naws_api/workspaces_thin_client delete_device","url":"aws_api/workspaces_thin_client.html#delete_device"},{"doc":"aws_api/workspaces_thin_client","title":"delete_environment","content":"pub fn delete_environment(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces_thin_client.delete_environment\naws_api/workspaces_thin_client delete_environment","url":"aws_api/workspaces_thin_client.html#delete_environment"},{"doc":"aws_api/workspaces_thin_client","title":"deregister_device","content":"pub fn deregister_device(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces_thin_client.deregister_device\naws_api/workspaces_thin_client deregister_device","url":"aws_api/workspaces_thin_client.html#deregister_device"},{"doc":"aws_api/workspaces_thin_client","title":"get_device","content":"pub fn get_device(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces_thin_client.get_device\naws_api/workspaces_thin_client get_device","url":"aws_api/workspaces_thin_client.html#get_device"},{"doc":"aws_api/workspaces_thin_client","title":"get_environment","content":"pub fn get_environment(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces_thin_client.get_environment\naws_api/workspaces_thin_client get_environment","url":"aws_api/workspaces_thin_client.html#get_environment"},{"doc":"aws_api/workspaces_thin_client","title":"get_software_set","content":"pub fn get_software_set(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces_thin_client.get_software_set\naws_api/workspaces_thin_client get_software_set","url":"aws_api/workspaces_thin_client.html#get_software_set"},{"doc":"aws_api/workspaces_thin_client","title":"list_devices","content":"pub fn list_devices(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces_thin_client.list_devices\naws_api/workspaces_thin_client list_devices","url":"aws_api/workspaces_thin_client.html#list_devices"},{"doc":"aws_api/workspaces_thin_client","title":"list_environments","content":"pub fn list_environments(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces_thin_client.list_environments\naws_api/workspaces_thin_client list_environments","url":"aws_api/workspaces_thin_client.html#list_environments"},{"doc":"aws_api/workspaces_thin_client","title":"list_software_sets","content":"pub fn list_software_sets(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces_thin_client.list_software_sets\naws_api/workspaces_thin_client list_software_sets","url":"aws_api/workspaces_thin_client.html#list_software_sets"},{"doc":"aws_api/workspaces_thin_client","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces_thin_client.list_tags_for_resource\naws_api/workspaces_thin_client list_tags_for_resource","url":"aws_api/workspaces_thin_client.html#list_tags_for_resource"},{"doc":"aws_api/workspaces_thin_client","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/workspaces_thin_client.new\naws_api/workspaces_thin_client new","url":"aws_api/workspaces_thin_client.html#new"},{"doc":"aws_api/workspaces_thin_client","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces_thin_client.tag_resource\naws_api/workspaces_thin_client tag_resource","url":"aws_api/workspaces_thin_client.html#tag_resource"},{"doc":"aws_api/workspaces_thin_client","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces_thin_client.untag_resource\naws_api/workspaces_thin_client untag_resource","url":"aws_api/workspaces_thin_client.html#untag_resource"},{"doc":"aws_api/workspaces_thin_client","title":"update_device","content":"pub fn update_device(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces_thin_client.update_device\naws_api/workspaces_thin_client update_device","url":"aws_api/workspaces_thin_client.html#update_device"},{"doc":"aws_api/workspaces_thin_client","title":"update_environment","content":"pub fn update_environment(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces_thin_client.update_environment\naws_api/workspaces_thin_client update_environment","url":"aws_api/workspaces_thin_client.html#update_environment"},{"doc":"aws_api/workspaces_thin_client","title":"update_software_set","content":"pub fn update_software_set(\n  client: Client,\n  id: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces_thin_client.update_software_set\naws_api/workspaces_thin_client update_software_set","url":"aws_api/workspaces_thin_client.html#update_software_set"},{"doc":"aws_api/workspaces_thin_client","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/workspaces_thin_client.with_custom_endpoint\naws_api/workspaces_thin_client with_custom_endpoint","url":"aws_api/workspaces_thin_client.html#with_custom_endpoint"},{"doc":"aws_api/workspaces_thin_client","title":"aws_api/workspaces_thin_client","content":"","url":"aws_api/workspaces_thin_client.html"},{"doc":"aws_api/workspaces_web","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/workspaces_web.Client\naws_api/workspaces_web Client","url":"aws_api/workspaces_web.html#Client"},{"doc":"aws_api/workspaces_web","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces_web.list_tags_for_resource\naws_api/workspaces_web list_tags_for_resource","url":"aws_api/workspaces_web.html#list_tags_for_resource"},{"doc":"aws_api/workspaces_web","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/workspaces_web.new\naws_api/workspaces_web new","url":"aws_api/workspaces_web.html#new"},{"doc":"aws_api/workspaces_web","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces_web.tag_resource\naws_api/workspaces_web tag_resource","url":"aws_api/workspaces_web.html#tag_resource"},{"doc":"aws_api/workspaces_web","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  resource_arn: String,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/workspaces_web.untag_resource\naws_api/workspaces_web untag_resource","url":"aws_api/workspaces_web.html#untag_resource"},{"doc":"aws_api/workspaces_web","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/workspaces_web.with_custom_endpoint\naws_api/workspaces_web with_custom_endpoint","url":"aws_api/workspaces_web.html#with_custom_endpoint"},{"doc":"aws_api/workspaces_web","title":"aws_api/workspaces_web","content":"","url":"aws_api/workspaces_web.html"},{"doc":"aws_api/xray","title":"Client","content":"pub opaque type Client\n\n\nSynonyms:\naws_api/xray.Client\naws_api/xray Client","url":"aws_api/xray.html#Client"},{"doc":"aws_api/xray","title":"batch_get_traces","content":"pub fn batch_get_traces(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/xray.batch_get_traces\naws_api/xray batch_get_traces","url":"aws_api/xray.html#batch_get_traces"},{"doc":"aws_api/xray","title":"create_group","content":"pub fn create_group(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/xray.create_group\naws_api/xray create_group","url":"aws_api/xray.html#create_group"},{"doc":"aws_api/xray","title":"create_sampling_rule","content":"pub fn create_sampling_rule(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/xray.create_sampling_rule\naws_api/xray create_sampling_rule","url":"aws_api/xray.html#create_sampling_rule"},{"doc":"aws_api/xray","title":"delete_group","content":"pub fn delete_group(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/xray.delete_group\naws_api/xray delete_group","url":"aws_api/xray.html#delete_group"},{"doc":"aws_api/xray","title":"delete_resource_policy","content":"pub fn delete_resource_policy(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/xray.delete_resource_policy\naws_api/xray delete_resource_policy","url":"aws_api/xray.html#delete_resource_policy"},{"doc":"aws_api/xray","title":"delete_sampling_rule","content":"pub fn delete_sampling_rule(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/xray.delete_sampling_rule\naws_api/xray delete_sampling_rule","url":"aws_api/xray.html#delete_sampling_rule"},{"doc":"aws_api/xray","title":"get_encryption_config","content":"pub fn get_encryption_config(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/xray.get_encryption_config\naws_api/xray get_encryption_config","url":"aws_api/xray.html#get_encryption_config"},{"doc":"aws_api/xray","title":"get_group","content":"pub fn get_group(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/xray.get_group\naws_api/xray get_group","url":"aws_api/xray.html#get_group"},{"doc":"aws_api/xray","title":"get_groups","content":"pub fn get_groups(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/xray.get_groups\naws_api/xray get_groups","url":"aws_api/xray.html#get_groups"},{"doc":"aws_api/xray","title":"get_insight","content":"pub fn get_insight(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/xray.get_insight\naws_api/xray get_insight","url":"aws_api/xray.html#get_insight"},{"doc":"aws_api/xray","title":"get_insight_events","content":"pub fn get_insight_events(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/xray.get_insight_events\naws_api/xray get_insight_events","url":"aws_api/xray.html#get_insight_events"},{"doc":"aws_api/xray","title":"get_insight_impact_graph","content":"pub fn get_insight_impact_graph(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/xray.get_insight_impact_graph\naws_api/xray get_insight_impact_graph","url":"aws_api/xray.html#get_insight_impact_graph"},{"doc":"aws_api/xray","title":"get_insight_summaries","content":"pub fn get_insight_summaries(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/xray.get_insight_summaries\naws_api/xray get_insight_summaries","url":"aws_api/xray.html#get_insight_summaries"},{"doc":"aws_api/xray","title":"get_sampling_rules","content":"pub fn get_sampling_rules(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/xray.get_sampling_rules\naws_api/xray get_sampling_rules","url":"aws_api/xray.html#get_sampling_rules"},{"doc":"aws_api/xray","title":"get_sampling_statistic_summaries","content":"pub fn get_sampling_statistic_summaries(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/xray.get_sampling_statistic_summaries\naws_api/xray get_sampling_statistic_summaries","url":"aws_api/xray.html#get_sampling_statistic_summaries"},{"doc":"aws_api/xray","title":"get_sampling_targets","content":"pub fn get_sampling_targets(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/xray.get_sampling_targets\naws_api/xray get_sampling_targets","url":"aws_api/xray.html#get_sampling_targets"},{"doc":"aws_api/xray","title":"get_service_graph","content":"pub fn get_service_graph(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/xray.get_service_graph\naws_api/xray get_service_graph","url":"aws_api/xray.html#get_service_graph"},{"doc":"aws_api/xray","title":"get_time_series_service_statistics","content":"pub fn get_time_series_service_statistics(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/xray.get_time_series_service_statistics\naws_api/xray get_time_series_service_statistics","url":"aws_api/xray.html#get_time_series_service_statistics"},{"doc":"aws_api/xray","title":"get_trace_graph","content":"pub fn get_trace_graph(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/xray.get_trace_graph\naws_api/xray get_trace_graph","url":"aws_api/xray.html#get_trace_graph"},{"doc":"aws_api/xray","title":"get_trace_summaries","content":"pub fn get_trace_summaries(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/xray.get_trace_summaries\naws_api/xray get_trace_summaries","url":"aws_api/xray.html#get_trace_summaries"},{"doc":"aws_api/xray","title":"list_resource_policies","content":"pub fn list_resource_policies(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/xray.list_resource_policies\naws_api/xray list_resource_policies","url":"aws_api/xray.html#list_resource_policies"},{"doc":"aws_api/xray","title":"list_tags_for_resource","content":"pub fn list_tags_for_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/xray.list_tags_for_resource\naws_api/xray list_tags_for_resource","url":"aws_api/xray.html#list_tags_for_resource"},{"doc":"aws_api/xray","title":"new","content":"pub fn new(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n) -&gt; Client\n\nSynonyms:\naws_api/xray.new\naws_api/xray new","url":"aws_api/xray.html#new"},{"doc":"aws_api/xray","title":"put_encryption_config","content":"pub fn put_encryption_config(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/xray.put_encryption_config\naws_api/xray put_encryption_config","url":"aws_api/xray.html#put_encryption_config"},{"doc":"aws_api/xray","title":"put_resource_policy","content":"pub fn put_resource_policy(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/xray.put_resource_policy\naws_api/xray put_resource_policy","url":"aws_api/xray.html#put_resource_policy"},{"doc":"aws_api/xray","title":"put_telemetry_records","content":"pub fn put_telemetry_records(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/xray.put_telemetry_records\naws_api/xray put_telemetry_records","url":"aws_api/xray.html#put_telemetry_records"},{"doc":"aws_api/xray","title":"put_trace_segments","content":"pub fn put_trace_segments(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/xray.put_trace_segments\naws_api/xray put_trace_segments","url":"aws_api/xray.html#put_trace_segments"},{"doc":"aws_api/xray","title":"tag_resource","content":"pub fn tag_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/xray.tag_resource\naws_api/xray tag_resource","url":"aws_api/xray.html#tag_resource"},{"doc":"aws_api/xray","title":"untag_resource","content":"pub fn untag_resource(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/xray.untag_resource\naws_api/xray untag_resource","url":"aws_api/xray.html#untag_resource"},{"doc":"aws_api/xray","title":"update_group","content":"pub fn update_group(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/xray.update_group\naws_api/xray update_group","url":"aws_api/xray.html#update_group"},{"doc":"aws_api/xray","title":"update_sampling_rule","content":"pub fn update_sampling_rule(\n  client: Client,\n  headers: List(#(String, String)),\n  query: Option(String),\n) -&gt; Request(BitArray)\n\nSynonyms:\naws_api/xray.update_sampling_rule\naws_api/xray update_sampling_rule","url":"aws_api/xray.html#update_sampling_rule"},{"doc":"aws_api/xray","title":"with_custom_endpoint","content":"pub fn with_custom_endpoint(\n  client: Client,\n  custom_endpoint: String,\n) -&gt; Client\n\nSynonyms:\naws_api/xray.with_custom_endpoint\naws_api/xray with_custom_endpoint","url":"aws_api/xray.html#with_custom_endpoint"},{"doc":"aws_api/xray","title":"aws_api/xray","content":"","url":"aws_api/xray.html"}]);